'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4e4a0217.js');
const utils = require('./utils-ae677cb5.js');

const taskCardListCss = ".sc-task-card-list-h{width:100%;display:-ms-flexbox;display:flex;-ms-flex-wrap:wrap;flex-wrap:wrap}";
const TaskCardListStyle0 = taskCardListCss;

const TaskCardList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.registerKeyboardShortcut = index.createEvent(this, "registerKeyboardShortcut", 7);
        this.backKeyboardShortcut = undefined;
        this.forwardKeyboardShortcut = undefined;
        this.advanceWhenComplete = true;
        this.cards = undefined;
        this.active = 0;
    }
    componentWillLoad() {
        this.cards = Array.from(this.host.children).filter(node => node.nodeName === "TASK-CARD");
        if (this.cards.length > this.active) {
            this.cards[this.active]["active"] = true;
        }
        if (this.backKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Left", keys: this.backKeyboardShortcut });
        }
        if (this.forwardKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Right", keys: this.forwardKeyboardShortcut });
        }
    }
    scrollIntoView(cardIndex) {
        this.cards[cardIndex].scrollIntoView({ behavior: "smooth", block: "end" });
    }
    keypressHandler(event) {
        if (!utils.ignoreKeypress()) {
            if (this.backKeyboardShortcut && this.backKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.max(this.active - 1, 0);
                this.scrollIntoView(this.active);
            }
            else if (this.forwardKeyboardShortcut && this.forwardKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.min(this.active + 1, this.cards.length - 1);
                this.scrollIntoView(this.active);
            }
        }
    }
    cardClickedHandler(event) {
        if (this.cards.includes(event.target)) {
            this.active = this.cards.indexOf(event.target);
        }
    }
    cardReadyToSubmitHandler(event) {
        if (event.detail && !utils.ignoreKeypress()) {
            this.active = Math.min(this.active + 1, this.cards.length - 1);
            this.scrollIntoView(this.active);
        }
    }
    render() {
        for (let i = 0; i < this.cards.length; i++) {
            this.cards[i]["active"] = i === this.active;
        }
        return (index.h(index.Host, { key: '4a22ecc7060c61f75537b3ae643e252b61edb75e' }, index.h("slot", { key: '78d7225da46bd3a0234065458b6b2a7174ca9ea2' })));
    }
    get host() { return index.getElement(this); }
};
TaskCardList.style = TaskCardListStyle0;

exports.task_card_list = TaskCardList;

//# sourceMappingURL=task-card-list.cjs.entry.js.map