import { Host, h } from "@stencil/core";
import { childInputs, inputsWithAnswers } from "../../utils/inputBase";
import { context } from "../../utils/context";
export class TaskBody {
    constructor() {
        this.localStorageId = () => {
            // TODO: Figure out what the default id should be for smgt
            if (this.localId) {
                return this.localId;
            }
            else {
                if (context.mode !== "working") {
                    return "PREVIEW";
                }
                else {
                    return context.assignmentId;
                }
            }
        };
        this.saveLocal = false;
        this.localId = undefined;
        this.showCorrections = false;
    }
    componentWillLoad() {
        if (this.saveLocal) {
            this.previous = JSON.parse(localStorage.getItem(this.localStorageId()));
            if (this.previous && "showCorrections" in this.previous) {
                this.showCorrections = Boolean(this.previous.showCorrections);
            }
        }
    }
    componentDidLoad() {
        this.hideUnnecessaryCrowdFormSubmit();
        if (this.previous) {
            for (let input of childInputs(this.host)) {
                if (input.name in this.previous) {
                    input.value = this.previous[input.name];
                }
            }
        }
        this.formElement = document.querySelector("form");
    }
    hideUnnecessaryCrowdFormSubmit() {
        /*
        Crowd HTML Elements will add a submit button if it doesn't detect one in your template.
        Unfortunately, if it loads before Task Components, then it will add one, even if Task Components
        will be adding one later. This checks for its presence and hides it.
         */
        const submitButtons = document.getElementsByTagName("task-submit");
        if (submitButtons.length > 0) {
            const els = document.getElementsByTagName("crowd-button");
            for (let el of els) {
                if (el.hasAttribute("form-action") &&
                    el.getAttribute("form-action") === "submit") {
                    el.style.display = "none";
                }
            }
        }
    }
    handleInputUpdated(event) {
        // small delay to allow time for the value to propagate to the input
        if (this.saveLocal) {
            setTimeout(() => this.writeFormData(event.detail), 500);
        }
    }
    writeFormData(form) {
        let f = form || this.formElement;
        if (f) {
            const formData = new FormData(f);
            const data = Object.fromEntries(formData.entries());
            data.showCorrections = String(this.showCorrections);
            localStorage.setItem(this.localStorageId(), JSON.stringify(data));
        }
    }
    handleShowCorrections() {
        this.showCorrections = true;
        if (this.saveLocal) {
            this.writeFormData();
        }
    }
    handleShowCorrectionsUpdated(value) {
        for (let input of inputsWithAnswers()) {
            input.setShowCorrections(value);
        }
        const submitButtons = document.getElementsByTagName("task-submit");
        for (let button of submitButtons) {
            button.setShowCorrections(value);
        }
    }
    handleTaskSubmit() {
        if (this.saveLocal) {
            localStorage.removeItem(this.localStorageId());
        }
    }
    cardReadyToSubmitHandler() {
        const progressBars = this.host.querySelectorAll("TASK-PROGRESSBAR");
        for (let bar of Array.from(progressBars)) {
            bar.refreshProgress();
        }
    }
    registerKeyboardShortcutHandler(event) {
        const shortcutLists = this.host.querySelectorAll("TASK-KEYBOARD-SHORTCUT-LIST");
        for (let list of Array.from(shortcutLists)) {
            list.addShortCut(event.detail);
        }
    }
    render() {
        return (h(Host, { key: 'd6ad1ea2e8cb35c2100b96edb7c775c91c7944b2' }, h("slot", { key: '80d477bfeb0099585a22baea1859e313b929d245' })));
    }
    static get is() { return "task-body"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-body.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-body.css"]
        };
    }
    static get properties() {
        return {
            "saveLocal": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "save-local",
                "reflect": false,
                "defaultValue": "false"
            },
            "localId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "local-id",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "showCorrections": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "showCorrections",
                "methodName": "handleShowCorrectionsUpdated"
            }];
    }
    static get listeners() {
        return [{
                "name": "inputUpdated",
                "method": "handleInputUpdated",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "showCorrections",
                "method": "handleShowCorrections",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "taskSubmit",
                "method": "handleTaskSubmit",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "cardReadyToSubmit",
                "method": "cardReadyToSubmitHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "registerKeyboardShortcut",
                "method": "registerKeyboardShortcutHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-body.js.map
