import { Host, Fragment, h } from "@stencil/core";
import classNames from "classnames";
import { isKeyboardClick } from "../../utils/utils";
export class TaskButton {
    constructor() {
        this.anchor = false;
        this.label = false;
        this.active = false;
        this.alignText = "center";
        this.disabled = false;
        this.fill = false;
        this.large = false;
        this.small = false;
        this.loading = false;
        this.type = "button";
        this.intent = undefined;
        this.selected = false;
        this.minimal = false;
        this.outlined = false;
        this.text = undefined;
        this.icon = undefined;
        this.iconSize = undefined;
        this.rightIcon = undefined;
        this.href = undefined;
        this.target = undefined;
        this.newWindow = false;
        this.tabindex = undefined;
        this.isActive = false;
        this.currentKeyPressed = undefined;
    }
    handleBlur() {
        if (this.isActive) {
            this.isActive = false;
        }
    }
    handleKeyDown(e) {
        if (isKeyboardClick(e)) {
            e.preventDefault();
            if (e.key !== this.currentKeyPressed) {
                this.isActive = true;
            }
        }
        this.currentKeyPressed = e.key;
        //props.onKeyDown?.(e)
    }
    handleKeyUp(e) {
        var _a;
        if (isKeyboardClick(e)) {
            this.isActive = false;
            (_a = this.button) === null || _a === void 0 ? void 0 : _a.click();
        }
        this.currentKeyPressed = undefined;
        //props.onKeyUp?.(e);
    }
    renderContents() {
        return h(Fragment, null, this.loading && h("task-spinner", { key: "loading", class: "button-spinner", size: "small" }), this.icon && h("task-icon", { key: "leftIcon", icon: this.icon, size: this.iconSize }), h("span", { key: "text", class: "button-text" }, this.text, h("slot", null)), this.rightIcon && h("task-icon", { key: "rightIcon", icon: this.rightIcon, size: this.iconSize }));
    }
    render() {
        const disabled = this.disabled || this.loading;
        const classes = classNames("button", {
            ["active"]: !disabled && (this.active || this.isActive),
            ["disabled"]: disabled,
            ["fill"]: this.fill,
            ["large"]: this.large,
            ["loading"]: this.loading,
            ["minimal"]: this.minimal,
            ["outlined"]: this.outlined,
            ["small"]: this.small,
            [`intent-${this.intent}`]: this.intent,
            ["selected"]: this.selected,
        }, this.alignText ? `align-${this.alignText}` : undefined);
        return (h(Host, { key: '4e4bf0f5b6e45274261f28f6e505f19f5c9f8312' }, this.anchor ?
            h("a", { key: "anchorButton", href: this.href, class: classes, target: this.newWindow ? "_blank" : this.target, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents())
            : (this.label ?
                h("label", { class: classes }, this.renderContents())
                :
                    h("button", { key: "button", type: this.type, class: classes, disabled: disabled, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents()))));
    }
    static get is() { return "task-button"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-button.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-button.css"]
        };
    }
    static get properties() {
        return {
            "anchor": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "anchor",
                "reflect": false,
                "defaultValue": "false"
            },
            "label": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label",
                "reflect": false,
                "defaultValue": "false"
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false,
                "defaultValue": "false"
            },
            "alignText": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "align-text",
                "reflect": false,
                "defaultValue": "\"center\""
            },
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "fill": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "fill",
                "reflect": false,
                "defaultValue": "false"
            },
            "large": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "large",
                "reflect": false,
                "defaultValue": "false"
            },
            "small": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "small",
                "reflect": false,
                "defaultValue": "false"
            },
            "loading": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "loading",
                "reflect": false,
                "defaultValue": "false"
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "type",
                "reflect": false,
                "defaultValue": "\"button\""
            },
            "intent": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "intent",
                "reflect": false
            },
            "selected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "selected",
                "reflect": false,
                "defaultValue": "false"
            },
            "minimal": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "minimal",
                "reflect": false,
                "defaultValue": "false"
            },
            "outlined": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "outlined",
                "reflect": false,
                "defaultValue": "false"
            },
            "text": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "text",
                "reflect": false
            },
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "icon",
                "reflect": false
            },
            "iconSize": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "icon-size",
                "reflect": false
            },
            "rightIcon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "right-icon",
                "reflect": false
            },
            "href": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "href",
                "reflect": false
            },
            "target": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "target",
                "reflect": false
            },
            "newWindow": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "new-window",
                "reflect": false,
                "defaultValue": "false"
            },
            "tabindex": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "tabindex",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isActive": {},
            "currentKeyPressed": {}
        };
    }
    static get events() {
        return [{
                "method": "click",
                "name": "click",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "focus",
                "name": "focus",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=task-button.js.map
