import { Host, h } from "@stencil/core";
import { ignoreKeypress } from "../../utils/utils";
export class TaskCardList {
    constructor() {
        this.backKeyboardShortcut = undefined;
        this.forwardKeyboardShortcut = undefined;
        this.advanceWhenComplete = true;
        this.cards = undefined;
        this.active = 0;
    }
    componentWillLoad() {
        this.cards = Array.from(this.host.children).filter(node => node.nodeName === "TASK-CARD");
        if (this.cards.length > this.active) {
            this.cards[this.active]["active"] = true;
        }
        if (this.backKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Left", keys: this.backKeyboardShortcut });
        }
        if (this.forwardKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Right", keys: this.forwardKeyboardShortcut });
        }
    }
    scrollIntoView(cardIndex) {
        this.cards[cardIndex].scrollIntoView({ behavior: "smooth", block: "end" });
    }
    keypressHandler(event) {
        if (!ignoreKeypress()) {
            if (this.backKeyboardShortcut && this.backKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.max(this.active - 1, 0);
                this.scrollIntoView(this.active);
            }
            else if (this.forwardKeyboardShortcut && this.forwardKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.min(this.active + 1, this.cards.length - 1);
                this.scrollIntoView(this.active);
            }
        }
    }
    cardClickedHandler(event) {
        if (this.cards.includes(event.target)) {
            this.active = this.cards.indexOf(event.target);
        }
    }
    cardReadyToSubmitHandler(event) {
        if (event.detail && !ignoreKeypress()) {
            this.active = Math.min(this.active + 1, this.cards.length - 1);
            this.scrollIntoView(this.active);
        }
    }
    render() {
        for (let i = 0; i < this.cards.length; i++) {
            this.cards[i]["active"] = i === this.active;
        }
        return (h(Host, { key: '4a22ecc7060c61f75537b3ae643e252b61edb75e' }, h("slot", { key: '78d7225da46bd3a0234065458b6b2a7174ca9ea2' })));
    }
    static get is() { return "task-card-list"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-card-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-card-list.css"]
        };
    }
    static get properties() {
        return {
            "backKeyboardShortcut": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "back-keyboard-shortcut",
                "reflect": false
            },
            "forwardKeyboardShortcut": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "forward-keyboard-shortcut",
                "reflect": false
            },
            "advanceWhenComplete": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "advance-when-complete",
                "reflect": false,
                "defaultValue": "true"
            }
        };
    }
    static get states() {
        return {
            "cards": {},
            "active": {}
        };
    }
    static get events() {
        return [{
                "method": "registerKeyboardShortcut",
                "name": "registerKeyboardShortcut",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "KeyboardShortcut",
                    "resolved": "{ label: string; keys: string; value?: string; }",
                    "references": {
                        "KeyboardShortcut": {
                            "location": "import",
                            "path": "../../utils/utils",
                            "id": "src/utils/utils.ts::KeyboardShortcut"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get listeners() {
        return [{
                "name": "keydown",
                "method": "keypressHandler",
                "target": "document",
                "capture": false,
                "passive": false
            }, {
                "name": "cardClicked",
                "method": "cardClickedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "cardReadyToSubmit",
                "method": "cardReadyToSubmitHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-card-list.js.map
