import { Host, h } from "@stencil/core";
import { childInputs, evaluateFormula, getFormElement, requiredChildInputs } from "../../utils/inputBase";
import classNames from "classnames";
export class TaskCard {
    constructor() {
        this.active = undefined;
        this.width = undefined;
        this.displayIf = undefined;
        this.hidden = false;
    }
    // TODO: Props for width and other configurable values
    connectedCallback() {
        this.form = getFormElement(this.host);
        if (this.form) {
            this.form.addEventListener("input", this.formUpdated.bind(this));
            this.formUpdated();
        }
    }
    clickHandler() {
        this.cardClicked.emit(this.host);
    }
    handleActiveUpdate(newValue) {
        for (let input of childInputs(this.host)) {
            input.active = newValue;
        }
    }
    handleInputUpdated() {
        this.readyToSubmit().then(ready => {
            this.cardReadyToSubmit.emit(ready);
        });
    }
    async readyToSubmit() {
        return Promise.all(requiredChildInputs(this.host).map(i => i.readyToSubmit()))
            .then(values => {
            return values.every(Boolean);
        });
    }
    hostStyle() {
        if (this.width) {
            return { width: `${this.width}` };
        }
        else {
            return {};
        }
    }
    formUpdated() {
        if (this.form && this.displayIf) {
            const result = evaluateFormula(this.displayIf, this.form);
            if (result !== undefined) {
                const previous = this.hidden;
                this.hidden = !result;
                if (this.hidden !== previous) {
                    this.inputUpdated.emit(this.form);
                }
            }
        }
    }
    render() {
        return (h(Host, { key: '050047e2460d8f1202acb130ce5c08b1d7b6d82b', class: classNames({ active: this.active, hidden: this.hidden }), style: this.hostStyle() }, h("slot", { key: '57ffff3dde4d9f14afed3a4e0ff37226be9851bd' })));
    }
    static get is() { return "task-card"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-card.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-card.css"]
        };
    }
    static get properties() {
        return {
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false
            },
            "width": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "width",
                "reflect": false
            },
            "displayIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-if",
                "reflect": false
            },
            "hidden": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hidden",
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get events() {
        return [{
                "method": "cardClicked",
                "name": "cardClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "TaskCard",
                    "resolved": "TaskCard",
                    "references": {
                        "TaskCard": {
                            "location": "global",
                            "id": "global::TaskCard"
                        }
                    }
                }
            }, {
                "method": "cardReadyToSubmit",
                "name": "cardReadyToSubmit",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }, {
                "method": "inputUpdated",
                "name": "inputUpdated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "readyToSubmit": {
                "complexType": {
                    "signature": "() => Promise<boolean>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<boolean>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "active",
                "methodName": "handleActiveUpdate"
            }];
    }
    static get listeners() {
        return [{
                "name": "click",
                "method": "clickHandler",
                "target": undefined,
                "capture": true,
                "passive": false
            }, {
                "name": "inputUpdated",
                "method": "handleInputUpdated",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-card.js.map
