import { Host, h } from "@stencil/core";
import icons from "./icons";
import classNames from "classnames";
const STANDARD = 16;
const LARGE = 20;
export class TaskIcon {
    constructor() {
        this.icon = "blank";
        this.size = STANDARD;
    }
    iconSVG() {
        const pathSize = this.size < LARGE ? STANDARD : LARGE;
        return h("svg", { "data-icon": this.icon, height: this.size, width: this.size, role: "img", viewBox: `0 0 ${pathSize} ${pathSize}` }, icons[this.icon][pathSize].map(p => h("path", { d: p, "fill-rule": "evenodd" })));
    }
    iconFont() {
        const sizeClass = this.size < LARGE ? "icon-standard" : "icon-large";
        const classes = classNames(sizeClass, `icon-${this.icon}`);
        let style = {};
        if (![16, 20].includes(this.size)) {
            const size = `${this.size}px`;
            style = {
                "font-size": size,
                height: size,
                width: size
            };
        }
        return h("span", { class: classes, style: style });
    }
    render() {
        return (
        // TODO: Figure out why this size override is necessary
        h(Host, { key: '01ffd92d301c600e799fe95a69ca42f9b7e00244', class: "icon", style: { height: `${this.size}px` } }, this.icon in icons ? this.iconSVG() : this.iconFont()));
    }
    static get is() { return "task-icon"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-icon.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-icon.css"]
        };
    }
    static get properties() {
        return {
            "icon": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "icon",
                "reflect": false,
                "defaultValue": "\"blank\""
            },
            "size": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "size",
                "reflect": false,
                "defaultValue": "STANDARD"
            }
        };
    }
}
//# sourceMappingURL=task-icon.js.map
