import { Host, h } from "@stencil/core";
import { computeBoxLocation } from "../../utils/image";
export class TaskImage {
    constructor() {
        this.src = undefined;
        this.width = undefined;
        this.height = undefined;
        this.cropTop = undefined;
        this.cropLeft = undefined;
        this.cropWidth = undefined;
        this.cropHeight = undefined;
        this.cropCoordinates = undefined;
        this.hoverZoom = false;
        this.zoomSize = "100px";
        this.zoomPercentage = 200;
        this.zBoxSize = undefined;
        this.image = undefined;
        this.scalar = 1;
        this.calculatedWidth = undefined;
        this.calculatedHeight = undefined;
        this.boxes = undefined;
        this.crop = undefined;
        this.mouseover = false;
        this.zoomLocation = undefined;
    }
    componentWillLoad() {
        this.boxes = Array.from(this.host.getElementsByTagName("task-image-box"));
        this.crop = computeBoxLocation(this.cropLeft, this.cropTop, this.cropWidth, this.cropHeight, this.cropCoordinates);
        this.image = new Image();
        this.image.crossOrigin = "anonymous";
        this.image.src = this.src;
        // TODO: Add error handler and/or switch to load event?
        this.image.decode().then(() => this.renderCanvas());
        // this.image.onload = () => this.renderCanvas()
    }
    getContext() {
        if (this.ctx) {
            return this.ctx;
        }
        else {
            this.ctx = this.canvasElement.getContext("2d");
            return this.ctx;
        }
    }
    renderCanvas() {
        const width = this.crop ? this.crop[2] : this.image.naturalWidth;
        let height = this.crop ? this.crop[3] : this.image.naturalHeight;
        if (this.image.complete) {
            // TODO: flush out the sizing logic
            if (this.width && this.width.endsWith("%")) {
                const percentage = parseFloat(this.width.substring(0, this.width.length - 1));
                this.calculatedWidth = this.host.offsetWidth * percentage / 100;
                this.scalar = this.calculatedWidth / width;
                this.calculatedHeight = height * this.scalar;
            }
            else if (this.width && this.width.endsWith("px")) {
                this.calculatedWidth = parseFloat(this.width.substring(0, this.width.length - 1));
                this.scalar = this.calculatedWidth / width;
                this.calculatedHeight = height * this.scalar;
            }
            else {
                this.calculatedWidth = this.image.naturalWidth;
                this.calculatedHeight = this.image.naturalHeight;
                this.scalar = 1;
            }
            this.canvasElement.width = this.calculatedWidth;
            this.canvasElement.height = this.calculatedHeight;
            if (this.crop) {
                this.getContext().drawImage(this.image, -this.crop[0] * this.scalar, -this.crop[1] * this.scalar, this.image.naturalWidth * this.scalar, this.image.naturalHeight * this.scalar);
            }
            else {
                this.getContext().drawImage(this.image, 0, 0, this.canvasElement.width, this.canvasElement.height);
            }
            for (let b of this.boxes) {
                b.drawBox(this.getContext(), this.scalar, this.crop ? -this.crop[0] * this.scalar : 0, this.crop ? -this.crop[1] * this.scalar : 0);
            }
            // compute the size of the zoom box
            if (this.hoverZoom && this.zoomSize) {
                if (this.zoomSize.endsWith("px")) {
                    this.zBoxSize = parseFloat(this.zoomSize.substring(0, this.zoomSize.length - 2));
                }
                else if (this.zoomSize.endsWith("%")) {
                    const percent = parseFloat(this.zoomSize.substring(0, this.zoomSize.length - 1));
                    this.zBoxSize = Math.min(this.calculatedWidth, this.calculatedHeight) * percent / 100;
                }
                else {
                    try {
                        this.zBoxSize = parseFloat(this.zoomSize);
                    }
                    catch (_a) {
                        console.error("Failed to parse zoomSize");
                    }
                }
            }
        }
    }
    handleResize() {
        this.renderCanvas();
    }
    bound(value, min, max) {
        return Math.min(Math.max(value, min), max);
    }
    handleMouseMove(event) {
        if (this.hoverZoom && this.zBoxSize) {
            const bounds = this.host.getBoundingClientRect();
            const boxOffset = this.zBoxSize / 4;
            const x = event.x - bounds.left;
            const y = event.y - bounds.top;
            // limit the zoom origin to keep the zoom contents within the image
            const originX = this.bound(x, boxOffset, this.calculatedWidth - boxOffset);
            const originY = this.bound(y, boxOffset, this.calculatedHeight - boxOffset);
            // Get the coordinates of the zoom canvas in the page
            const boxLeft = this.bound(originX - this.zBoxSize / 2, 0, this.calculatedWidth - this.zBoxSize);
            const boxTop = this.bound(originY - this.zBoxSize / 2, 0, this.calculatedHeight - this.zBoxSize - 1);
            // Get the relative position of the zoom region (top-left) within the image
            const ratioX = (originX - boxOffset) / (this.calculatedWidth - this.zBoxSize / 2);
            const ratioY = (originY - boxOffset) / (this.calculatedHeight - this.zBoxSize / 2);
            this.zoomLocation = {
                x,
                y,
                originX,
                originY,
                boxLeft: boxLeft + window.scrollX + bounds.left,
                boxTop: boxTop + window.scrollY + bounds.top,
                left: ratioX * (this.zBoxSize - this.calculatedWidth * 2),
                top: ratioY * (this.zBoxSize - this.calculatedHeight * 2),
                ratioX,
                ratioY
            };
        }
    }
    handleMouseOver() {
        this.mouseover = true;
    }
    handleMouseOut() {
        this.mouseover = false;
    }
    render() {
        let zoomStyle = {
            display: "none"
        };
        if (this.zoomCanvas && this.hoverZoom && this.canvasElement &&
            this.mouseover && this.zoomLocation &&
            this.calculatedHeight && this.calculatedWidth) {
            const zoomContext = this.zoomCanvas.getContext("2d");
            zoomContext.drawImage(this.canvasElement, this.zoomLocation.left, this.zoomLocation.top, this.calculatedWidth * 2, this.calculatedHeight * 2);
            zoomStyle = {
                display: "block",
                left: `${this.zoomLocation.boxLeft}px`,
                top: `${this.zoomLocation.boxTop}px`,
                width: `${this.zBoxSize}px`,
                height: `${this.zBoxSize}px`
            };
        }
        return (h(Host, { key: '1bc6ecaa9c0a4db45067e3674cf59b71ef0534be' }, h("canvas", { key: '3fe495a3fcd6a1a49ea2113543f6eee86d5ade35', ref: el => this.canvasElement = el }), h("div", { key: 'f7101ea2df1660a5c45557ad415773f8a96d1679', class: "zoomBox", style: zoomStyle }, h("canvas", { key: '443a3804774255f95eeed3418e0334706dda7349', ref: el => this.zoomCanvas = el, width: this.zBoxSize, height: this.zBoxSize }))));
    }
    static get is() { return "task-image"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-image.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-image.css"]
        };
    }
    static get properties() {
        return {
            "src": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "src",
                "reflect": false
            },
            "width": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "width",
                "reflect": false
            },
            "height": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "height",
                "reflect": false
            },
            "cropTop": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "crop-top",
                "reflect": false
            },
            "cropLeft": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "crop-left",
                "reflect": false
            },
            "cropWidth": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "crop-width",
                "reflect": false
            },
            "cropHeight": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "crop-height",
                "reflect": false
            },
            "cropCoordinates": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "crop-coordinates",
                "reflect": false
            },
            "hoverZoom": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hover-zoom",
                "reflect": false,
                "defaultValue": "false"
            },
            "zoomSize": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "zoom-size",
                "reflect": false,
                "defaultValue": "\"100px\""
            },
            "zoomPercentage": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "zoom-percentage",
                "reflect": false,
                "defaultValue": "200"
            }
        };
    }
    static get states() {
        return {
            "zBoxSize": {},
            "image": {},
            "scalar": {},
            "calculatedWidth": {},
            "calculatedHeight": {},
            "boxes": {},
            "crop": {},
            "mouseover": {},
            "zoomLocation": {}
        };
    }
    static get elementRef() { return "host"; }
    static get listeners() {
        return [{
                "name": "resize",
                "method": "handleResize",
                "target": "window",
                "capture": false,
                "passive": true
            }, {
                "name": "mousemove",
                "method": "handleMouseMove",
                "target": undefined,
                "capture": false,
                "passive": true
            }, {
                "name": "mouseover",
                "method": "handleMouseOver",
                "target": undefined,
                "capture": false,
                "passive": true
            }, {
                "name": "mouseout",
                "method": "handleMouseOut",
                "target": undefined,
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=task-image.js.map
