import { Host, h } from "@stencil/core";
import { InputBase } from "../../utils/inputBase";
import { gatherInputOptions, inputOptionKeyboardShortcuts, } from "../../utils/utils";
import { computePosition, autoUpdate, flip, shift, offset } from "@floating-ui/dom";
export class TaskInputMultiselect {
    constructor() {
        this.optionsMap = new Map();
        this.formUpdated = InputBase.prototype.formUpdated;
        this.setupDependentInputs = InputBase.prototype.setupDependentInputs;
        this.hasAnswerToValidate = InputBase.prototype.hasAnswerToValidate;
        this.handleParentElementUpdate = InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = InputBase.prototype.fromInputUpdated.bind(this);
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
        this.placeholder = "Select options";
        this.values = [];
        this.shortcutMap = new Map();
        this.optionsDisplayed = undefined;
    }
    connectedCallback() {
        InputBase.prototype.connectedCallback.bind(this)();
    }
    async validateAgainstAnswer() { return InputBase.prototype.validateAgainstAnswer.bind(this)(); }
    async setShowCorrections() { return InputBase.prototype.setShowCorrections.bind(this)(); }
    componentWillLoad() {
        InputBase.prototype.componentWillLoad.bind(this)();
        this.options = gatherInputOptions(this.host);
        for (let option of this.options) {
            this.optionsMap[option.value] = option.innerHTML;
        }
        for (let ks of inputOptionKeyboardShortcuts(this.options)) {
            this.shortcutMap[ks.keys] = ks.value;
            this.registerKeyboardShortcut.emit(ks);
        }
    }
    componentDidLoad() {
        this.button.addEventListener("click", this.handleButtonClick.bind(this));
        document.addEventListener("click", this.handleDocumentClick.bind(this));
        document.addEventListener("blur", this.handleBlur.bind(this), { capture: true });
    }
    disconnectedCallback() {
        InputBase.prototype.displayOnCallback.bind(this)();
        document.removeEventListener("click", this.handleDocumentClick.bind(this));
        document.removeEventListener("blur", this.handleBlur.bind(this), { capture: true });
    }
    handleButtonClick() {
        this.optionsDisplayed = !this.optionsDisplayed;
        if (this.optionsDisplayed) {
            this.cleanup = autoUpdate(this.button, this.optionsDropdown, this.updatePosition.bind(this));
        }
        else if (this.cleanup) {
            this.cleanup();
        }
    }
    handleDocumentClick(event) {
        if (!this.host.contains(event.target)) {
            this.optionsDisplayed = false;
        }
    }
    handleBlur(event) {
        if (!this.host.contains(event.target)) {
            this.optionsDisplayed = false;
        }
    }
    updatePosition() {
        computePosition(this.button, this.optionsDropdown, {
            placement: "bottom-start",
            middleware: [offset(6), flip(), shift({ padding: 5 })]
        }).then(({ x, y }) => {
            Object.assign(this.optionsDropdown.style, {
                left: `${x}px`,
                top: `${y}px`,
            });
        });
    }
    handleChange(event) {
        this.values = Array.from(event.target.selectedOptions).map(v => v.value);
    }
    async readyToSubmit() {
        return Boolean(this.values);
    }
    handleValueUpdate() {
        this.value = this.values.join(",");
        this.inputUpdated.emit(this.input.form);
    }
    handleOptionSelect(e, value) {
        e.preventDefault();
        if (this.values.includes(value)) {
            this.values = this.values.filter(v => v !== value);
        }
        else {
            this.values = [...this.values, value];
        }
    }
    render() {
        return (h(Host, { key: '6e80efa9132f40fa928f346081a9fca0fb3daa03' }, !this.hidden && h("label", { key: '2f23da02a09e55d58ab068608d88c0c9cf5dff76' }, this.label, h("div", { key: '93bd88ee64ca1af4b75a64002956839be970b566', class: "multiselect" }, h("div", { key: 'f397dce2b65dedc6e6d8c5d26236ee2e296d50b6', class: "selectbar" }, h("button", { key: '60ba9b090253af3a5cee3fb90c3c844cfc16a2b8', type: "button", ref: el => this.button = el }, this.placeholder)), h("div", { key: '4ab48577a0f5052a8ca99c42be800931301b78d5', class: "options " + (this.optionsDisplayed ? "" : "options-hidden"), ref: el => this.optionsDropdown = el }, h("select", { key: '2638062417c148841e673cc237a11f048c772531', name: this.name, required: this.required, disabled: this.disabled, onChange: e => this.handleChange(e), multiple: true, style: { display: "none" }, ref: el => this.input = el }, this.options.map(option => h("option", { value: option.value, selected: this.values.includes(option.value) }, option.innerHTML))), h("div", { key: '9b5f722a844a3fb24c9772a7c646805152cbedc7', class: "option-list" }, this.options.map(option => h("div", { onClick: (e) => this.handleOptionSelect.bind(this)(e, option.value) }, h("div", { tabindex: "0", class: "item" }, h("task-icon", { icon: this.values.includes(option.value) ? "small-tick" : "blank" }), option.innerHTML))))), h("div", { key: 'b3a6bb8b7cf2938109d7481c253249062e78239d', class: "selectedvalues" }, this.values.map(v => h("task-tag", { small: true }, this.optionsMap[v])))))));
    }
    static get is() { return "task-input-multiselect"; }
    static get encapsulation() { return "scoped"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["task-input-multiselect.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-input-multiselect.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label",
                "reflect": false
            },
            "labelClass": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label-class",
                "reflect": false
            },
            "required": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required",
                "reflect": false
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disabled",
                "reflect": false
            },
            "disableIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disable-if",
                "reflect": false
            },
            "requireIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "require-if",
                "reflect": false
            },
            "requiredIndicator": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required-indicator",
                "reflect": false
            },
            "displayOn": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-on",
                "reflect": false
            },
            "displayIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-if",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value",
                "reflect": false
            },
            "valueFrom": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value-from",
                "reflect": false
            },
            "hidden": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hidden",
                "reflect": false
            },
            "placeholder": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "placeholder",
                "reflect": false,
                "defaultValue": "\"Select options\""
            }
        };
    }
    static get states() {
        return {
            "preventChanges": {},
            "answer": {},
            "answerCorrection": {},
            "values": {},
            "shortcutMap": {},
            "optionsDisplayed": {}
        };
    }
    static get events() {
        return [{
                "method": "inputUpdated",
                "name": "inputUpdated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }, {
                "method": "registerKeyboardShortcut",
                "name": "registerKeyboardShortcut",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "KeyboardShortcut",
                    "resolved": "{ label: string; keys: string; value?: string; }",
                    "references": {
                        "KeyboardShortcut": {
                            "location": "import",
                            "path": "../../utils/utils",
                            "id": "src/utils/utils.ts::KeyboardShortcut"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "validateAgainstAnswer": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setShowCorrections": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "readyToSubmit": {
                "complexType": {
                    "signature": "() => Promise<boolean>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<boolean>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "values",
                "methodName": "handleValueUpdate"
            }];
    }
}
//# sourceMappingURL=task-input-multiselect.js.map
