import { Host, h, Fragment } from "@stencil/core";
import { InputBase } from "../../utils/inputBase";
import { gatherInputOptions, ignoreKeypress, inputOptionKeyboardShortcuts, } from "../../utils/utils";
import classNames from "classnames";
export class TaskInputRadio {
    constructor() {
        this.shortcutMap = new Map();
        this.disconnectedCallback = InputBase.prototype.disconnectedCallback;
        this.formUpdated = InputBase.prototype.formUpdated;
        this.setupDependentInputs = InputBase.prototype.setupDependentInputs;
        this.handleParentElementUpdate = InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = InputBase.prototype.fromInputUpdated.bind(this);
        this.hasAnswerToValidate = () => {
            // TODO: Review why this is different from the others
            return this.answer && this.answerCorrection && true;
        };
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
        this.mode = "radio";
        this.inline = undefined;
        this.answerTag = "Answer";
    }
    connectedCallback() {
        InputBase.prototype.connectedCallback.bind(this)();
    }
    async readyToSubmit() { return InputBase.prototype.readyToSubmit.bind(this)(); }
    async setShowCorrections() { return InputBase.prototype.setShowCorrections.bind(this)(); }
    componentWillLoad() {
        InputBase.prototype.componentWillLoad.bind(this)();
        this.options = gatherInputOptions(this.host);
        for (let ks of inputOptionKeyboardShortcuts(this.options)) {
            this.shortcutMap[ks.keys] = ks.value;
            this.registerKeyboardShortcut.emit(ks);
        }
    }
    hasFocus() {
        return document.activeElement === this.host ||
            this.host.contains(document.activeElement) ||
            document.activeElement.contains(this.host);
    }
    keypressHandler(event) {
        if (event.key in this.shortcutMap &&
            this.hasFocus() &&
            !ignoreKeypress() &&
            !this.disabled &&
            !this.preventChanges) {
            const advance = this.value === this.shortcutMap[event.key];
            this.value = this.shortcutMap[event.key];
            // If the value does not change as a result of the key press, trigger card advance from here
            if (advance) {
                this.inputUpdated.emit(this.input.form);
            }
            // The following addresses an issue observed with dependent form elements
            // not receiving form updated events when the value is changed via keypress
            this.input.form.elements[this.name].value = this.shortcutMap[event.key];
            this.input.form.dispatchEvent(new InputEvent("input"));
        }
    }
    handleValueUpdate(value) {
        InputBase.prototype.handleValueUpdate.bind(this)(value);
        if (this.answer && this.answerCorrection && this.answerCorrection.displayOn === "mismatch") {
            this.answerCorrection.displayCorrection = (this.answer.value !== value);
        }
        this.input.form.dispatchEvent(new InputEvent("input"));
    }
    async validateAgainstAnswer() {
        // TODO: Review why this is different from the others
        return !(this.hasAnswerToValidate() && this.answerCorrection.displayOn === "submit" && this.value !== this.answer.value);
    }
    renderRadio() {
        return this.options.map(option => h("label", { class: classNames("radio", { "inline": this.inline }), key: option.value }, h("input", { type: "radio", name: this.name, value: option.value, required: this.required, onChange: e => this.value = e.target.value, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), h("span", { class: "indicator", key: "indicator" }), h("div", { class: classNames("content", { "inline": this.inline }) }, option.tooltip && h("span", { class: "tooltipText" }, option.tooltip), h("span", { innerHTML: option.innerHTML.trim() })), this.answer &&
            this.answer.value === option.value &&
            (this.answer.showAnswer || (this.answerCorrection.showAnswer &&
                this.answerCorrection.displayCorrection)) &&
            h("task-tag", { round: true, color: "red", small: true, style: { marginLeft: "4px" } }, this.answerTag)));
    }
    renderButtonGroup() {
        return h("task-button-group", null, this.options.map(option => h("task-button", { label: true, class: classNames("radio", { "inline": this.inline }), selected: option.value === this.value, onClick: () => this.value = option.value, key: option.value }, h("input", { type: "radio", name: this.name, value: option.value, required: this.required, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), h("div", { class: classNames("content", { "inline": this.inline }), innerHTML: option.innerHTML }))));
    }
    render() {
        return (h(Host, { key: '1db323318756277d3f7cb4737969e6b4c74aa746' }, !this.hidden && h(Fragment, { key: '980ddfae1e1c622fbc6628b4e9fc90a00aa9429f' }, this.label && h("task-label", { key: '1bc3db77c1045e04eb36c4eae99f1ccf931179c0', class: this.labelClass }, this.label), this.mode === "button" ? this.renderButtonGroup() : this.renderRadio()), h("slot", { key: '8b7655ebca792a340880fc508f1abe7c9da639fb' })));
    }
    static get is() { return "task-input-radio"; }
    static get encapsulation() { return "scoped"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["task-input-radio.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-input-radio.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label",
                "reflect": false
            },
            "labelClass": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label-class",
                "reflect": false
            },
            "required": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required",
                "reflect": false
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disabled",
                "reflect": false
            },
            "disableIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disable-if",
                "reflect": false
            },
            "requireIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "require-if",
                "reflect": false
            },
            "requiredIndicator": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required-indicator",
                "reflect": false
            },
            "displayOn": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-on",
                "reflect": false
            },
            "displayIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-if",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value",
                "reflect": false
            },
            "valueFrom": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value-from",
                "reflect": false
            },
            "hidden": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hidden",
                "reflect": false
            },
            "mode": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "mode",
                "reflect": false,
                "defaultValue": "\"radio\""
            },
            "inline": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "inline",
                "reflect": false
            },
            "answerTag": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "answer-tag",
                "reflect": false,
                "defaultValue": "\"Answer\""
            }
        };
    }
    static get states() {
        return {
            "preventChanges": {},
            "answer": {},
            "answerCorrection": {}
        };
    }
    static get events() {
        return [{
                "method": "inputUpdated",
                "name": "inputUpdated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }, {
                "method": "registerKeyboardShortcut",
                "name": "registerKeyboardShortcut",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "KeyboardShortcut",
                    "resolved": "{ label: string; keys: string; value?: string; }",
                    "references": {
                        "KeyboardShortcut": {
                            "location": "import",
                            "path": "../../utils/utils",
                            "id": "src/utils/utils.ts::KeyboardShortcut"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "readyToSubmit": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setShowCorrections": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "validateAgainstAnswer": {
                "complexType": {
                    "signature": "() => Promise<boolean>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<boolean>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "handleValueUpdate"
            }];
    }
    static get listeners() {
        return [{
                "name": "keypress",
                "method": "keypressHandler",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-input-radio.js.map
