import { Host, h } from "@stencil/core";
import { InputBase } from "../../utils/inputBase";
import { gatherInputOptions, ignoreKeypress, inputOptionKeyboardShortcuts, } from "../../utils/utils";
export class TaskInputSelect {
    constructor() {
        this.shortcutMap = new Map();
        this.disconnectedCallback = InputBase.prototype.disconnectedCallback;
        this.formUpdated = InputBase.prototype.formUpdated;
        this.setupDependentInputs = InputBase.prototype.setupDependentInputs;
        this.hasAnswerToValidate = InputBase.prototype.hasAnswerToValidate;
        this.handleParentElementUpdate = InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = InputBase.prototype.fromInputUpdated.bind(this);
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
    }
    componentWillLoad() {
        InputBase.prototype.componentWillLoad.bind(this)();
        this.options = gatherInputOptions(this.host);
        for (let ks of inputOptionKeyboardShortcuts(this.options)) {
            this.shortcutMap[ks.keys] = ks.value;
            this.registerKeyboardShortcut.emit(ks);
        }
    }
    connectedCallback() {
        InputBase.prototype.connectedCallback.bind(this)();
    }
    async readyToSubmit() { return InputBase.prototype.readyToSubmit.bind(this)(); }
    async validateAgainstAnswer() { return InputBase.prototype.validateAgainstAnswer.bind(this)(); }
    async setShowCorrections() { return InputBase.prototype.setShowCorrections.bind(this)(); }
    async handleValueUpdate() { return InputBase.prototype.handleValueUpdate.bind(this)(); }
    keypressHandler(event) {
        if (event.key in this.shortcutMap && this.active && !ignoreKeypress() && !this.disabled && !this.preventChanges) {
            const advance = this.value === this.shortcutMap[event.key];
            this.value = this.shortcutMap[event.key];
            // If the value doesn't change as a result of the key press, trigger card advance from here
            if (advance) {
                this.inputUpdated.emit(this.input.form);
            }
            // The following addresses an issue observed with dependent form elements
            // not receiving form updated events when the value is changed via keypress
            this.input.form.elements[this.name].value = this.shortcutMap[event.key];
            this.input.form.dispatchEvent(new InputEvent("input"));
        }
    }
    render() {
        return (h(Host, { key: '396254092a597b7ed454382cf19df2fda66da378' }, !this.hidden && h("label", { key: 'e7fee74bf4171197628eb248bbfac5f538b2d3df', class: this.labelClass }, this.label, h("div", { key: 'ab47d8a707b805d3153428076ee6d5488e399af5', class: "select" }, h("select", { key: '868ea66c4097238ebbfad3a7bd0990a55037eed6', name: this.name, required: this.required, disabled: this.disabled, onChange: e => this.value = e.target.value, ref: el => this.input = el }, this.options.map(option => h("option", { value: option.value, selected: option.value === this.value }, option.innerHTML))))), h("slot", { key: '2229ef6401a3a4b8aa8df588e3057e2abe90c48a' })));
    }
    static get is() { return "task-input-select"; }
    static get encapsulation() { return "scoped"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["task-input-select.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-input-select.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false
            },
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label",
                "reflect": false
            },
            "labelClass": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label-class",
                "reflect": false
            },
            "required": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required",
                "reflect": false
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disabled",
                "reflect": false
            },
            "disableIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "disable-if",
                "reflect": false
            },
            "requireIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "require-if",
                "reflect": false
            },
            "requiredIndicator": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "required-indicator",
                "reflect": false
            },
            "displayOn": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-on",
                "reflect": false
            },
            "displayIf": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "display-if",
                "reflect": false
            },
            "value": {
                "type": "string",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value",
                "reflect": false
            },
            "valueFrom": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "value-from",
                "reflect": false
            },
            "hidden": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hidden",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "preventChanges": {},
            "answer": {},
            "answerCorrection": {}
        };
    }
    static get events() {
        return [{
                "method": "inputUpdated",
                "name": "inputUpdated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }, {
                "method": "registerKeyboardShortcut",
                "name": "registerKeyboardShortcut",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "KeyboardShortcut",
                    "resolved": "{ label: string; keys: string; value?: string; }",
                    "references": {
                        "KeyboardShortcut": {
                            "location": "import",
                            "path": "../../utils/utils",
                            "id": "src/utils/utils.ts::KeyboardShortcut"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "readyToSubmit": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "validateAgainstAnswer": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setShowCorrections": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "value",
                "methodName": "handleValueUpdate"
            }, {
                "propName": "required",
                "methodName": "handleValueUpdate"
            }];
    }
    static get listeners() {
        return [{
                "name": "keypress",
                "method": "keypressHandler",
                "target": "document",
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-input-select.js.map
