import { Host, h, Fragment } from "@stencil/core";
export class TaskKeyboardShortcutList {
    constructor() {
        this.valueMap = {
            "ArrowLeft": "Left Arrow",
            "ArrowRight": "Right Arrow",
            "tab": "Tab"
        };
        this.shortcuts = new Map();
    }
    componentWillLoad() {
        for (let child of Array.from(this.host.children)) {
            if (child.nodeName === "TASK-KEYBOARD-SHORTCUT") {
                this.addShortCut({
                    label: child.innerHTML,
                    keys: child.attributes.getNamedItem("keyboard-shortcut").value
                });
            }
        }
    }
    async addShortCut(shortcut) {
        this.shortcuts = new Map(this.shortcuts.set(shortcut.label, shortcut));
    }
    formatKey(key) {
        if (key in this.valueMap) {
            return this.valueMap[key];
        }
        else if (key.length === 1) {
            return key.toUpperCase();
        }
        else {
            return key;
        }
    }
    renderRow(ks) {
        const keys = ks.keys.split(",");
        return (h("div", { class: "hotkey" }, h("div", { class: "hotkey-label" }, ks.label), keys.length > 1 ?
            h("span", { class: "key-combo" }, keys.map((k, i) => h(Fragment, null, h("kbd", { class: "key" }, this.formatKey(k)), i < keys.length - 1 && h("span", null, " or "))))
            : h("kbd", { class: "key" }, this.formatKey(keys[0]))));
    }
    render() {
        return (h(Host, { key: 'd1a5b9d301bf8a48a6acfe07ecf6da9f29522634' }, Array.from(this.shortcuts.values()).map((ks) => this.renderRow(ks))));
    }
    static get is() { return "task-keyboard-shortcut-list"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-keyboard-shortcut-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-keyboard-shortcut-list.css"]
        };
    }
    static get states() {
        return {
            "shortcuts": {}
        };
    }
    static get methods() {
        return {
            "addShortCut": {
                "complexType": {
                    "signature": "(shortcut: KeyboardShortcut) => Promise<void>",
                    "parameters": [{
                            "name": "shortcut",
                            "type": "{ label: string; keys: string; value?: string; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "KeyboardShortcut": {
                            "location": "import",
                            "path": "../../utils/utils",
                            "id": "src/utils/utils.ts::KeyboardShortcut"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=task-keyboard-shortcut-list.js.map
