import { h } from "@stencil/core";
import { parse } from "marked";
export class TaskMarkdown {
    constructor() {
        this.markdown_url = undefined;
        this.markdownHTML = undefined;
        this.children = [];
    }
    componentWillLoad() {
        const assetMap = new Map();
        let child;
        for (child of Array.from(this.host.children)) {
            if (child.tagName === "TASK-ASSET") {
                assetMap.set(child.getAttribute("asset"), child.getAttribute("value"));
            }
        }
        fetch(this.markdown_url, {
            method: 'GET', cache: "no-cache"
        }).then(response => response.text())
            .then(response => {
            let html = parse(response);
            assetMap.forEach((value, key) => {
                html = html.replace(key, value);
            });
            this.markdownHTML = html;
        });
    }
    render() {
        return (h("div", { key: 'fdaafad395aa5ba83f221867966fa1270ebda6d9', class: "content", innerHTML: this.markdownHTML }));
    }
    static get is() { return "task-markdown"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-markdown.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-markdown.css"]
        };
    }
    static get properties() {
        return {
            "markdown_url": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "markdown_url",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "markdownHTML": {},
            "children": {}
        };
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=task-markdown.js.map
