import { Host, h } from "@stencil/core";
import { getActiveElement, isFunction } from "../../utils/utils";
import classNames from "classnames";
export class TaskOverlay {
    constructor() {
        this.isAutoFocusing = false;
        this.maybeRenderChild = (child) => {
            console.log(child);
            if (isFunction(child)) {
                child = child();
            }
            if (child == null) {
                console.log("null");
                return null;
            }
            // decorate the child with a few injected props
            const tabIndex = this.enforceFocus || this.autoFocus ? 0 : undefined;
            let decoratedChild;
            if (typeof child === "object") {
                decoratedChild = child.cloneNode();
                decoratedChild.className = classNames(child.className, "overlay-content");
                decoratedChild.tabIndex = tabIndex;
            }
            else {
                decoratedChild = h("span", { class: "content", tabIndex: tabIndex }, child);
            }
            return decoratedChild;
        };
        /**
         * Ensures repeatedly pressing shift+tab keeps focus inside the Overlay. Moves focus to
         * the `endFocusTrapElement` or the first keyboard-focusable element in the Overlay (excluding
         * the `startFocusTrapElement`), depending on whether the element losing focus is inside the
         * Overlay.
         */
        this.handleStartFocusTrapElementFocus = (e) => {
            var _a, _b;
            if (!this.enforceFocus || this.isAutoFocusing) {
                return;
            }
            // e.relatedTarget will not be defined if this was a programmatic focus event, as is the
            // case when we call this.bringFocusInsideOverlay() after a user clicked on the backdrop.
            // Otherwise, we're handling a user interaction, and we should wrap around to the last
            // element in this transition group.
            if (e.relatedTarget != null &&
                ((_a = this.host) === null || _a === void 0 ? void 0 : _a.contains(e.relatedTarget)) &&
                e.relatedTarget !== this.endFocusTrapElement) {
                (_b = this.endFocusTrapElement) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
            }
        };
        /**
         * Wrap around to the end of the dialog if `enforceFocus` is enabled.
         */
        this.handleStartFocusTrapElementKeyDown = (e) => {
            var _a;
            if (!this.enforceFocus) {
                return;
            }
            if (e.shiftKey && e.key === "Tab") {
                const lastFocusableElement = this.getKeyboardFocusableElements().pop();
                if (lastFocusableElement != null) {
                    lastFocusableElement.focus();
                }
                else {
                    (_a = this.endFocusTrapElement) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true });
                }
            }
        };
        /**
         * Ensures repeatedly pressing tab keeps focus inside the Overlay. Moves focus to the
         * `startFocusTrapElement` or the last keyboard-focusable element in the Overlay (excluding the
         * `startFocusTrapElement`), depending on whether the element losing focus is inside the
         * Overlay.
         */
        this.handleEndFocusTrapElementFocus = (e) => {
            var _a, _b, _c;
            console.log("handleEndFocusTrapElementFocus");
            // No need for this.props.enforceFocus check here because this element is only rendered
            // when that prop is true.
            // During user interactions, e.relatedTarget will be defined, and we should wrap around to the
            // "start focus trap" element.
            // Otherwise, we're handling a programmatic focus event, which can only happen after a user
            // presses shift+tab from the first focusable element in the overlay.
            console.log(e.target);
            console.log(e.relatedTarget);
            if (e.relatedTarget != null &&
                ((_a = this.host) === null || _a === void 0 ? void 0 : _a.contains(e.relatedTarget)) &&
                e.relatedTarget !== this.startFocusTrapElement) {
                console.log("a");
                const firstFocusableElement = this.getKeyboardFocusableElements().shift();
                // ensure we don't re-focus an already active element by comparing against e.relatedTarget
                console.log(firstFocusableElement);
                if (!this.isAutoFocusing && firstFocusableElement != null && firstFocusableElement !== e.relatedTarget) {
                    firstFocusableElement.focus({ preventScroll: true });
                }
                else {
                    (_b = this.startFocusTrapElement) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
                }
            }
            else {
                console.log("b");
                const lastFocusableElement = this.getKeyboardFocusableElements().pop();
                if (lastFocusableElement != null) {
                    lastFocusableElement.focus({ preventScroll: true });
                }
                else {
                    // Keeps focus within Overlay even if there are no keyboard-focusable children
                    (_c = this.startFocusTrapElement) === null || _c === void 0 ? void 0 : _c.focus({ preventScroll: true });
                }
            }
        };
        this.handleBackdropMouseDown = () => {
            if (this.canOutsideClickClose) {
                this.close.emit();
            }
            if (this.enforceFocus) {
                this.bringFocusInsideOverlay();
            }
        };
        this.handleDocumentClick = (e) => {
            const eventTarget = (e.composed ? e.composedPath()[0] : e.target);
            const stackIndex = openStack.indexOf(this);
            const isClickInThisOverlayOrDescendant = openStack
                .slice(stackIndex)
                .some(({ host: elem }) => {
                return (elem === null || elem === void 0 ? void 0 : elem.contains(eventTarget)) && !elem.isSameNode(eventTarget);
            });
            if (this.isOpen && !isClickInThisOverlayOrDescendant && this.canOutsideClickClose) {
                this.close.emit();
            }
        };
        this.handleDocumentFocus = (e) => {
            const eventTarget = e.composed ? e.composedPath()[0] : e.target;
            if (this.enforceFocus &&
                this.host != null &&
                eventTarget instanceof Node &&
                !this.host.contains(eventTarget)) {
                // prevent default focus behavior (sometimes auto-scrolls the page)
                e.preventDefault();
                e.stopImmediatePropagation();
                this.bringFocusInsideOverlay();
            }
        };
        this.isOpen = undefined;
        this.autoFocus = true;
        this.containerClass = undefined;
        this.enforceFocus = true;
        this.canEscapeKeyClose = true;
        this.canOutsideClickClose = true;
        this.hasBackdrop = true;
        this.shouldReturnFocusOnClose = true;
        this.transitionName = "overlay";
        this.transitionDuration = 300;
        this.backdropClass = undefined;
    }
    componentWillLoad() {
        this.children = Array.from(this.host.children);
    }
    componentDidLoad() {
        if (this.isOpen) {
            this.overlayWillOpen();
        }
    }
    watchIsOpen(newValue, oldValue) {
        if (oldValue && !newValue) {
            this.overlayWillClose();
        }
        else if (!oldValue && newValue) {
            this.overlayWillOpen();
        }
    }
    disconnectedCallback() {
        this.overlayWillClose();
    }
    bringFocusInsideOverlay() {
        // always delay focus manipulation to just before repaint to prevent scroll jumping
        return window.requestAnimationFrame(() => {
            // container element may be undefined between component mounting and Portal rendering
            // activeElement may be undefined in some rare cases in IE
            const activeElement = getActiveElement(this.host);
            if (this.host == null || activeElement == null || !this.isOpen) {
                return;
            }
            const isFocusOutsideModal = !this.host.contains(activeElement);
            if (isFocusOutsideModal) {
                this.startFocusTrapElement.focus({ preventScroll: true });
                this.isAutoFocusing = false;
            }
        });
    }
    getKeyboardFocusableElements() {
        console.log("getKeyboardFocusableElements");
        const focusableElements = this.host !== null
            ? Array.from(
            // Order may not be correct if children elements use tabindex values > 0.
            // Selectors derived from this SO question:
            // https://stackoverflow.com/questions/1599660/which-html-elements-can-receive-focus
            this.host.querySelectorAll([
                'a[href]:not([tabindex="-1"])',
                'button:not([disabled]):not([tabindex="-1"])',
                'details:not([tabindex="-1"])',
                'input:not([disabled]):not([tabindex="-1"])',
                'select:not([disabled]):not([tabindex="-1"])',
                'textarea:not([disabled]):not([tabindex="-1"])',
                '[tabindex]:not([tabindex="-1"])',
            ].join(",")))
            : [];
        return focusableElements.filter(el => !el.classList.contains("start-focus-trap") &&
            !el.classList.contains("end-focus-trap"));
    }
    overlayWillOpen() {
        if (openStack.length > 0) {
            document.removeEventListener("focus", getLastOpened().handleDocumentFocus, { capture: true });
        }
        openStack.push(this);
        if (this.autoFocus) {
            this.isAutoFocusing = true;
            this.bringFocusInsideOverlay();
        }
        if (this.enforceFocus) {
            // Focus events do not bubble, but setting useCapture allows us to listen in and execute
            // our handler before all others
            document.addEventListener("focus", this.handleDocumentFocus, { capture: true });
        }
        if (this.canOutsideClickClose && !this.hasBackdrop) {
            document.addEventListener("mousedown", this.handleDocumentClick);
        }
        if (this.hasBackdrop) {
            // add a class to the body to prevent scrolling of content below the overlay
            document.body.classList.add("overlay-open");
        }
        this.lastActiveElementBeforeOpened = getActiveElement(this.host);
    }
    overlayWillClose() {
        document.removeEventListener("focus", this.handleDocumentFocus, { capture: true });
        document.removeEventListener("mousedown", this.handleDocumentClick);
        const stackIndex = openStack.indexOf(this);
        if (stackIndex !== -1) {
            openStack.splice(stackIndex, 1);
            if (openStack.length > 0) {
                const lastOpenedOverlay = getLastOpened();
                // Only bring focus back to last overlay if it had autoFocus _and_ enforceFocus enabled.
                // If `autoFocus={false}`, it's likely that the overlay never received focus in the first place,
                // so it would be surprising for us to send it there. See https://github.com/palantir/blueprint/issues/4921
                if (lastOpenedOverlay.autoFocus && lastOpenedOverlay.enforceFocus) {
                    lastOpenedOverlay.bringFocusInsideOverlay();
                    document.addEventListener("focus", lastOpenedOverlay.handleDocumentFocus, /* useCapture */ true);
                }
            }
            if (openStack.filter(o => o.hasBackdrop).length === 0) {
                document.body.classList.remove("overlay-open");
            }
        }
    }
    handleKeyDown(e) {
        if (e.key === "Escape" && this.canEscapeKeyClose) {
            this.close.emit();
            e.stopPropagation();
            e.preventDefault();
        }
    }
    render2() {
        return (h(Host, { class: this.isOpen ? "overlay-open overlay-scroll-container" : "overlay-scroll-container" }, this.hasBackdrop && h("div", { class: "overlay-backdrop" }), h("div", { class: "content" }, h("slot", null))));
    }
    render() {
        for (let el of this.children) {
            if (this.isOpen) {
                if (!el.classList.contains('overlay-content')) {
                    el.className = classNames(el.className, "overlay-content");
                }
                if (this.enforceFocus || this.autoFocus) {
                    el.tabIndex = 0;
                }
            }
            else {
                if (el.classList.contains('overlay-content')) {
                    el.classList.remove('overlay-content');
                }
                el.tabIndex = undefined;
            }
        }
        const containerClasses = classNames("overlay", {
            ["overlay-open"]: this.isOpen
        }, this.containerClass, "overlay-portal" // TODO: Evaluate how exactly we want to handle top-level overlay
        );
        return (h(Host, { key: 'aaea07ee141019cf93d4d5f7149f0252483cbe0d', class: containerClasses, onKeyDown: e => this.handleKeyDown(e) }, this.isOpen && (this.autoFocus || this.enforceFocus) ?
            h("div", { key: "__start", class: "start-focus-trap", tabindex: 0, onFocus: e => this.handleStartFocusTrapElementFocus(e), onKeyDown: e => this.handleStartFocusTrapElementKeyDown(e), ref: el => this.startFocusTrapElement = el }) : null, this.hasBackdrop && this.isOpen ?
            h("div", { key: "__backdrop", class: classNames("overlay-backdrop", this.backdropClass), onMouseDown: () => this.handleBackdropMouseDown(), ref: el => this.backdropElement = el }) : null, h("div", { key: "__content", class: this.isOpen ? "" : "overlay-closed" }, h("slot", { key: 'ecf013a18dec7d25a2c8deb0ef390e4c3d48faa0' })), this.isOpen && this.enforceFocus ?
            h("div", { key: "__end", class: "end-focus-trap", tabindex: 0, onFocus: e => this.handleEndFocusTrapElementFocus(e), ref: el => this.endFocusTrapElement = el }) : null));
    }
    static get is() { return "task-overlay"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-overlay.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-overlay.css"]
        };
    }
    static get properties() {
        return {
            "isOpen": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-open",
                "reflect": false
            },
            "autoFocus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "auto-focus",
                "reflect": false,
                "defaultValue": "true"
            },
            "containerClass": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "container-class",
                "reflect": false
            },
            "enforceFocus": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "enforce-focus",
                "reflect": false,
                "defaultValue": "true"
            },
            "canEscapeKeyClose": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "can-escape-key-close",
                "reflect": false,
                "defaultValue": "true"
            },
            "canOutsideClickClose": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "can-outside-click-close",
                "reflect": false,
                "defaultValue": "true"
            },
            "hasBackdrop": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "has-backdrop",
                "reflect": false,
                "defaultValue": "true"
            },
            "shouldReturnFocusOnClose": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "should-return-focus-on-close",
                "reflect": false,
                "defaultValue": "true"
            },
            "transitionName": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "transition-name",
                "reflect": false,
                "defaultValue": "\"overlay\""
            },
            "transitionDuration": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "transition-duration",
                "reflect": false,
                "defaultValue": "300"
            },
            "backdropClass": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "backdrop-class",
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "close",
                "name": "close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "closed",
                "name": "closed",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "closing",
                "name": "closing",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "opened",
                "name": "opened",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "opening",
                "name": "opening",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "isOpen",
                "methodName": "watchIsOpen"
            }];
    }
}
const openStack = [];
const getLastOpened = () => openStack[openStack.length - 1];
//# sourceMappingURL=task-overlay.js.map
