import { Host, h } from "@stencil/core";
export class TaskProgressbar {
    constructor() {
        this.completedCount = 0;
        this.taskCount = undefined;
        this.mode = undefined;
        this.completePercentage = "0";
    }
    componentWillLoad() {
        this.completePercentage = this.computePercentage();
        // TODO: This probably needs to be rerun if the mode changes for some reason
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            this.taskCount = cards.length;
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            this.taskCount = steps.length;
        }
    }
    watchPercentage() {
        this.completePercentage = this.computePercentage();
    }
    async refreshProgress() {
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            Promise.all(Array.from(cards).map(card => card.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            Promise.all(Array.from(steps).map(step => step.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
    }
    computePercentage() {
        if (this.taskCount > 0) {
            return (this.completedCount / this.taskCount * 100).toString() + "%";
        }
        else {
            return "0";
        }
    }
    render() {
        return (h(Host, { key: '1928dcf02290b80e8817d10c6fa103eab80a2067' }, h("div", { key: 'fbad4b01bd46f4d6a887d5df094c1c1096c47062', class: "bar" }, h("div", { key: '9c3db82eb909f86d796eba7080c677e2c87ecc46', class: "meter", style: { "width": this.completePercentage } })), h("slot", { key: '86dfd3089b171c50497fb1a7e1411f9154cdc3fa' }, h("div", { key: 'd6fb6044b0bdc6b6380bcd205287b4c98e5b4b4f', class: "text" }, "Completed ", this.completedCount, " of ", this.taskCount))));
    }
    static get is() { return "task-progressbar"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-progressbar.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-progressbar.css"]
        };
    }
    static get properties() {
        return {
            "completedCount": {
                "type": "number",
                "mutable": true,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "completed-count",
                "reflect": false,
                "defaultValue": "0"
            },
            "taskCount": {
                "type": "number",
                "mutable": true,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "task-count",
                "reflect": false
            },
            "mode": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "mode",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "completePercentage": {}
        };
    }
    static get methods() {
        return {
            "refreshProgress": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "TaskCard": {
                            "location": "import",
                            "path": "../task-card/task-card",
                            "id": "src/components/task-card/task-card.tsx::TaskCard"
                        },
                        "TaskStep": {
                            "location": "global",
                            "id": "global::TaskStep"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get watchers() {
        return [{
                "propName": "completedCount",
                "methodName": "watchPercentage"
            }, {
                "propName": "taskCount",
                "methodName": "watchPercentage"
            }];
    }
}
//# sourceMappingURL=task-progressbar.js.map
