import { Host, h } from "@stencil/core";
import { childInputs, requiredChildInputs } from "../../utils/inputBase";
export class TaskStep {
    constructor() {
        this.label = undefined;
        this.active = undefined;
        this.open = false;
    }
    componentWillLoad() {
        this.open = this.active;
    }
    handleOpenToggle() {
        this.open = !this.open;
        if (this.open) {
            this.cardClicked.emit(this.host);
        }
    }
    activeUpdated(newValue) {
        this.open = newValue;
        for (let input of childInputs(this.host)) {
            input.active = newValue;
        }
    }
    handleInputUpdated() {
        this.readyToSubmit().then(ready => {
            this.cardReadyToSubmit.emit(ready);
        });
    }
    async readyToSubmit() {
        return Promise.all(requiredChildInputs(this.host).map(i => i.readyToSubmit()))
            .then(values => {
            return values.every(Boolean);
        });
    }
    render() {
        return (h(Host, { key: '2974edb4b0c4f1967e8df72ab34614ca078eda3f', class: this.active ? "active" : "" }, h("h3", { key: 'e65bcd763536474e220e79415add8016b9c34b4e', onClick: this.handleOpenToggle.bind(this) }, h("task-icon", { key: 'f7018a216f50be41e9059657c0b5f14761822039', icon: this.open ? "caret-down" : "caret-right" }), this.label), h("div", { key: '6af91a146f0157bd0d35b78993ac1e61b0f4a46d', class: !this.open && "content-hidden" }, h("slot", { key: '92e94494e5e10ebdbfba287e0ba923f1a9840413' }))));
    }
    static get is() { return "task-step"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-step.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-step.css"]
        };
    }
    static get properties() {
        return {
            "label": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "label",
                "reflect": false
            },
            "active": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "open": {}
        };
    }
    static get events() {
        return [{
                "method": "cardReadyToSubmit",
                "name": "cardReadyToSubmit",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                }
            }, {
                "method": "cardClicked",
                "name": "cardClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "HTMLElement",
                    "resolved": "HTMLElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "readyToSubmit": {
                "complexType": {
                    "signature": "() => Promise<boolean>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<boolean>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "active",
                "methodName": "activeUpdated"
            }];
    }
    static get listeners() {
        return [{
                "name": "inputUpdated",
                "method": "handleInputUpdated",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-step.js.map
