import { Host, h } from "@stencil/core";
import { ignoreKeypress } from "../../utils/utils";
export class TaskSteps {
    constructor() {
        this.activeStep = 0;
        this.steps = undefined;
    }
    componentWillLoad() {
        this.steps = Array.from(this.host.children).filter(node => node.nodeName === "TASK-STEP");
        this.updateActiveStep();
    }
    updateActiveStep() {
        for (let step of this.steps) {
            step.active = this.activeStep === this.steps.indexOf(step);
        }
    }
    cardClickedHandler(event) {
        const target = event.detail;
        if (this.steps.includes(target)) {
            this.activeStep = this.steps.indexOf(target);
        }
    }
    cardReadyToSubmitHandler(event) {
        if (event.detail && !ignoreKeypress()) {
            this.activeStep = Math.min(this.activeStep + 1, this.steps.length - 1);
        }
    }
    activeStepUpdated() {
        this.updateActiveStep();
    }
    render() {
        return (h(Host, { key: 'bbc318c8cc88ad26b6fd143abfb936989328b69d' }, h("slot", { key: '368a76619c5e0ada7c0b2ed7590a63fd89ae5f78' })));
    }
    static get is() { return "task-steps"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-steps.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-steps.css"]
        };
    }
    static get states() {
        return {
            "activeStep": {},
            "steps": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "activeStep",
                "methodName": "activeStepUpdated"
            }];
    }
    static get listeners() {
        return [{
                "name": "cardClicked",
                "method": "cardClickedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "cardReadyToSubmit",
                "method": "cardReadyToSubmitHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=task-steps.js.map
