import { Host, h } from "@stencil/core";
import { attachInputListener } from "../../utils/inputBase";
export class TaskVar {
    constructor() {
        this.data = undefined;
        this.name = undefined;
        this.value = undefined;
    }
    componentWillLoad() {
        if (this.data) {
            let element = this.host;
            while (element.parentElement && !this.value) {
                element = element.parentElement;
                if (this.data in element.dataset) {
                    this.value = element.dataset[this.data];
                }
            }
        }
        else if (this.name) {
            if (['interactive', 'complete'].includes(document.readyState)) {
                this.setupInputListener();
            }
            else {
                this.loadCallback = this.setupInputListener.bind(this);
                document.addEventListener("load", this.setupInputListener);
            }
        }
    }
    disconnectedCallback() {
        if (this.loadCallback) {
            document.removeEventListener("load", this.loadCallback);
        }
        if (this.inputCallback && this.input) {
            // TODO: Look at this
            // Commented out because the immediate disconnect event is overlapping and deleting early
            // this.input.removeEventListener("inputUpdated", this.inputCallback)
        }
    }
    setupInputListener() {
        this.inputCallback = this.inputUpdated.bind(this);
        attachInputListener(this.name, this.inputCallback)
            .then(input => {
            this.input = input;
            this.inputUpdated();
        });
    }
    inputUpdated() {
        if (this.input) {
            this.value = this.input.value;
        }
    }
    render() {
        return (h(Host, { key: 'd29f884d8c2027bcab046522d49671e149ecf81d' }, this.value, h("slot", { key: '52b5091e98ec0dfec7546d39b924fcd1aaffec6c' })));
    }
    static get is() { return "task-var"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["task-var.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["task-var.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "data",
                "reflect": false
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "value": {}
        };
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=task-var.js.map
