export function format(first, middle, last) {
    return (first || '') + (middle ? ` ${middle}` : '') + (last ? ` ${last}` : '');
}
export function ignoreKeypress() {
    const activeEl = document.activeElement;
    return activeEl.nodeName === "TEXTAREA" ||
        (activeEl.nodeName === "INPUT" && activeEl.getAttribute("type") === "text");
}
export function gatherInputOptions(parent) {
    return Array.from(parent.getElementsByTagName("task-input-option"))
        .filter(n => Array.from(parent.children).includes(n));
}
export function inputOptionKeyboardShortcuts(options) {
    const shortcuts = [];
    for (let option of options) {
        if (option.keyboardShortcut) {
            if (option.keyboardShortcutLabel) {
                shortcuts.push({ label: option.keyboardShortcutLabel, keys: option.keyboardShortcut, value: option.value });
            }
            else {
                shortcuts.push({ label: option.innerHTML, keys: option.keyboardShortcut, value: option.value });
            }
        }
    }
    return shortcuts;
}
export function getAnswerElement(host) {
    return host.querySelector("TASK-ANSWER");
}
export function getAnswerCorrectionElement(host) {
    return host.querySelector("TASK-ANSWER-CORRECTION");
}
export function getActiveElement(element, options) {
    var _a;
    if (element == null) {
        return document.activeElement;
    }
    const rootNode = ((_a = element.getRootNode(options)) !== null && _a !== void 0 ? _a : document);
    return rootNode.activeElement;
}
export function isFunction(value) {
    return typeof value === "function";
}
export function isKeyboardClick(event) {
    return event.key === "Enter" || event.key === " ";
}
export function isArrowKey(event) {
    return ["ArrowUp", "ArrowDown", "ArrowLeft", "ArrowRight"].indexOf(event.key) >= 0;
}
const MARK_NAMESPACE = "tc";
export function mark(name) {
    // console.log(`Logging mark: ${name}`)
    window.performance.mark(`${MARK_NAMESPACE}:${name}`);
}
export function getMarks() {
    return window.performance.getEntriesByType("mark")
        .filter(mark => mark.name.startsWith(`${MARK_NAMESPACE}:`));
}
export function debounce(callback, wait = 300) {
    let timeoutId = null;
    return (...args) => {
        window.clearTimeout(timeoutId);
        timeoutId = window.setTimeout(() => {
            callback.apply(null, args);
        }, wait);
    };
}
//# sourceMappingURL=utils.js.map
