import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { a as ignoreKeypress } from './utils.js';

const taskCardListCss = ".sc-task-card-list-h{width:100%;display:-ms-flexbox;display:flex;-ms-flex-wrap:wrap;flex-wrap:wrap}";
const TaskCardListStyle0 = taskCardListCss;

const TaskCardList$1 = /*@__PURE__*/ proxyCustomElement(class TaskCardList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.registerKeyboardShortcut = createEvent(this, "registerKeyboardShortcut", 7);
        this.backKeyboardShortcut = undefined;
        this.forwardKeyboardShortcut = undefined;
        this.advanceWhenComplete = true;
        this.cards = undefined;
        this.active = 0;
    }
    componentWillLoad() {
        this.cards = Array.from(this.host.children).filter(node => node.nodeName === "TASK-CARD");
        if (this.cards.length > this.active) {
            this.cards[this.active]["active"] = true;
        }
        if (this.backKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Left", keys: this.backKeyboardShortcut });
        }
        if (this.forwardKeyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Move Right", keys: this.forwardKeyboardShortcut });
        }
    }
    scrollIntoView(cardIndex) {
        this.cards[cardIndex].scrollIntoView({ behavior: "smooth", block: "end" });
    }
    keypressHandler(event) {
        if (!ignoreKeypress()) {
            if (this.backKeyboardShortcut && this.backKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.max(this.active - 1, 0);
                this.scrollIntoView(this.active);
            }
            else if (this.forwardKeyboardShortcut && this.forwardKeyboardShortcut.split(",").includes(event.key)) {
                this.active = Math.min(this.active + 1, this.cards.length - 1);
                this.scrollIntoView(this.active);
            }
        }
    }
    cardClickedHandler(event) {
        if (this.cards.includes(event.target)) {
            this.active = this.cards.indexOf(event.target);
        }
    }
    cardReadyToSubmitHandler(event) {
        if (event.detail && !ignoreKeypress()) {
            this.active = Math.min(this.active + 1, this.cards.length - 1);
            this.scrollIntoView(this.active);
        }
    }
    render() {
        for (let i = 0; i < this.cards.length; i++) {
            this.cards[i]["active"] = i === this.active;
        }
        return (h(Host, { key: '4a22ecc7060c61f75537b3ae643e252b61edb75e' }, h("slot", { key: '78d7225da46bd3a0234065458b6b2a7174ca9ea2' })));
    }
    get host() { return this; }
    static get style() { return TaskCardListStyle0; }
}, [6, "task-card-list", {
        "backKeyboardShortcut": [1, "back-keyboard-shortcut"],
        "forwardKeyboardShortcut": [1, "forward-keyboard-shortcut"],
        "advanceWhenComplete": [4, "advance-when-complete"],
        "cards": [32],
        "active": [32]
    }, [[4, "keydown", "keypressHandler"], [0, "cardClicked", "cardClickedHandler"], [0, "cardReadyToSubmit", "cardReadyToSubmitHandler"]]]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-card-list"];
    components.forEach(tagName => { switch (tagName) {
        case "task-card-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskCardList$1);
            }
            break;
    } });
}

const TaskCardList = TaskCardList$1;
const defineCustomElement = defineCustomElement$1;

export { TaskCardList, defineCustomElement };

//# sourceMappingURL=task-card-list.js.map