import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { g as getFormElement, c as childInputs, r as requiredChildInputs, e as evaluateFormula } from './inputBase.js';
import { c as classNames } from './index2.js';

const taskCardCss = ".sc-task-card-h{display:block;margin-bottom:0.5rem;margin-right:0.5rem;background-color:rgb(251 179 96 / 0.2);padding:10px;width:200px;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);border-radius:3px;-webkit-transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9)}.active.sc-task-card-h{background-color:rgb(114 202 155 / 40%);-webkit-box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%);box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%)}.hidden.sc-task-card-h{display:none}";
const TaskCardStyle0 = taskCardCss;

const TaskCard$1 = /*@__PURE__*/ proxyCustomElement(class TaskCard extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.cardClicked = createEvent(this, "cardClicked", 7);
        this.cardReadyToSubmit = createEvent(this, "cardReadyToSubmit", 7);
        this.inputUpdated = createEvent(this, "inputUpdated", 7);
        this.active = undefined;
        this.width = undefined;
        this.displayIf = undefined;
        this.hidden = false;
    }
    // TODO: Props for width and other configurable values
    connectedCallback() {
        this.form = getFormElement(this.host);
        if (this.form) {
            this.form.addEventListener("input", this.formUpdated.bind(this));
            this.formUpdated();
        }
    }
    clickHandler() {
        this.cardClicked.emit(this.host);
    }
    handleActiveUpdate(newValue) {
        for (let input of childInputs(this.host)) {
            input.active = newValue;
        }
    }
    handleInputUpdated() {
        this.readyToSubmit().then(ready => {
            this.cardReadyToSubmit.emit(ready);
        });
    }
    async readyToSubmit() {
        return Promise.all(requiredChildInputs(this.host).map(i => i.readyToSubmit()))
            .then(values => {
            return values.every(Boolean);
        });
    }
    hostStyle() {
        if (this.width) {
            return { width: `${this.width}` };
        }
        else {
            return {};
        }
    }
    formUpdated() {
        if (this.form && this.displayIf) {
            const result = evaluateFormula(this.displayIf, this.form);
            if (result !== undefined) {
                const previous = this.hidden;
                this.hidden = !result;
                if (this.hidden !== previous) {
                    this.inputUpdated.emit(this.form);
                }
            }
        }
    }
    render() {
        return (h(Host, { key: '050047e2460d8f1202acb130ce5c08b1d7b6d82b', class: classNames({ active: this.active, hidden: this.hidden }), style: this.hostStyle() }, h("slot", { key: '57ffff3dde4d9f14afed3a4e0ff37226be9851bd' })));
    }
    get host() { return this; }
    static get watchers() { return {
        "active": ["handleActiveUpdate"]
    }; }
    static get style() { return TaskCardStyle0; }
}, [6, "task-card", {
        "active": [4],
        "width": [1],
        "displayIf": [1, "display-if"],
        "hidden": [1028],
        "readyToSubmit": [64]
    }, [[2, "click", "clickHandler"], [0, "inputUpdated", "handleInputUpdated"]], {
        "active": ["handleActiveUpdate"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-card"];
    components.forEach(tagName => { switch (tagName) {
        case "task-card":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskCard$1);
            }
            break;
    } });
}

const TaskCard = TaskCard$1;
const defineCustomElement = defineCustomElement$1;

export { TaskCard, defineCustomElement };

//# sourceMappingURL=task-card.js.map