import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { C as Context } from './context.js';
import { h as debounce } from './utils.js';

const taskFormCss = ":host{display:block}";
const TaskFormStyle0 = taskFormCss;

const TaskForm$1 = /*@__PURE__*/ proxyCustomElement(class TaskForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.sendFormState = debounce(() => sendFormState(this.formElement, this.context));
        this.crowdForm = null;
        this.crowdApp = null;
        this.saveLocal = false;
        this.localId = undefined;
    }
    componentDidLoad() {
        // TODO: do something when we don't have a form...
        // TODO: Remove the event listener when unloaded
        if (this.formElement) {
            this.formElement.addEventListener("submit", e => this.onSubmit(e));
            this.formElement.focus();
        }
        this.context = new Context();
        window.parent.postMessage({ type: 'requestTaskContext' }, window.origin);
        window.addEventListener('appload', () => this.inputFocus());
    }
    onInputUpdated() {
        console.log('inputUpdated');
        this.sendFormState();
    }
    onMessage(event) {
        switch (event.data.type) {
            case "taskContext":
                console.log("received taskContext", event);
                this.context.updateFromContextMessage(event.data);
                if (event.data.response) {
                    console.log(`updating form response for assignment ${event.data.assignmentId}`);
                    console.log(event.data.response);
                    if (this.formElement) {
                        for (const [key, value] of Object.entries(event.data.response)) {
                            const element = this.formElement.elements[key];
                            element.value = value;
                        }
                    }
                }
                if (this.crowdForm) {
                    // @ts-ignore
                    this.crowdForm._submitHelperForm = crowdSubmitHandler.bind(this.crowdForm, this.context);
                }
                break;
            case "taskStart":
                this.inputFocus();
                break;
            case "requestTaskContext":
                break;
            default:
                if (event.data.source !== "react-devtools-content-script") {
                    console.error("Unexpected event", event);
                }
        }
    }
    onCrowdElementsReady() {
        // This will be fired if the task contains `crowd-form` from Amazon's Crowd Elements
        // In that case we will want to replace the default submit handling that component uses
        this.crowdForm = document.querySelector("crowd-form");
        // @ts-ignore
        this.crowdForm._submitHelperForm = crowdSubmitHandler.bind(this.crowdForm, this.context);
        const answersBox = this.crowdForm.shadowRoot.querySelector("#answers-box");
        if (answersBox) {
            answersBox.style.display = "none";
        }
        this.crowdApp = findCrowdApp(this.crowdForm);
        if (this.crowdApp) {
            console.log(this.crowdApp);
            const header = this.crowdApp.shadowRoot.querySelector(".headerContainer");
            if (header) {
                header.style.display = "none";
            }
            console.log("CER FOCUS ON CROWD APP");
            // this.crowdApp.shadowRoot.querySelector(".awsui").focus()
            console.log(document.activeElement);
        }
    }
    inputFocus() {
        if (this.crowdApp) {
            this.crowdApp.focus();
        }
        else {
            // TODO: Update this to find the correct input to focus on
            const input = document.querySelector("input");
            if (input) {
                input.focus();
            }
        }
    }
    onSubmit(event) {
        event.preventDefault();
        const formResponse = buildFormResponse(this.formElement);
        submitFormResponse(formResponse, this.context);
    }
    render() {
        return (h(Host, { key: '04e2ddf2cce815c71145a1a83c5af6d9bb5da6eb' }, h("form", { key: '4c11b8ca6e40459cd06e43d1c9a4bbb3f7876332', ref: el => this.formElement = el }, h("slot", { key: 'b3d4bf523c92cf837b8bea57de769fa49d64bc50' }))));
    }
    get host() { return this; }
    static get style() { return TaskFormStyle0; }
}, [4, "task-form", {
        "saveLocal": [4, "save-local"],
        "localId": [1, "local-id"]
    }, [[4, "inputUpdated", "onInputUpdated"], [8, "message", "onMessage"], [4, "all-crowd-elements-ready", "onCrowdElementsReady"]]]);
function crowdSubmitHandler(context) {
    let formData = this._serializeForm();
    console.log(JSON.parse(formData.taskAnswers)[0]);
    submitFormResponse(JSON.parse(formData.taskAnswers)[0], context);
}
function buildFormResponse(form) {
    const formData = new FormData(form);
    const response = {};
    for (let pair of formData.entries()) {
        response[pair[0]] = pair[1];
    }
    return response;
}
function sendFormState(form, context) {
    const formResponse = buildFormResponse(form);
    window.parent.postMessage({
        type: "formUpdated",
        assignmentId: context.assignmentId,
        formData: formResponse,
        formState: null
    }, window.origin);
}
function findCrowdApp(crowdForm) {
    const children = [];
    const cfForm = crowdForm.querySelector("form");
    for (let child of cfForm.children) {
        if (child.shadowRoot) {
            children.push(child);
        }
    }
    if (children.length === 1) {
        return children[0];
    }
}
function submitFormResponse(formResponse, context) {
    if (context.mode === "requester-preview") {
        // TODO: Display preview response
        console.log("Submitted in preview:");
        console.log(formResponse);
    }
    else if (context.mode === "working" && context.site === "open-event") {
        const eventType = context.submitEventType || "submitTask";
        console.log("sending form data to parent");
        window.parent.postMessage({
            type: eventType,
            assignmentId: context.assignmentId,
            formData: formResponse,
            formState: null
        }, window.origin);
    }
}
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-form"];
    components.forEach(tagName => { switch (tagName) {
        case "task-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskForm$1);
            }
            break;
    } });
}

const TaskForm = TaskForm$1;
const defineCustomElement = defineCustomElement$1;

export { TaskForm, defineCustomElement };

//# sourceMappingURL=task-form.js.map