import { proxyCustomElement, HTMLElement, createEvent, h, Host, Fragment } from '@stencil/core/internal/client';
import { I as InputBase } from './inputBase.js';
import { g as gatherInputOptions, i as inputOptionKeyboardShortcuts, a as ignoreKeypress } from './utils.js';
import { c as classNames } from './index2.js';
import { d as defineCustomElement$6 } from './task-button2.js';
import { d as defineCustomElement$5 } from './task-button-group2.js';
import { d as defineCustomElement$4 } from './task-icon2.js';
import { d as defineCustomElement$3 } from './task-label2.js';
import { d as defineCustomElement$2 } from './task-tag2.js';

const taskInputRadioCss = ".sc-task-input-radio-h{display:block;margin-bottom:0.5rem}label.sc-task-input-radio{cursor:pointer;display:block;margin-bottom:10px;position:relative;text-transform:none}label.sc-task-input-radio:not(.button){padding-left:26px}label.inline.sc-task-input-radio{display:inline-block;margin-right:20px}input.sc-task-input-radio{left:0;opacity:0;position:absolute;top:0;z-index:-1}.indicator.sc-task-input-radio{margin-left:-26px;background-clip:padding-box;background-color:transparent;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));border:none;-webkit-box-shadow:inset 0 0 0 1px #738091;box-shadow:inset 0 0 0 1px #738091;cursor:pointer;display:inline-block;font-size:16px;height:1em;margin-right:10px;margin-top:-3px;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:middle;width:1em;text-transform:none;border-radius:50%}label.sc-task-input-radio input.sc-task-input-radio:checked~.indicator.sc-task-input-radio{background-color:#2d72d2;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2);color:#fff}.indicator.sc-task-input-radio::before{content:\"\";display:block;height:1em;width:1em}label.sc-task-input-radio input.sc-task-input-radio:checked~.indicator.sc-task-input-radio::before{background-image:radial-gradient(#fff, #fff 28%, transparent 32%)}.content.sc-task-input-radio{display:initial}.content.inline.sc-task-input-radio{display:inline-block}.content.sc-task-input-radio .tooltipText.sc-task-input-radio{visibility:hidden;width:180px;background-color:black;color:#fff;text-align:center;padding:12px;border-radius:6px;position:absolute;top:20px;z-index:100}.content.sc-task-input-radio:hover .tooltipText.sc-task-input-radio{visibility:visible}";
const TaskInputRadioStyle0 = taskInputRadioCss;

const TaskInputRadio$1 = /*@__PURE__*/ proxyCustomElement(class TaskInputRadio extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.inputUpdated = createEvent(this, "inputUpdated", 7);
        this.registerKeyboardShortcut = createEvent(this, "registerKeyboardShortcut", 7);
        this.shortcutMap = new Map();
        this.disconnectedCallback = InputBase.prototype.disconnectedCallback;
        this.formUpdated = InputBase.prototype.formUpdated;
        this.setupDependentInputs = InputBase.prototype.setupDependentInputs;
        this.handleParentElementUpdate = InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = InputBase.prototype.fromInputUpdated.bind(this);
        this.hasAnswerToValidate = () => {
            // TODO: Review why this is different from the others
            return this.answer && this.answerCorrection && true;
        };
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
        this.mode = "radio";
        this.inline = undefined;
        this.answerTag = "Answer";
    }
    connectedCallback() {
        InputBase.prototype.connectedCallback.bind(this)();
    }
    async readyToSubmit() { return InputBase.prototype.readyToSubmit.bind(this)(); }
    async setShowCorrections() { return InputBase.prototype.setShowCorrections.bind(this)(); }
    componentWillLoad() {
        InputBase.prototype.componentWillLoad.bind(this)();
        this.options = gatherInputOptions(this.host);
        for (let ks of inputOptionKeyboardShortcuts(this.options)) {
            this.shortcutMap[ks.keys] = ks.value;
            this.registerKeyboardShortcut.emit(ks);
        }
    }
    hasFocus() {
        return document.activeElement === this.host ||
            this.host.contains(document.activeElement) ||
            document.activeElement.contains(this.host);
    }
    keypressHandler(event) {
        if (event.key in this.shortcutMap &&
            this.hasFocus() &&
            !ignoreKeypress() &&
            !this.disabled &&
            !this.preventChanges) {
            const advance = this.value === this.shortcutMap[event.key];
            this.value = this.shortcutMap[event.key];
            // If the value does not change as a result of the key press, trigger card advance from here
            if (advance) {
                this.inputUpdated.emit(this.input.form);
            }
            // The following addresses an issue observed with dependent form elements
            // not receiving form updated events when the value is changed via keypress
            this.input.form.elements[this.name].value = this.shortcutMap[event.key];
            this.input.form.dispatchEvent(new InputEvent("input"));
        }
    }
    handleValueUpdate(value) {
        InputBase.prototype.handleValueUpdate.bind(this)(value);
        if (this.answer && this.answerCorrection && this.answerCorrection.displayOn === "mismatch") {
            this.answerCorrection.displayCorrection = (this.answer.value !== value);
        }
        this.input.form.dispatchEvent(new InputEvent("input"));
    }
    async validateAgainstAnswer() {
        // TODO: Review why this is different from the others
        return !(this.hasAnswerToValidate() && this.answerCorrection.displayOn === "submit" && this.value !== this.answer.value);
    }
    renderRadio() {
        return this.options.map(option => h("label", { class: classNames("radio", { "inline": this.inline }), key: option.value }, h("input", { type: "radio", name: this.name, value: option.value, required: this.required, onChange: e => this.value = e.target.value, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), h("span", { class: "indicator", key: "indicator" }), h("div", { class: classNames("content", { "inline": this.inline }) }, option.tooltip && h("span", { class: "tooltipText" }, option.tooltip), h("span", { innerHTML: option.innerHTML.trim() })), this.answer &&
            this.answer.value === option.value &&
            (this.answer.showAnswer || (this.answerCorrection.showAnswer &&
                this.answerCorrection.displayCorrection)) &&
            h("task-tag", { round: true, color: "red", small: true, style: { marginLeft: "4px" } }, this.answerTag)));
    }
    renderButtonGroup() {
        return h("task-button-group", null, this.options.map(option => h("task-button", { label: true, class: classNames("radio", { "inline": this.inline }), selected: option.value === this.value, onClick: () => this.value = option.value, key: option.value }, h("input", { type: "radio", name: this.name, value: option.value, required: this.required, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), h("div", { class: classNames("content", { "inline": this.inline }), innerHTML: option.innerHTML }))));
    }
    render() {
        return (h(Host, { key: '1db323318756277d3f7cb4737969e6b4c74aa746' }, !this.hidden && h(Fragment, { key: '980ddfae1e1c622fbc6628b4e9fc90a00aa9429f' }, this.label && h("task-label", { key: '1bc3db77c1045e04eb36c4eae99f1ccf931179c0', class: this.labelClass }, this.label), this.mode === "button" ? this.renderButtonGroup() : this.renderRadio()), h("slot", { key: '8b7655ebca792a340880fc508f1abe7c9da639fb' })));
    }
    static get formAssociated() { return true; }
    get host() { return this; }
    static get watchers() { return {
        "value": ["handleValueUpdate"]
    }; }
    static get style() { return TaskInputRadioStyle0; }
}, [70, "task-input-radio", {
        "name": [1],
        "label": [1],
        "labelClass": [1, "label-class"],
        "required": [1028],
        "active": [4],
        "disabled": [1028],
        "disableIf": [1, "disable-if"],
        "requireIf": [1, "require-if"],
        "requiredIndicator": [1, "required-indicator"],
        "displayOn": [1, "display-on"],
        "displayIf": [1, "display-if"],
        "value": [1025],
        "valueFrom": [1, "value-from"],
        "hidden": [1028],
        "mode": [1],
        "inline": [4],
        "answerTag": [1, "answer-tag"],
        "preventChanges": [32],
        "answer": [32],
        "answerCorrection": [32],
        "readyToSubmit": [64],
        "setShowCorrections": [64],
        "validateAgainstAnswer": [64]
    }, [[4, "keypress", "keypressHandler"]], {
        "value": ["handleValueUpdate"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-input-radio", "task-button", "task-button-group", "task-icon", "task-label", "task-tag"];
    components.forEach(tagName => { switch (tagName) {
        case "task-input-radio":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskInputRadio$1);
            }
            break;
        case "task-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "task-button-group":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "task-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "task-label":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "task-tag":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const TaskInputRadio = TaskInputRadio$1;
const defineCustomElement = defineCustomElement$1;

export { TaskInputRadio, defineCustomElement };

//# sourceMappingURL=task-input-radio.js.map