import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { I as InputBase } from './inputBase.js';

const taskInputCss = ".sc-task-input-h{display:block;margin-bottom:0.5rem}.input.sc-task-input{display:block;margin-top:5px;text-transform:none;-webkit-appearance:none;-moz-appearance:none;appearance:none;background:#fff;border:none;border-radius:3px;-webkit-box-shadow:0 0 0 0 rgba(45, 114, 210, 0), 0 0 0 0 rgba(45, 114, 210, 0), inset 0 0 0 1px rgba(17, 20, 24, 0.2), inset 0 1px 1px rgba(17, 20, 24, 0.5);box-shadow:0 0 0 0 rgba(45, 114, 210, 0), 0 0 0 0 rgba(45, 114, 210, 0), inset 0 0 0 1px rgba(17, 20, 24, 0.2), inset 0 1px 1px rgba(17, 20, 24, 0.5);color:#1c2127;font-size:14px;font-weight:400;height:30px;line-height:30px;outline:none;padding:0 10px;-webkit-transition:-webkit-box-shadow 100ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:-webkit-box-shadow 100ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:box-shadow 100ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 100ms cubic-bezier(0.4, 1, 0.75, 0.9);vertical-align:middle}textarea.input.sc-task-input{max-width:100%;padding:10px;height:auto;line-height:inherit;-webkit-box-sizing:border-box;box-sizing:border-box}";
const TaskInputStyle0 = taskInputCss;

const TaskInput$1 = /*@__PURE__*/ proxyCustomElement(class TaskInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.inputUpdated = createEvent(this, "inputUpdated", 7);
        this.internals = this.attachInternals();
        this.componentWillLoad = InputBase.prototype.componentWillLoad;
        this.disconnectedCallback = InputBase.prototype.disconnectedCallback;
        this.formUpdated = InputBase.prototype.formUpdated;
        this.setupDependentInputs = InputBase.prototype.setupDependentInputs;
        this.hasAnswerToValidate = InputBase.prototype.hasAnswerToValidate;
        this.handleParentElementUpdate = InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = InputBase.prototype.fromInputUpdated.bind(this);
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
        this.type = "text";
        this.rows = undefined;
        this.cols = undefined;
        this.size = undefined;
        this.maxlength = undefined;
        this.placeholder = undefined;
    }
    connectedCallback() {
        InputBase.prototype.connectedCallback.bind(this)();
    }
    async readyToSubmit() { return InputBase.prototype.readyToSubmit.bind(this)(); }
    async validateAgainstAnswer() { return InputBase.prototype.validateAgainstAnswer.bind(this)(); }
    async setShowCorrections() { return InputBase.prototype.setShowCorrections.bind(this)(); }
    async handleValueUpdate() { return InputBase.prototype.handleValueUpdate.bind(this)(); }
    text() {
        return h("input", { type: "text", class: "input", placeholder: this.placeholder, size: this.size, maxLength: this.maxlength, required: this.required, disabled: this.disabled, onInput: e => {
                this.value = e.target.value;
                this.internals.setFormValue(e.target.value);
            }, ref: el => this.input = el, value: this.value });
    }
    textarea() {
        return h("textarea", { class: "input", rows: this.rows, cols: this.cols, placeholder: this.placeholder, maxLength: this.maxlength, required: this.required, disabled: this.disabled, onInput: e => this.value = e.target.value, ref: el => this.input = el }, this.value);
    }
    render() {
        return (h(Host, { key: '79163ba4d656a91c8acd73cb9808851089119768' }, !this.hidden && h("label", { key: '496ac39659fcbb82e06a97e82f687415c8256f87', class: this.labelClass }, this.label, " ", this.required && this.requiredIndicator ? this.requiredIndicator : "", this.type === "textarea" && this.textarea(), this.type === "text" && this.text())));
    }
    static get formAssociated() { return true; }
    get host() { return this; }
    static get watchers() { return {
        "value": ["handleValueUpdate"],
        "required": ["handleValueUpdate"]
    }; }
    static get style() { return TaskInputStyle0; }
}, [66, "task-input", {
        "name": [1],
        "label": [1],
        "labelClass": [1, "label-class"],
        "required": [1028],
        "active": [4],
        "disabled": [1028],
        "disableIf": [1, "disable-if"],
        "requireIf": [1, "require-if"],
        "requiredIndicator": [1, "required-indicator"],
        "displayOn": [1, "display-on"],
        "displayIf": [1, "display-if"],
        "value": [1025],
        "valueFrom": [1, "value-from"],
        "hidden": [1028],
        "type": [1],
        "rows": [2],
        "cols": [2],
        "size": [2],
        "maxlength": [2],
        "placeholder": [1],
        "preventChanges": [32],
        "answer": [32],
        "answerCorrection": [32],
        "readyToSubmit": [64],
        "validateAgainstAnswer": [64],
        "setShowCorrections": [64]
    }, undefined, {
        "value": ["handleValueUpdate"],
        "required": ["handleValueUpdate"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-input"];
    components.forEach(tagName => { switch (tagName) {
        case "task-input":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskInput$1);
            }
            break;
    } });
}

const TaskInput = TaskInput$1;
const defineCustomElement = defineCustomElement$1;

export { TaskInput, defineCustomElement };

//# sourceMappingURL=task-input.js.map