import { proxyCustomElement, HTMLElement, h, Fragment, Host } from '@stencil/core/internal/client';

const taskKeyboardShortcutListCss = ".sc-task-keyboard-shortcut-list-h{display:block}.key-combo.sc-task-keyboard-shortcut-list{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.key-combo.sc-task-keyboard-shortcut-list>*.sc-task-keyboard-shortcut-list{-webkit-box-flex:0;-ms-flex-positive:0;flex-grow:0;-ms-flex-negative:0;flex-shrink:0}.key-combo.sc-task-keyboard-shortcut-list::before,.key-combo.sc-task-keyboard-shortcut-list>*.sc-task-keyboard-shortcut-list{margin-right:5px}.key-combo.sc-task-keyboard-shortcut-list:empty::before,.key-combo.sc-task-keyboard-shortcut-list>.sc-task-keyboard-shortcut-list:last-child{margin-right:0}.hotkey.sc-task-keyboard-shortcut-list{-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;margin-left:0;margin-right:0}.hotkey.sc-task-keyboard-shortcut-list:not(:last-child){margin-bottom:10px}.key.sc-task-keyboard-shortcut-list{-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:#fff;border-radius:3px;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 0 0 rgba(17, 20, 24, 0), 0 1px 1px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 0 0 rgba(17, 20, 24, 0), 0 1px 1px rgba(17, 20, 24, 0.2);color:#5f6b7c;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:inherit;font-size:12px;height:24px;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;line-height:24px;min-width:24px;padding:3px 6px;vertical-align:middle}";
const TaskKeyboardShortcutListStyle0 = taskKeyboardShortcutListCss;

const TaskKeyboardShortcutList$1 = /*@__PURE__*/ proxyCustomElement(class TaskKeyboardShortcutList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.valueMap = {
            "ArrowLeft": "Left Arrow",
            "ArrowRight": "Right Arrow",
            "tab": "Tab"
        };
        this.shortcuts = new Map();
    }
    componentWillLoad() {
        for (let child of Array.from(this.host.children)) {
            if (child.nodeName === "TASK-KEYBOARD-SHORTCUT") {
                this.addShortCut({
                    label: child.innerHTML,
                    keys: child.attributes.getNamedItem("keyboard-shortcut").value
                });
            }
        }
    }
    async addShortCut(shortcut) {
        this.shortcuts = new Map(this.shortcuts.set(shortcut.label, shortcut));
    }
    formatKey(key) {
        if (key in this.valueMap) {
            return this.valueMap[key];
        }
        else if (key.length === 1) {
            return key.toUpperCase();
        }
        else {
            return key;
        }
    }
    renderRow(ks) {
        const keys = ks.keys.split(",");
        return (h("div", { class: "hotkey" }, h("div", { class: "hotkey-label" }, ks.label), keys.length > 1 ?
            h("span", { class: "key-combo" }, keys.map((k, i) => h(Fragment, null, h("kbd", { class: "key" }, this.formatKey(k)), i < keys.length - 1 && h("span", null, " or "))))
            : h("kbd", { class: "key" }, this.formatKey(keys[0]))));
    }
    render() {
        return (h(Host, { key: 'd1a5b9d301bf8a48a6acfe07ecf6da9f29522634' }, Array.from(this.shortcuts.values()).map((ks) => this.renderRow(ks))));
    }
    get host() { return this; }
    static get style() { return TaskKeyboardShortcutListStyle0; }
}, [2, "task-keyboard-shortcut-list", {
        "shortcuts": [32],
        "addShortCut": [64]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-keyboard-shortcut-list"];
    components.forEach(tagName => { switch (tagName) {
        case "task-keyboard-shortcut-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskKeyboardShortcutList$1);
            }
            break;
    } });
}

const TaskKeyboardShortcutList = TaskKeyboardShortcutList$1;
const defineCustomElement = defineCustomElement$1;

export { TaskKeyboardShortcutList, defineCustomElement };

//# sourceMappingURL=task-keyboard-shortcut-list.js.map