import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const taskProgressbarCss = ".sc-task-progressbar-h{display:block}.bar.sc-task-progressbar{background:rgba(95, 107, 124, 0.2);border-radius:40px;display:block;height:8px;overflow:hidden;position:relative;width:100%}.meter.sc-task-progressbar{background-color:#2d72d2;background-size:30px 30px;border-radius:40px;height:100%;position:absolute;-webkit-transition:width 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:width 200ms cubic-bezier(0.4, 1, 0.75, 0.9);width:100%}.text.sc-task-progressbar{margin:6px 0}";
const TaskProgressbarStyle0 = taskProgressbarCss;

const TaskProgressbar$1 = /*@__PURE__*/ proxyCustomElement(class TaskProgressbar extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.completedCount = 0;
        this.taskCount = undefined;
        this.mode = undefined;
        this.completePercentage = "0";
    }
    componentWillLoad() {
        this.completePercentage = this.computePercentage();
        // TODO: This probably needs to be rerun if the mode changes for some reason
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            this.taskCount = cards.length;
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            this.taskCount = steps.length;
        }
    }
    watchPercentage() {
        this.completePercentage = this.computePercentage();
    }
    async refreshProgress() {
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            Promise.all(Array.from(cards).map(card => card.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            Promise.all(Array.from(steps).map(step => step.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
    }
    computePercentage() {
        if (this.taskCount > 0) {
            return (this.completedCount / this.taskCount * 100).toString() + "%";
        }
        else {
            return "0";
        }
    }
    render() {
        return (h(Host, { key: '1928dcf02290b80e8817d10c6fa103eab80a2067' }, h("div", { key: 'fbad4b01bd46f4d6a887d5df094c1c1096c47062', class: "bar" }, h("div", { key: '9c3db82eb909f86d796eba7080c677e2c87ecc46', class: "meter", style: { "width": this.completePercentage } })), h("slot", { key: '86dfd3089b171c50497fb1a7e1411f9154cdc3fa' }, h("div", { key: 'd6fb6044b0bdc6b6380bcd205287b4c98e5b4b4f', class: "text" }, "Completed ", this.completedCount, " of ", this.taskCount))));
    }
    static get watchers() { return {
        "completedCount": ["watchPercentage"],
        "taskCount": ["watchPercentage"]
    }; }
    static get style() { return TaskProgressbarStyle0; }
}, [6, "task-progressbar", {
        "completedCount": [1026, "completed-count"],
        "taskCount": [1026, "task-count"],
        "mode": [1],
        "completePercentage": [32],
        "refreshProgress": [64]
    }, undefined, {
        "completedCount": ["watchPercentage"],
        "taskCount": ["watchPercentage"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-progressbar"];
    components.forEach(tagName => { switch (tagName) {
        case "task-progressbar":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskProgressbar$1);
            }
            break;
    } });
}

const TaskProgressbar = TaskProgressbar$1;
const defineCustomElement = defineCustomElement$1;

export { TaskProgressbar, defineCustomElement };

//# sourceMappingURL=task-progressbar.js.map