import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { c as childInputs, r as requiredChildInputs } from './inputBase.js';
import { d as defineCustomElement$2 } from './task-icon2.js';

const taskStepCss = ".sc-task-step-h{display:block;margin-bottom:0.5rem;margin-right:0.5rem;background-color:rgb(251 179 96 / 0.2);padding:10px;width:100%;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);-webkit-box-sizing:border-box;box-sizing:border-box;border-radius:3px;-webkit-transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9)}.active.sc-task-step-h{background-color:rgb(114 202 155 / 40%);-webkit-box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%);box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%)}.content-hidden.sc-task-step{display:none}h3.sc-task-step{margin-top:3px;width:100%;cursor:pointer}task-icon.sc-task-step{height:18px;margin-right:3px}";
const TaskStepStyle0 = taskStepCss;

const TaskStep$1 = /*@__PURE__*/ proxyCustomElement(class TaskStep extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.cardReadyToSubmit = createEvent(this, "cardReadyToSubmit", 7);
        this.cardClicked = createEvent(this, "cardClicked", 7);
        this.label = undefined;
        this.active = undefined;
        this.open = false;
    }
    componentWillLoad() {
        this.open = this.active;
    }
    handleOpenToggle() {
        this.open = !this.open;
        if (this.open) {
            this.cardClicked.emit(this.host);
        }
    }
    activeUpdated(newValue) {
        this.open = newValue;
        for (let input of childInputs(this.host)) {
            input.active = newValue;
        }
    }
    handleInputUpdated() {
        this.readyToSubmit().then(ready => {
            this.cardReadyToSubmit.emit(ready);
        });
    }
    async readyToSubmit() {
        return Promise.all(requiredChildInputs(this.host).map(i => i.readyToSubmit()))
            .then(values => {
            return values.every(Boolean);
        });
    }
    render() {
        return (h(Host, { key: '2974edb4b0c4f1967e8df72ab34614ca078eda3f', class: this.active ? "active" : "" }, h("h3", { key: 'e65bcd763536474e220e79415add8016b9c34b4e', onClick: this.handleOpenToggle.bind(this) }, h("task-icon", { key: 'f7018a216f50be41e9059657c0b5f14761822039', icon: this.open ? "caret-down" : "caret-right" }), this.label), h("div", { key: '6af91a146f0157bd0d35b78993ac1e61b0f4a46d', class: !this.open && "content-hidden" }, h("slot", { key: '92e94494e5e10ebdbfba287e0ba923f1a9840413' }))));
    }
    get host() { return this; }
    static get watchers() { return {
        "active": ["activeUpdated"]
    }; }
    static get style() { return TaskStepStyle0; }
}, [6, "task-step", {
        "label": [1],
        "active": [4],
        "open": [32],
        "readyToSubmit": [64]
    }, [[0, "inputUpdated", "handleInputUpdated"]], {
        "active": ["activeUpdated"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-step", "task-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "task-step":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskStep$1);
            }
            break;
        case "task-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const TaskStep = TaskStep$1;
const defineCustomElement = defineCustomElement$1;

export { TaskStep, defineCustomElement };

//# sourceMappingURL=task-step.js.map