import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { a as ignoreKeypress } from './utils.js';

const taskStepsCss = ".sc-task-steps-h{display:block}";
const TaskStepsStyle0 = taskStepsCss;

const TaskSteps$1 = /*@__PURE__*/ proxyCustomElement(class TaskSteps extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.activeStep = 0;
        this.steps = undefined;
    }
    componentWillLoad() {
        this.steps = Array.from(this.host.children).filter(node => node.nodeName === "TASK-STEP");
        this.updateActiveStep();
    }
    updateActiveStep() {
        for (let step of this.steps) {
            step.active = this.activeStep === this.steps.indexOf(step);
        }
    }
    cardClickedHandler(event) {
        const target = event.detail;
        if (this.steps.includes(target)) {
            this.activeStep = this.steps.indexOf(target);
        }
    }
    cardReadyToSubmitHandler(event) {
        if (event.detail && !ignoreKeypress()) {
            this.activeStep = Math.min(this.activeStep + 1, this.steps.length - 1);
        }
    }
    activeStepUpdated() {
        this.updateActiveStep();
    }
    render() {
        return (h(Host, { key: 'bbc318c8cc88ad26b6fd143abfb936989328b69d' }, h("slot", { key: '368a76619c5e0ada7c0b2ed7590a63fd89ae5f78' })));
    }
    get host() { return this; }
    static get watchers() { return {
        "activeStep": ["activeStepUpdated"]
    }; }
    static get style() { return TaskStepsStyle0; }
}, [6, "task-steps", {
        "activeStep": [32],
        "steps": [32]
    }, [[0, "cardClicked", "cardClickedHandler"], [0, "cardReadyToSubmit", "cardReadyToSubmitHandler"]], {
        "activeStep": ["activeStepUpdated"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-steps"];
    components.forEach(tagName => { switch (tagName) {
        case "task-steps":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskSteps$1);
            }
            break;
    } });
}

const TaskSteps = TaskSteps$1;
const defineCustomElement = defineCustomElement$1;

export { TaskSteps, defineCustomElement };

//# sourceMappingURL=task-steps.js.map