import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { g as getFormElement, r as requiredChildInputs, i as inputsWithAnswers } from './inputBase.js';
import { a as ignoreKeypress } from './utils.js';

const taskSubmitCss = ".sc-task-submit-h{display:block}button.sc-task-submit{display:-ms-inline-flexbox;display:inline-flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border:none;border-radius:3px;cursor:pointer;font-size:14px;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:5px 10px;text-align:left;vertical-align:middle;min-height:30px;min-width:30px;background-color:#2d72d2;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.4), inset 0 -1px 0 rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.4), inset 0 -1px 0 rgba(17, 20, 24, 0.2);color:#fff;margin-bottom:6px}button.sc-task-submit:disabled{cursor:not-allowed;background-color:rgba(45, 114, 210, 0.5);background-image:none;border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}.message-hidden.sc-task-submit{display:none}";
const TaskSubmitStyle0 = taskSubmitCss;

const TaskSubmit$1 = /*@__PURE__*/ proxyCustomElement(class TaskSubmit extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.registerKeyboardShortcut = createEvent(this, "registerKeyboardShortcut", 7);
        this.showCorrections = createEvent(this, "showCorrections", 7);
        this.taskSubmit = createEvent(this, "taskSubmit", 7);
        this.keyboardShortcut = undefined;
        this.disabled = false;
        this.disableUntilComplete = true;
        this.label = "Submit";
        this.correctionMode = false;
        this.readyToSubmit = false;
    }
    componentWillLoad() {
        // TODO: This probably needs to be rerun if the mode changes for some reason
        this.refreshSubmitReady();
        if (this.keyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Submit", keys: this.keyboardShortcut });
        }
    }
    connectedCallback() {
        if (['interactive', 'complete'].includes(document.readyState)) {
            this.setupFormListener();
        }
        else {
            this.loadCallback = this.setupFormListener.bind(this);
            document.addEventListener("load", this.loadCallback);
        }
    }
    setupFormListener() {
        this.form = getFormElement(this.host);
        if (this.form) {
            this.formUpdatedCallback = this.refreshSubmitReady.bind(this);
            this.form.addEventListener("input", this.formUpdatedCallback);
            this.refreshSubmitReady();
        }
        else {
            setTimeout(() => this.setupFormListener(), 100);
        }
    }
    disconnectedCallback() {
        if (this.formUpdatedCallback) {
            this.form.removeEventListener("input", this.formUpdatedCallback);
        }
        if (this.loadCallback) {
            document.removeEventListener("load", this.loadCallback);
        }
    }
    keypressHandler(event) {
        if (!ignoreKeypress() && event.key === this.keyboardShortcut && !this.disabled) {
            this.button.click();
        }
    }
    async refreshSubmitReady() {
        if (this.form && this.disableUntilComplete) {
            Promise.all(requiredChildInputs(this.form).map(i => i.readyToSubmit()))
                .then(values => {
                this.disabled = !values.every(Boolean);
            });
        }
    }
    handleValidationResult(values) {
        if (values.every(Boolean)) {
            this.readyToSubmit = true;
            this.button.click();
        }
        else {
            this.showCorrections.emit();
            this.correctionMode = true;
        }
    }
    handleSubmit(event) {
        const answeredInputs = inputsWithAnswers();
        if (answeredInputs && answeredInputs.length > 0 && !this.readyToSubmit && !this.correctionMode) {
            event.preventDefault();
            Promise.all(answeredInputs.map(input => input.validateAgainstAnswer()))
                .then(values => this.handleValidationResult(values));
        }
        else {
            this.taskSubmit.emit();
        }
    }
    async setShowCorrections(value) {
        this.correctionMode = value;
    }
    render() {
        // Note that the button tag must be a single row to prevent crowd-form adding another one
        return (h(Host, { key: '707a0df3333865b0c88ee162427c5567169d311f' }, h("button", { key: 'd90af2681d8e7c9f09d92ade6ce66bb1f4b343ef', type: "submit", ref: el => this.button = el, disabled: this.disabled, onClick: this.handleSubmit.bind(this) }, this.label), h("div", { key: '5b5d87b901813ecfe033199fa260fbe0ebd8ce16', class: this.correctionMode ? "" : "message-hidden" }, h("slot", { key: 'd990bbd54ada648f46c38f5bc0b366c613316785' }))));
    }
    get host() { return this; }
    static get style() { return TaskSubmitStyle0; }
}, [6, "task-submit", {
        "keyboardShortcut": [1, "keyboard-shortcut"],
        "disabled": [1028],
        "disableUntilComplete": [4, "disable-until-complete"],
        "label": [1],
        "correctionMode": [32],
        "readyToSubmit": [32],
        "refreshSubmitReady": [64],
        "setShowCorrections": [64]
    }, [[4, "keydown", "keypressHandler"]]]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-submit"];
    components.forEach(tagName => { switch (tagName) {
        case "task-submit":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskSubmit$1);
            }
            break;
    } });
}

const TaskSubmit = TaskSubmit$1;
const defineCustomElement = defineCustomElement$1;

export { TaskSubmit, defineCustomElement };

//# sourceMappingURL=task-submit.js.map