import { r as registerInstance, h, H as Host } from './index-d23ea3f6.js';

const taskProgressbarCss = ".sc-task-progressbar-h{display:block}.bar.sc-task-progressbar{background:rgba(95, 107, 124, 0.2);border-radius:40px;display:block;height:8px;overflow:hidden;position:relative;width:100%}.meter.sc-task-progressbar{background-color:#2d72d2;background-size:30px 30px;border-radius:40px;height:100%;position:absolute;-webkit-transition:width 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:width 200ms cubic-bezier(0.4, 1, 0.75, 0.9);width:100%}.text.sc-task-progressbar{margin:6px 0}";
const TaskProgressbarStyle0 = taskProgressbarCss;

const TaskProgressbar = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.completedCount = 0;
        this.taskCount = undefined;
        this.mode = undefined;
        this.completePercentage = "0";
    }
    componentWillLoad() {
        this.completePercentage = this.computePercentage();
        // TODO: This probably needs to be rerun if the mode changes for some reason
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            this.taskCount = cards.length;
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            this.taskCount = steps.length;
        }
    }
    watchPercentage() {
        this.completePercentage = this.computePercentage();
    }
    async refreshProgress() {
        if (this.mode === "card") {
            const cards = document.querySelectorAll("TASK-CARD");
            Promise.all(Array.from(cards).map(card => card.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
        if (this.mode === "step") {
            const steps = document.querySelectorAll("TASK-STEP");
            Promise.all(Array.from(steps).map(step => step.readyToSubmit()))
                .then(values => {
                this.completedCount = values.reduce((n, v) => n + Number(v), 0);
            });
        }
    }
    computePercentage() {
        if (this.taskCount > 0) {
            return (this.completedCount / this.taskCount * 100).toString() + "%";
        }
        else {
            return "0";
        }
    }
    render() {
        return (h(Host, { key: '1928dcf02290b80e8817d10c6fa103eab80a2067' }, h("div", { key: 'fbad4b01bd46f4d6a887d5df094c1c1096c47062', class: "bar" }, h("div", { key: '9c3db82eb909f86d796eba7080c677e2c87ecc46', class: "meter", style: { "width": this.completePercentage } })), h("slot", { key: '86dfd3089b171c50497fb1a7e1411f9154cdc3fa' }, h("div", { key: 'd6fb6044b0bdc6b6380bcd205287b4c98e5b4b4f', class: "text" }, "Completed ", this.completedCount, " of ", this.taskCount))));
    }
    static get watchers() { return {
        "completedCount": ["watchPercentage"],
        "taskCount": ["watchPercentage"]
    }; }
};
TaskProgressbar.style = TaskProgressbarStyle0;

export { TaskProgressbar as task_progressbar };

//# sourceMappingURL=task-progressbar.entry.js.map