function ignoreKeypress() {
    const activeEl = document.activeElement;
    return activeEl.nodeName === "TEXTAREA" ||
        (activeEl.nodeName === "INPUT" && activeEl.getAttribute("type") === "text");
}
function gatherInputOptions(parent) {
    return Array.from(parent.getElementsByTagName("task-input-option"))
        .filter(n => Array.from(parent.children).includes(n));
}
function inputOptionKeyboardShortcuts(options) {
    const shortcuts = [];
    for (let option of options) {
        if (option.keyboardShortcut) {
            if (option.keyboardShortcutLabel) {
                shortcuts.push({ label: option.keyboardShortcutLabel, keys: option.keyboardShortcut, value: option.value });
            }
            else {
                shortcuts.push({ label: option.innerHTML, keys: option.keyboardShortcut, value: option.value });
            }
        }
    }
    return shortcuts;
}
function getAnswerElement(host) {
    return host.querySelector("TASK-ANSWER");
}
function getAnswerCorrectionElement(host) {
    return host.querySelector("TASK-ANSWER-CORRECTION");
}
function getActiveElement(element, options) {
    var _a;
    if (element == null) {
        return document.activeElement;
    }
    const rootNode = ((_a = element.getRootNode(options)) !== null && _a !== void 0 ? _a : document);
    return rootNode.activeElement;
}
function isFunction(value) {
    return typeof value === "function";
}
function isKeyboardClick(event) {
    return event.key === "Enter" || event.key === " ";
}
const MARK_NAMESPACE = "tc";
function mark(name) {
    // console.log(`Logging mark: ${name}`)
    window.performance.mark(`${MARK_NAMESPACE}:${name}`);
}
function getMarks() {
    return window.performance.getEntriesByType("mark")
        .filter(mark => mark.name.startsWith(`${MARK_NAMESPACE}:`));
}
function debounce(callback, wait = 300) {
    let timeoutId = null;
    return (...args) => {
        window.clearTimeout(timeoutId);
        timeoutId = window.setTimeout(() => {
            callback.apply(null, args);
        }, wait);
    };
}

export { inputOptionKeyboardShortcuts as a, ignoreKeypress as b, isFunction as c, getActiveElement as d, getAnswerElement as e, getAnswerCorrectionElement as f, gatherInputOptions as g, debounce as h, isKeyboardClick as i, getMarks as j, mark as m };

//# sourceMappingURL=utils-d346b0ee.js.map