import { EventEmitter } from '../stencil-public-runtime';
import { CallbackFunction } from './utils';
import { TaskAnswer } from '../components/task-answer/task-answer';
import { TaskAnswerCorrection } from '../components/task-answer-correction/task-answer-correction';
export interface Input {
    name: string;
    label: string;
    labelClass: string;
    required: boolean;
    active: boolean;
    disabled: boolean;
    disableIf: string;
    requireIf: string;
    requiredIndicator: string;
    displayOn: string;
    displayIf: string;
    value: string;
    valueFrom: string;
    hidden: boolean;
    preventChanges: boolean;
    answer: TaskAnswer;
    answerCorrection: TaskAnswerCorrection;
    inputUpdated: EventEmitter<HTMLElement>;
    host: HTMLElement;
    input: HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement;
    fromInput: InputEventTarget;
    form: HTMLFormElement;
    loadCallback: CallbackFunction;
    formCallback: CallbackFunction;
    displayOnCallback: CallbackFunction;
    fromInputUpdated: CallbackFunction;
    readyToSubmit(): Promise<boolean>;
    validateAgainstAnswer(): Promise<boolean>;
    setShowCorrections(value: boolean): Promise<void>;
}
export type InputEventTarget = Input & EventTarget;
export declare function childInputs(parent: HTMLElement): Input[];
export declare function requiredChildInputs(parent: HTMLElement): Input[];
export declare function inputsWithAnswers(): Input[];
export declare function evaluateFormula(formula: string, form: HTMLFormElement): boolean;
export declare function getFormElement(host: Element): HTMLFormElement;
export declare function findInput(name: string): Promise<InputEventTarget>;
export declare function attachInputListener(name: string, callback: CallbackFunction, type?: string): Promise<InputEventTarget>;
export declare abstract class InputBase implements Input {
    /***
     Lifecycle methods
     */
    componentWillLoad(): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    formUpdated(): void;
    setupDependentInputs(): void;
    fromInputUpdated(): void;
    handleParentElementUpdate(): void;
    hasAnswerToValidate: () => boolean;
    readyToSubmit(): Promise<boolean>;
    validateAgainstAnswer(): Promise<boolean>;
    setShowCorrections(value: boolean): Promise<void>;
    handleValueUpdate(_value: string): void;
    active: boolean;
    answer: TaskAnswer;
    answerCorrection: TaskAnswerCorrection;
    disabled: boolean;
    disableIf: string;
    displayOn: string;
    displayIf: string;
    hidden: boolean;
    host: HTMLElement;
    input: HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement;
    fromInput: InputEventTarget;
    form: HTMLFormElement;
    inputUpdated: EventEmitter<HTMLElement>;
    label: string;
    labelClass: string;
    name: string;
    preventChanges: boolean;
    requireIf: string;
    required: boolean;
    requiredIndicator: string;
    value: string;
    valueFrom: string;
    displayOnCallback(_ev: Event): any;
    formCallback(_ev: Event): any;
    loadCallback(_ev: Event): any;
}
