'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4e4a0217.js');
const inputBase = require('./inputBase-ae3f2f06.js');
const context = require('./context-9aeea8b3.js');
const utils = require('./utils-ae677cb5.js');

const TaskAsset = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.asset = undefined;
        this.value = undefined;
    }
    render() {
        return null;
    }
};

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

const taskBodyCss = ":host{display:-ms-flexbox;display:flex;height:100vh;font-size:14px;font-weight:400}";
const TaskBodyStyle0 = taskBodyCss;

const TaskBody = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.localStorageId = () => {
            // TODO: Figure out what the default id should be for smgt
            if (this.localId) {
                return this.localId;
            }
            else {
                if (context.context.mode !== "working") {
                    return "PREVIEW";
                }
                else {
                    return context.context.assignmentId;
                }
            }
        };
        this.saveLocal = false;
        this.localId = undefined;
        this.showCorrections = false;
    }
    componentWillLoad() {
        if (this.saveLocal) {
            this.previous = JSON.parse(localStorage.getItem(this.localStorageId()));
            if (this.previous && "showCorrections" in this.previous) {
                this.showCorrections = Boolean(this.previous.showCorrections);
            }
        }
    }
    componentDidLoad() {
        this.hideUnnecessaryCrowdFormSubmit();
        if (this.previous) {
            for (let input of inputBase.childInputs(this.host)) {
                if (input.name in this.previous) {
                    input.value = this.previous[input.name];
                }
            }
        }
        this.formElement = document.querySelector("form");
    }
    hideUnnecessaryCrowdFormSubmit() {
        /*
        Crowd HTML Elements will add a submit button if it doesn't detect one in your template.
        Unfortunately, if it loads before Task Components, then it will add one, even if Task Components
        will be adding one later. This checks for its presence and hides it.
         */
        const submitButtons = document.getElementsByTagName("task-submit");
        if (submitButtons.length > 0) {
            const els = document.getElementsByTagName("crowd-button");
            for (let el of els) {
                if (el.hasAttribute("form-action") &&
                    el.getAttribute("form-action") === "submit") {
                    el.style.display = "none";
                }
            }
        }
    }
    handleInputUpdated(event) {
        // small delay to allow time for the value to propagate to the input
        if (this.saveLocal) {
            setTimeout(() => this.writeFormData(event.detail), 500);
        }
    }
    writeFormData(form) {
        let f = form || this.formElement;
        if (f) {
            const formData = new FormData(f);
            const data = Object.fromEntries(formData.entries());
            data.showCorrections = String(this.showCorrections);
            localStorage.setItem(this.localStorageId(), JSON.stringify(data));
        }
    }
    handleShowCorrections() {
        this.showCorrections = true;
        if (this.saveLocal) {
            this.writeFormData();
        }
    }
    handleShowCorrectionsUpdated(value) {
        for (let input of inputBase.inputsWithAnswers()) {
            input.setShowCorrections(value);
        }
        const submitButtons = document.getElementsByTagName("task-submit");
        for (let button of submitButtons) {
            button.setShowCorrections(value);
        }
    }
    handleTaskSubmit() {
        if (this.saveLocal) {
            localStorage.removeItem(this.localStorageId());
        }
    }
    cardReadyToSubmitHandler() {
        const progressBars = this.host.querySelectorAll("TASK-PROGRESSBAR");
        for (let bar of Array.from(progressBars)) {
            bar.refreshProgress();
        }
    }
    registerKeyboardShortcutHandler(event) {
        const shortcutLists = this.host.querySelectorAll("TASK-KEYBOARD-SHORTCUT-LIST");
        for (let list of Array.from(shortcutLists)) {
            list.addShortCut(event.detail);
        }
    }
    render() {
        return (index.h(index.Host, { key: 'd6ad1ea2e8cb35c2100b96edb7c775c91c7944b2' }, index.h("slot", { key: '80d477bfeb0099585a22baea1859e313b929d245' })));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "showCorrections": ["handleShowCorrectionsUpdated"]
    }; }
};
TaskBody.style = TaskBodyStyle0;

const taskButtonCss = ":host{display:inline-block}button{font-family:inherit;font-size:100%;line-height:1.15;margin:0}.button{display:-ms-inline-flexbox;display:inline-flex;-ms-flex-direction:row;flex-direction:row;-ms-flex-align:center;align-items:center;border:none;border-radius:2px;cursor:pointer;font-size:14px;-ms-flex-pack:center;justify-content:center;padding:5px 10px;text-align:left;vertical-align:middle;min-height:30px;min-width:30px;-webkit-box-sizing:border-box;box-sizing:border-box}.button>*{-ms-flex-positive:0;flex-grow:0;-ms-flex-negative:0;flex-shrink:0}.button>.fill{-ms-flex-positive:1;flex-grow:1;-ms-flex-negative:1;flex-shrink:1}.button::before,.button>*{margin-right:7px}.button:empty::before,.button>:last-child{margin-right:0}.button:empty{padding:0 !important}.button:disabled,.button.disabled{cursor:not-allowed}.button.fill{display:-ms-flexbox;display:flex;width:100%}.button.align-right,.align-right .button{text-align:right}.button.align-left,.align-left .button{text-align:left}.button:not([class*=intent-]){background-color:#f6f7f9;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#1c2127}.button:not([class*=intent-]):hover{background-clip:padding-box;background-color:#edeff2;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button:not([class*=intent-]):active,.button:not([class*=intent-]).active{background-color:#dce0e5;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.selected,.button.selected:hover{background-color:#566573;color:white}@media (forced-colors: active) and (prefers-color-scheme: dark){.button:not([class*=intent-]):active,.button:not([class*=intent-]).active{background:highlight}}.button:not([class*=intent-]):disabled,.button:not([class*=intent-]).disabled{background-color:rgba(211, 216, 222, 0.5);-webkit-box-shadow:none;box-shadow:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed;outline:none}.button:not([class*=intent-]):disabled.active,.button:not([class*=intent-]):disabled.active:hover,.button:not([class*=intent-]).disabled.active,.button:not([class*=intent-]).disabled.active:hover{background:rgba(211, 216, 222, 0.7)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button:not([class*=intent-]){border:1px solid buttonborder}}.button.intent-primary{background-color:#2d72d2;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-primary:hover,.button.intent-primary:active,.button.intent-primary.active{color:#ffffff}.button.intent-primary:hover{background-color:#215db0;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-primary:active,.button.intent-primary.active{background-color:#184a90;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-primary:disabled,.button.intent-primary.disabled{background-color:rgba(45, 114, 210, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-primary:disabled,.button.intent-primary.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-primary{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-success{background-color:#238551;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-success:hover,.button.intent-success:active,.button.intent-success.active{color:#ffffff}.button.intent-success:hover{background-color:#1c6e42;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-success:active,.button.intent-success.active{background-color:#165a36;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-success:disabled,.button.intent-success.disabled{background-color:rgba(35, 133, 81, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-success:disabled,.button.intent-success.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-success{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-warning{background-color:#c87619;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-warning:hover,.button.intent-warning:active,.button.intent-warning.active{color:#ffffff}.button.intent-warning:hover{background-color:#935610;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-warning:active,.button.intent-warning.active{background-color:#77450d;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-warning:disabled,.button.intent-warning.disabled{background-color:rgba(200, 118, 25, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning:disabled,.button.intent-warning.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-danger{background-color:#cd4246;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-danger:hover,.button.intent-danger:active,.button.intent-danger.active{color:#ffffff}.button.intent-danger:hover{background-color:#ac2f33;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-danger:active,.button.intent-danger.active{background-color:#8e292c;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-danger:disabled,.button.intent-danger.disabled{background-color:rgba(205, 66, 70, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-danger:disabled,.button.intent-danger.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-danger{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button[class*=intent-] .button-spinner .spinner-head{stroke:#ffffff}.button.large,.large .button{min-height:40px;min-width:40px;font-size:16px;padding:5px 15px}.button.large::before,.button.large>*,.large .button::before,.large .button>*{margin-right:10px}.button.large:empty::before,.button.large>:last-child,.large .button:empty::before,.large .button>:last-child{margin-right:0}.button.small,.small .button{min-height:24px;min-width:24px;padding:0 7px}.button.loading{position:relative}.button.loading[class*=icon-]::before{visibility:hidden}.button.loading .button-spinner{margin:0;position:absolute}.button.loading>:not(.button-spinner){visibility:hidden}.button[class*=icon-]::before{font-family:\"blueprint-icons-16\", sans-serif;font-size:16px;font-style:normal;font-variant:normal;font-weight:400;height:16px;line-height:1;width:16px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;color:#5f6b7c}.button .icon,.button .icon-standard,.button .icon-large{color:#5f6b7c}.button .icon.align-right,.button .icon-standard.align-right,.button .icon-large.align-right{margin-left:7px}.button .icon:first-child:last-child,.button .spinner+.icon:last-child{margin:0 -7px}.dark .button:not([class*=intent-]){background-color:#383e47;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);color:#f6f7f9}.dark .button:not([class*=intent-]):hover,.dark .button:not([class*=intent-]):active,.dark .button:not([class*=intent-]).active{color:#f6f7f9}.dark .button:not([class*=intent-]):hover{background-color:#2f343c;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button:not([class*=intent-]):active,.dark .button:not([class*=intent-]).active{background-color:#1c2127;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button:not([class*=intent-]):disabled,.dark .button:not([class*=intent-]).disabled{background-color:rgba(64, 72, 84, 0.5);-webkit-box-shadow:none;box-shadow:none;color:rgba(171, 179, 191, 0.6)}.dark .button:not([class*=intent-]):disabled.active,.dark .button:not([class*=intent-]).disabled.active{background:rgba(64, 72, 84, 0.7)}.dark .button:not([class*=intent-]) .button-spinner .spinner-head{background:rgba(17, 20, 24, 0.5);stroke:#8f99a8}.dark .button:not([class*=intent-])[class*=icon-]::before{color:#abb3bf}.dark .button:not([class*=intent-]) .icon:not([class*=intent-]),.dark .button:not([class*=intent-]) .icon-standard:not([class*=intent-]),.dark .button:not([class*=intent-]) .icon-large:not([class*=intent-]){color:#abb3bf}.dark .button[class*=intent-]{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2)}.dark .button[class*=intent-]:hover{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2)}.dark .button[class*=intent-]:active,.dark .button[class*=intent-].active{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button[class*=intent-]:disabled,.dark .button[class*=intent-].disabled{-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.3)}.dark .button[class*=intent-] .button-spinner .spinner-head{stroke:#8f99a8}.button:disabled::before,.button:disabled .icon,.button:disabled .icon-standard,.button:disabled .icon-large,.button.disabled::before,.button.disabled .icon,.button.disabled .icon-standard,.button.disabled .icon-large,.button[class*=intent-]::before,.button[class*=intent-] .icon,.button[class*=intent-] .icon-standard,.button[class*=intent-] .icon-large{color:inherit !important}.button.minimal{background:none;-webkit-box-shadow:none;box-shadow:none}.button.minimal:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button.minimal:active,.button.minimal.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button.minimal:disabled,.button.minimal:disabled:hover,.button.minimal.disabled,.button.minimal.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button.minimal:disabled.active,.button.minimal:disabled:hover.active,.button.minimal.disabled.active,.button.minimal.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button.minimal{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.minimal:hover,.dark .button.minimal:active,.dark .button.minimal.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.minimal:hover{background:rgba(143, 153, 168, 0.15)}.dark .button.minimal:active,.dark .button.minimal.active{background:rgba(143, 153, 168, 0.3)}.dark .button.minimal:disabled,.dark .button.minimal:disabled:hover,.dark .button.minimal.disabled,.dark .button.minimal.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button.minimal:disabled.active,.dark .button.minimal:disabled:hover.active,.dark .button.minimal.disabled.active,.dark .button.minimal.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button.minimal.intent-primary{color:#215db0}.button.minimal.intent-primary:hover,.button.minimal.intent-primary:active,.button.minimal.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button.minimal.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button.minimal.intent-primary:active,.button.minimal.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button.minimal.intent-primary:disabled,.button.minimal.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button.minimal.intent-primary:disabled.active,.button.minimal.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.minimal.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button.minimal.intent-primary{color:#8abbff}.dark .button.minimal.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button.minimal.intent-primary:active,.dark .button.minimal.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button.minimal.intent-primary:disabled,.dark .button.minimal.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button.minimal.intent-primary:disabled.active,.dark .button.minimal.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.minimal.intent-success{color:#1c6e42}.button.minimal.intent-success:hover,.button.minimal.intent-success:active,.button.minimal.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button.minimal.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button.minimal.intent-success:active,.button.minimal.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button.minimal.intent-success:disabled,.button.minimal.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button.minimal.intent-success:disabled.active,.button.minimal.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.minimal.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button.minimal.intent-success{color:#72ca9b}.dark .button.minimal.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button.minimal.intent-success:active,.dark .button.minimal.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button.minimal.intent-success:disabled,.dark .button.minimal.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button.minimal.intent-success:disabled.active,.dark .button.minimal.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.minimal.intent-warning{color:#935610}.button.minimal.intent-warning:hover,.button.minimal.intent-warning:active,.button.minimal.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button.minimal.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button.minimal.intent-warning:active,.button.minimal.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button.minimal.intent-warning:disabled,.button.minimal.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button.minimal.intent-warning:disabled.active,.button.minimal.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.minimal.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button.minimal.intent-warning{color:#fbb360}.dark .button.minimal.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button.minimal.intent-warning:active,.dark .button.minimal.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button.minimal.intent-warning:disabled,.dark .button.minimal.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button.minimal.intent-warning:disabled.active,.dark .button.minimal.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.minimal.intent-danger{color:#ac2f33}.button.minimal.intent-danger:hover,.button.minimal.intent-danger:active,.button.minimal.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button.minimal.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button.minimal.intent-danger:active,.button.minimal.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button.minimal.intent-danger:disabled,.button.minimal.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button.minimal.intent-danger:disabled.active,.button.minimal.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.minimal.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button.minimal.intent-danger{color:#fa999c}.dark .button.minimal.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button.minimal.intent-danger:active,.dark .button.minimal.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button.minimal.intent-danger:disabled,.dark .button.minimal.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button.minimal.intent-danger:disabled.active,.dark .button.minimal.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined{background:none;-webkit-box-shadow:none;box-shadow:none;border:1px solid rgba(28, 33, 39, 0.2);-webkit-box-sizing:border-box;box-sizing:border-box}.button.outlined:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button.outlined:active,.button.outlined.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button.outlined:disabled,.button.outlined:disabled:hover,.button.outlined.disabled,.button.outlined.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button.outlined:disabled.active,.button.outlined:disabled:hover.active,.button.outlined.disabled.active,.button.outlined.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button.outlined{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.outlined:hover,.dark .button.outlined:active,.dark .button.outlined.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.outlined:hover{background:rgba(143, 153, 168, 0.15)}.dark .button.outlined:active,.dark .button.outlined.active{background:rgba(143, 153, 168, 0.3)}.dark .button.outlined:disabled,.dark .button.outlined:disabled:hover,.dark .button.outlined.disabled,.dark .button.outlined.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button.outlined:disabled.active,.dark .button.outlined:disabled:hover.active,.dark .button.outlined.disabled.active,.dark .button.outlined.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button.outlined.intent-primary{color:#215db0}.button.outlined.intent-primary:hover,.button.outlined.intent-primary:active,.button.outlined.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button.outlined.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button.outlined.intent-primary:active,.button.outlined.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button.outlined.intent-primary:disabled,.button.outlined.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button.outlined.intent-primary:disabled.active,.button.outlined.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.outlined.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button.outlined.intent-primary{color:#8abbff}.dark .button.outlined.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button.outlined.intent-primary:active,.dark .button.outlined.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button.outlined.intent-primary:disabled,.dark .button.outlined.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button.outlined.intent-primary:disabled.active,.dark .button.outlined.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.outlined.intent-success{color:#1c6e42}.button.outlined.intent-success:hover,.button.outlined.intent-success:active,.button.outlined.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button.outlined.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button.outlined.intent-success:active,.button.outlined.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button.outlined.intent-success:disabled,.button.outlined.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button.outlined.intent-success:disabled.active,.button.outlined.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.outlined.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button.outlined.intent-success{color:#72ca9b}.dark .button.outlined.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button.outlined.intent-success:active,.dark .button.outlined.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button.outlined.intent-success:disabled,.dark .button.outlined.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button.outlined.intent-success:disabled.active,.dark .button.outlined.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.outlined.intent-warning{color:#935610}.button.outlined.intent-warning:hover,.button.outlined.intent-warning:active,.button.outlined.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button.outlined.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button.outlined.intent-warning:active,.button.outlined.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button.outlined.intent-warning:disabled,.button.outlined.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button.outlined.intent-warning:disabled.active,.button.outlined.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.outlined.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button.outlined.intent-warning{color:#fbb360}.dark .button.outlined.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button.outlined.intent-warning:active,.dark .button.outlined.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button.outlined.intent-warning:disabled,.dark .button.outlined.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button.outlined.intent-warning:disabled.active,.dark .button.outlined.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.outlined.intent-danger{color:#ac2f33}.button.outlined.intent-danger:hover,.button.outlined.intent-danger:active,.button.outlined.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button.outlined.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button.outlined.intent-danger:active,.button.outlined.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button.outlined.intent-danger:disabled,.button.outlined.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button.outlined.intent-danger:disabled.active,.button.outlined.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button.outlined.intent-danger{color:#fa999c}.dark .button.outlined.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button.outlined.intent-danger:active,.dark .button.outlined.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button.outlined.intent-danger:disabled,.dark .button.outlined.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button.outlined.intent-danger:disabled.active,.dark .button.outlined.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined:disabled,.button.outlined.disabled,.button.outlined:disabled:hover,.button.outlined.disabled:hover{border-color:rgba(95, 107, 124, 0.1)}.dark .button.outlined{border-color:rgba(255, 255, 255, 0.4)}.dark .button.outlined:disabled,.dark .button.outlined:disabled:hover,.dark .button.outlined.disabled,.dark .button.outlined.disabled:hover{border-color:rgba(255, 255, 255, 0.2)}.button.outlined.intent-primary{border-color:rgba(33, 93, 176, 0.6)}.button.outlined.intent-primary:disabled,.button.outlined.intent-primary.disabled{border-color:rgba(33, 93, 176, 0.2)}.dark .button.outlined.intent-primary{border-color:rgba(138, 187, 255, 0.6)}.dark .button.outlined.intent-primary:disabled,.dark .button.outlined.intent-primary.disabled{border-color:rgba(138, 187, 255, 0.2)}.button.outlined.intent-success{border-color:rgba(28, 110, 66, 0.6)}.button.outlined.intent-success:disabled,.button.outlined.intent-success.disabled{border-color:rgba(28, 110, 66, 0.2)}.dark .button.outlined.intent-success{border-color:rgba(114, 202, 155, 0.6)}.dark .button.outlined.intent-success:disabled,.dark .button.outlined.intent-success.disabled{border-color:rgba(114, 202, 155, 0.2)}.button.outlined.intent-warning{border-color:rgba(147, 86, 16, 0.6)}.button.outlined.intent-warning:disabled,.button.outlined.intent-warning.disabled{border-color:rgba(147, 86, 16, 0.2)}.dark .button.outlined.intent-warning{border-color:rgba(251, 179, 96, 0.6)}.dark .button.outlined.intent-warning:disabled,.dark .button.outlined.intent-warning.disabled{border-color:rgba(251, 179, 96, 0.2)}.button.outlined.intent-danger{border-color:rgba(172, 47, 51, 0.6)}.button.outlined.intent-danger:disabled,.button.outlined.intent-danger.disabled{border-color:rgba(172, 47, 51, 0.2)}.dark .button.outlined.intent-danger{border-color:rgba(250, 153, 156, 0.6)}.dark .button.outlined.intent-danger:disabled,.dark .button.outlined.intent-danger.disabled{border-color:rgba(250, 153, 156, 0.2)}.button.intent-warning{background:#fbb360;color:#1c2127}.button.intent-warning:not(.disabled).icon>svg{fill:rgba(28, 33, 39, 0.7)}.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):hover{background:#ec9a3c;color:#1c2127}.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):active,.button.intent-warning:not(.disabled):not(.minimal):not(.outlined).active{background:#c87619;color:#1c2127}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):active,.button.intent-warning:not(.disabled):not(.minimal):not(.outlined).active{background:highlight}}.button.intent-warning:disabled,.button.intent-warning.disabled{background:rgba(200, 118, 25, 0.5);color:rgba(28, 33, 39, 0.35)}.dark .button.intent-warning:disabled,.dark .button.intent-warning.disabled{color:rgba(28, 33, 39, 0.6)}.button.intent-warning.minimal,.button.intent-warning.outlined{background:none}.dark .button.intent-warning.minimal:not(.disabled).icon>svg,.dark .button.intent-warning.outlined:not(.disabled).icon>svg{fill:#fbb360}a.button{text-align:center;text-decoration:none;-webkit-transition:none;transition:none}a.button,a.button:hover,a.button:active{color:#1c2127}a.button.disabled{color:rgba(95, 107, 124, 0.6)}.button-text{-ms-flex:0 1 auto;flex:0 1 auto}.button.align-left .button-text,.button.align-right .button-text,.button-group.align-left .button-text,.button-group.align-right .button-text{-ms-flex:1 1 auto;flex:1 1 auto}.button-group{display:-ms-inline-flexbox;display:inline-flex}.button-group .button{-ms-flex:0 0 auto;flex:0 0 auto;position:relative;z-index:4}.button-group .button:focus{z-index:5}.button-group .button:hover{z-index:6}.button-group .button:active,.button-group .button.active{z-index:7}.button-group .button:disabled,.button-group .button.disabled{z-index:3}.button-group .button[class*=intent-]{z-index:9}.button-group .button[class*=intent-]:focus{z-index:10}.button-group .button[class*=intent-]:hover{z-index:11}.button-group .button[class*=intent-]:active,.button-group .button[class*=intent-].active{z-index:12}.button-group .button[class*=intent-]:disabled,.button-group .button[class*=intent-].disabled{z-index:8}.button-group:not(.minimal)>.popover-wrapper:not(:first-child) .button,.button-group:not(.minimal)>.button:not(:first-child){border-bottom-left-radius:0;border-top-left-radius:0}.button-group:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group:not(.minimal)>.button:not(:last-child){border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}.button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none}.button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button-group.minimal .button:active,.button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button-group.minimal .button:disabled,.button-group.minimal .button:disabled:hover,.button-group.minimal .button.disabled,.button-group.minimal .button.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button-group.minimal .button:disabled.active,.button-group.minimal .button:disabled:hover.active,.button-group.minimal .button.disabled.active,.button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover,.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15)}.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button:disabled,.dark .button-group.minimal .button:disabled:hover,.dark .button-group.minimal .button.disabled,.dark .button-group.minimal .button.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button-group.minimal .button:disabled.active,.dark .button-group.minimal .button:disabled:hover.active,.dark .button-group.minimal .button.disabled.active,.dark .button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button-group.minimal .button.intent-primary{color:#215db0}.button-group.minimal .button.intent-primary:hover,.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button-group.minimal .button.intent-primary:disabled,.button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button-group.minimal .button.intent-primary:disabled.active,.button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button-group.minimal .button.intent-primary{color:#8abbff}.dark .button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button-group.minimal .button.intent-primary:active,.dark .button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button-group.minimal .button.intent-primary:disabled,.dark .button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button-group.minimal .button.intent-primary:disabled.active,.dark .button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-success{color:#1c6e42}.button-group.minimal .button.intent-success:hover,.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button-group.minimal .button.intent-success:disabled,.button-group.minimal .button.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button-group.minimal .button.intent-success:disabled.active,.button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button-group.minimal .button.intent-success{color:#72ca9b}.dark .button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button-group.minimal .button.intent-success:active,.dark .button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button-group.minimal .button.intent-success:disabled,.dark .button-group.minimal .button.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button-group.minimal .button.intent-success:disabled.active,.dark .button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-warning{color:#935610}.button-group.minimal .button.intent-warning:hover,.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button-group.minimal .button.intent-warning:disabled,.button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button-group.minimal .button.intent-warning:disabled.active,.button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button-group.minimal .button.intent-warning{color:#fbb360}.dark .button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button-group.minimal .button.intent-warning:active,.dark .button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button-group.minimal .button.intent-warning:disabled,.dark .button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button-group.minimal .button.intent-warning:disabled.active,.dark .button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-danger{color:#ac2f33}.button-group.minimal .button.intent-danger:hover,.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button-group.minimal .button.intent-danger:disabled,.button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button-group.minimal .button.intent-danger:disabled.active,.button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button-group.minimal .button.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button-group.minimal .button.intent-danger{color:#fa999c}.dark .button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button-group.minimal .button.intent-danger:active,.dark .button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button-group.minimal .button.intent-danger:disabled,.dark .button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button-group.minimal .button.intent-danger:disabled.active,.dark .button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button-group.minimal:not(:first-child){border-bottom-left-radius:0;border-left:none;border-top-left-radius:0}.button-group.minimal:not(:last-child){border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}}.button-group .popover-wrapper,.button-group .popover-target{display:-ms-flexbox;display:flex;-ms-flex:1 1 auto;flex:1 1 auto}.button-group.fill{display:-ms-flexbox;display:flex;width:100%}.button-group .button.fill,.button-group.fill .button:not(.fixed){-ms-flex:1 1 auto;flex:1 1 auto}.button-group.vertical{-ms-flex-align:stretch;align-items:stretch;-ms-flex-direction:column;flex-direction:column;vertical-align:top}.button-group.vertical.fill{height:100%;width:unset}.button-group.vertical .button{margin-right:0 !important;width:100%}.button-group.vertical:not(.minimal)>.popover-wrapper:first-child .button,.button-group.vertical:not(.minimal)>.button:first-child{border-radius:2px 2px 0 0}.button-group.vertical:not(.minimal)>.popover-wrapper:last-child .button,.button-group.vertical:not(.minimal)>.button:last-child{border-radius:0 0 2px 2px}.button-group.vertical:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group.vertical:not(.minimal)>.button:not(:last-child){margin-bottom:-1px}.button-group.align-left .button{text-align:left}";
const TaskButtonStyle0 = taskButtonCss;

const TaskButton = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.click = index.createEvent(this, "click", 7);
        this.focus = index.createEvent(this, "focus", 7);
        this.anchor = false;
        this.label = false;
        this.active = false;
        this.alignText = "center";
        this.disabled = false;
        this.fill = false;
        this.large = false;
        this.small = false;
        this.loading = false;
        this.type = "button";
        this.intent = undefined;
        this.selected = false;
        this.minimal = false;
        this.outlined = false;
        this.text = undefined;
        this.icon = undefined;
        this.iconSize = undefined;
        this.rightIcon = undefined;
        this.href = undefined;
        this.target = undefined;
        this.newWindow = false;
        this.tabindex = undefined;
        this.isActive = false;
        this.currentKeyPressed = undefined;
    }
    handleBlur() {
        if (this.isActive) {
            this.isActive = false;
        }
    }
    handleKeyDown(e) {
        if (utils.isKeyboardClick(e)) {
            e.preventDefault();
            if (e.key !== this.currentKeyPressed) {
                this.isActive = true;
            }
        }
        this.currentKeyPressed = e.key;
        //props.onKeyDown?.(e)
    }
    handleKeyUp(e) {
        var _a;
        if (utils.isKeyboardClick(e)) {
            this.isActive = false;
            (_a = this.button) === null || _a === void 0 ? void 0 : _a.click();
        }
        this.currentKeyPressed = undefined;
        //props.onKeyUp?.(e);
    }
    renderContents() {
        return index.h(index.Fragment, null, this.loading && index.h("task-spinner", { key: "loading", class: "button-spinner", size: "small" }), this.icon && index.h("task-icon", { key: "leftIcon", icon: this.icon, size: this.iconSize }), index.h("span", { key: "text", class: "button-text" }, this.text, index.h("slot", null)), this.rightIcon && index.h("task-icon", { key: "rightIcon", icon: this.rightIcon, size: this.iconSize }));
    }
    render() {
        const disabled = this.disabled || this.loading;
        const classes = inputBase.classNames("button", {
            ["active"]: !disabled && (this.active || this.isActive),
            ["disabled"]: disabled,
            ["fill"]: this.fill,
            ["large"]: this.large,
            ["loading"]: this.loading,
            ["minimal"]: this.minimal,
            ["outlined"]: this.outlined,
            ["small"]: this.small,
            [`intent-${this.intent}`]: this.intent,
            ["selected"]: this.selected,
        }, this.alignText ? `align-${this.alignText}` : undefined);
        return (index.h(index.Host, { key: '4e4bf0f5b6e45274261f28f6e505f19f5c9f8312' }, this.anchor ?
            index.h("a", { key: "anchorButton", href: this.href, class: classes, target: this.newWindow ? "_blank" : this.target, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents())
            : (this.label ?
                index.h("label", { class: classes }, this.renderContents())
                :
                    index.h("button", { key: "button", type: this.type, class: classes, disabled: disabled, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents()))));
    }
    get host() { return index.getElement(this); }
};
TaskButton.style = TaskButtonStyle0;

const taskButtonGroupCss = ":host{display:block}.button-group.align-left .button-text,.button-group.align-right .button-text{-ms-flex:1 1 auto;flex:1 1 auto}.button-group{display:-ms-inline-flexbox;display:inline-flex;margin-bottom:8px}.button-group .button{-ms-flex:0 0 auto;flex:0 0 auto;position:relative;z-index:4}.button-group .button:focus{z-index:5}.button-group .button:hover{z-index:6}.button-group .button:active,.button-group .button.active{z-index:7}.button-group .button:disabled,.button-group .button.disabled{z-index:3}.button-group .button[class*=intent-]{z-index:9}.button-group .button[class*=intent-]:focus{z-index:10}.button-group .button[class*=intent-]:hover{z-index:11}.button-group .button[class*=intent-]:active,.button-group .button[class*=intent-].active{z-index:12}.button-group .button[class*=intent-]:disabled,.button-group .button[class*=intent-].disabled{z-index:8}.button-group:not(.minimal)>.popover-wrapper:not(:first-child) .button,.button-group:not(.minimal)>task-button:not(:first-child)>.button{border-bottom-left-radius:0;border-top-left-radius:0}.button-group:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group:not(.minimal)>task-button:not(:last-child)>.button{border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}.button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none}.button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button-group.minimal .button:active,.button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button-group.minimal .button:disabled,.button-group.minimal .button:disabled:hover,.button-group.minimal .button.disabled,.button-group.minimal .button.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button-group.minimal .button:disabled.active,.button-group.minimal .button:disabled:hover.active,.button-group.minimal .button.disabled.active,.button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover,.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15)}.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button:disabled,.dark .button-group.minimal .button:disabled:hover,.dark .button-group.minimal .button.disabled,.dark .button-group.minimal .button.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button-group.minimal .button:disabled.active,.dark .button-group.minimal .button:disabled:hover.active,.dark .button-group.minimal .button.disabled.active,.dark .button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button-group.minimal .button.intent-primary{color:#215db0}.button-group.minimal .button.intent-primary:hover,.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button-group.minimal .button.intent-primary:disabled,.button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button-group.minimal .button.intent-primary:disabled.active,.button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button-group.minimal .button.intent-primary{color:#8abbff}.dark .button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button-group.minimal .button.intent-primary:active,.dark .button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button-group.minimal .button.intent-primary:disabled,.dark .button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button-group.minimal .button.intent-primary:disabled.active,.dark .button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-success{color:#1c6e42}.button-group.minimal .button.intent-success:hover,.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button-group.minimal .button.intent-success:disabled,.button-group.minimal .button.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button-group.minimal .button.intent-success:disabled.active,.button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button-group.minimal .button.intent-success{color:#72ca9b}.dark .button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button-group.minimal .button.intent-success:active,.dark .button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button-group.minimal .button.intent-success:disabled,.dark .button-group.minimal .button.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button-group.minimal .button.intent-success:disabled.active,.dark .button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-warning{color:#935610}.button-group.minimal .button.intent-warning:hover,.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button-group.minimal .button.intent-warning:disabled,.button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button-group.minimal .button.intent-warning:disabled.active,.button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button-group.minimal .button.intent-warning{color:#fbb360}.dark .button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button-group.minimal .button.intent-warning:active,.dark .button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button-group.minimal .button.intent-warning:disabled,.dark .button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button-group.minimal .button.intent-warning:disabled.active,.dark .button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-danger{color:#ac2f33}.button-group.minimal .button.intent-danger:hover,.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button-group.minimal .button.intent-danger:disabled,.button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button-group.minimal .button.intent-danger:disabled.active,.button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button-group.minimal .button.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button-group.minimal .button.intent-danger{color:#fa999c}.dark .button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button-group.minimal .button.intent-danger:active,.dark .button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button-group.minimal .button.intent-danger:disabled,.dark .button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button-group.minimal .button.intent-danger:disabled.active,.dark .button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button-group.minimal:not(:first-child){border-bottom-left-radius:0;border-left:none;border-top-left-radius:0}.button-group.minimal:not(:last-child){border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}}.button-group .popover-wrapper,.button-group .popover-target{display:-ms-flexbox;display:flex;-ms-flex:1 1 auto;flex:1 1 auto}.button-group.fill{display:-ms-flexbox;display:flex;width:100%}.button-group .button.fill,.button-group.fill .button:not(.fixed){-ms-flex:1 1 auto;flex:1 1 auto}.button-group.vertical{-ms-flex-align:stretch;align-items:stretch;-ms-flex-direction:column;flex-direction:column;vertical-align:top}.button-group.vertical.fill{height:100%;width:unset}.button-group.vertical .button{margin-right:0 !important;width:100%}.button-group.vertical:not(.minimal)>.popover-wrapper:first-child .button,.button-group.vertical:not(.minimal)>.button:first-child{border-radius:2px 2px 0 0}.button-group.vertical:not(.minimal)>.popover-wrapper:last-child .button,.button-group.vertical:not(.minimal)>.button:last-child{border-radius:0 0 2px 2px}.button-group.vertical:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group.vertical:not(.minimal)>.button:not(:last-child){margin-bottom:-1px}.button-group.align-left .button{text-align:left}";
const TaskButtonGroupStyle0 = taskButtonGroupCss;

const TaskButtonGroup = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.alignText = "center";
        this.fill = false;
        this.large = false;
        this.minimal = false;
        this.vertical = false;
    }
    render() {
        return (index.h(index.Host, { key: 'c6ff72bb63bcc95083369fc4abee58cb01030dbc', class: inputBase.classNames("button-group") }, index.h("slot", { key: 'f5f873233feb3810ccbf5751446680500d2c775b' })));
    }
};
TaskButtonGroup.style = TaskButtonGroupStyle0;

const taskCardCss = ".sc-task-card-h{display:block;margin-bottom:0.5rem;margin-right:0.5rem;background-color:rgb(251 179 96 / 0.2);padding:10px;width:200px;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 1px 1px rgba(17, 20, 24, 0.2), 0 2px 6px rgba(17, 20, 24, 0.2);border-radius:3px;-webkit-transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:-webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9);transition:transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-transform 200ms cubic-bezier(0.4, 1, 0.75, 0.9), -webkit-box-shadow 200ms cubic-bezier(0.4, 1, 0.75, 0.9)}.active.sc-task-card-h{background-color:rgb(114 202 155 / 40%);-webkit-box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%);box-shadow:0 0 0 1px rgb(17 20 24 / 10%), 0 4px 8px rgb(17 20 24 / 20%), 0 18px 46px 6px rgb(17 20 24 / 20%)}.hidden.sc-task-card-h{display:none}";
const TaskCardStyle0 = taskCardCss;

const TaskCard = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.cardClicked = index.createEvent(this, "cardClicked", 7);
        this.cardReadyToSubmit = index.createEvent(this, "cardReadyToSubmit", 7);
        this.inputUpdated = index.createEvent(this, "inputUpdated", 7);
        this.active = undefined;
        this.width = undefined;
        this.displayIf = undefined;
        this.hidden = false;
    }
    // TODO: Props for width and other configurable values
    connectedCallback() {
        this.form = inputBase.getFormElement(this.host);
        if (this.form) {
            this.form.addEventListener("input", this.formUpdated.bind(this));
            this.formUpdated();
        }
    }
    clickHandler() {
        this.cardClicked.emit(this.host);
    }
    handleActiveUpdate(newValue) {
        for (let input of inputBase.childInputs(this.host)) {
            input.active = newValue;
        }
    }
    handleInputUpdated() {
        this.readyToSubmit().then(ready => {
            this.cardReadyToSubmit.emit(ready);
        });
    }
    async readyToSubmit() {
        return Promise.all(inputBase.requiredChildInputs(this.host).map(i => i.readyToSubmit()))
            .then(values => {
            return values.every(Boolean);
        });
    }
    hostStyle() {
        if (this.width) {
            return { width: `${this.width}` };
        }
        else {
            return {};
        }
    }
    formUpdated() {
        if (this.form && this.displayIf) {
            const result = inputBase.evaluateFormula(this.displayIf, this.form);
            if (result !== undefined) {
                const previous = this.hidden;
                this.hidden = !result;
                if (this.hidden !== previous) {
                    this.inputUpdated.emit(this.form);
                }
            }
        }
    }
    render() {
        return (index.h(index.Host, { key: '050047e2460d8f1202acb130ce5c08b1d7b6d82b', class: inputBase.classNames({ active: this.active, hidden: this.hidden }), style: this.hostStyle() }, index.h("slot", { key: '57ffff3dde4d9f14afed3a4e0ff37226be9851bd' })));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "active": ["handleActiveUpdate"]
    }; }
};
TaskCard.style = TaskCardStyle0;

const taskClickToViewCss = ".sc-task-click-to-view-h{display:block}";
const TaskClickToViewStyle0 = taskClickToViewCss;

const TaskClickToView = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.visible = false;
    }
    render() {
        return (index.h(index.Host, { key: '0ebe3f2fafd945d84f8a960b925dec7241acd1cb' }, index.h("div", { key: '9745c51c2c4d0ab473d6a7f8decc3cde2bf0b299', style: { display: this.visible ? "none" : "block" }, onClick: () => this.visible = true }, index.h("slot", { key: 'fdef316b5ac288cffa0e62801f1ec4ff537be36c', name: "trigger" })), index.h("div", { key: '431f9da296ab016c9df5e4fe5b7c50dbbd509266', style: { display: this.visible ? "block" : "none" } }, index.h("slot", { key: '62cac4220505bed347ee78fae43a69d25fa87586', name: "content" }))));
    }
};
TaskClickToView.style = TaskClickToViewStyle0;

const taskColumnCss = ".sc-task-column-h{display:block;-ms-flex:1;flex:1}";
const TaskColumnStyle0 = taskColumnCss;

const TaskColumn = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        return (index.h(index.Host, { key: 'f9bd75e50a0eb588d04e2ce5005efab092b6f869' }, index.h("slot", { key: 'b38cca603d54249b6f82d6405a737454e05e61da' })));
    }
};
TaskColumn.style = TaskColumnStyle0;

const taskColumnsCss = ".sc-task-columns-h{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;width:100%;-ms-flex-wrap:nowrap;flex-wrap:nowrap}";
const TaskColumnsStyle0 = taskColumnsCss;

const TaskColumns = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        return (index.h(index.Host, { key: '6ec399a8f45130338e9bc0a733e596442652375b' }, index.h("slot", { key: 'b64358adcfdcf90c3530bfc4057981a20eacf243' })));
    }
};
TaskColumns.style = TaskColumnsStyle0;

const taskDialogCss = ".sc-task-dialog-h{display:block}.dialog-container.sc-task-dialog{opacity:1;-webkit-transform:scale(1);transform:scale(1);-ms-flex-align:center;align-items:center;display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;min-height:100%;pointer-events:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:100%}.dialog.sc-task-dialog{background:#f6f7f9;border-radius:4px;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 2px 4px rgba(17, 20, 24, 0.2), 0 8px 24px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 2px 4px rgba(17, 20, 24, 0.2), 0 8px 24px rgba(17, 20, 24, 0.2);display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column;margin:30px 0;pointer-events:all;-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text;width:500px}.dialog.sc-task-dialog:focus{outline:0}.dialog.dark.sc-task-dialog,.dark.sc-task-dialog .dialog.sc-task-dialog{background:#252a31;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.2), 0 2px 4px rgba(17, 20, 24, 0.4), 0 8px 24px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.2), 0 2px 4px rgba(17, 20, 24, 0.4), 0 8px 24px rgba(17, 20, 24, 0.4);color:#f6f7f9}@media (forced-colors: active) and (prefers-color-scheme: dark){.dialog.sc-task-dialog{border:1px solid buttonborder}}.dialog-header.sc-task-dialog{-ms-flex-align:center;align-items:center;background:#ffffff;border-radius:4px 4px 0 0;-webkit-box-shadow:0 1px 0 rgba(17, 20, 24, 0.15);box-shadow:0 1px 0 rgba(17, 20, 24, 0.15);display:-ms-flexbox;display:flex;-ms-flex:0 0 auto;flex:0 0 auto;min-height:40px;padding:5px;padding-left:15px;z-index:0}.dialog-header.sc-task-dialog .icon-large.sc-task-dialog,.dialog-header.sc-task-dialog .icon.sc-task-dialog{color:#5f6b7c;-ms-flex:0 0 auto;flex:0 0 auto;margin-left:-3px;margin-right:7.5px}.dialog-header.sc-task-dialog .heading.sc-task-dialog{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;word-wrap:normal;-ms-flex:1 1 auto;flex:1 1 auto;line-height:inherit;margin:0}.dialog-header.sc-task-dialog .heading.sc-task-dialog:last-child{margin-right:15px}.dark.sc-task-dialog .dialog-header.sc-task-dialog{background:#2f343c;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.2)}.dark.sc-task-dialog .dialog-header.sc-task-dialog .icon-large.sc-task-dialog,.dark.sc-task-dialog .dialog-header.sc-task-dialog .icon.sc-task-dialog{color:#abb3bf}@media (forced-colors: active) and (prefers-color-scheme: dark){.dialog-header.sc-task-dialog{border-bottom:1px solid buttonborder}}.dialog-body.sc-task-dialog{-ms-flex:1 1 auto;flex:1 1 auto;margin:15px}.dialog-body-scroll-container.sc-task-dialog{margin:0;max-height:70vh;overflow:auto;padding:15px}.dialog-footer.sc-task-dialog{-ms-flex:0 0 auto;flex:0 0 auto;margin:15px}.dialog-footer-fixed.sc-task-dialog{-ms-flex-align:center;align-items:center;background-color:#ffffff;border-radius:0 0 4px 4px;border-top:1px solid rgba(17, 20, 24, 0.15);display:-ms-flexbox;display:flex;gap:15px;-ms-flex-pack:justify;justify-content:space-between;margin:0;padding:10px 10px 10px 15px}.dark.sc-task-dialog .dialog-footer-fixed.sc-task-dialog{background:#383e47;border-top:1px solid rgba(255, 255, 255, 0.2)}.dialog-footer-main-section.sc-task-dialog{-ms-flex:1 0 auto;flex:1 0 auto}.dialog-footer-actions.sc-task-dialog{display:-ms-flexbox;display:flex;-ms-flex-pack:end;justify-content:flex-end}.dialog-footer-actions.sc-task-dialog .button.sc-task-dialog{margin-left:10px}.multistep-dialog-panels.sc-task-dialog{display:-ms-flexbox;display:flex}.multistep-dialog-panels.sc-task-dialog:first-child .dialog-step-container.sc-task-dialog:first-child{border-radius:4px 0 0 0}.multistep-dialog-panels.sc-task-dialog:first-child .multistep-dialog-right-panel.sc-task-dialog{border-top-right-radius:4px}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog{-ms-flex-direction:column;flex-direction:column}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog:first-child .dialog-step-container.sc-task-dialog:first-child{border-radius:4px 0 0 0}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog:first-child .dialog-step-container.sc-task-dialog:last-child{border-radius:0 4px 0 0}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-left-panel.sc-task-dialog{-ms-flex-direction:row;flex-direction:row}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .dialog-step-container.sc-task-dialog{-ms-flex-positive:1;flex-grow:1}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .dialog-step-container.sc-task-dialog:not(:first-child){border-left:1px solid rgba(17, 20, 24, 0.15)}.dark.sc-task-dialog .multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .dialog-step-container.sc-task-dialog{border-color:rgba(17, 20, 24, 0.4)}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-right-panel.sc-task-dialog{border-left:none}.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-right-panel.sc-task-dialog,.multistep-dialog-nav-top.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-footer.sc-task-dialog{border-radius:0 0 4px 4px}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog{-ms-flex-direction:row-reverse;flex-direction:row-reverse}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog:first-child .multistep-dialog-right-panel.sc-task-dialog{border-radius:4px 0 0 4px}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog:first-child .dialog-step-container.sc-task-dialog:first-child{border-radius:0 4px 0 0}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-left-panel.sc-task-dialog{border-radius:0 0 4px 0}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-right-panel.sc-task-dialog{border-left:none;border-radius:4px 0 0 4px;border-right:1px solid rgba(17, 20, 24, 0.15)}.dark.sc-task-dialog .multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .multistep-dialog-right-panel.sc-task-dialog{border-color:rgba(17, 20, 24, 0.4)}.multistep-dialog-nav-right.sc-task-dialog .multistep-dialog-panels.sc-task-dialog .dialog-footer.sc-task-dialog{border-bottom-left-radius:0}.multistep-dialog-left-panel.sc-task-dialog{display:-ms-flexbox;display:flex;-ms-flex:1;flex:1;-ms-flex-direction:column;flex-direction:column}.dark.sc-task-dialog .multistep-dialog-left-panel.sc-task-dialog{background:#252a31;border-bottom:1px solid rgba(255, 255, 255, 0.2);border-bottom-left-radius:4px;border-left:1px solid rgba(255, 255, 255, 0.2)}.multistep-dialog-right-panel.sc-task-dialog{background-color:#f6f7f9;border-left:1px solid rgba(17, 20, 24, 0.15);border-radius:0 0 4px 0;-ms-flex:3;flex:3;min-width:0}.dark.sc-task-dialog .multistep-dialog-right-panel.sc-task-dialog{background-color:#2f343c;border-bottom:1px solid rgba(255, 255, 255, 0.2);border-bottom-right-radius:4px;border-left:1px solid rgba(255, 255, 255, 0.2);border-right:1px solid rgba(255, 255, 255, 0.2)}.dialog-step-container.sc-task-dialog{background-color:#f6f7f9;border-bottom:1px solid rgba(17, 20, 24, 0.15)}.dark.sc-task-dialog .dialog-step-container.sc-task-dialog{background:#2f343c;border-bottom:1px solid rgba(255, 255, 255, 0.2)}.dialog-step-container.dialog-step-viewed.sc-task-dialog{background-color:#ffffff}.dark.sc-task-dialog .dialog-step-container.dialog-step-viewed.sc-task-dialog{background:#383e47}.dialog-step.sc-task-dialog{-ms-flex-align:center;align-items:center;border-radius:4px;cursor:not-allowed;display:-ms-flexbox;display:flex;margin:4px;padding:6px 14px}.dark.sc-task-dialog .dialog-step.sc-task-dialog{background:#2f343c}.dialog-step-viewed.sc-task-dialog .dialog-step.sc-task-dialog{background-color:#ffffff;cursor:pointer}.dark.sc-task-dialog .dialog-step-viewed.sc-task-dialog .dialog-step.sc-task-dialog{background:#383e47}.dialog-step.sc-task-dialog:hover{background-color:#f6f7f9}.dark.sc-task-dialog .dialog-step.sc-task-dialog:hover{background:#2f343c}.dialog-step-icon.sc-task-dialog{-ms-flex-align:center;align-items:center;background-color:rgba(95, 107, 124, 0.6);border-radius:50%;color:#ffffff;display:-ms-flexbox;display:flex;height:25px;-ms-flex-pack:center;justify-content:center;width:25px}.dark.sc-task-dialog .dialog-step-icon.sc-task-dialog{background-color:rgba(171, 179, 191, 0.6)}.active.dialog-step-viewed.sc-task-dialog .dialog-step-icon.sc-task-dialog{background-color:#4c90f0}.dialog-step-viewed.sc-task-dialog .dialog-step-icon.sc-task-dialog{background-color:#8f99a8}.dialog-step-title.sc-task-dialog{color:rgba(95, 107, 124, 0.6);-ms-flex:1;flex:1;padding-left:10px}.dark.sc-task-dialog .dialog-step-title.sc-task-dialog{color:rgba(171, 179, 191, 0.6)}.active.dialog-step-viewed.sc-task-dialog .dialog-step-title.sc-task-dialog{color:#4c90f0}.dialog-step-viewed.sc-task-dialog:not(.active) .dialog-step-title.sc-task-dialog{color:#1c2127}.dark.sc-task-dialog .dialog-step-viewed.sc-task-dialog:not(.active) .dialog-step-title.sc-task-dialog{color:#f6f7f9}";
const TaskDialogStyle0 = taskDialogCss;

const TaskDialog = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.close = index.createEvent(this, "close", 7);
        this.isOpen = true;
        this.headerText = undefined;
        this.isCloseButtonShown = true;
    }
    header() {
        if (this.headerText === null) {
            return null;
        }
        return index.h("div", { class: "dialog-header" }, index.h("h6", null, this.headerText), this.isCloseButtonShown &&
            index.h("task-button", { class: '', icon: 'small-cross', minimal: true, "on-click": () => this.close.emit() }));
    }
    render() {
        return (index.h(index.Host, { key: '435f89f7c1bbdfd6e4a7d769086b3188ba9335e8' }, index.h("task-overlay", { key: '62ef90bf9c4dea6339ca14e7ff1055dfbf983b5b', "is-open": this.isOpen, "has-backdrop": true, "container-class": "overlay-scroll-container" }, index.h("div", { key: 'b92761e25e40b504a30565a22ff41ede6ee5b562', class: "dialog-container" }, index.h("div", { key: '80655a05508424eb3d1258bdf6b5409b0b52b7ca', class: "dialog", role: "dialog" }, this.header(), index.h("slot", { key: '2f09c4ad050f70d26e7faa22c8453dfcf178cc7a' }))))));
    }
    get host() { return index.getElement(this); }
};
TaskDialog.style = TaskDialogStyle0;

const icons = {
    "blank": {
        16: [],
        20: [],
    },
    "small-tick": {
        16: ["M12 5c-.28 0-.53.11-.71.29L7 9.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l5-5A1.003 1.003 0 0012 5z"],
        20: ["M15 5c-.28 0-.53.11-.71.29L8 11.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l7-7A1.003 1.003 0 0015 5z"],
    },
    "caret-down": {
        16: ["M12 6.5c0-.28-.22-.5-.5-.5h-7a.495.495 0 00-.37.83l3.5 4c.09.1.22.17.37.17s.28-.07.37-.17l3.5-4c.08-.09.13-.2.13-.33z"],
        20: ["M16 7c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1 0 .24.1.46.24.63l-.01.01 5 6 .01-.01c.19.22.45.37.76.37s.57-.15.76-.37l.01.01 5-6-.01-.01c.14-.17.24-.39.24-.63z"],
    },
    "caret-left": {
        16: ["M9.5 4c-.13 0-.24.05-.33.13l-4 3.5c-.1.09-.17.22-.17.37s.07.28.17.37l4 3.5a.495.495 0 00.83-.37v-7c0-.28-.22-.5-.5-.5z"],
        20: ["M13 4c-.24 0-.46.1-.63.24l-.01-.01-6 5 .01.01c-.22.19-.37.45-.37.76s.15.57.37.76l-.01.01 6 5 .01-.01c.17.14.39.24.63.24.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],
    },
    "caret-up": {
        16: ["M11.87 9.17s.01 0 0 0l-3.5-4C8.28 5.07 8.15 5 8 5s-.28.07-.37.17l-3.5 4a.495.495 0 00.37.83h7a.495.495 0 00.37-.83z"],
        20: ["M15.76 12.37l.01-.01-5-6-.01.01C10.57 6.15 10.31 6 10 6s-.57.15-.76.37l-.01-.01-5 6 .01.01c-.14.17-.24.39-.24.63 0 .55.45 1 1 1h10c.55 0 1-.45 1-1 0-.24-.1-.46-.24-.63z"],
    },
    "info-sign": {
        16: ["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zM7 3h2v2H7V3zm3 10H6v-1h1V7H6V6h3v6h1v1z"],
        20: ["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM9 4h2v2H9V4zm4 12H7v-1h2V8H8V7h3v8h2v1z"],
    },
};

const taskIconCss = ".icon-add.sc-task-icon::before{content:\"\\f109\"}.icon-add-clip.sc-task-icon::before{content:\"\\f101\"}.icon-add-column-left.sc-task-icon::before{content:\"\\f102\"}.icon-add-column-right.sc-task-icon::before{content:\"\\f103\"}.icon-add-location.sc-task-icon::before{content:\"\\f104\"}.icon-add-row-bottom.sc-task-icon::before{content:\"\\f105\"}.icon-add-row-top.sc-task-icon::before{content:\"\\f106\"}.icon-add-to-artifact.sc-task-icon::before{content:\"\\f107\"}.icon-add-to-folder.sc-task-icon::before{content:\"\\f108\"}.icon-aimpoints-target.sc-task-icon::before{content:\"\\f335\"}.icon-airplane.sc-task-icon::before{content:\"\\f10a\"}.icon-align-center.sc-task-icon::before{content:\"\\f10b\"}.icon-align-justify.sc-task-icon::before{content:\"\\f10c\"}.icon-align-left.sc-task-icon::before{content:\"\\f10d\"}.icon-align-right.sc-task-icon::before{content:\"\\f10e\"}.icon-alignment-bottom.sc-task-icon::before{content:\"\\f10f\"}.icon-alignment-horizontal-center.sc-task-icon::before{content:\"\\f110\"}.icon-alignment-left.sc-task-icon::before{content:\"\\f111\"}.icon-alignment-right.sc-task-icon::before{content:\"\\f112\"}.icon-alignment-top.sc-task-icon::before{content:\"\\f113\"}.icon-alignment-vertical-center.sc-task-icon::before{content:\"\\f114\"}.icon-ammunition.sc-task-icon::before{content:\"\\f342\"}.icon-anchor.sc-task-icon::before{content:\"\\f330\"}.icon-annotation.sc-task-icon::before{content:\"\\f115\"}.icon-antenna.sc-task-icon::before{content:\"\\f116\"}.icon-app-header.sc-task-icon::before{content:\"\\f117\"}.icon-application.sc-task-icon::before{content:\"\\f118\"}.icon-applications.sc-task-icon::before{content:\"\\f119\"}.icon-archive.sc-task-icon::before{content:\"\\f11a\"}.icon-area-of-interest.sc-task-icon::before{content:\"\\f11b\"}.icon-array.sc-task-icon::before{content:\"\\f121\"}.icon-array-boolean.sc-task-icon::before{content:\"\\f11c\"}.icon-array-date.sc-task-icon::before{content:\"\\f11d\"}.icon-array-floating-point.sc-task-icon::before{content:\"\\f32d\"}.icon-array-numeric.sc-task-icon::before{content:\"\\f11e\"}.icon-array-string.sc-task-icon::before{content:\"\\f11f\"}.icon-array-timestamp.sc-task-icon::before{content:\"\\f120\"}.icon-arrow-bottom-left.sc-task-icon::before{content:\"\\f122\"}.icon-arrow-bottom-right.sc-task-icon::before{content:\"\\f123\"}.icon-arrow-down.sc-task-icon::before{content:\"\\f124\"}.icon-arrow-left.sc-task-icon::before{content:\"\\f125\"}.icon-arrow-right.sc-task-icon::before{content:\"\\f126\"}.icon-arrow-top-left.sc-task-icon::before{content:\"\\f127\"}.icon-arrow-top-right.sc-task-icon::before{content:\"\\f128\"}.icon-arrow-up.sc-task-icon::before{content:\"\\f129\"}.icon-arrows-horizontal.sc-task-icon::before{content:\"\\f12a\"}.icon-arrows-vertical.sc-task-icon::before{content:\"\\f12b\"}.icon-asterisk.sc-task-icon::before{content:\"\\f12c\"}.icon-at.sc-task-icon::before{content:\"\\f331\"}.icon-automatic-updates.sc-task-icon::before{content:\"\\f12d\"}.icon-axle.sc-task-icon::before{content:\"\\f338\"}.icon-backlink.sc-task-icon::before{content:\"\\f12e\"}.icon-badge.sc-task-icon::before{content:\"\\f12f\"}.icon-ban-circle.sc-task-icon::before{content:\"\\f130\"}.icon-bank-account.sc-task-icon::before{content:\"\\f131\"}.icon-barcode.sc-task-icon::before{content:\"\\f132\"}.icon-blank.sc-task-icon::before{content:\"\\f133\"}.icon-blocked-person.sc-task-icon::before{content:\"\\f134\"}.icon-bold.sc-task-icon::before{content:\"\\f135\"}.icon-book.sc-task-icon::before{content:\"\\f136\"}.icon-bookmark.sc-task-icon::before{content:\"\\f137\"}.icon-box.sc-task-icon::before{content:\"\\f138\"}.icon-briefcase.sc-task-icon::before{content:\"\\f139\"}.icon-bring-data.sc-task-icon::before{content:\"\\f13a\"}.icon-bug.sc-task-icon::before{content:\"\\f32e\"}.icon-buggy.sc-task-icon::before{content:\"\\f13b\"}.icon-build.sc-task-icon::before{content:\"\\f13c\"}.icon-calculator.sc-task-icon::before{content:\"\\f13d\"}.icon-calendar.sc-task-icon::before{content:\"\\f13e\"}.icon-camera.sc-task-icon::before{content:\"\\f13f\"}.icon-caret-down.sc-task-icon::before{content:\"\\f140\"}.icon-caret-left.sc-task-icon::before{content:\"\\f141\"}.icon-caret-right.sc-task-icon::before{content:\"\\f142\"}.icon-caret-up.sc-task-icon::before{content:\"\\f143\"}.icon-cargo-ship.sc-task-icon::before{content:\"\\f144\"}.icon-cell-tower.sc-task-icon::before{content:\"\\f145\"}.icon-changes.sc-task-icon::before{content:\"\\f146\"}.icon-chart.sc-task-icon::before{content:\"\\f147\"}.icon-chat.sc-task-icon::before{content:\"\\f148\"}.icon-chevron-backward.sc-task-icon::before{content:\"\\f149\"}.icon-chevron-down.sc-task-icon::before{content:\"\\f14a\"}.icon-chevron-forward.sc-task-icon::before{content:\"\\f14b\"}.icon-chevron-left.sc-task-icon::before{content:\"\\f14c\"}.icon-chevron-right.sc-task-icon::before{content:\"\\f14d\"}.icon-chevron-up.sc-task-icon::before{content:\"\\f14e\"}.icon-circle.sc-task-icon::before{content:\"\\f153\"}.icon-circle-arrow-down.sc-task-icon::before{content:\"\\f14f\"}.icon-circle-arrow-left.sc-task-icon::before{content:\"\\f150\"}.icon-circle-arrow-right.sc-task-icon::before{content:\"\\f151\"}.icon-circle-arrow-up.sc-task-icon::before{content:\"\\f152\"}.icon-citation.sc-task-icon::before{content:\"\\f154\"}.icon-clean.sc-task-icon::before{content:\"\\f155\"}.icon-clip.sc-task-icon::before{content:\"\\f156\"}.icon-clipboard.sc-task-icon::before{content:\"\\f157\"}.icon-cloud.sc-task-icon::before{content:\"\\f15a\"}.icon-cloud-download.sc-task-icon::before{content:\"\\f158\"}.icon-cloud-upload.sc-task-icon::before{content:\"\\f159\"}.icon-code.sc-task-icon::before{content:\"\\f15c\"}.icon-code-block.sc-task-icon::before{content:\"\\f15b\"}.icon-cog.sc-task-icon::before{content:\"\\f15d\"}.icon-collapse-all.sc-task-icon::before{content:\"\\f15e\"}.icon-color-fill.sc-task-icon::before{content:\"\\f328\"}.icon-column-layout.sc-task-icon::before{content:\"\\f15f\"}.icon-comment.sc-task-icon::before{content:\"\\f160\"}.icon-comparison.sc-task-icon::before{content:\"\\f161\"}.icon-compass.sc-task-icon::before{content:\"\\f162\"}.icon-compressed.sc-task-icon::before{content:\"\\f163\"}.icon-confirm.sc-task-icon::before{content:\"\\f164\"}.icon-console.sc-task-icon::before{content:\"\\f165\"}.icon-contrast.sc-task-icon::before{content:\"\\f166\"}.icon-control.sc-task-icon::before{content:\"\\f167\"}.icon-credit-card.sc-task-icon::before{content:\"\\f168\"}.icon-cross.sc-task-icon::before{content:\"\\f169\"}.icon-cross-circle.sc-task-icon::before{content:\"\\f336\"}.icon-crown.sc-task-icon::before{content:\"\\f16a\"}.icon-cube.sc-task-icon::before{content:\"\\f16d\"}.icon-cube-add.sc-task-icon::before{content:\"\\f16b\"}.icon-cube-remove.sc-task-icon::before{content:\"\\f16c\"}.icon-curved-range-chart.sc-task-icon::before{content:\"\\f16e\"}.icon-cut.sc-task-icon::before{content:\"\\f16f\"}.icon-cycle.sc-task-icon::before{content:\"\\f170\"}.icon-dashboard.sc-task-icon::before{content:\"\\f171\"}.icon-data-connection.sc-task-icon::before{content:\"\\f172\"}.icon-data-lineage.sc-task-icon::before{content:\"\\f173\"}.icon-database.sc-task-icon::before{content:\"\\f174\"}.icon-delete.sc-task-icon::before{content:\"\\f175\"}.icon-delta.sc-task-icon::before{content:\"\\f176\"}.icon-derive-column.sc-task-icon::before{content:\"\\f177\"}.icon-desktop.sc-task-icon::before{content:\"\\f178\"}.icon-detection.sc-task-icon::before{content:\"\\f341\"}.icon-diagnosis.sc-task-icon::before{content:\"\\f179\"}.icon-diagram-tree.sc-task-icon::before{content:\"\\f17a\"}.icon-direction-left.sc-task-icon::before{content:\"\\f17b\"}.icon-direction-right.sc-task-icon::before{content:\"\\f17c\"}.icon-disable.sc-task-icon::before{content:\"\\f17d\"}.icon-divide.sc-task-icon::before{content:\"\\f327\"}.icon-document.sc-task-icon::before{content:\"\\f180\"}.icon-document-open.sc-task-icon::before{content:\"\\f17e\"}.icon-document-share.sc-task-icon::before{content:\"\\f17f\"}.icon-dollar.sc-task-icon::before{content:\"\\f181\"}.icon-dot.sc-task-icon::before{content:\"\\f182\"}.icon-double-caret-horizontal.sc-task-icon::before{content:\"\\f183\"}.icon-double-caret-vertical.sc-task-icon::before{content:\"\\f184\"}.icon-double-chevron-down.sc-task-icon::before{content:\"\\f185\"}.icon-double-chevron-left.sc-task-icon::before{content:\"\\f186\"}.icon-double-chevron-right.sc-task-icon::before{content:\"\\f187\"}.icon-double-chevron-up.sc-task-icon::before{content:\"\\f188\"}.icon-doughnut-chart.sc-task-icon::before{content:\"\\f189\"}.icon-download.sc-task-icon::before{content:\"\\f18a\"}.icon-drag-handle-horizontal.sc-task-icon::before{content:\"\\f18b\"}.icon-drag-handle-vertical.sc-task-icon::before{content:\"\\f18c\"}.icon-draw.sc-task-icon::before{content:\"\\f18d\"}.icon-drawer-left.sc-task-icon::before{content:\"\\f18f\"}.icon-drawer-left-filled.sc-task-icon::before{content:\"\\f18e\"}.icon-drawer-right.sc-task-icon::before{content:\"\\f191\"}.icon-drawer-right-filled.sc-task-icon::before{content:\"\\f190\"}.icon-drive-time.sc-task-icon::before{content:\"\\f192\"}.icon-duplicate.sc-task-icon::before{content:\"\\f193\"}.icon-edit.sc-task-icon::before{content:\"\\f194\"}.icon-eject.sc-task-icon::before{content:\"\\f195\"}.icon-emoji.sc-task-icon::before{content:\"\\f196\"}.icon-endorsed.sc-task-icon::before{content:\"\\f197\"}.icon-envelope.sc-task-icon::before{content:\"\\f198\"}.icon-equals.sc-task-icon::before{content:\"\\f199\"}.icon-eraser.sc-task-icon::before{content:\"\\f19a\"}.icon-error.sc-task-icon::before{content:\"\\f19b\"}.icon-euro.sc-task-icon::before{content:\"\\f19c\"}.icon-exchange.sc-task-icon::before{content:\"\\f19d\"}.icon-exclude-row.sc-task-icon::before{content:\"\\f19e\"}.icon-expand-all.sc-task-icon::before{content:\"\\f19f\"}.icon-export.sc-task-icon::before{content:\"\\f1a0\"}.icon-eye-off.sc-task-icon::before{content:\"\\f1a1\"}.icon-eye-on.sc-task-icon::before{content:\"\\f1a2\"}.icon-eye-open.sc-task-icon::before{content:\"\\f1a3\"}.icon-fast-backward.sc-task-icon::before{content:\"\\f1a4\"}.icon-fast-forward.sc-task-icon::before{content:\"\\f1a5\"}.icon-feed.sc-task-icon::before{content:\"\\f1a7\"}.icon-feed-subscribed.sc-task-icon::before{content:\"\\f1a6\"}.icon-film.sc-task-icon::before{content:\"\\f1a8\"}.icon-filter.sc-task-icon::before{content:\"\\f1ad\"}.icon-filter-keep.sc-task-icon::before{content:\"\\f1a9\"}.icon-filter-list.sc-task-icon::before{content:\"\\f1aa\"}.icon-filter-open.sc-task-icon::before{content:\"\\f1ab\"}.icon-filter-remove.sc-task-icon::before{content:\"\\f1ac\"}.icon-flag.sc-task-icon::before{content:\"\\f1ae\"}.icon-flame.sc-task-icon::before{content:\"\\f1af\"}.icon-flash.sc-task-icon::before{content:\"\\f1b0\"}.icon-floating-point.sc-task-icon::before{content:\"\\f32c\"}.icon-floppy-disk.sc-task-icon::before{content:\"\\f1b1\"}.icon-flow-branch.sc-task-icon::before{content:\"\\f1b2\"}.icon-flow-end.sc-task-icon::before{content:\"\\f1b3\"}.icon-flow-linear.sc-task-icon::before{content:\"\\f1b4\"}.icon-flow-review.sc-task-icon::before{content:\"\\f1b6\"}.icon-flow-review-branch.sc-task-icon::before{content:\"\\f1b5\"}.icon-flows.sc-task-icon::before{content:\"\\f1b7\"}.icon-folder-close.sc-task-icon::before{content:\"\\f1b8\"}.icon-folder-new.sc-task-icon::before{content:\"\\f1b9\"}.icon-folder-open.sc-task-icon::before{content:\"\\f1ba\"}.icon-folder-shared.sc-task-icon::before{content:\"\\f1bc\"}.icon-folder-shared-open.sc-task-icon::before{content:\"\\f1bb\"}.icon-follower.sc-task-icon::before{content:\"\\f1bd\"}.icon-following.sc-task-icon::before{content:\"\\f1be\"}.icon-font.sc-task-icon::before{content:\"\\f1bf\"}.icon-fork.sc-task-icon::before{content:\"\\f1c0\"}.icon-form.sc-task-icon::before{content:\"\\f1c1\"}.icon-fuel.sc-task-icon::before{content:\"\\f323\"}.icon-full-circle.sc-task-icon::before{content:\"\\f1c2\"}.icon-full-stacked-chart.sc-task-icon::before{content:\"\\f1c3\"}.icon-fullscreen.sc-task-icon::before{content:\"\\f1c4\"}.icon-function.sc-task-icon::before{content:\"\\f1c5\"}.icon-gantt-chart.sc-task-icon::before{content:\"\\f1c6\"}.icon-geofence.sc-task-icon::before{content:\"\\f1c7\"}.icon-geolocation.sc-task-icon::before{content:\"\\f1c8\"}.icon-geosearch.sc-task-icon::before{content:\"\\f1c9\"}.icon-git-branch.sc-task-icon::before{content:\"\\f1ca\"}.icon-git-commit.sc-task-icon::before{content:\"\\f1cb\"}.icon-git-merge.sc-task-icon::before{content:\"\\f1cc\"}.icon-git-new-branch.sc-task-icon::before{content:\"\\f1cd\"}.icon-git-pull.sc-task-icon::before{content:\"\\f1ce\"}.icon-git-push.sc-task-icon::before{content:\"\\f1cf\"}.icon-git-repo.sc-task-icon::before{content:\"\\f1d0\"}.icon-glass.sc-task-icon::before{content:\"\\f1d1\"}.icon-globe.sc-task-icon::before{content:\"\\f1d3\"}.icon-globe-network.sc-task-icon::before{content:\"\\f1d2\"}.icon-graph.sc-task-icon::before{content:\"\\f1d5\"}.icon-graph-remove.sc-task-icon::before{content:\"\\f1d4\"}.icon-greater-than.sc-task-icon::before{content:\"\\f1d7\"}.icon-greater-than-or-equal-to.sc-task-icon::before{content:\"\\f1d6\"}.icon-grid.sc-task-icon::before{content:\"\\f1d9\"}.icon-grid-view.sc-task-icon::before{content:\"\\f1d8\"}.icon-group-objects.sc-task-icon::before{content:\"\\f1da\"}.icon-grouped-bar-chart.sc-task-icon::before{content:\"\\f1db\"}.icon-hand.sc-task-icon::before{content:\"\\f1e0\"}.icon-hand-down.sc-task-icon::before{content:\"\\f1dc\"}.icon-hand-left.sc-task-icon::before{content:\"\\f1dd\"}.icon-hand-right.sc-task-icon::before{content:\"\\f1de\"}.icon-hand-up.sc-task-icon::before{content:\"\\f1df\"}.icon-hat.sc-task-icon::before{content:\"\\f1e1\"}.icon-header.sc-task-icon::before{content:\"\\f1e5\"}.icon-header-one.sc-task-icon::before{content:\"\\f1e2\"}.icon-header-three.sc-task-icon::before{content:\"\\f1e3\"}.icon-header-two.sc-task-icon::before{content:\"\\f1e4\"}.icon-headset.sc-task-icon::before{content:\"\\f1e6\"}.icon-heart.sc-task-icon::before{content:\"\\f1e8\"}.icon-heart-broken.sc-task-icon::before{content:\"\\f1e7\"}.icon-heat-grid.sc-task-icon::before{content:\"\\f1e9\"}.icon-heatmap.sc-task-icon::before{content:\"\\f1ea\"}.icon-helicopter.sc-task-icon::before{content:\"\\f1eb\"}.icon-help.sc-task-icon::before{content:\"\\f1ec\"}.icon-helper-management.sc-task-icon::before{content:\"\\f1ed\"}.icon-high-priority.sc-task-icon::before{content:\"\\f1ee\"}.icon-high-voltage-pole.sc-task-icon::before{content:\"\\f333\"}.icon-highlight.sc-task-icon::before{content:\"\\f1ef\"}.icon-history.sc-task-icon::before{content:\"\\f1f0\"}.icon-home.sc-task-icon::before{content:\"\\f1f1\"}.icon-horizontal-bar-chart.sc-task-icon::before{content:\"\\f1f4\"}.icon-horizontal-bar-chart-asc.sc-task-icon::before{content:\"\\f1f2\"}.icon-horizontal-bar-chart-desc.sc-task-icon::before{content:\"\\f1f3\"}.icon-horizontal-distribution.sc-task-icon::before{content:\"\\f1f5\"}.icon-horizontal-inbetween.sc-task-icon::before{content:\"\\f329\"}.icon-hurricane.sc-task-icon::before{content:\"\\f1f6\"}.icon-id-number.sc-task-icon::before{content:\"\\f1f7\"}.icon-image-rotate-left.sc-task-icon::before{content:\"\\f1f8\"}.icon-image-rotate-right.sc-task-icon::before{content:\"\\f1f9\"}.icon-import.sc-task-icon::before{content:\"\\f1fa\"}.icon-inbox.sc-task-icon::before{content:\"\\f1ff\"}.icon-inbox-filtered.sc-task-icon::before{content:\"\\f1fb\"}.icon-inbox-geo.sc-task-icon::before{content:\"\\f1fc\"}.icon-inbox-search.sc-task-icon::before{content:\"\\f1fd\"}.icon-inbox-update.sc-task-icon::before{content:\"\\f1fe\"}.icon-info-sign.sc-task-icon::before{content:\"\\f200\"}.icon-inheritance.sc-task-icon::before{content:\"\\f201\"}.icon-inherited-group.sc-task-icon::before{content:\"\\f202\"}.icon-inner-join.sc-task-icon::before{content:\"\\f203\"}.icon-insert.sc-task-icon::before{content:\"\\f204\"}.icon-intelligence.sc-task-icon::before{content:\"\\f337\"}.icon-intersection.sc-task-icon::before{content:\"\\f205\"}.icon-ip-address.sc-task-icon::before{content:\"\\f206\"}.icon-issue.sc-task-icon::before{content:\"\\f209\"}.icon-issue-closed.sc-task-icon::before{content:\"\\f207\"}.icon-issue-new.sc-task-icon::before{content:\"\\f208\"}.icon-italic.sc-task-icon::before{content:\"\\f20a\"}.icon-join-table.sc-task-icon::before{content:\"\\f20b\"}.icon-key.sc-task-icon::before{content:\"\\f215\"}.icon-key-backspace.sc-task-icon::before{content:\"\\f20c\"}.icon-key-command.sc-task-icon::before{content:\"\\f20d\"}.icon-key-control.sc-task-icon::before{content:\"\\f20e\"}.icon-key-delete.sc-task-icon::before{content:\"\\f20f\"}.icon-key-enter.sc-task-icon::before{content:\"\\f210\"}.icon-key-escape.sc-task-icon::before{content:\"\\f211\"}.icon-key-option.sc-task-icon::before{content:\"\\f212\"}.icon-key-shift.sc-task-icon::before{content:\"\\f213\"}.icon-key-tab.sc-task-icon::before{content:\"\\f214\"}.icon-known-vehicle.sc-task-icon::before{content:\"\\f216\"}.icon-lab-test.sc-task-icon::before{content:\"\\f217\"}.icon-label.sc-task-icon::before{content:\"\\f218\"}.icon-layer.sc-task-icon::before{content:\"\\f21a\"}.icon-layer-outline.sc-task-icon::before{content:\"\\f219\"}.icon-layers.sc-task-icon::before{content:\"\\f21b\"}.icon-layout.sc-task-icon::before{content:\"\\f225\"}.icon-layout-auto.sc-task-icon::before{content:\"\\f21c\"}.icon-layout-balloon.sc-task-icon::before{content:\"\\f21d\"}.icon-layout-circle.sc-task-icon::before{content:\"\\f21e\"}.icon-layout-grid.sc-task-icon::before{content:\"\\f21f\"}.icon-layout-group-by.sc-task-icon::before{content:\"\\f220\"}.icon-layout-hierarchy.sc-task-icon::before{content:\"\\f221\"}.icon-layout-linear.sc-task-icon::before{content:\"\\f222\"}.icon-layout-skew-grid.sc-task-icon::before{content:\"\\f223\"}.icon-layout-sorted-clusters.sc-task-icon::before{content:\"\\f224\"}.icon-learning.sc-task-icon::before{content:\"\\f226\"}.icon-left-join.sc-task-icon::before{content:\"\\f227\"}.icon-lengthen-text.sc-task-icon::before{content:\"\\f33e\"}.icon-less-than.sc-task-icon::before{content:\"\\f229\"}.icon-less-than-or-equal-to.sc-task-icon::before{content:\"\\f228\"}.icon-lifesaver.sc-task-icon::before{content:\"\\f22a\"}.icon-lightbulb.sc-task-icon::before{content:\"\\f22b\"}.icon-lightning.sc-task-icon::before{content:\"\\f22c\"}.icon-link.sc-task-icon::before{content:\"\\f22d\"}.icon-list.sc-task-icon::before{content:\"\\f230\"}.icon-list-columns.sc-task-icon::before{content:\"\\f22e\"}.icon-list-detail-view.sc-task-icon::before{content:\"\\f22f\"}.icon-locate.sc-task-icon::before{content:\"\\f231\"}.icon-lock.sc-task-icon::before{content:\"\\f232\"}.icon-locomotive.sc-task-icon::before{content:\"\\f33b\"}.icon-log-in.sc-task-icon::before{content:\"\\f233\"}.icon-log-out.sc-task-icon::before{content:\"\\f234\"}.icon-low-voltage-pole.sc-task-icon::before{content:\"\\f332\"}.icon-manual.sc-task-icon::before{content:\"\\f235\"}.icon-manually-entered-data.sc-task-icon::before{content:\"\\f236\"}.icon-many-to-many.sc-task-icon::before{content:\"\\f237\"}.icon-many-to-one.sc-task-icon::before{content:\"\\f238\"}.icon-map.sc-task-icon::before{content:\"\\f23b\"}.icon-map-create.sc-task-icon::before{content:\"\\f239\"}.icon-map-marker.sc-task-icon::before{content:\"\\f23a\"}.icon-maximize.sc-task-icon::before{content:\"\\f23c\"}.icon-media.sc-task-icon::before{content:\"\\f23d\"}.icon-menu.sc-task-icon::before{content:\"\\f240\"}.icon-menu-closed.sc-task-icon::before{content:\"\\f23e\"}.icon-menu-open.sc-task-icon::before{content:\"\\f23f\"}.icon-merge-columns.sc-task-icon::before{content:\"\\f241\"}.icon-merge-links.sc-task-icon::before{content:\"\\f242\"}.icon-microphone.sc-task-icon::before{content:\"\\f343\"}.icon-minimize.sc-task-icon::before{content:\"\\f243\"}.icon-minus.sc-task-icon::before{content:\"\\f244\"}.icon-mobile-phone.sc-task-icon::before{content:\"\\f245\"}.icon-mobile-video.sc-task-icon::before{content:\"\\f246\"}.icon-modal.sc-task-icon::before{content:\"\\f248\"}.icon-modal-filled.sc-task-icon::before{content:\"\\f247\"}.icon-model.sc-task-icon::before{content:\"\\f33d\"}.icon-moon.sc-task-icon::before{content:\"\\f249\"}.icon-more.sc-task-icon::before{content:\"\\f24a\"}.icon-mountain.sc-task-icon::before{content:\"\\f24b\"}.icon-move.sc-task-icon::before{content:\"\\f24c\"}.icon-mugshot.sc-task-icon::before{content:\"\\f24d\"}.icon-multi-select.sc-task-icon::before{content:\"\\f24e\"}.icon-music.sc-task-icon::before{content:\"\\f24f\"}.icon-nest.sc-task-icon::before{content:\"\\f250\"}.icon-new-drawing.sc-task-icon::before{content:\"\\f251\"}.icon-new-grid-item.sc-task-icon::before{content:\"\\f252\"}.icon-new-layer.sc-task-icon::before{content:\"\\f253\"}.icon-new-layers.sc-task-icon::before{content:\"\\f254\"}.icon-new-link.sc-task-icon::before{content:\"\\f255\"}.icon-new-object.sc-task-icon::before{content:\"\\f256\"}.icon-new-person.sc-task-icon::before{content:\"\\f257\"}.icon-new-prescription.sc-task-icon::before{content:\"\\f258\"}.icon-new-text-box.sc-task-icon::before{content:\"\\f259\"}.icon-ninja.sc-task-icon::before{content:\"\\f25a\"}.icon-not-equal-to.sc-task-icon::before{content:\"\\f25b\"}.icon-notifications.sc-task-icon::before{content:\"\\f25e\"}.icon-notifications-snooze.sc-task-icon::before{content:\"\\f25c\"}.icon-notifications-updated.sc-task-icon::before{content:\"\\f25d\"}.icon-numbered-list.sc-task-icon::before{content:\"\\f25f\"}.icon-numerical.sc-task-icon::before{content:\"\\f260\"}.icon-office.sc-task-icon::before{content:\"\\f261\"}.icon-offline.sc-task-icon::before{content:\"\\f262\"}.icon-oil-field.sc-task-icon::before{content:\"\\f263\"}.icon-one-column.sc-task-icon::before{content:\"\\f264\"}.icon-one-to-many.sc-task-icon::before{content:\"\\f265\"}.icon-one-to-one.sc-task-icon::before{content:\"\\f266\"}.icon-open-application.sc-task-icon::before{content:\"\\f32b\"}.icon-outdated.sc-task-icon::before{content:\"\\f267\"}.icon-page-layout.sc-task-icon::before{content:\"\\f268\"}.icon-panel-stats.sc-task-icon::before{content:\"\\f269\"}.icon-panel-table.sc-task-icon::before{content:\"\\f26a\"}.icon-paperclip.sc-task-icon::before{content:\"\\f26b\"}.icon-paragraph.sc-task-icon::before{content:\"\\f26c\"}.icon-path.sc-task-icon::before{content:\"\\f26e\"}.icon-path-search.sc-task-icon::before{content:\"\\f26d\"}.icon-pause.sc-task-icon::before{content:\"\\f26f\"}.icon-people.sc-task-icon::before{content:\"\\f270\"}.icon-percentage.sc-task-icon::before{content:\"\\f271\"}.icon-person.sc-task-icon::before{content:\"\\f272\"}.icon-phone.sc-task-icon::before{content:\"\\f273\"}.icon-pie-chart.sc-task-icon::before{content:\"\\f274\"}.icon-pin.sc-task-icon::before{content:\"\\f275\"}.icon-pivot.sc-task-icon::before{content:\"\\f277\"}.icon-pivot-table.sc-task-icon::before{content:\"\\f276\"}.icon-play.sc-task-icon::before{content:\"\\f278\"}.icon-playbook.sc-task-icon::before{content:\"\\f324\"}.icon-plus.sc-task-icon::before{content:\"\\f279\"}.icon-polygon-filter.sc-task-icon::before{content:\"\\f27a\"}.icon-power.sc-task-icon::before{content:\"\\f27b\"}.icon-predictive-analysis.sc-task-icon::before{content:\"\\f27c\"}.icon-prescription.sc-task-icon::before{content:\"\\f27d\"}.icon-presentation.sc-task-icon::before{content:\"\\f27e\"}.icon-print.sc-task-icon::before{content:\"\\f27f\"}.icon-projects.sc-task-icon::before{content:\"\\f280\"}.icon-properties.sc-task-icon::before{content:\"\\f281\"}.icon-property.sc-task-icon::before{content:\"\\f282\"}.icon-publish-function.sc-task-icon::before{content:\"\\f283\"}.icon-pulse.sc-task-icon::before{content:\"\\f284\"}.icon-rain.sc-task-icon::before{content:\"\\f285\"}.icon-random.sc-task-icon::before{content:\"\\f286\"}.icon-record.sc-task-icon::before{content:\"\\f287\"}.icon-rect-height.sc-task-icon::before{content:\"\\f325\"}.icon-rect-width.sc-task-icon::before{content:\"\\f326\"}.icon-rectangle.sc-task-icon::before{content:\"\\f321\"}.icon-redo.sc-task-icon::before{content:\"\\f288\"}.icon-refresh.sc-task-icon::before{content:\"\\f289\"}.icon-regex.sc-task-icon::before{content:\"\\f32f\"}.icon-regression-chart.sc-task-icon::before{content:\"\\f28a\"}.icon-remove.sc-task-icon::before{content:\"\\f290\"}.icon-remove-column.sc-task-icon::before{content:\"\\f28d\"}.icon-remove-column-left.sc-task-icon::before{content:\"\\f28b\"}.icon-remove-column-right.sc-task-icon::before{content:\"\\f28c\"}.icon-remove-row-bottom.sc-task-icon::before{content:\"\\f28e\"}.icon-remove-row-top.sc-task-icon::before{content:\"\\f28f\"}.icon-repeat.sc-task-icon::before{content:\"\\f291\"}.icon-reset.sc-task-icon::before{content:\"\\f292\"}.icon-resolve.sc-task-icon::before{content:\"\\f293\"}.icon-rig.sc-task-icon::before{content:\"\\f294\"}.icon-right-join.sc-task-icon::before{content:\"\\f295\"}.icon-ring.sc-task-icon::before{content:\"\\f296\"}.icon-rocket.sc-task-icon::before{content:\"\\f298\"}.icon-rocket-slant.sc-task-icon::before{content:\"\\f297\"}.icon-rotate-document.sc-task-icon::before{content:\"\\f299\"}.icon-rotate-page.sc-task-icon::before{content:\"\\f29a\"}.icon-route.sc-task-icon::before{content:\"\\f29b\"}.icon-satellite.sc-task-icon::before{content:\"\\f29c\"}.icon-saved.sc-task-icon::before{content:\"\\f29d\"}.icon-scatter-plot.sc-task-icon::before{content:\"\\f29e\"}.icon-search.sc-task-icon::before{content:\"\\f2a2\"}.icon-search-around.sc-task-icon::before{content:\"\\f29f\"}.icon-search-template.sc-task-icon::before{content:\"\\f2a0\"}.icon-search-text.sc-task-icon::before{content:\"\\f2a1\"}.icon-segmented-control.sc-task-icon::before{content:\"\\f2a3\"}.icon-select.sc-task-icon::before{content:\"\\f2a4\"}.icon-selection.sc-task-icon::before{content:\"\\f2a5\"}.icon-send-message.sc-task-icon::before{content:\"\\f2a6\"}.icon-send-to.sc-task-icon::before{content:\"\\f2a9\"}.icon-send-to-graph.sc-task-icon::before{content:\"\\f2a7\"}.icon-send-to-map.sc-task-icon::before{content:\"\\f2a8\"}.icon-sensor.sc-task-icon::before{content:\"\\f33c\"}.icon-series-add.sc-task-icon::before{content:\"\\f2aa\"}.icon-series-configuration.sc-task-icon::before{content:\"\\f2ab\"}.icon-series-derived.sc-task-icon::before{content:\"\\f2ac\"}.icon-series-filtered.sc-task-icon::before{content:\"\\f2ad\"}.icon-series-search.sc-task-icon::before{content:\"\\f2ae\"}.icon-settings.sc-task-icon::before{content:\"\\f2af\"}.icon-shapes.sc-task-icon::before{content:\"\\f2b0\"}.icon-share.sc-task-icon::before{content:\"\\f2b1\"}.icon-shared-filter.sc-task-icon::before{content:\"\\f2b2\"}.icon-shield.sc-task-icon::before{content:\"\\f2b3\"}.icon-ship.sc-task-icon::before{content:\"\\f2b4\"}.icon-shop.sc-task-icon::before{content:\"\\f2b5\"}.icon-shopping-cart.sc-task-icon::before{content:\"\\f2b6\"}.icon-shorten-text.sc-task-icon::before{content:\"\\f33f\"}.icon-signal-search.sc-task-icon::before{content:\"\\f2b7\"}.icon-sim-card.sc-task-icon::before{content:\"\\f2b8\"}.icon-slash.sc-task-icon::before{content:\"\\f2b9\"}.icon-small-cross.sc-task-icon::before{content:\"\\f2ba\"}.icon-small-info-sign.sc-task-icon::before{content:\"\\f334\"}.icon-small-minus.sc-task-icon::before{content:\"\\f2bb\"}.icon-small-plus.sc-task-icon::before{content:\"\\f2bc\"}.icon-small-square.sc-task-icon::before{content:\"\\f2bd\"}.icon-small-tick.sc-task-icon::before{content:\"\\f2be\"}.icon-snowflake.sc-task-icon::before{content:\"\\f2bf\"}.icon-social-media.sc-task-icon::before{content:\"\\f2c0\"}.icon-sort.sc-task-icon::before{content:\"\\f2c7\"}.icon-sort-alphabetical.sc-task-icon::before{content:\"\\f2c2\"}.icon-sort-alphabetical-desc.sc-task-icon::before{content:\"\\f2c1\"}.icon-sort-asc.sc-task-icon::before{content:\"\\f2c3\"}.icon-sort-desc.sc-task-icon::before{content:\"\\f2c4\"}.icon-sort-numerical.sc-task-icon::before{content:\"\\f2c6\"}.icon-sort-numerical-desc.sc-task-icon::before{content:\"\\f2c5\"}.icon-spell-check.sc-task-icon::before{content:\"\\f340\"}.icon-split-columns.sc-task-icon::before{content:\"\\f2c8\"}.icon-square.sc-task-icon::before{content:\"\\f2c9\"}.icon-stacked-chart.sc-task-icon::before{content:\"\\f2ca\"}.icon-stadium-geometry.sc-task-icon::before{content:\"\\f2cb\"}.icon-star.sc-task-icon::before{content:\"\\f2cd\"}.icon-star-empty.sc-task-icon::before{content:\"\\f2cc\"}.icon-step-backward.sc-task-icon::before{content:\"\\f2ce\"}.icon-step-chart.sc-task-icon::before{content:\"\\f2cf\"}.icon-step-forward.sc-task-icon::before{content:\"\\f2d0\"}.icon-stop.sc-task-icon::before{content:\"\\f2d1\"}.icon-stopwatch.sc-task-icon::before{content:\"\\f2d2\"}.icon-strikethrough.sc-task-icon::before{content:\"\\f2d3\"}.icon-style.sc-task-icon::before{content:\"\\f2d4\"}.icon-subscript.sc-task-icon::before{content:\"\\f339\"}.icon-superscript.sc-task-icon::before{content:\"\\f33a\"}.icon-swap-horizontal.sc-task-icon::before{content:\"\\f2d5\"}.icon-swap-vertical.sc-task-icon::before{content:\"\\f2d6\"}.icon-switch.sc-task-icon::before{content:\"\\f2d7\"}.icon-symbol-circle.sc-task-icon::before{content:\"\\f2d8\"}.icon-symbol-cross.sc-task-icon::before{content:\"\\f2d9\"}.icon-symbol-diamond.sc-task-icon::before{content:\"\\f2da\"}.icon-symbol-rectangle.sc-task-icon::before{content:\"\\f322\"}.icon-symbol-square.sc-task-icon::before{content:\"\\f2db\"}.icon-symbol-triangle-down.sc-task-icon::before{content:\"\\f2dc\"}.icon-symbol-triangle-up.sc-task-icon::before{content:\"\\f2dd\"}.icon-syringe.sc-task-icon::before{content:\"\\f2de\"}.icon-tag.sc-task-icon::before{content:\"\\f2df\"}.icon-take-action.sc-task-icon::before{content:\"\\f2e0\"}.icon-tank.sc-task-icon::before{content:\"\\f2e1\"}.icon-target.sc-task-icon::before{content:\"\\f2e2\"}.icon-taxi.sc-task-icon::before{content:\"\\f2e3\"}.icon-temperature.sc-task-icon::before{content:\"\\f2e4\"}.icon-text-highlight.sc-task-icon::before{content:\"\\f2e5\"}.icon-th.sc-task-icon::before{content:\"\\f2ea\"}.icon-th-derived.sc-task-icon::before{content:\"\\f2e6\"}.icon-th-disconnect.sc-task-icon::before{content:\"\\f2e7\"}.icon-th-filtered.sc-task-icon::before{content:\"\\f2e8\"}.icon-th-list.sc-task-icon::before{content:\"\\f2e9\"}.icon-third-party.sc-task-icon::before{content:\"\\f2eb\"}.icon-thumbs-down.sc-task-icon::before{content:\"\\f2ec\"}.icon-thumbs-up.sc-task-icon::before{content:\"\\f2ed\"}.icon-tick.sc-task-icon::before{content:\"\\f2ef\"}.icon-tick-circle.sc-task-icon::before{content:\"\\f2ee\"}.icon-time.sc-task-icon::before{content:\"\\f2f0\"}.icon-timeline-area-chart.sc-task-icon::before{content:\"\\f2f1\"}.icon-timeline-bar-chart.sc-task-icon::before{content:\"\\f2f2\"}.icon-timeline-events.sc-task-icon::before{content:\"\\f2f3\"}.icon-timeline-line-chart.sc-task-icon::before{content:\"\\f2f4\"}.icon-tint.sc-task-icon::before{content:\"\\f2f5\"}.icon-torch.sc-task-icon::before{content:\"\\f2f6\"}.icon-tractor.sc-task-icon::before{content:\"\\f2f7\"}.icon-train.sc-task-icon::before{content:\"\\f2f8\"}.icon-translate.sc-task-icon::before{content:\"\\f2f9\"}.icon-trash.sc-task-icon::before{content:\"\\f2fa\"}.icon-tree.sc-task-icon::before{content:\"\\f2fb\"}.icon-trending-down.sc-task-icon::before{content:\"\\f2fc\"}.icon-trending-up.sc-task-icon::before{content:\"\\f2fd\"}.icon-truck.sc-task-icon::before{content:\"\\f2fe\"}.icon-two-columns.sc-task-icon::before{content:\"\\f2ff\"}.icon-unarchive.sc-task-icon::before{content:\"\\f300\"}.icon-underline.sc-task-icon::before{content:\"\\f301\"}.icon-undo.sc-task-icon::before{content:\"\\f302\"}.icon-ungroup-objects.sc-task-icon::before{content:\"\\f303\"}.icon-unknown-vehicle.sc-task-icon::before{content:\"\\f304\"}.icon-unlock.sc-task-icon::before{content:\"\\f305\"}.icon-unpin.sc-task-icon::before{content:\"\\f306\"}.icon-unresolve.sc-task-icon::before{content:\"\\f307\"}.icon-updated.sc-task-icon::before{content:\"\\f308\"}.icon-upload.sc-task-icon::before{content:\"\\f309\"}.icon-user.sc-task-icon::before{content:\"\\f30a\"}.icon-variable.sc-task-icon::before{content:\"\\f30b\"}.icon-vertical-bar-chart-asc.sc-task-icon::before{content:\"\\f30c\"}.icon-vertical-bar-chart-desc.sc-task-icon::before{content:\"\\f30d\"}.icon-vertical-distribution.sc-task-icon::before{content:\"\\f30e\"}.icon-vertical-inbetween.sc-task-icon::before{content:\"\\f32a\"}.icon-video.sc-task-icon::before{content:\"\\f30f\"}.icon-virus.sc-task-icon::before{content:\"\\f310\"}.icon-volume-down.sc-task-icon::before{content:\"\\f311\"}.icon-volume-off.sc-task-icon::before{content:\"\\f312\"}.icon-volume-up.sc-task-icon::before{content:\"\\f313\"}.icon-walk.sc-task-icon::before{content:\"\\f314\"}.icon-warning-sign.sc-task-icon::before{content:\"\\f315\"}.icon-waterfall-chart.sc-task-icon::before{content:\"\\f316\"}.icon-waves.sc-task-icon::before{content:\"\\f317\"}.icon-widget.sc-task-icon::before{content:\"\\f31b\"}.icon-widget-button.sc-task-icon::before{content:\"\\f318\"}.icon-widget-footer.sc-task-icon::before{content:\"\\f319\"}.icon-widget-header.sc-task-icon::before{content:\"\\f31a\"}.icon-wind.sc-task-icon::before{content:\"\\f31c\"}.icon-wrench.sc-task-icon::before{content:\"\\f31d\"}.icon-zoom-in.sc-task-icon::before{content:\"\\f31e\"}.icon-zoom-out.sc-task-icon::before{content:\"\\f31f\"}.icon-zoom-to-fit.sc-task-icon::before{content:\"\\f320\"}.icon-add.sc-task-icon::before{content:\"\\f109\"}.icon-add-clip.sc-task-icon::before{content:\"\\f101\"}.icon-add-column-left.sc-task-icon::before{content:\"\\f102\"}.icon-add-column-right.sc-task-icon::before{content:\"\\f103\"}.icon-add-location.sc-task-icon::before{content:\"\\f104\"}.icon-add-row-bottom.sc-task-icon::before{content:\"\\f105\"}.icon-add-row-top.sc-task-icon::before{content:\"\\f106\"}.icon-add-to-artifact.sc-task-icon::before{content:\"\\f107\"}.icon-add-to-folder.sc-task-icon::before{content:\"\\f108\"}.icon-aimpoints-target.sc-task-icon::before{content:\"\\f335\"}.icon-airplane.sc-task-icon::before{content:\"\\f10a\"}.icon-align-center.sc-task-icon::before{content:\"\\f10b\"}.icon-align-justify.sc-task-icon::before{content:\"\\f10c\"}.icon-align-left.sc-task-icon::before{content:\"\\f10d\"}.icon-align-right.sc-task-icon::before{content:\"\\f10e\"}.icon-alignment-bottom.sc-task-icon::before{content:\"\\f10f\"}.icon-alignment-horizontal-center.sc-task-icon::before{content:\"\\f110\"}.icon-alignment-left.sc-task-icon::before{content:\"\\f111\"}.icon-alignment-right.sc-task-icon::before{content:\"\\f112\"}.icon-alignment-top.sc-task-icon::before{content:\"\\f113\"}.icon-alignment-vertical-center.sc-task-icon::before{content:\"\\f114\"}.icon-ammunition.sc-task-icon::before{content:\"\\f342\"}.icon-anchor.sc-task-icon::before{content:\"\\f330\"}.icon-annotation.sc-task-icon::before{content:\"\\f115\"}.icon-antenna.sc-task-icon::before{content:\"\\f116\"}.icon-app-header.sc-task-icon::before{content:\"\\f117\"}.icon-application.sc-task-icon::before{content:\"\\f118\"}.icon-applications.sc-task-icon::before{content:\"\\f119\"}.icon-archive.sc-task-icon::before{content:\"\\f11a\"}.icon-area-of-interest.sc-task-icon::before{content:\"\\f11b\"}.icon-array.sc-task-icon::before{content:\"\\f121\"}.icon-array-boolean.sc-task-icon::before{content:\"\\f11c\"}.icon-array-date.sc-task-icon::before{content:\"\\f11d\"}.icon-array-floating-point.sc-task-icon::before{content:\"\\f32d\"}.icon-array-numeric.sc-task-icon::before{content:\"\\f11e\"}.icon-array-string.sc-task-icon::before{content:\"\\f11f\"}.icon-array-timestamp.sc-task-icon::before{content:\"\\f120\"}.icon-arrow-bottom-left.sc-task-icon::before{content:\"\\f122\"}.icon-arrow-bottom-right.sc-task-icon::before{content:\"\\f123\"}.icon-arrow-down.sc-task-icon::before{content:\"\\f124\"}.icon-arrow-left.sc-task-icon::before{content:\"\\f125\"}.icon-arrow-right.sc-task-icon::before{content:\"\\f126\"}.icon-arrow-top-left.sc-task-icon::before{content:\"\\f127\"}.icon-arrow-top-right.sc-task-icon::before{content:\"\\f128\"}.icon-arrow-up.sc-task-icon::before{content:\"\\f129\"}.icon-arrows-horizontal.sc-task-icon::before{content:\"\\f12a\"}.icon-arrows-vertical.sc-task-icon::before{content:\"\\f12b\"}.icon-asterisk.sc-task-icon::before{content:\"\\f12c\"}.icon-at.sc-task-icon::before{content:\"\\f331\"}.icon-automatic-updates.sc-task-icon::before{content:\"\\f12d\"}.icon-axle.sc-task-icon::before{content:\"\\f338\"}.icon-backlink.sc-task-icon::before{content:\"\\f12e\"}.icon-badge.sc-task-icon::before{content:\"\\f12f\"}.icon-ban-circle.sc-task-icon::before{content:\"\\f130\"}.icon-bank-account.sc-task-icon::before{content:\"\\f131\"}.icon-barcode.sc-task-icon::before{content:\"\\f132\"}.icon-blank.sc-task-icon::before{content:\"\\f133\"}.icon-blocked-person.sc-task-icon::before{content:\"\\f134\"}.icon-bold.sc-task-icon::before{content:\"\\f135\"}.icon-book.sc-task-icon::before{content:\"\\f136\"}.icon-bookmark.sc-task-icon::before{content:\"\\f137\"}.icon-box.sc-task-icon::before{content:\"\\f138\"}.icon-briefcase.sc-task-icon::before{content:\"\\f139\"}.icon-bring-data.sc-task-icon::before{content:\"\\f13a\"}.icon-bug.sc-task-icon::before{content:\"\\f32e\"}.icon-buggy.sc-task-icon::before{content:\"\\f13b\"}.icon-build.sc-task-icon::before{content:\"\\f13c\"}.icon-calculator.sc-task-icon::before{content:\"\\f13d\"}.icon-calendar.sc-task-icon::before{content:\"\\f13e\"}.icon-camera.sc-task-icon::before{content:\"\\f13f\"}.icon-caret-down.sc-task-icon::before{content:\"\\f140\"}.icon-caret-left.sc-task-icon::before{content:\"\\f141\"}.icon-caret-right.sc-task-icon::before{content:\"\\f142\"}.icon-caret-up.sc-task-icon::before{content:\"\\f143\"}.icon-cargo-ship.sc-task-icon::before{content:\"\\f144\"}.icon-cell-tower.sc-task-icon::before{content:\"\\f145\"}.icon-changes.sc-task-icon::before{content:\"\\f146\"}.icon-chart.sc-task-icon::before{content:\"\\f147\"}.icon-chat.sc-task-icon::before{content:\"\\f148\"}.icon-chevron-backward.sc-task-icon::before{content:\"\\f149\"}.icon-chevron-down.sc-task-icon::before{content:\"\\f14a\"}.icon-chevron-forward.sc-task-icon::before{content:\"\\f14b\"}.icon-chevron-left.sc-task-icon::before{content:\"\\f14c\"}.icon-chevron-right.sc-task-icon::before{content:\"\\f14d\"}.icon-chevron-up.sc-task-icon::before{content:\"\\f14e\"}.icon-circle.sc-task-icon::before{content:\"\\f153\"}.icon-circle-arrow-down.sc-task-icon::before{content:\"\\f14f\"}.icon-circle-arrow-left.sc-task-icon::before{content:\"\\f150\"}.icon-circle-arrow-right.sc-task-icon::before{content:\"\\f151\"}.icon-circle-arrow-up.sc-task-icon::before{content:\"\\f152\"}.icon-citation.sc-task-icon::before{content:\"\\f154\"}.icon-clean.sc-task-icon::before{content:\"\\f155\"}.icon-clip.sc-task-icon::before{content:\"\\f156\"}.icon-clipboard.sc-task-icon::before{content:\"\\f157\"}.icon-cloud.sc-task-icon::before{content:\"\\f15a\"}.icon-cloud-download.sc-task-icon::before{content:\"\\f158\"}.icon-cloud-upload.sc-task-icon::before{content:\"\\f159\"}.icon-code.sc-task-icon::before{content:\"\\f15c\"}.icon-code-block.sc-task-icon::before{content:\"\\f15b\"}.icon-cog.sc-task-icon::before{content:\"\\f15d\"}.icon-collapse-all.sc-task-icon::before{content:\"\\f15e\"}.icon-color-fill.sc-task-icon::before{content:\"\\f328\"}.icon-column-layout.sc-task-icon::before{content:\"\\f15f\"}.icon-comment.sc-task-icon::before{content:\"\\f160\"}.icon-comparison.sc-task-icon::before{content:\"\\f161\"}.icon-compass.sc-task-icon::before{content:\"\\f162\"}.icon-compressed.sc-task-icon::before{content:\"\\f163\"}.icon-confirm.sc-task-icon::before{content:\"\\f164\"}.icon-console.sc-task-icon::before{content:\"\\f165\"}.icon-contrast.sc-task-icon::before{content:\"\\f166\"}.icon-control.sc-task-icon::before{content:\"\\f167\"}.icon-credit-card.sc-task-icon::before{content:\"\\f168\"}.icon-cross.sc-task-icon::before{content:\"\\f169\"}.icon-cross-circle.sc-task-icon::before{content:\"\\f336\"}.icon-crown.sc-task-icon::before{content:\"\\f16a\"}.icon-cube.sc-task-icon::before{content:\"\\f16d\"}.icon-cube-add.sc-task-icon::before{content:\"\\f16b\"}.icon-cube-remove.sc-task-icon::before{content:\"\\f16c\"}.icon-curved-range-chart.sc-task-icon::before{content:\"\\f16e\"}.icon-cut.sc-task-icon::before{content:\"\\f16f\"}.icon-cycle.sc-task-icon::before{content:\"\\f170\"}.icon-dashboard.sc-task-icon::before{content:\"\\f171\"}.icon-data-connection.sc-task-icon::before{content:\"\\f172\"}.icon-data-lineage.sc-task-icon::before{content:\"\\f173\"}.icon-database.sc-task-icon::before{content:\"\\f174\"}.icon-delete.sc-task-icon::before{content:\"\\f175\"}.icon-delta.sc-task-icon::before{content:\"\\f176\"}.icon-derive-column.sc-task-icon::before{content:\"\\f177\"}.icon-desktop.sc-task-icon::before{content:\"\\f178\"}.icon-detection.sc-task-icon::before{content:\"\\f341\"}.icon-diagnosis.sc-task-icon::before{content:\"\\f179\"}.icon-diagram-tree.sc-task-icon::before{content:\"\\f17a\"}.icon-direction-left.sc-task-icon::before{content:\"\\f17b\"}.icon-direction-right.sc-task-icon::before{content:\"\\f17c\"}.icon-disable.sc-task-icon::before{content:\"\\f17d\"}.icon-divide.sc-task-icon::before{content:\"\\f327\"}.icon-document.sc-task-icon::before{content:\"\\f180\"}.icon-document-open.sc-task-icon::before{content:\"\\f17e\"}.icon-document-share.sc-task-icon::before{content:\"\\f17f\"}.icon-dollar.sc-task-icon::before{content:\"\\f181\"}.icon-dot.sc-task-icon::before{content:\"\\f182\"}.icon-double-caret-horizontal.sc-task-icon::before{content:\"\\f183\"}.icon-double-caret-vertical.sc-task-icon::before{content:\"\\f184\"}.icon-double-chevron-down.sc-task-icon::before{content:\"\\f185\"}.icon-double-chevron-left.sc-task-icon::before{content:\"\\f186\"}.icon-double-chevron-right.sc-task-icon::before{content:\"\\f187\"}.icon-double-chevron-up.sc-task-icon::before{content:\"\\f188\"}.icon-doughnut-chart.sc-task-icon::before{content:\"\\f189\"}.icon-download.sc-task-icon::before{content:\"\\f18a\"}.icon-drag-handle-horizontal.sc-task-icon::before{content:\"\\f18b\"}.icon-drag-handle-vertical.sc-task-icon::before{content:\"\\f18c\"}.icon-draw.sc-task-icon::before{content:\"\\f18d\"}.icon-drawer-left.sc-task-icon::before{content:\"\\f18f\"}.icon-drawer-left-filled.sc-task-icon::before{content:\"\\f18e\"}.icon-drawer-right.sc-task-icon::before{content:\"\\f191\"}.icon-drawer-right-filled.sc-task-icon::before{content:\"\\f190\"}.icon-drive-time.sc-task-icon::before{content:\"\\f192\"}.icon-duplicate.sc-task-icon::before{content:\"\\f193\"}.icon-edit.sc-task-icon::before{content:\"\\f194\"}.icon-eject.sc-task-icon::before{content:\"\\f195\"}.icon-emoji.sc-task-icon::before{content:\"\\f196\"}.icon-endorsed.sc-task-icon::before{content:\"\\f197\"}.icon-envelope.sc-task-icon::before{content:\"\\f198\"}.icon-equals.sc-task-icon::before{content:\"\\f199\"}.icon-eraser.sc-task-icon::before{content:\"\\f19a\"}.icon-error.sc-task-icon::before{content:\"\\f19b\"}.icon-euro.sc-task-icon::before{content:\"\\f19c\"}.icon-exchange.sc-task-icon::before{content:\"\\f19d\"}.icon-exclude-row.sc-task-icon::before{content:\"\\f19e\"}.icon-expand-all.sc-task-icon::before{content:\"\\f19f\"}.icon-export.sc-task-icon::before{content:\"\\f1a0\"}.icon-eye-off.sc-task-icon::before{content:\"\\f1a1\"}.icon-eye-on.sc-task-icon::before{content:\"\\f1a2\"}.icon-eye-open.sc-task-icon::before{content:\"\\f1a3\"}.icon-fast-backward.sc-task-icon::before{content:\"\\f1a4\"}.icon-fast-forward.sc-task-icon::before{content:\"\\f1a5\"}.icon-feed.sc-task-icon::before{content:\"\\f1a7\"}.icon-feed-subscribed.sc-task-icon::before{content:\"\\f1a6\"}.icon-film.sc-task-icon::before{content:\"\\f1a8\"}.icon-filter.sc-task-icon::before{content:\"\\f1ad\"}.icon-filter-keep.sc-task-icon::before{content:\"\\f1a9\"}.icon-filter-list.sc-task-icon::before{content:\"\\f1aa\"}.icon-filter-open.sc-task-icon::before{content:\"\\f1ab\"}.icon-filter-remove.sc-task-icon::before{content:\"\\f1ac\"}.icon-flag.sc-task-icon::before{content:\"\\f1ae\"}.icon-flame.sc-task-icon::before{content:\"\\f1af\"}.icon-flash.sc-task-icon::before{content:\"\\f1b0\"}.icon-floating-point.sc-task-icon::before{content:\"\\f32c\"}.icon-floppy-disk.sc-task-icon::before{content:\"\\f1b1\"}.icon-flow-branch.sc-task-icon::before{content:\"\\f1b2\"}.icon-flow-end.sc-task-icon::before{content:\"\\f1b3\"}.icon-flow-linear.sc-task-icon::before{content:\"\\f1b4\"}.icon-flow-review.sc-task-icon::before{content:\"\\f1b6\"}.icon-flow-review-branch.sc-task-icon::before{content:\"\\f1b5\"}.icon-flows.sc-task-icon::before{content:\"\\f1b7\"}.icon-folder-close.sc-task-icon::before{content:\"\\f1b8\"}.icon-folder-new.sc-task-icon::before{content:\"\\f1b9\"}.icon-folder-open.sc-task-icon::before{content:\"\\f1ba\"}.icon-folder-shared.sc-task-icon::before{content:\"\\f1bc\"}.icon-folder-shared-open.sc-task-icon::before{content:\"\\f1bb\"}.icon-follower.sc-task-icon::before{content:\"\\f1bd\"}.icon-following.sc-task-icon::before{content:\"\\f1be\"}.icon-font.sc-task-icon::before{content:\"\\f1bf\"}.icon-fork.sc-task-icon::before{content:\"\\f1c0\"}.icon-form.sc-task-icon::before{content:\"\\f1c1\"}.icon-fuel.sc-task-icon::before{content:\"\\f323\"}.icon-full-circle.sc-task-icon::before{content:\"\\f1c2\"}.icon-full-stacked-chart.sc-task-icon::before{content:\"\\f1c3\"}.icon-fullscreen.sc-task-icon::before{content:\"\\f1c4\"}.icon-function.sc-task-icon::before{content:\"\\f1c5\"}.icon-gantt-chart.sc-task-icon::before{content:\"\\f1c6\"}.icon-geofence.sc-task-icon::before{content:\"\\f1c7\"}.icon-geolocation.sc-task-icon::before{content:\"\\f1c8\"}.icon-geosearch.sc-task-icon::before{content:\"\\f1c9\"}.icon-git-branch.sc-task-icon::before{content:\"\\f1ca\"}.icon-git-commit.sc-task-icon::before{content:\"\\f1cb\"}.icon-git-merge.sc-task-icon::before{content:\"\\f1cc\"}.icon-git-new-branch.sc-task-icon::before{content:\"\\f1cd\"}.icon-git-pull.sc-task-icon::before{content:\"\\f1ce\"}.icon-git-push.sc-task-icon::before{content:\"\\f1cf\"}.icon-git-repo.sc-task-icon::before{content:\"\\f1d0\"}.icon-glass.sc-task-icon::before{content:\"\\f1d1\"}.icon-globe.sc-task-icon::before{content:\"\\f1d3\"}.icon-globe-network.sc-task-icon::before{content:\"\\f1d2\"}.icon-graph.sc-task-icon::before{content:\"\\f1d5\"}.icon-graph-remove.sc-task-icon::before{content:\"\\f1d4\"}.icon-greater-than.sc-task-icon::before{content:\"\\f1d7\"}.icon-greater-than-or-equal-to.sc-task-icon::before{content:\"\\f1d6\"}.icon-grid.sc-task-icon::before{content:\"\\f1d9\"}.icon-grid-view.sc-task-icon::before{content:\"\\f1d8\"}.icon-group-objects.sc-task-icon::before{content:\"\\f1da\"}.icon-grouped-bar-chart.sc-task-icon::before{content:\"\\f1db\"}.icon-hand.sc-task-icon::before{content:\"\\f1e0\"}.icon-hand-down.sc-task-icon::before{content:\"\\f1dc\"}.icon-hand-left.sc-task-icon::before{content:\"\\f1dd\"}.icon-hand-right.sc-task-icon::before{content:\"\\f1de\"}.icon-hand-up.sc-task-icon::before{content:\"\\f1df\"}.icon-hat.sc-task-icon::before{content:\"\\f1e1\"}.icon-header.sc-task-icon::before{content:\"\\f1e5\"}.icon-header-one.sc-task-icon::before{content:\"\\f1e2\"}.icon-header-three.sc-task-icon::before{content:\"\\f1e3\"}.icon-header-two.sc-task-icon::before{content:\"\\f1e4\"}.icon-headset.sc-task-icon::before{content:\"\\f1e6\"}.icon-heart.sc-task-icon::before{content:\"\\f1e8\"}.icon-heart-broken.sc-task-icon::before{content:\"\\f1e7\"}.icon-heat-grid.sc-task-icon::before{content:\"\\f1e9\"}.icon-heatmap.sc-task-icon::before{content:\"\\f1ea\"}.icon-helicopter.sc-task-icon::before{content:\"\\f1eb\"}.icon-help.sc-task-icon::before{content:\"\\f1ec\"}.icon-helper-management.sc-task-icon::before{content:\"\\f1ed\"}.icon-high-priority.sc-task-icon::before{content:\"\\f1ee\"}.icon-high-voltage-pole.sc-task-icon::before{content:\"\\f333\"}.icon-highlight.sc-task-icon::before{content:\"\\f1ef\"}.icon-history.sc-task-icon::before{content:\"\\f1f0\"}.icon-home.sc-task-icon::before{content:\"\\f1f1\"}.icon-horizontal-bar-chart.sc-task-icon::before{content:\"\\f1f4\"}.icon-horizontal-bar-chart-asc.sc-task-icon::before{content:\"\\f1f2\"}.icon-horizontal-bar-chart-desc.sc-task-icon::before{content:\"\\f1f3\"}.icon-horizontal-distribution.sc-task-icon::before{content:\"\\f1f5\"}.icon-horizontal-inbetween.sc-task-icon::before{content:\"\\f329\"}.icon-hurricane.sc-task-icon::before{content:\"\\f1f6\"}.icon-id-number.sc-task-icon::before{content:\"\\f1f7\"}.icon-image-rotate-left.sc-task-icon::before{content:\"\\f1f8\"}.icon-image-rotate-right.sc-task-icon::before{content:\"\\f1f9\"}.icon-import.sc-task-icon::before{content:\"\\f1fa\"}.icon-inbox.sc-task-icon::before{content:\"\\f1ff\"}.icon-inbox-filtered.sc-task-icon::before{content:\"\\f1fb\"}.icon-inbox-geo.sc-task-icon::before{content:\"\\f1fc\"}.icon-inbox-search.sc-task-icon::before{content:\"\\f1fd\"}.icon-inbox-update.sc-task-icon::before{content:\"\\f1fe\"}.icon-info-sign.sc-task-icon::before{content:\"\\f200\"}.icon-inheritance.sc-task-icon::before{content:\"\\f201\"}.icon-inherited-group.sc-task-icon::before{content:\"\\f202\"}.icon-inner-join.sc-task-icon::before{content:\"\\f203\"}.icon-insert.sc-task-icon::before{content:\"\\f204\"}.icon-intelligence.sc-task-icon::before{content:\"\\f337\"}.icon-intersection.sc-task-icon::before{content:\"\\f205\"}.icon-ip-address.sc-task-icon::before{content:\"\\f206\"}.icon-issue.sc-task-icon::before{content:\"\\f209\"}.icon-issue-closed.sc-task-icon::before{content:\"\\f207\"}.icon-issue-new.sc-task-icon::before{content:\"\\f208\"}.icon-italic.sc-task-icon::before{content:\"\\f20a\"}.icon-join-table.sc-task-icon::before{content:\"\\f20b\"}.icon-key.sc-task-icon::before{content:\"\\f215\"}.icon-key-backspace.sc-task-icon::before{content:\"\\f20c\"}.icon-key-command.sc-task-icon::before{content:\"\\f20d\"}.icon-key-control.sc-task-icon::before{content:\"\\f20e\"}.icon-key-delete.sc-task-icon::before{content:\"\\f20f\"}.icon-key-enter.sc-task-icon::before{content:\"\\f210\"}.icon-key-escape.sc-task-icon::before{content:\"\\f211\"}.icon-key-option.sc-task-icon::before{content:\"\\f212\"}.icon-key-shift.sc-task-icon::before{content:\"\\f213\"}.icon-key-tab.sc-task-icon::before{content:\"\\f214\"}.icon-known-vehicle.sc-task-icon::before{content:\"\\f216\"}.icon-lab-test.sc-task-icon::before{content:\"\\f217\"}.icon-label.sc-task-icon::before{content:\"\\f218\"}.icon-layer.sc-task-icon::before{content:\"\\f21a\"}.icon-layer-outline.sc-task-icon::before{content:\"\\f219\"}.icon-layers.sc-task-icon::before{content:\"\\f21b\"}.icon-layout.sc-task-icon::before{content:\"\\f225\"}.icon-layout-auto.sc-task-icon::before{content:\"\\f21c\"}.icon-layout-balloon.sc-task-icon::before{content:\"\\f21d\"}.icon-layout-circle.sc-task-icon::before{content:\"\\f21e\"}.icon-layout-grid.sc-task-icon::before{content:\"\\f21f\"}.icon-layout-group-by.sc-task-icon::before{content:\"\\f220\"}.icon-layout-hierarchy.sc-task-icon::before{content:\"\\f221\"}.icon-layout-linear.sc-task-icon::before{content:\"\\f222\"}.icon-layout-skew-grid.sc-task-icon::before{content:\"\\f223\"}.icon-layout-sorted-clusters.sc-task-icon::before{content:\"\\f224\"}.icon-learning.sc-task-icon::before{content:\"\\f226\"}.icon-left-join.sc-task-icon::before{content:\"\\f227\"}.icon-lengthen-text.sc-task-icon::before{content:\"\\f33e\"}.icon-less-than.sc-task-icon::before{content:\"\\f229\"}.icon-less-than-or-equal-to.sc-task-icon::before{content:\"\\f228\"}.icon-lifesaver.sc-task-icon::before{content:\"\\f22a\"}.icon-lightbulb.sc-task-icon::before{content:\"\\f22b\"}.icon-lightning.sc-task-icon::before{content:\"\\f22c\"}.icon-link.sc-task-icon::before{content:\"\\f22d\"}.icon-list.sc-task-icon::before{content:\"\\f230\"}.icon-list-columns.sc-task-icon::before{content:\"\\f22e\"}.icon-list-detail-view.sc-task-icon::before{content:\"\\f22f\"}.icon-locate.sc-task-icon::before{content:\"\\f231\"}.icon-lock.sc-task-icon::before{content:\"\\f232\"}.icon-locomotive.sc-task-icon::before{content:\"\\f33b\"}.icon-log-in.sc-task-icon::before{content:\"\\f233\"}.icon-log-out.sc-task-icon::before{content:\"\\f234\"}.icon-low-voltage-pole.sc-task-icon::before{content:\"\\f332\"}.icon-manual.sc-task-icon::before{content:\"\\f235\"}.icon-manually-entered-data.sc-task-icon::before{content:\"\\f236\"}.icon-many-to-many.sc-task-icon::before{content:\"\\f237\"}.icon-many-to-one.sc-task-icon::before{content:\"\\f238\"}.icon-map.sc-task-icon::before{content:\"\\f23b\"}.icon-map-create.sc-task-icon::before{content:\"\\f239\"}.icon-map-marker.sc-task-icon::before{content:\"\\f23a\"}.icon-maximize.sc-task-icon::before{content:\"\\f23c\"}.icon-media.sc-task-icon::before{content:\"\\f23d\"}.icon-menu.sc-task-icon::before{content:\"\\f240\"}.icon-menu-closed.sc-task-icon::before{content:\"\\f23e\"}.icon-menu-open.sc-task-icon::before{content:\"\\f23f\"}.icon-merge-columns.sc-task-icon::before{content:\"\\f241\"}.icon-merge-links.sc-task-icon::before{content:\"\\f242\"}.icon-microphone.sc-task-icon::before{content:\"\\f343\"}.icon-minimize.sc-task-icon::before{content:\"\\f243\"}.icon-minus.sc-task-icon::before{content:\"\\f244\"}.icon-mobile-phone.sc-task-icon::before{content:\"\\f245\"}.icon-mobile-video.sc-task-icon::before{content:\"\\f246\"}.icon-modal.sc-task-icon::before{content:\"\\f248\"}.icon-modal-filled.sc-task-icon::before{content:\"\\f247\"}.icon-model.sc-task-icon::before{content:\"\\f33d\"}.icon-moon.sc-task-icon::before{content:\"\\f249\"}.icon-more.sc-task-icon::before{content:\"\\f24a\"}.icon-mountain.sc-task-icon::before{content:\"\\f24b\"}.icon-move.sc-task-icon::before{content:\"\\f24c\"}.icon-mugshot.sc-task-icon::before{content:\"\\f24d\"}.icon-multi-select.sc-task-icon::before{content:\"\\f24e\"}.icon-music.sc-task-icon::before{content:\"\\f24f\"}.icon-nest.sc-task-icon::before{content:\"\\f250\"}.icon-new-drawing.sc-task-icon::before{content:\"\\f251\"}.icon-new-grid-item.sc-task-icon::before{content:\"\\f252\"}.icon-new-layer.sc-task-icon::before{content:\"\\f253\"}.icon-new-layers.sc-task-icon::before{content:\"\\f254\"}.icon-new-link.sc-task-icon::before{content:\"\\f255\"}.icon-new-object.sc-task-icon::before{content:\"\\f256\"}.icon-new-person.sc-task-icon::before{content:\"\\f257\"}.icon-new-prescription.sc-task-icon::before{content:\"\\f258\"}.icon-new-text-box.sc-task-icon::before{content:\"\\f259\"}.icon-ninja.sc-task-icon::before{content:\"\\f25a\"}.icon-not-equal-to.sc-task-icon::before{content:\"\\f25b\"}.icon-notifications.sc-task-icon::before{content:\"\\f25e\"}.icon-notifications-snooze.sc-task-icon::before{content:\"\\f25c\"}.icon-notifications-updated.sc-task-icon::before{content:\"\\f25d\"}.icon-numbered-list.sc-task-icon::before{content:\"\\f25f\"}.icon-numerical.sc-task-icon::before{content:\"\\f260\"}.icon-office.sc-task-icon::before{content:\"\\f261\"}.icon-offline.sc-task-icon::before{content:\"\\f262\"}.icon-oil-field.sc-task-icon::before{content:\"\\f263\"}.icon-one-column.sc-task-icon::before{content:\"\\f264\"}.icon-one-to-many.sc-task-icon::before{content:\"\\f265\"}.icon-one-to-one.sc-task-icon::before{content:\"\\f266\"}.icon-open-application.sc-task-icon::before{content:\"\\f32b\"}.icon-outdated.sc-task-icon::before{content:\"\\f267\"}.icon-page-layout.sc-task-icon::before{content:\"\\f268\"}.icon-panel-stats.sc-task-icon::before{content:\"\\f269\"}.icon-panel-table.sc-task-icon::before{content:\"\\f26a\"}.icon-paperclip.sc-task-icon::before{content:\"\\f26b\"}.icon-paragraph.sc-task-icon::before{content:\"\\f26c\"}.icon-path.sc-task-icon::before{content:\"\\f26e\"}.icon-path-search.sc-task-icon::before{content:\"\\f26d\"}.icon-pause.sc-task-icon::before{content:\"\\f26f\"}.icon-people.sc-task-icon::before{content:\"\\f270\"}.icon-percentage.sc-task-icon::before{content:\"\\f271\"}.icon-person.sc-task-icon::before{content:\"\\f272\"}.icon-phone.sc-task-icon::before{content:\"\\f273\"}.icon-pie-chart.sc-task-icon::before{content:\"\\f274\"}.icon-pin.sc-task-icon::before{content:\"\\f275\"}.icon-pivot.sc-task-icon::before{content:\"\\f277\"}.icon-pivot-table.sc-task-icon::before{content:\"\\f276\"}.icon-play.sc-task-icon::before{content:\"\\f278\"}.icon-playbook.sc-task-icon::before{content:\"\\f324\"}.icon-plus.sc-task-icon::before{content:\"\\f279\"}.icon-polygon-filter.sc-task-icon::before{content:\"\\f27a\"}.icon-power.sc-task-icon::before{content:\"\\f27b\"}.icon-predictive-analysis.sc-task-icon::before{content:\"\\f27c\"}.icon-prescription.sc-task-icon::before{content:\"\\f27d\"}.icon-presentation.sc-task-icon::before{content:\"\\f27e\"}.icon-print.sc-task-icon::before{content:\"\\f27f\"}.icon-projects.sc-task-icon::before{content:\"\\f280\"}.icon-properties.sc-task-icon::before{content:\"\\f281\"}.icon-property.sc-task-icon::before{content:\"\\f282\"}.icon-publish-function.sc-task-icon::before{content:\"\\f283\"}.icon-pulse.sc-task-icon::before{content:\"\\f284\"}.icon-rain.sc-task-icon::before{content:\"\\f285\"}.icon-random.sc-task-icon::before{content:\"\\f286\"}.icon-record.sc-task-icon::before{content:\"\\f287\"}.icon-rect-height.sc-task-icon::before{content:\"\\f325\"}.icon-rect-width.sc-task-icon::before{content:\"\\f326\"}.icon-rectangle.sc-task-icon::before{content:\"\\f321\"}.icon-redo.sc-task-icon::before{content:\"\\f288\"}.icon-refresh.sc-task-icon::before{content:\"\\f289\"}.icon-regex.sc-task-icon::before{content:\"\\f32f\"}.icon-regression-chart.sc-task-icon::before{content:\"\\f28a\"}.icon-remove.sc-task-icon::before{content:\"\\f290\"}.icon-remove-column.sc-task-icon::before{content:\"\\f28d\"}.icon-remove-column-left.sc-task-icon::before{content:\"\\f28b\"}.icon-remove-column-right.sc-task-icon::before{content:\"\\f28c\"}.icon-remove-row-bottom.sc-task-icon::before{content:\"\\f28e\"}.icon-remove-row-top.sc-task-icon::before{content:\"\\f28f\"}.icon-repeat.sc-task-icon::before{content:\"\\f291\"}.icon-reset.sc-task-icon::before{content:\"\\f292\"}.icon-resolve.sc-task-icon::before{content:\"\\f293\"}.icon-rig.sc-task-icon::before{content:\"\\f294\"}.icon-right-join.sc-task-icon::before{content:\"\\f295\"}.icon-ring.sc-task-icon::before{content:\"\\f296\"}.icon-rocket.sc-task-icon::before{content:\"\\f298\"}.icon-rocket-slant.sc-task-icon::before{content:\"\\f297\"}.icon-rotate-document.sc-task-icon::before{content:\"\\f299\"}.icon-rotate-page.sc-task-icon::before{content:\"\\f29a\"}.icon-route.sc-task-icon::before{content:\"\\f29b\"}.icon-satellite.sc-task-icon::before{content:\"\\f29c\"}.icon-saved.sc-task-icon::before{content:\"\\f29d\"}.icon-scatter-plot.sc-task-icon::before{content:\"\\f29e\"}.icon-search.sc-task-icon::before{content:\"\\f2a2\"}.icon-search-around.sc-task-icon::before{content:\"\\f29f\"}.icon-search-template.sc-task-icon::before{content:\"\\f2a0\"}.icon-search-text.sc-task-icon::before{content:\"\\f2a1\"}.icon-segmented-control.sc-task-icon::before{content:\"\\f2a3\"}.icon-select.sc-task-icon::before{content:\"\\f2a4\"}.icon-selection.sc-task-icon::before{content:\"\\f2a5\"}.icon-send-message.sc-task-icon::before{content:\"\\f2a6\"}.icon-send-to.sc-task-icon::before{content:\"\\f2a9\"}.icon-send-to-graph.sc-task-icon::before{content:\"\\f2a7\"}.icon-send-to-map.sc-task-icon::before{content:\"\\f2a8\"}.icon-sensor.sc-task-icon::before{content:\"\\f33c\"}.icon-series-add.sc-task-icon::before{content:\"\\f2aa\"}.icon-series-configuration.sc-task-icon::before{content:\"\\f2ab\"}.icon-series-derived.sc-task-icon::before{content:\"\\f2ac\"}.icon-series-filtered.sc-task-icon::before{content:\"\\f2ad\"}.icon-series-search.sc-task-icon::before{content:\"\\f2ae\"}.icon-settings.sc-task-icon::before{content:\"\\f2af\"}.icon-shapes.sc-task-icon::before{content:\"\\f2b0\"}.icon-share.sc-task-icon::before{content:\"\\f2b1\"}.icon-shared-filter.sc-task-icon::before{content:\"\\f2b2\"}.icon-shield.sc-task-icon::before{content:\"\\f2b3\"}.icon-ship.sc-task-icon::before{content:\"\\f2b4\"}.icon-shop.sc-task-icon::before{content:\"\\f2b5\"}.icon-shopping-cart.sc-task-icon::before{content:\"\\f2b6\"}.icon-shorten-text.sc-task-icon::before{content:\"\\f33f\"}.icon-signal-search.sc-task-icon::before{content:\"\\f2b7\"}.icon-sim-card.sc-task-icon::before{content:\"\\f2b8\"}.icon-slash.sc-task-icon::before{content:\"\\f2b9\"}.icon-small-cross.sc-task-icon::before{content:\"\\f2ba\"}.icon-small-info-sign.sc-task-icon::before{content:\"\\f334\"}.icon-small-minus.sc-task-icon::before{content:\"\\f2bb\"}.icon-small-plus.sc-task-icon::before{content:\"\\f2bc\"}.icon-small-square.sc-task-icon::before{content:\"\\f2bd\"}.icon-small-tick.sc-task-icon::before{content:\"\\f2be\"}.icon-snowflake.sc-task-icon::before{content:\"\\f2bf\"}.icon-social-media.sc-task-icon::before{content:\"\\f2c0\"}.icon-sort.sc-task-icon::before{content:\"\\f2c7\"}.icon-sort-alphabetical.sc-task-icon::before{content:\"\\f2c2\"}.icon-sort-alphabetical-desc.sc-task-icon::before{content:\"\\f2c1\"}.icon-sort-asc.sc-task-icon::before{content:\"\\f2c3\"}.icon-sort-desc.sc-task-icon::before{content:\"\\f2c4\"}.icon-sort-numerical.sc-task-icon::before{content:\"\\f2c6\"}.icon-sort-numerical-desc.sc-task-icon::before{content:\"\\f2c5\"}.icon-spell-check.sc-task-icon::before{content:\"\\f340\"}.icon-split-columns.sc-task-icon::before{content:\"\\f2c8\"}.icon-square.sc-task-icon::before{content:\"\\f2c9\"}.icon-stacked-chart.sc-task-icon::before{content:\"\\f2ca\"}.icon-stadium-geometry.sc-task-icon::before{content:\"\\f2cb\"}.icon-star.sc-task-icon::before{content:\"\\f2cd\"}.icon-star-empty.sc-task-icon::before{content:\"\\f2cc\"}.icon-step-backward.sc-task-icon::before{content:\"\\f2ce\"}.icon-step-chart.sc-task-icon::before{content:\"\\f2cf\"}.icon-step-forward.sc-task-icon::before{content:\"\\f2d0\"}.icon-stop.sc-task-icon::before{content:\"\\f2d1\"}.icon-stopwatch.sc-task-icon::before{content:\"\\f2d2\"}.icon-strikethrough.sc-task-icon::before{content:\"\\f2d3\"}.icon-style.sc-task-icon::before{content:\"\\f2d4\"}.icon-subscript.sc-task-icon::before{content:\"\\f339\"}.icon-superscript.sc-task-icon::before{content:\"\\f33a\"}.icon-swap-horizontal.sc-task-icon::before{content:\"\\f2d5\"}.icon-swap-vertical.sc-task-icon::before{content:\"\\f2d6\"}.icon-switch.sc-task-icon::before{content:\"\\f2d7\"}.icon-symbol-circle.sc-task-icon::before{content:\"\\f2d8\"}.icon-symbol-cross.sc-task-icon::before{content:\"\\f2d9\"}.icon-symbol-diamond.sc-task-icon::before{content:\"\\f2da\"}.icon-symbol-rectangle.sc-task-icon::before{content:\"\\f322\"}.icon-symbol-square.sc-task-icon::before{content:\"\\f2db\"}.icon-symbol-triangle-down.sc-task-icon::before{content:\"\\f2dc\"}.icon-symbol-triangle-up.sc-task-icon::before{content:\"\\f2dd\"}.icon-syringe.sc-task-icon::before{content:\"\\f2de\"}.icon-tag.sc-task-icon::before{content:\"\\f2df\"}.icon-take-action.sc-task-icon::before{content:\"\\f2e0\"}.icon-tank.sc-task-icon::before{content:\"\\f2e1\"}.icon-target.sc-task-icon::before{content:\"\\f2e2\"}.icon-taxi.sc-task-icon::before{content:\"\\f2e3\"}.icon-temperature.sc-task-icon::before{content:\"\\f2e4\"}.icon-text-highlight.sc-task-icon::before{content:\"\\f2e5\"}.icon-th.sc-task-icon::before{content:\"\\f2ea\"}.icon-th-derived.sc-task-icon::before{content:\"\\f2e6\"}.icon-th-disconnect.sc-task-icon::before{content:\"\\f2e7\"}.icon-th-filtered.sc-task-icon::before{content:\"\\f2e8\"}.icon-th-list.sc-task-icon::before{content:\"\\f2e9\"}.icon-third-party.sc-task-icon::before{content:\"\\f2eb\"}.icon-thumbs-down.sc-task-icon::before{content:\"\\f2ec\"}.icon-thumbs-up.sc-task-icon::before{content:\"\\f2ed\"}.icon-tick.sc-task-icon::before{content:\"\\f2ef\"}.icon-tick-circle.sc-task-icon::before{content:\"\\f2ee\"}.icon-time.sc-task-icon::before{content:\"\\f2f0\"}.icon-timeline-area-chart.sc-task-icon::before{content:\"\\f2f1\"}.icon-timeline-bar-chart.sc-task-icon::before{content:\"\\f2f2\"}.icon-timeline-events.sc-task-icon::before{content:\"\\f2f3\"}.icon-timeline-line-chart.sc-task-icon::before{content:\"\\f2f4\"}.icon-tint.sc-task-icon::before{content:\"\\f2f5\"}.icon-torch.sc-task-icon::before{content:\"\\f2f6\"}.icon-tractor.sc-task-icon::before{content:\"\\f2f7\"}.icon-train.sc-task-icon::before{content:\"\\f2f8\"}.icon-translate.sc-task-icon::before{content:\"\\f2f9\"}.icon-trash.sc-task-icon::before{content:\"\\f2fa\"}.icon-tree.sc-task-icon::before{content:\"\\f2fb\"}.icon-trending-down.sc-task-icon::before{content:\"\\f2fc\"}.icon-trending-up.sc-task-icon::before{content:\"\\f2fd\"}.icon-truck.sc-task-icon::before{content:\"\\f2fe\"}.icon-two-columns.sc-task-icon::before{content:\"\\f2ff\"}.icon-unarchive.sc-task-icon::before{content:\"\\f300\"}.icon-underline.sc-task-icon::before{content:\"\\f301\"}.icon-undo.sc-task-icon::before{content:\"\\f302\"}.icon-ungroup-objects.sc-task-icon::before{content:\"\\f303\"}.icon-unknown-vehicle.sc-task-icon::before{content:\"\\f304\"}.icon-unlock.sc-task-icon::before{content:\"\\f305\"}.icon-unpin.sc-task-icon::before{content:\"\\f306\"}.icon-unresolve.sc-task-icon::before{content:\"\\f307\"}.icon-updated.sc-task-icon::before{content:\"\\f308\"}.icon-upload.sc-task-icon::before{content:\"\\f309\"}.icon-user.sc-task-icon::before{content:\"\\f30a\"}.icon-variable.sc-task-icon::before{content:\"\\f30b\"}.icon-vertical-bar-chart-asc.sc-task-icon::before{content:\"\\f30c\"}.icon-vertical-bar-chart-desc.sc-task-icon::before{content:\"\\f30d\"}.icon-vertical-distribution.sc-task-icon::before{content:\"\\f30e\"}.icon-vertical-inbetween.sc-task-icon::before{content:\"\\f32a\"}.icon-video.sc-task-icon::before{content:\"\\f30f\"}.icon-virus.sc-task-icon::before{content:\"\\f310\"}.icon-volume-down.sc-task-icon::before{content:\"\\f311\"}.icon-volume-off.sc-task-icon::before{content:\"\\f312\"}.icon-volume-up.sc-task-icon::before{content:\"\\f313\"}.icon-walk.sc-task-icon::before{content:\"\\f314\"}.icon-warning-sign.sc-task-icon::before{content:\"\\f315\"}.icon-waterfall-chart.sc-task-icon::before{content:\"\\f316\"}.icon-waves.sc-task-icon::before{content:\"\\f317\"}.icon-widget.sc-task-icon::before{content:\"\\f31b\"}.icon-widget-button.sc-task-icon::before{content:\"\\f318\"}.icon-widget-footer.sc-task-icon::before{content:\"\\f319\"}.icon-widget-header.sc-task-icon::before{content:\"\\f31a\"}.icon-wind.sc-task-icon::before{content:\"\\f31c\"}.icon-wrench.sc-task-icon::before{content:\"\\f31d\"}.icon-zoom-in.sc-task-icon::before{content:\"\\f31e\"}.icon-zoom-out.sc-task-icon::before{content:\"\\f31f\"}.icon-zoom-to-fit.sc-task-icon::before{content:\"\\f320\"}.sc-task-icon-h{display:inline-block;color:inherit;-ms-flex:0 0 auto;flex:0 0 auto;vertical-align:text-bottom}@font-face{font-family:\"blueprint-icons-16\";src:url(\"/assets/blueprint-icons-16.woff2\") format(\"woff2\")}@font-face{font-family:\"blueprint-icons-20\";src:url(\"/assets/blueprint-icons-20.woff2\") format(\"woff2\")}.icon.sc-task-icon:not(:empty)::before{content:\"\" !important;content:unset !important}.icon.sc-task-icon>svg.sc-task-icon{display:block}.icon.sc-task-icon>svg.sc-task-icon:not([fill]){fill:currentcolor}span.icon-standard.sc-task-icon{font-family:\"blueprint-icons-16\", sans-serif;font-size:16px;font-style:normal;font-variant:normal;font-weight:400;height:16px;line-height:1;width:16px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;display:inline-block}span.icon-large.sc-task-icon{font-family:\"blueprint-icons-20\", sans-serif;font-size:20px;font-style:normal;font-variant:normal;font-weight:400;height:20px;line-height:1;width:20px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;display:inline-block}span.icon_.sc-task-icon:empty{font-family:\"blueprint-icons-20\";font-size:inherit;font-style:normal;font-weight:400;line-height:1}span.icon_.sc-task-icon:empty::before{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}";
const TaskIconStyle0 = taskIconCss;

const STANDARD = 16;
const LARGE = 20;
const TaskIcon = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.icon = "blank";
        this.size = STANDARD;
    }
    iconSVG() {
        const pathSize = this.size < LARGE ? STANDARD : LARGE;
        return index.h("svg", { "data-icon": this.icon, height: this.size, width: this.size, role: "img", viewBox: `0 0 ${pathSize} ${pathSize}` }, icons[this.icon][pathSize].map(p => index.h("path", { d: p, "fill-rule": "evenodd" })));
    }
    iconFont() {
        const sizeClass = this.size < LARGE ? "icon-standard" : "icon-large";
        const classes = inputBase.classNames(sizeClass, `icon-${this.icon}`);
        let style = {};
        if (![16, 20].includes(this.size)) {
            const size = `${this.size}px`;
            style = {
                "font-size": size,
                height: size,
                width: size
            };
        }
        return index.h("span", { class: classes, style: style });
    }
    render() {
        return (
        // TODO: Figure out why this size override is necessary
        index.h(index.Host, { key: '01ffd92d301c600e799fe95a69ca42f9b7e00244', class: "icon", style: { height: `${this.size}px` } }, this.icon in icons ? this.iconSVG() : this.iconFont()));
    }
};
TaskIcon.style = TaskIconStyle0;

const taskInfoPaneCss = ".sc-task-info-pane-h{display:block;padding:6px;-ms-flex:0 0 280px;flex:0 0 280px;overflow-y:auto}";
const TaskInfoPaneStyle0 = taskInfoPaneCss;

const TaskInfoPane = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.width = undefined;
    }
    hostStyle() {
        if (this.width) {
            return { flex: `0 0 ${this.width}px` };
        }
        else {
            return {};
        }
    }
    render() {
        return (index.h(index.Host, { key: '09488647246b90dc2308925c43cedc83a4a69a97', style: this.hostStyle() }, index.h("slot", { key: 'd47730a267a8daba7e8e17396789950bf3200ebb' })));
    }
};
TaskInfoPane.style = TaskInfoPaneStyle0;

const taskInfoSectionCss = ".sc-task-info-section-h{display:block;margin-bottom:0;border-bottom:2px solid black;padding:16px 0}.sc-task-info-section-h:last-of-type{margin-bottom:0;border-bottom:none}.sc-task-info-section-h p.sc-task-info-section{line-height:1.4rem}.header.sc-task-info-section{font-weight:bold;font-size:medium;margin-bottom:0.5rem}";
const TaskInfoSectionStyle0 = taskInfoSectionCss;

const TaskInfoSection = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.header = undefined;
    }
    render() {
        return (index.h(index.Host, { key: 'daa2fa98908d302383a22d0bc5c051336fa96ea4' }, this.header && index.h("div", { key: 'b286729d1bb135724c283a7e7faf1ee85f1c95be', class: "header" }, this.header), index.h("slot", { key: '4f4b80d54c61cbae8b36afb1fb444a845248772b' })));
    }
};
TaskInfoSection.style = TaskInfoSectionStyle0;

const taskInputOptionCss = ".sc-task-input-option-h{display:none}";
const TaskInputOptionStyle0 = taskInputOptionCss;

const TaskInputOption = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.value = undefined;
        this.tooltip = undefined;
        this.keyboardShortcut = undefined;
        this.keyboardShortcutLabel = undefined;
    }
    render() {
        return (index.h(index.Host, { key: '3c20abb2c62d3c6c6896d43f6a416e71ba1093f4' }));
    }
};
TaskInputOption.style = TaskInputOptionStyle0;

const taskInputRadioCss = ".sc-task-input-radio-h{display:block;margin-bottom:0.5rem}label.sc-task-input-radio{cursor:pointer;display:block;margin-bottom:10px;position:relative;text-transform:none}label.sc-task-input-radio:not(.button){padding-left:26px}label.inline.sc-task-input-radio{display:inline-block;margin-right:20px}input.sc-task-input-radio{left:0;opacity:0;position:absolute;top:0;z-index:-1}.indicator.sc-task-input-radio{margin-left:-26px;background-clip:padding-box;background-color:transparent;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));border:none;-webkit-box-shadow:inset 0 0 0 1px #738091;box-shadow:inset 0 0 0 1px #738091;cursor:pointer;display:inline-block;font-size:16px;height:1em;margin-right:10px;margin-top:-3px;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:middle;width:1em;text-transform:none;border-radius:50%}label.sc-task-input-radio input.sc-task-input-radio:checked~.indicator.sc-task-input-radio{background-color:#2d72d2;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2);color:#fff}.indicator.sc-task-input-radio::before{content:\"\";display:block;height:1em;width:1em}label.sc-task-input-radio input.sc-task-input-radio:checked~.indicator.sc-task-input-radio::before{background-image:radial-gradient(#fff, #fff 28%, transparent 32%)}.content.sc-task-input-radio{display:initial}.content.inline.sc-task-input-radio{display:inline-block}.content.sc-task-input-radio .tooltipText.sc-task-input-radio{visibility:hidden;width:180px;background-color:black;color:#fff;text-align:center;padding:12px;border-radius:6px;position:absolute;top:20px;z-index:100}.content.sc-task-input-radio:hover .tooltipText.sc-task-input-radio{visibility:visible}";
const TaskInputRadioStyle0 = taskInputRadioCss;

const TaskInputRadio = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.inputUpdated = index.createEvent(this, "inputUpdated", 7);
        this.registerKeyboardShortcut = index.createEvent(this, "registerKeyboardShortcut", 7);
        this.shortcutMap = new Map();
        this.disconnectedCallback = inputBase.InputBase.prototype.disconnectedCallback;
        this.formUpdated = inputBase.InputBase.prototype.formUpdated;
        this.setupDependentInputs = inputBase.InputBase.prototype.setupDependentInputs;
        this.handleParentElementUpdate = inputBase.InputBase.prototype.handleParentElementUpdate;
        this.fromInputUpdated = inputBase.InputBase.prototype.fromInputUpdated.bind(this);
        this.hasAnswerToValidate = () => {
            // TODO: Review why this is different from the others
            return this.answer && this.answerCorrection && true;
        };
        this.name = undefined;
        this.label = undefined;
        this.labelClass = undefined;
        this.required = undefined;
        this.active = undefined;
        this.disabled = undefined;
        this.disableIf = undefined;
        this.requireIf = undefined;
        this.requiredIndicator = undefined;
        this.displayOn = undefined;
        this.displayIf = undefined;
        this.value = undefined;
        this.valueFrom = undefined;
        this.hidden = undefined;
        this.preventChanges = undefined;
        this.answer = undefined;
        this.answerCorrection = undefined;
        this.mode = "radio";
        this.inline = undefined;
        this.answerTag = "Answer";
    }
    connectedCallback() {
        inputBase.InputBase.prototype.connectedCallback.bind(this)();
    }
    async readyToSubmit() { return inputBase.InputBase.prototype.readyToSubmit.bind(this)(); }
    async setShowCorrections() { return inputBase.InputBase.prototype.setShowCorrections.bind(this)(); }
    componentWillLoad() {
        inputBase.InputBase.prototype.componentWillLoad.bind(this)();
        this.options = utils.gatherInputOptions(this.host);
        for (let ks of utils.inputOptionKeyboardShortcuts(this.options)) {
            this.shortcutMap[ks.keys] = ks.value;
            this.registerKeyboardShortcut.emit(ks);
        }
    }
    hasFocus() {
        return document.activeElement === this.host ||
            this.host.contains(document.activeElement) ||
            document.activeElement.contains(this.host);
    }
    keypressHandler(event) {
        if (event.key in this.shortcutMap &&
            this.hasFocus() &&
            !utils.ignoreKeypress() &&
            !this.disabled &&
            !this.preventChanges) {
            const advance = this.value === this.shortcutMap[event.key];
            this.value = this.shortcutMap[event.key];
            // If the value does not change as a result of the key press, trigger card advance from here
            if (advance) {
                this.inputUpdated.emit(this.input.form);
            }
            // The following addresses an issue observed with dependent form elements
            // not receiving form updated events when the value is changed via keypress
            this.input.form.elements[this.name].value = this.shortcutMap[event.key];
            this.input.form.dispatchEvent(new InputEvent("input"));
        }
    }
    handleValueUpdate(value) {
        inputBase.InputBase.prototype.handleValueUpdate.bind(this)(value);
        if (this.answer && this.answerCorrection && this.answerCorrection.displayOn === "mismatch") {
            this.answerCorrection.displayCorrection = (this.answer.value !== value);
        }
        this.input.form.dispatchEvent(new InputEvent("input"));
    }
    async validateAgainstAnswer() {
        // TODO: Review why this is different from the others
        return !(this.hasAnswerToValidate() && this.answerCorrection.displayOn === "submit" && this.value !== this.answer.value);
    }
    renderRadio() {
        return this.options.map(option => index.h("label", { class: inputBase.classNames("radio", { "inline": this.inline }), key: option.value }, index.h("input", { type: "radio", name: this.name, value: option.value, required: this.required, onChange: e => this.value = e.target.value, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), index.h("span", { class: "indicator", key: "indicator" }), index.h("div", { class: inputBase.classNames("content", { "inline": this.inline }) }, option.tooltip && index.h("span", { class: "tooltipText" }, option.tooltip), index.h("span", { innerHTML: option.innerHTML.trim() })), this.answer &&
            this.answer.value === option.value &&
            (this.answer.showAnswer || (this.answerCorrection.showAnswer &&
                this.answerCorrection.displayCorrection)) &&
            index.h("task-tag", { round: true, color: "red", small: true, style: { marginLeft: "4px" } }, this.answerTag)));
    }
    renderButtonGroup() {
        return index.h("task-button-group", null, this.options.map(option => index.h("task-button", { label: true, class: inputBase.classNames("radio", { "inline": this.inline }), selected: option.value === this.value, onClick: () => this.value = option.value, key: option.value }, index.h("input", { type: "radio", name: this.name, value: option.value, required: this.required, checked: option.value === this.value, disabled: this.disabled || (this.preventChanges && option.value !== this.value), ref: el => this.input = el,
            // Prevents the input getting focus and changing values using arrow keys
            onClick: (e) => e.target.blur() }), index.h("div", { class: inputBase.classNames("content", { "inline": this.inline }), innerHTML: option.innerHTML }))));
    }
    render() {
        return (index.h(index.Host, { key: '1db323318756277d3f7cb4737969e6b4c74aa746' }, !this.hidden && index.h(index.Fragment, { key: '980ddfae1e1c622fbc6628b4e9fc90a00aa9429f' }, this.label && index.h("task-label", { key: '1bc3db77c1045e04eb36c4eae99f1ccf931179c0', class: this.labelClass }, this.label), this.mode === "button" ? this.renderButtonGroup() : this.renderRadio()), index.h("slot", { key: '8b7655ebca792a340880fc508f1abe7c9da639fb' })));
    }
    static get formAssociated() { return true; }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "value": ["handleValueUpdate"]
    }; }
};
TaskInputRadio.style = TaskInputRadioStyle0;

const taskKeyboardShortcutListCss = ".sc-task-keyboard-shortcut-list-h{display:block}.key-combo.sc-task-keyboard-shortcut-list{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.key-combo.sc-task-keyboard-shortcut-list>*.sc-task-keyboard-shortcut-list{-webkit-box-flex:0;-ms-flex-positive:0;flex-grow:0;-ms-flex-negative:0;flex-shrink:0}.key-combo.sc-task-keyboard-shortcut-list::before,.key-combo.sc-task-keyboard-shortcut-list>*.sc-task-keyboard-shortcut-list{margin-right:5px}.key-combo.sc-task-keyboard-shortcut-list:empty::before,.key-combo.sc-task-keyboard-shortcut-list>.sc-task-keyboard-shortcut-list:last-child{margin-right:0}.hotkey.sc-task-keyboard-shortcut-list{-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;margin-left:0;margin-right:0}.hotkey.sc-task-keyboard-shortcut-list:not(:last-child){margin-bottom:10px}.key.sc-task-keyboard-shortcut-list{-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:#fff;border-radius:3px;-webkit-box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 0 0 rgba(17, 20, 24, 0), 0 1px 1px rgba(17, 20, 24, 0.2);box-shadow:0 0 0 1px rgba(17, 20, 24, 0.1), 0 0 0 rgba(17, 20, 24, 0), 0 1px 1px rgba(17, 20, 24, 0.2);color:#5f6b7c;display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:inherit;font-size:12px;height:24px;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;line-height:24px;min-width:24px;padding:3px 6px;vertical-align:middle}";
const TaskKeyboardShortcutListStyle0 = taskKeyboardShortcutListCss;

const TaskKeyboardShortcutList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.valueMap = {
            "ArrowLeft": "Left Arrow",
            "ArrowRight": "Right Arrow",
            "tab": "Tab"
        };
        this.shortcuts = new Map();
    }
    componentWillLoad() {
        for (let child of Array.from(this.host.children)) {
            if (child.nodeName === "TASK-KEYBOARD-SHORTCUT") {
                this.addShortCut({
                    label: child.innerHTML,
                    keys: child.attributes.getNamedItem("keyboard-shortcut").value
                });
            }
        }
    }
    async addShortCut(shortcut) {
        this.shortcuts = new Map(this.shortcuts.set(shortcut.label, shortcut));
    }
    formatKey(key) {
        if (key in this.valueMap) {
            return this.valueMap[key];
        }
        else if (key.length === 1) {
            return key.toUpperCase();
        }
        else {
            return key;
        }
    }
    renderRow(ks) {
        const keys = ks.keys.split(",");
        return (index.h("div", { class: "hotkey" }, index.h("div", { class: "hotkey-label" }, ks.label), keys.length > 1 ?
            index.h("span", { class: "key-combo" }, keys.map((k, i) => index.h(index.Fragment, null, index.h("kbd", { class: "key" }, this.formatKey(k)), i < keys.length - 1 && index.h("span", null, " or "))))
            : index.h("kbd", { class: "key" }, this.formatKey(keys[0]))));
    }
    render() {
        return (index.h(index.Host, { key: 'd1a5b9d301bf8a48a6acfe07ecf6da9f29522634' }, Array.from(this.shortcuts.values()).map((ks) => this.renderRow(ks))));
    }
    get host() { return index.getElement(this); }
};
TaskKeyboardShortcutList.style = TaskKeyboardShortcutListStyle0;

const taskLabelCss = ".sc-task-label-h{display:block}.sc-task-label-h label.sc-task-label{display:block;margin-bottom:10px;margin-top:0}label.sc-task-label .html-select.sc-task-label,label.sc-task-label .input.sc-task-label,label.sc-task-label .select.sc-task-label{display:block;margin-top:5px;text-transform:none}label.sc-task-label .select.sc-task-label select.sc-task-label,label.sc-task-label .html-select.sc-task-label select.sc-task-label{font-weight:400;vertical-align:top;width:100%}label.disabled.sc-task-label{color:rgba(95, 107, 124, 0.6)}label.label.inline.sc-task-label{line-height:30px}label.inline.sc-task-label .input.sc-task-label,label.inline.sc-task-label .select.sc-task-label{display:inline-block;margin:0 0 0 5px;vertical-align:top}";
const TaskLabelStyle0 = taskLabelCss;

const TaskLabel = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        return (index.h(index.Host, { key: 'e0e6239d02c312da2595a1e371326663515a0723' }, index.h("label", { key: '9dbe189c6cfb1dd111c3517b7f22f63b9e3b952e' }, index.h("slot", { key: '41f02d9e68424a368cb32dd8d9f2cf8233cb7c79' }))));
    }
};
TaskLabel.style = TaskLabelStyle0;

const taskMainCss = ".sc-task-main-h{-ms-flex:1 1 auto;flex:1 1 auto;display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap;height:100%}.header.sc-task-main{padding:6px;-ms-flex:0 0 auto;flex:0 0 auto}.main.sc-task-main{padding:6px;-ms-flex:1 1 auto;flex:1 1 auto;overflow-y:auto}";
const TaskMainStyle0 = taskMainCss;

const TaskMain = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        return (index.h(index.Host, { key: '75934b02fb93c6ca02f29b306018c181d6438d18' }, index.h("div", { key: 'dd136b84d67d0245874e3db3f864a90f68f7c8d9', class: "header" }, index.h("slot", { key: '9a2f53aad2272e14969b78ea4357ff83e5b8b64c', name: "header" })), index.h("div", { key: 'af5e03ce177b8e63c227939734f29edc6c6fa2da', class: "main" }, index.h("slot", { key: 'f76b5a72e03c3ebe9f8a112a1934673269f275e1' }))));
    }
};
TaskMain.style = TaskMainStyle0;

var marked_umd = {exports: {}};

/**
 * marked v4.3.0 - a markdown parser
 * Copyright (c) 2011-2023, Christopher Jeffrey. (MIT Licensed)
 * https://github.com/markedjs/marked
 */

(function (module, exports) {
/**
 * DO NOT EDIT THIS FILE
 * The code in this file is generated from files in ./src/
 */

(function (global, factory) {
  factory(exports) ;
})(commonjsGlobal, (function (exports) {
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
    }
  }
  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }
  function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function (target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i];
        for (var key in source) {
          if (Object.prototype.hasOwnProperty.call(source, key)) {
            target[key] = source[key];
          }
        }
      }
      return target;
    };
    return _extends.apply(this, arguments);
  }
  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }
  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;
    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
    return arr2;
  }
  function _createForOfIteratorHelperLoose(o, allowArrayLike) {
    var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
    if (it) return (it = it.call(o)).next.bind(it);
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;
      return function () {
        if (i >= o.length) return {
          done: true
        };
        return {
          done: false,
          value: o[i++]
        };
      };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  function _toPrimitive(input, hint) {
    if (typeof input !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (typeof res !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
  function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return typeof key === "symbol" ? key : String(key);
  }

  function getDefaults() {
    return {
      async: false,
      baseUrl: null,
      breaks: false,
      extensions: null,
      gfm: true,
      headerIds: true,
      headerPrefix: '',
      highlight: null,
      hooks: null,
      langPrefix: 'language-',
      mangle: true,
      pedantic: false,
      renderer: null,
      sanitize: false,
      sanitizer: null,
      silent: false,
      smartypants: false,
      tokenizer: null,
      walkTokens: null,
      xhtml: false
    };
  }
  exports.defaults = getDefaults();
  function changeDefaults(newDefaults) {
    exports.defaults = newDefaults;
  }

  /**
   * Helpers
   */
  var escapeTest = /[&<>"']/;
  var escapeReplace = new RegExp(escapeTest.source, 'g');
  var escapeTestNoEncode = /[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/;
  var escapeReplaceNoEncode = new RegExp(escapeTestNoEncode.source, 'g');
  var escapeReplacements = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '"': '&quot;',
    "'": '&#39;'
  };
  var getEscapeReplacement = function getEscapeReplacement(ch) {
    return escapeReplacements[ch];
  };
  function escape(html, encode) {
    if (encode) {
      if (escapeTest.test(html)) {
        return html.replace(escapeReplace, getEscapeReplacement);
      }
    } else {
      if (escapeTestNoEncode.test(html)) {
        return html.replace(escapeReplaceNoEncode, getEscapeReplacement);
      }
    }
    return html;
  }
  var unescapeTest = /&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig;

  /**
   * @param {string} html
   */
  function unescape(html) {
    // explicitly match decimal, hex, and named HTML entities
    return html.replace(unescapeTest, function (_, n) {
      n = n.toLowerCase();
      if (n === 'colon') return ':';
      if (n.charAt(0) === '#') {
        return n.charAt(1) === 'x' ? String.fromCharCode(parseInt(n.substring(2), 16)) : String.fromCharCode(+n.substring(1));
      }
      return '';
    });
  }
  var caret = /(^|[^\[])\^/g;

  /**
   * @param {string | RegExp} regex
   * @param {string} opt
   */
  function edit(regex, opt) {
    regex = typeof regex === 'string' ? regex : regex.source;
    opt = opt || '';
    var obj = {
      replace: function replace(name, val) {
        val = val.source || val;
        val = val.replace(caret, '$1');
        regex = regex.replace(name, val);
        return obj;
      },
      getRegex: function getRegex() {
        return new RegExp(regex, opt);
      }
    };
    return obj;
  }
  var nonWordAndColonTest = /[^\w:]/g;
  var originIndependentUrl = /^$|^[a-z][a-z0-9+.-]*:|^[?#]/i;

  /**
   * @param {boolean} sanitize
   * @param {string} base
   * @param {string} href
   */
  function cleanUrl(sanitize, base, href) {
    if (sanitize) {
      var prot;
      try {
        prot = decodeURIComponent(unescape(href)).replace(nonWordAndColonTest, '').toLowerCase();
      } catch (e) {
        return null;
      }
      if (prot.indexOf('javascript:') === 0 || prot.indexOf('vbscript:') === 0 || prot.indexOf('data:') === 0) {
        return null;
      }
    }
    if (base && !originIndependentUrl.test(href)) {
      href = resolveUrl(base, href);
    }
    try {
      href = encodeURI(href).replace(/%25/g, '%');
    } catch (e) {
      return null;
    }
    return href;
  }
  var baseUrls = {};
  var justDomain = /^[^:]+:\/*[^/]*$/;
  var protocol = /^([^:]+:)[\s\S]*$/;
  var domain = /^([^:]+:\/*[^/]*)[\s\S]*$/;

  /**
   * @param {string} base
   * @param {string} href
   */
  function resolveUrl(base, href) {
    if (!baseUrls[' ' + base]) {
      // we can ignore everything in base after the last slash of its path component,
      // but we might need to add _that_
      // https://tools.ietf.org/html/rfc3986#section-3
      if (justDomain.test(base)) {
        baseUrls[' ' + base] = base + '/';
      } else {
        baseUrls[' ' + base] = rtrim(base, '/', true);
      }
    }
    base = baseUrls[' ' + base];
    var relativeBase = base.indexOf(':') === -1;
    if (href.substring(0, 2) === '//') {
      if (relativeBase) {
        return href;
      }
      return base.replace(protocol, '$1') + href;
    } else if (href.charAt(0) === '/') {
      if (relativeBase) {
        return href;
      }
      return base.replace(domain, '$1') + href;
    } else {
      return base + href;
    }
  }
  var noopTest = {
    exec: function noopTest() {}
  };
  function splitCells(tableRow, count) {
    // ensure that every cell-delimiting pipe has a space
    // before it to distinguish it from an escaped pipe
    var row = tableRow.replace(/\|/g, function (match, offset, str) {
        var escaped = false,
          curr = offset;
        while (--curr >= 0 && str[curr] === '\\') {
          escaped = !escaped;
        }
        if (escaped) {
          // odd number of slashes means | is escaped
          // so we leave it alone
          return '|';
        } else {
          // add space before unescaped |
          return ' |';
        }
      }),
      cells = row.split(/ \|/);
    var i = 0;

    // First/last cell in a row cannot be empty if it has no leading/trailing pipe
    if (!cells[0].trim()) {
      cells.shift();
    }
    if (cells.length > 0 && !cells[cells.length - 1].trim()) {
      cells.pop();
    }
    if (cells.length > count) {
      cells.splice(count);
    } else {
      while (cells.length < count) {
        cells.push('');
      }
    }
    for (; i < cells.length; i++) {
      // leading or trailing whitespace is ignored per the gfm spec
      cells[i] = cells[i].trim().replace(/\\\|/g, '|');
    }
    return cells;
  }

  /**
   * Remove trailing 'c's. Equivalent to str.replace(/c*$/, '').
   * /c*$/ is vulnerable to REDOS.
   *
   * @param {string} str
   * @param {string} c
   * @param {boolean} invert Remove suffix of non-c chars instead. Default falsey.
   */
  function rtrim(str, c, invert) {
    var l = str.length;
    if (l === 0) {
      return '';
    }

    // Length of suffix matching the invert condition.
    var suffLen = 0;

    // Step left until we fail to match the invert condition.
    while (suffLen < l) {
      var currChar = str.charAt(l - suffLen - 1);
      if (currChar === c && !invert) {
        suffLen++;
      } else if (currChar !== c && invert) {
        suffLen++;
      } else {
        break;
      }
    }
    return str.slice(0, l - suffLen);
  }
  function findClosingBracket(str, b) {
    if (str.indexOf(b[1]) === -1) {
      return -1;
    }
    var l = str.length;
    var level = 0,
      i = 0;
    for (; i < l; i++) {
      if (str[i] === '\\') {
        i++;
      } else if (str[i] === b[0]) {
        level++;
      } else if (str[i] === b[1]) {
        level--;
        if (level < 0) {
          return i;
        }
      }
    }
    return -1;
  }
  function checkSanitizeDeprecation(opt) {
    if (opt && opt.sanitize && !opt.silent) {
      console.warn('marked(): sanitize and sanitizer parameters are deprecated since version 0.7.0, should not be used and will be removed in the future. Read more here: https://marked.js.org/#/USING_ADVANCED.md#options');
    }
  }

  // copied from https://stackoverflow.com/a/5450113/806777
  /**
   * @param {string} pattern
   * @param {number} count
   */
  function repeatString(pattern, count) {
    if (count < 1) {
      return '';
    }
    var result = '';
    while (count > 1) {
      if (count & 1) {
        result += pattern;
      }
      count >>= 1;
      pattern += pattern;
    }
    return result + pattern;
  }

  function outputLink(cap, link, raw, lexer) {
    var href = link.href;
    var title = link.title ? escape(link.title) : null;
    var text = cap[1].replace(/\\([\[\]])/g, '$1');
    if (cap[0].charAt(0) !== '!') {
      lexer.state.inLink = true;
      var token = {
        type: 'link',
        raw: raw,
        href: href,
        title: title,
        text: text,
        tokens: lexer.inlineTokens(text)
      };
      lexer.state.inLink = false;
      return token;
    }
    return {
      type: 'image',
      raw: raw,
      href: href,
      title: title,
      text: escape(text)
    };
  }
  function indentCodeCompensation(raw, text) {
    var matchIndentToCode = raw.match(/^(\s+)(?:```)/);
    if (matchIndentToCode === null) {
      return text;
    }
    var indentToCode = matchIndentToCode[1];
    return text.split('\n').map(function (node) {
      var matchIndentInNode = node.match(/^\s+/);
      if (matchIndentInNode === null) {
        return node;
      }
      var indentInNode = matchIndentInNode[0];
      if (indentInNode.length >= indentToCode.length) {
        return node.slice(indentToCode.length);
      }
      return node;
    }).join('\n');
  }

  /**
   * Tokenizer
   */
  var Tokenizer = /*#__PURE__*/function () {
    function Tokenizer(options) {
      this.options = options || exports.defaults;
    }
    var _proto = Tokenizer.prototype;
    _proto.space = function space(src) {
      var cap = this.rules.block.newline.exec(src);
      if (cap && cap[0].length > 0) {
        return {
          type: 'space',
          raw: cap[0]
        };
      }
    };
    _proto.code = function code(src) {
      var cap = this.rules.block.code.exec(src);
      if (cap) {
        var text = cap[0].replace(/^ {1,4}/gm, '');
        return {
          type: 'code',
          raw: cap[0],
          codeBlockStyle: 'indented',
          text: !this.options.pedantic ? rtrim(text, '\n') : text
        };
      }
    };
    _proto.fences = function fences(src) {
      var cap = this.rules.block.fences.exec(src);
      if (cap) {
        var raw = cap[0];
        var text = indentCodeCompensation(raw, cap[3] || '');
        return {
          type: 'code',
          raw: raw,
          lang: cap[2] ? cap[2].trim().replace(this.rules.inline._escapes, '$1') : cap[2],
          text: text
        };
      }
    };
    _proto.heading = function heading(src) {
      var cap = this.rules.block.heading.exec(src);
      if (cap) {
        var text = cap[2].trim();

        // remove trailing #s
        if (/#$/.test(text)) {
          var trimmed = rtrim(text, '#');
          if (this.options.pedantic) {
            text = trimmed.trim();
          } else if (!trimmed || / $/.test(trimmed)) {
            // CommonMark requires space before trailing #s
            text = trimmed.trim();
          }
        }
        return {
          type: 'heading',
          raw: cap[0],
          depth: cap[1].length,
          text: text,
          tokens: this.lexer.inline(text)
        };
      }
    };
    _proto.hr = function hr(src) {
      var cap = this.rules.block.hr.exec(src);
      if (cap) {
        return {
          type: 'hr',
          raw: cap[0]
        };
      }
    };
    _proto.blockquote = function blockquote(src) {
      var cap = this.rules.block.blockquote.exec(src);
      if (cap) {
        var text = cap[0].replace(/^ *>[ \t]?/gm, '');
        var top = this.lexer.state.top;
        this.lexer.state.top = true;
        var tokens = this.lexer.blockTokens(text);
        this.lexer.state.top = top;
        return {
          type: 'blockquote',
          raw: cap[0],
          tokens: tokens,
          text: text
        };
      }
    };
    _proto.list = function list(src) {
      var cap = this.rules.block.list.exec(src);
      if (cap) {
        var raw, istask, ischecked, indent, i, blankLine, endsWithBlankLine, line, nextLine, rawLine, itemContents, endEarly;
        var bull = cap[1].trim();
        var isordered = bull.length > 1;
        var list = {
          type: 'list',
          raw: '',
          ordered: isordered,
          start: isordered ? +bull.slice(0, -1) : '',
          loose: false,
          items: []
        };
        bull = isordered ? "\\d{1,9}\\" + bull.slice(-1) : "\\" + bull;
        if (this.options.pedantic) {
          bull = isordered ? bull : '[*+-]';
        }

        // Get next list item
        var itemRegex = new RegExp("^( {0,3}" + bull + ")((?:[\t ][^\\n]*)?(?:\\n|$))");

        // Check if current bullet point can start a new List Item
        while (src) {
          endEarly = false;
          if (!(cap = itemRegex.exec(src))) {
            break;
          }
          if (this.rules.block.hr.test(src)) {
            // End list if bullet was actually HR (possibly move into itemRegex?)
            break;
          }
          raw = cap[0];
          src = src.substring(raw.length);
          line = cap[2].split('\n', 1)[0].replace(/^\t+/, function (t) {
            return ' '.repeat(3 * t.length);
          });
          nextLine = src.split('\n', 1)[0];
          if (this.options.pedantic) {
            indent = 2;
            itemContents = line.trimLeft();
          } else {
            indent = cap[2].search(/[^ ]/); // Find first non-space char
            indent = indent > 4 ? 1 : indent; // Treat indented code blocks (> 4 spaces) as having only 1 indent
            itemContents = line.slice(indent);
            indent += cap[1].length;
          }
          blankLine = false;
          if (!line && /^ *$/.test(nextLine)) {
            // Items begin with at most one blank line
            raw += nextLine + '\n';
            src = src.substring(nextLine.length + 1);
            endEarly = true;
          }
          if (!endEarly) {
            var nextBulletRegex = new RegExp("^ {0," + Math.min(3, indent - 1) + "}(?:[*+-]|\\d{1,9}[.)])((?:[ \t][^\\n]*)?(?:\\n|$))");
            var hrRegex = new RegExp("^ {0," + Math.min(3, indent - 1) + "}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)");
            var fencesBeginRegex = new RegExp("^ {0," + Math.min(3, indent - 1) + "}(?:```|~~~)");
            var headingBeginRegex = new RegExp("^ {0," + Math.min(3, indent - 1) + "}#");

            // Check if following lines should be included in List Item
            while (src) {
              rawLine = src.split('\n', 1)[0];
              nextLine = rawLine;

              // Re-align to follow commonmark nesting rules
              if (this.options.pedantic) {
                nextLine = nextLine.replace(/^ {1,4}(?=( {4})*[^ ])/g, '  ');
              }

              // End list item if found code fences
              if (fencesBeginRegex.test(nextLine)) {
                break;
              }

              // End list item if found start of new heading
              if (headingBeginRegex.test(nextLine)) {
                break;
              }

              // End list item if found start of new bullet
              if (nextBulletRegex.test(nextLine)) {
                break;
              }

              // Horizontal rule found
              if (hrRegex.test(src)) {
                break;
              }
              if (nextLine.search(/[^ ]/) >= indent || !nextLine.trim()) {
                // Dedent if possible
                itemContents += '\n' + nextLine.slice(indent);
              } else {
                // not enough indentation
                if (blankLine) {
                  break;
                }

                // paragraph continuation unless last line was a different block level element
                if (line.search(/[^ ]/) >= 4) {
                  // indented code block
                  break;
                }
                if (fencesBeginRegex.test(line)) {
                  break;
                }
                if (headingBeginRegex.test(line)) {
                  break;
                }
                if (hrRegex.test(line)) {
                  break;
                }
                itemContents += '\n' + nextLine;
              }
              if (!blankLine && !nextLine.trim()) {
                // Check if current line is blank
                blankLine = true;
              }
              raw += rawLine + '\n';
              src = src.substring(rawLine.length + 1);
              line = nextLine.slice(indent);
            }
          }
          if (!list.loose) {
            // If the previous item ended with a blank line, the list is loose
            if (endsWithBlankLine) {
              list.loose = true;
            } else if (/\n *\n *$/.test(raw)) {
              endsWithBlankLine = true;
            }
          }

          // Check for task list items
          if (this.options.gfm) {
            istask = /^\[[ xX]\] /.exec(itemContents);
            if (istask) {
              ischecked = istask[0] !== '[ ] ';
              itemContents = itemContents.replace(/^\[[ xX]\] +/, '');
            }
          }
          list.items.push({
            type: 'list_item',
            raw: raw,
            task: !!istask,
            checked: ischecked,
            loose: false,
            text: itemContents
          });
          list.raw += raw;
        }

        // Do not consume newlines at end of final item. Alternatively, make itemRegex *start* with any newlines to simplify/speed up endsWithBlankLine logic
        list.items[list.items.length - 1].raw = raw.trimRight();
        list.items[list.items.length - 1].text = itemContents.trimRight();
        list.raw = list.raw.trimRight();
        var l = list.items.length;

        // Item child tokens handled here at end because we needed to have the final item to trim it first
        for (i = 0; i < l; i++) {
          this.lexer.state.top = false;
          list.items[i].tokens = this.lexer.blockTokens(list.items[i].text, []);
          if (!list.loose) {
            // Check if list should be loose
            var spacers = list.items[i].tokens.filter(function (t) {
              return t.type === 'space';
            });
            var hasMultipleLineBreaks = spacers.length > 0 && spacers.some(function (t) {
              return /\n.*\n/.test(t.raw);
            });
            list.loose = hasMultipleLineBreaks;
          }
        }

        // Set all items to loose if list is loose
        if (list.loose) {
          for (i = 0; i < l; i++) {
            list.items[i].loose = true;
          }
        }
        return list;
      }
    };
    _proto.html = function html(src) {
      var cap = this.rules.block.html.exec(src);
      if (cap) {
        var token = {
          type: 'html',
          raw: cap[0],
          pre: !this.options.sanitizer && (cap[1] === 'pre' || cap[1] === 'script' || cap[1] === 'style'),
          text: cap[0]
        };
        if (this.options.sanitize) {
          var text = this.options.sanitizer ? this.options.sanitizer(cap[0]) : escape(cap[0]);
          token.type = 'paragraph';
          token.text = text;
          token.tokens = this.lexer.inline(text);
        }
        return token;
      }
    };
    _proto.def = function def(src) {
      var cap = this.rules.block.def.exec(src);
      if (cap) {
        var tag = cap[1].toLowerCase().replace(/\s+/g, ' ');
        var href = cap[2] ? cap[2].replace(/^<(.*)>$/, '$1').replace(this.rules.inline._escapes, '$1') : '';
        var title = cap[3] ? cap[3].substring(1, cap[3].length - 1).replace(this.rules.inline._escapes, '$1') : cap[3];
        return {
          type: 'def',
          tag: tag,
          raw: cap[0],
          href: href,
          title: title
        };
      }
    };
    _proto.table = function table(src) {
      var cap = this.rules.block.table.exec(src);
      if (cap) {
        var item = {
          type: 'table',
          header: splitCells(cap[1]).map(function (c) {
            return {
              text: c
            };
          }),
          align: cap[2].replace(/^ *|\| *$/g, '').split(/ *\| */),
          rows: cap[3] && cap[3].trim() ? cap[3].replace(/\n[ \t]*$/, '').split('\n') : []
        };
        if (item.header.length === item.align.length) {
          item.raw = cap[0];
          var l = item.align.length;
          var i, j, k, row;
          for (i = 0; i < l; i++) {
            if (/^ *-+: *$/.test(item.align[i])) {
              item.align[i] = 'right';
            } else if (/^ *:-+: *$/.test(item.align[i])) {
              item.align[i] = 'center';
            } else if (/^ *:-+ *$/.test(item.align[i])) {
              item.align[i] = 'left';
            } else {
              item.align[i] = null;
            }
          }
          l = item.rows.length;
          for (i = 0; i < l; i++) {
            item.rows[i] = splitCells(item.rows[i], item.header.length).map(function (c) {
              return {
                text: c
              };
            });
          }

          // parse child tokens inside headers and cells

          // header child tokens
          l = item.header.length;
          for (j = 0; j < l; j++) {
            item.header[j].tokens = this.lexer.inline(item.header[j].text);
          }

          // cell child tokens
          l = item.rows.length;
          for (j = 0; j < l; j++) {
            row = item.rows[j];
            for (k = 0; k < row.length; k++) {
              row[k].tokens = this.lexer.inline(row[k].text);
            }
          }
          return item;
        }
      }
    };
    _proto.lheading = function lheading(src) {
      var cap = this.rules.block.lheading.exec(src);
      if (cap) {
        return {
          type: 'heading',
          raw: cap[0],
          depth: cap[2].charAt(0) === '=' ? 1 : 2,
          text: cap[1],
          tokens: this.lexer.inline(cap[1])
        };
      }
    };
    _proto.paragraph = function paragraph(src) {
      var cap = this.rules.block.paragraph.exec(src);
      if (cap) {
        var text = cap[1].charAt(cap[1].length - 1) === '\n' ? cap[1].slice(0, -1) : cap[1];
        return {
          type: 'paragraph',
          raw: cap[0],
          text: text,
          tokens: this.lexer.inline(text)
        };
      }
    };
    _proto.text = function text(src) {
      var cap = this.rules.block.text.exec(src);
      if (cap) {
        return {
          type: 'text',
          raw: cap[0],
          text: cap[0],
          tokens: this.lexer.inline(cap[0])
        };
      }
    };
    _proto.escape = function escape$1(src) {
      var cap = this.rules.inline.escape.exec(src);
      if (cap) {
        return {
          type: 'escape',
          raw: cap[0],
          text: escape(cap[1])
        };
      }
    };
    _proto.tag = function tag(src) {
      var cap = this.rules.inline.tag.exec(src);
      if (cap) {
        if (!this.lexer.state.inLink && /^<a /i.test(cap[0])) {
          this.lexer.state.inLink = true;
        } else if (this.lexer.state.inLink && /^<\/a>/i.test(cap[0])) {
          this.lexer.state.inLink = false;
        }
        if (!this.lexer.state.inRawBlock && /^<(pre|code|kbd|script)(\s|>)/i.test(cap[0])) {
          this.lexer.state.inRawBlock = true;
        } else if (this.lexer.state.inRawBlock && /^<\/(pre|code|kbd|script)(\s|>)/i.test(cap[0])) {
          this.lexer.state.inRawBlock = false;
        }
        return {
          type: this.options.sanitize ? 'text' : 'html',
          raw: cap[0],
          inLink: this.lexer.state.inLink,
          inRawBlock: this.lexer.state.inRawBlock,
          text: this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(cap[0]) : escape(cap[0]) : cap[0]
        };
      }
    };
    _proto.link = function link(src) {
      var cap = this.rules.inline.link.exec(src);
      if (cap) {
        var trimmedUrl = cap[2].trim();
        if (!this.options.pedantic && /^</.test(trimmedUrl)) {
          // commonmark requires matching angle brackets
          if (!/>$/.test(trimmedUrl)) {
            return;
          }

          // ending angle bracket cannot be escaped
          var rtrimSlash = rtrim(trimmedUrl.slice(0, -1), '\\');
          if ((trimmedUrl.length - rtrimSlash.length) % 2 === 0) {
            return;
          }
        } else {
          // find closing parenthesis
          var lastParenIndex = findClosingBracket(cap[2], '()');
          if (lastParenIndex > -1) {
            var start = cap[0].indexOf('!') === 0 ? 5 : 4;
            var linkLen = start + cap[1].length + lastParenIndex;
            cap[2] = cap[2].substring(0, lastParenIndex);
            cap[0] = cap[0].substring(0, linkLen).trim();
            cap[3] = '';
          }
        }
        var href = cap[2];
        var title = '';
        if (this.options.pedantic) {
          // split pedantic href and title
          var link = /^([^'"]*[^\s])\s+(['"])(.*)\2/.exec(href);
          if (link) {
            href = link[1];
            title = link[3];
          }
        } else {
          title = cap[3] ? cap[3].slice(1, -1) : '';
        }
        href = href.trim();
        if (/^</.test(href)) {
          if (this.options.pedantic && !/>$/.test(trimmedUrl)) {
            // pedantic allows starting angle bracket without ending angle bracket
            href = href.slice(1);
          } else {
            href = href.slice(1, -1);
          }
        }
        return outputLink(cap, {
          href: href ? href.replace(this.rules.inline._escapes, '$1') : href,
          title: title ? title.replace(this.rules.inline._escapes, '$1') : title
        }, cap[0], this.lexer);
      }
    };
    _proto.reflink = function reflink(src, links) {
      var cap;
      if ((cap = this.rules.inline.reflink.exec(src)) || (cap = this.rules.inline.nolink.exec(src))) {
        var link = (cap[2] || cap[1]).replace(/\s+/g, ' ');
        link = links[link.toLowerCase()];
        if (!link) {
          var text = cap[0].charAt(0);
          return {
            type: 'text',
            raw: text,
            text: text
          };
        }
        return outputLink(cap, link, cap[0], this.lexer);
      }
    };
    _proto.emStrong = function emStrong(src, maskedSrc, prevChar) {
      if (prevChar === void 0) {
        prevChar = '';
      }
      var match = this.rules.inline.emStrong.lDelim.exec(src);
      if (!match) return;

      // _ can't be between two alphanumerics. \p{L}\p{N} includes non-english alphabet/numbers as well
      if (match[3] && prevChar.match(/(?:[0-9A-Za-z\xAA\xB2\xB3\xB5\xB9\xBA\xBC-\xBE\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u0660-\u0669\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07C0-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u0870-\u0887\u0889-\u088E\u08A0-\u08C9\u0904-\u0939\u093D\u0950\u0958-\u0961\u0966-\u096F\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09E6-\u09F1\u09F4-\u09F9\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A66-\u0A6F\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AE6-\u0AEF\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B66-\u0B6F\u0B71-\u0B77\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0BE6-\u0BF2\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C5D\u0C60\u0C61\u0C66-\u0C6F\u0C78-\u0C7E\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDD\u0CDE\u0CE0\u0CE1\u0CE6-\u0CEF\u0CF1\u0CF2\u0D04-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D58-\u0D61\u0D66-\u0D78\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DE6-\u0DEF\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E86-\u0E8A\u0E8C-\u0EA3\u0EA5\u0EA7-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F20-\u0F33\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F-\u1049\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u1090-\u1099\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1369-\u137C\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u1711\u171F-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1820-\u1878\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A16\u1A20-\u1A54\u1A80-\u1A89\u1A90-\u1A99\u1AA7\u1B05-\u1B33\u1B45-\u1B4C\u1B50-\u1B59\u1B83-\u1BA0\u1BAE-\u1BE5\u1C00-\u1C23\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF3\u1CF5\u1CF6\u1CFA\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2070\u2071\u2074-\u2079\u207F-\u2089\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2150-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2C00-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2CFD\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u3192-\u3195\u31A0-\u31BF\u31F0-\u31FF\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\u3400-\u4DBF\u4E00-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7CA\uA7D0\uA7D1\uA7D3\uA7D5-\uA7D9\uA7F2-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA830-\uA835\uA840-\uA873\uA882-\uA8B3\uA8D0-\uA8D9\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA900-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF-\uA9D9\uA9E0-\uA9E4\uA9E6-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA50-\uAA59\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB69\uAB70-\uABE2\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD07-\uDD33\uDD40-\uDD78\uDD8A\uDD8B\uDE80-\uDE9C\uDEA0-\uDED0\uDEE1-\uDEFB\uDF00-\uDF23\uDF2D-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDD70-\uDD7A\uDD7C-\uDD8A\uDD8C-\uDD92\uDD94\uDD95\uDD97-\uDDA1\uDDA3-\uDDB1\uDDB3-\uDDB9\uDDBB\uDDBC\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67\uDF80-\uDF85\uDF87-\uDFB0\uDFB2-\uDFBA]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC58-\uDC76\uDC79-\uDC9E\uDCA7-\uDCAF\uDCE0-\uDCF2\uDCF4\uDCF5\uDCFB-\uDD1B\uDD20-\uDD39\uDD80-\uDDB7\uDDBC-\uDDCF\uDDD2-\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE35\uDE40-\uDE48\uDE60-\uDE7E\uDE80-\uDE9F\uDEC0-\uDEC7\uDEC9-\uDEE4\uDEEB-\uDEEF\uDF00-\uDF35\uDF40-\uDF55\uDF58-\uDF72\uDF78-\uDF91\uDFA9-\uDFAF]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2\uDCFA-\uDD23\uDD30-\uDD39\uDE60-\uDE7E\uDE80-\uDEA9\uDEB0\uDEB1\uDF00-\uDF27\uDF30-\uDF45\uDF51-\uDF54\uDF70-\uDF81\uDFB0-\uDFCB\uDFE0-\uDFF6]|\uD804[\uDC03-\uDC37\uDC52-\uDC6F\uDC71\uDC72\uDC75\uDC83-\uDCAF\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD03-\uDD26\uDD36-\uDD3F\uDD44\uDD47\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDD0-\uDDDA\uDDDC\uDDE1-\uDDF4\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDEF0-\uDEF9\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC50-\uDC59\uDC5F-\uDC61\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE50-\uDE59\uDE80-\uDEAA\uDEB8\uDEC0-\uDEC9\uDF00-\uDF1A\uDF30-\uDF3B\uDF40-\uDF46]|\uD806[\uDC00-\uDC2B\uDCA0-\uDCF2\uDCFF-\uDD06\uDD09\uDD0C-\uDD13\uDD15\uDD16\uDD18-\uDD2F\uDD3F\uDD41\uDD50-\uDD59\uDDA0-\uDDA7\uDDAA-\uDDD0\uDDE1\uDDE3\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE89\uDE9D\uDEB0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC50-\uDC6C\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46\uDD50-\uDD59\uDD60-\uDD65\uDD67\uDD68\uDD6A-\uDD89\uDD98\uDDA0-\uDDA9\uDEE0-\uDEF2\uDFB0\uDFC0-\uDFD4]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|\uD80B[\uDF90-\uDFF0]|[\uD80C\uD81C-\uD820\uD822\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879\uD880-\uD883][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDE70-\uDEBE\uDEC0-\uDEC9\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF50-\uDF59\uDF5B-\uDF61\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDE40-\uDE96\uDF00-\uDF4A\uDF50\uDF93-\uDF9F\uDFE0\uDFE1\uDFE3]|\uD821[\uDC00-\uDFF7]|\uD823[\uDC00-\uDCD5\uDD00-\uDD08]|\uD82B[\uDFF0-\uDFF3\uDFF5-\uDFFB\uDFFD\uDFFE]|\uD82C[\uDC00-\uDD22\uDD50-\uDD52\uDD64-\uDD67\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD834[\uDEE0-\uDEF3\uDF60-\uDF78]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD837[\uDF00-\uDF1E]|\uD838[\uDD00-\uDD2C\uDD37-\uDD3D\uDD40-\uDD49\uDD4E\uDE90-\uDEAD\uDEC0-\uDEEB\uDEF0-\uDEF9]|\uD839[\uDFE0-\uDFE6\uDFE8-\uDFEB\uDFED\uDFEE\uDFF0-\uDFFE]|\uD83A[\uDC00-\uDCC4\uDCC7-\uDCCF\uDD00-\uDD43\uDD4B\uDD50-\uDD59]|\uD83B[\uDC71-\uDCAB\uDCAD-\uDCAF\uDCB1-\uDCB4\uDD01-\uDD2D\uDD2F-\uDD3D\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD83C[\uDD00-\uDD0C]|\uD83E[\uDFF0-\uDFF9]|\uD869[\uDC00-\uDEDF\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF38\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D]|\uD884[\uDC00-\uDF4A])/)) return;
      var nextChar = match[1] || match[2] || '';
      if (!nextChar || nextChar && (prevChar === '' || this.rules.inline.punctuation.exec(prevChar))) {
        var lLength = match[0].length - 1;
        var rDelim,
          rLength,
          delimTotal = lLength,
          midDelimTotal = 0;
        var endReg = match[0][0] === '*' ? this.rules.inline.emStrong.rDelimAst : this.rules.inline.emStrong.rDelimUnd;
        endReg.lastIndex = 0;

        // Clip maskedSrc to same section of string as src (move to lexer?)
        maskedSrc = maskedSrc.slice(-1 * src.length + lLength);
        while ((match = endReg.exec(maskedSrc)) != null) {
          rDelim = match[1] || match[2] || match[3] || match[4] || match[5] || match[6];
          if (!rDelim) continue; // skip single * in __abc*abc__

          rLength = rDelim.length;
          if (match[3] || match[4]) {
            // found another Left Delim
            delimTotal += rLength;
            continue;
          } else if (match[5] || match[6]) {
            // either Left or Right Delim
            if (lLength % 3 && !((lLength + rLength) % 3)) {
              midDelimTotal += rLength;
              continue; // CommonMark Emphasis Rules 9-10
            }
          }

          delimTotal -= rLength;
          if (delimTotal > 0) continue; // Haven't found enough closing delimiters

          // Remove extra characters. *a*** -> *a*
          rLength = Math.min(rLength, rLength + delimTotal + midDelimTotal);
          var raw = src.slice(0, lLength + match.index + (match[0].length - rDelim.length) + rLength);

          // Create `em` if smallest delimiter has odd char count. *a***
          if (Math.min(lLength, rLength) % 2) {
            var _text = raw.slice(1, -1);
            return {
              type: 'em',
              raw: raw,
              text: _text,
              tokens: this.lexer.inlineTokens(_text)
            };
          }

          // Create 'strong' if smallest delimiter has even char count. **a***
          var text = raw.slice(2, -2);
          return {
            type: 'strong',
            raw: raw,
            text: text,
            tokens: this.lexer.inlineTokens(text)
          };
        }
      }
    };
    _proto.codespan = function codespan(src) {
      var cap = this.rules.inline.code.exec(src);
      if (cap) {
        var text = cap[2].replace(/\n/g, ' ');
        var hasNonSpaceChars = /[^ ]/.test(text);
        var hasSpaceCharsOnBothEnds = /^ /.test(text) && / $/.test(text);
        if (hasNonSpaceChars && hasSpaceCharsOnBothEnds) {
          text = text.substring(1, text.length - 1);
        }
        text = escape(text, true);
        return {
          type: 'codespan',
          raw: cap[0],
          text: text
        };
      }
    };
    _proto.br = function br(src) {
      var cap = this.rules.inline.br.exec(src);
      if (cap) {
        return {
          type: 'br',
          raw: cap[0]
        };
      }
    };
    _proto.del = function del(src) {
      var cap = this.rules.inline.del.exec(src);
      if (cap) {
        return {
          type: 'del',
          raw: cap[0],
          text: cap[2],
          tokens: this.lexer.inlineTokens(cap[2])
        };
      }
    };
    _proto.autolink = function autolink(src, mangle) {
      var cap = this.rules.inline.autolink.exec(src);
      if (cap) {
        var text, href;
        if (cap[2] === '@') {
          text = escape(this.options.mangle ? mangle(cap[1]) : cap[1]);
          href = 'mailto:' + text;
        } else {
          text = escape(cap[1]);
          href = text;
        }
        return {
          type: 'link',
          raw: cap[0],
          text: text,
          href: href,
          tokens: [{
            type: 'text',
            raw: text,
            text: text
          }]
        };
      }
    };
    _proto.url = function url(src, mangle) {
      var cap;
      if (cap = this.rules.inline.url.exec(src)) {
        var text, href;
        if (cap[2] === '@') {
          text = escape(this.options.mangle ? mangle(cap[0]) : cap[0]);
          href = 'mailto:' + text;
        } else {
          // do extended autolink path validation
          var prevCapZero;
          do {
            prevCapZero = cap[0];
            cap[0] = this.rules.inline._backpedal.exec(cap[0])[0];
          } while (prevCapZero !== cap[0]);
          text = escape(cap[0]);
          if (cap[1] === 'www.') {
            href = 'http://' + cap[0];
          } else {
            href = cap[0];
          }
        }
        return {
          type: 'link',
          raw: cap[0],
          text: text,
          href: href,
          tokens: [{
            type: 'text',
            raw: text,
            text: text
          }]
        };
      }
    };
    _proto.inlineText = function inlineText(src, smartypants) {
      var cap = this.rules.inline.text.exec(src);
      if (cap) {
        var text;
        if (this.lexer.state.inRawBlock) {
          text = this.options.sanitize ? this.options.sanitizer ? this.options.sanitizer(cap[0]) : escape(cap[0]) : cap[0];
        } else {
          text = escape(this.options.smartypants ? smartypants(cap[0]) : cap[0]);
        }
        return {
          type: 'text',
          raw: cap[0],
          text: text
        };
      }
    };
    return Tokenizer;
  }();

  /**
   * Block-Level Grammar
   */
  var block = {
    newline: /^(?: *(?:\n|$))+/,
    code: /^( {4}[^\n]+(?:\n(?: *(?:\n|$))*)?)+/,
    fences: /^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/,
    hr: /^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/,
    heading: /^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/,
    blockquote: /^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/,
    list: /^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/,
    html: '^ {0,3}(?:' // optional indentation
    + '<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)' // (1)
    + '|comment[^\\n]*(\\n+|$)' // (2)
    + '|<\\?[\\s\\S]*?(?:\\?>\\n*|$)' // (3)
    + '|<![A-Z][\\s\\S]*?(?:>\\n*|$)' // (4)
    + '|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)' // (5)
    + '|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n *)+\\n|$)' // (6)
    + '|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)' // (7) open tag
    + '|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n *)+\\n|$)' // (7) closing tag
    + ')',
    def: /^ {0,3}\[(label)\]: *(?:\n *)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n *)?| *\n *)(title))? *(?:\n+|$)/,
    table: noopTest,
    lheading: /^((?:.|\n(?!\n))+?)\n {0,3}(=+|-+) *(?:\n+|$)/,
    // regex template, placeholders will be replaced according to different paragraph
    // interruption rules of commonmark and the original markdown spec:
    _paragraph: /^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/,
    text: /^[^\n]+/
  };
  block._label = /(?!\s*\])(?:\\.|[^\[\]\\])+/;
  block._title = /(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/;
  block.def = edit(block.def).replace('label', block._label).replace('title', block._title).getRegex();
  block.bullet = /(?:[*+-]|\d{1,9}[.)])/;
  block.listItemStart = edit(/^( *)(bull) */).replace('bull', block.bullet).getRegex();
  block.list = edit(block.list).replace(/bull/g, block.bullet).replace('hr', '\\n+(?=\\1?(?:(?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$))').replace('def', '\\n+(?=' + block.def.source + ')').getRegex();
  block._tag = 'address|article|aside|base|basefont|blockquote|body|caption' + '|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption' + '|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe' + '|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option' + '|p|param|section|source|summary|table|tbody|td|tfoot|th|thead|title|tr' + '|track|ul';
  block._comment = /<!--(?!-?>)[\s\S]*?(?:-->|$)/;
  block.html = edit(block.html, 'i').replace('comment', block._comment).replace('tag', block._tag).replace('attribute', / +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex();
  block.paragraph = edit(block._paragraph).replace('hr', block.hr).replace('heading', ' {0,3}#{1,6} ').replace('|lheading', '') // setex headings don't interrupt commonmark paragraphs
  .replace('|table', '').replace('blockquote', ' {0,3}>').replace('fences', ' {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n').replace('list', ' {0,3}(?:[*+-]|1[.)]) ') // only lists starting from 1 can interrupt
  .replace('html', '</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)').replace('tag', block._tag) // pars can be interrupted by type (6) html blocks
  .getRegex();
  block.blockquote = edit(block.blockquote).replace('paragraph', block.paragraph).getRegex();

  /**
   * Normal Block Grammar
   */

  block.normal = _extends({}, block);

  /**
   * GFM Block Grammar
   */

  block.gfm = _extends({}, block.normal, {
    table: '^ *([^\\n ].*\\|.*)\\n' // Header
    + ' {0,3}(?:\\| *)?(:?-+:? *(?:\\| *:?-+:? *)*)(?:\\| *)?' // Align
    + '(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)' // Cells
  });

  block.gfm.table = edit(block.gfm.table).replace('hr', block.hr).replace('heading', ' {0,3}#{1,6} ').replace('blockquote', ' {0,3}>').replace('code', ' {4}[^\\n]').replace('fences', ' {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n').replace('list', ' {0,3}(?:[*+-]|1[.)]) ') // only lists starting from 1 can interrupt
  .replace('html', '</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)').replace('tag', block._tag) // tables can be interrupted by type (6) html blocks
  .getRegex();
  block.gfm.paragraph = edit(block._paragraph).replace('hr', block.hr).replace('heading', ' {0,3}#{1,6} ').replace('|lheading', '') // setex headings don't interrupt commonmark paragraphs
  .replace('table', block.gfm.table) // interrupt paragraphs with table
  .replace('blockquote', ' {0,3}>').replace('fences', ' {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n').replace('list', ' {0,3}(?:[*+-]|1[.)]) ') // only lists starting from 1 can interrupt
  .replace('html', '</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)').replace('tag', block._tag) // pars can be interrupted by type (6) html blocks
  .getRegex();
  /**
   * Pedantic grammar (original John Gruber's loose markdown specification)
   */

  block.pedantic = _extends({}, block.normal, {
    html: edit('^ *(?:comment *(?:\\n|\\s*$)' + '|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)' // closed tag
    + '|<tag(?:"[^"]*"|\'[^\']*\'|\\s[^\'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))').replace('comment', block._comment).replace(/tag/g, '(?!(?:' + 'a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub' + '|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)' + '\\b)\\w+(?!:|[^\\w\\s@]*@)\\b').getRegex(),
    def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,
    heading: /^(#{1,6})(.*)(?:\n+|$)/,
    fences: noopTest,
    // fences not supported
    lheading: /^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/,
    paragraph: edit(block.normal._paragraph).replace('hr', block.hr).replace('heading', ' *#{1,6} *[^\n]').replace('lheading', block.lheading).replace('blockquote', ' {0,3}>').replace('|fences', '').replace('|list', '').replace('|html', '').getRegex()
  });

  /**
   * Inline-Level Grammar
   */
  var inline = {
    escape: /^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/,
    autolink: /^<(scheme:[^\s\x00-\x1f<>]*|email)>/,
    url: noopTest,
    tag: '^comment' + '|^</[a-zA-Z][\\w:-]*\\s*>' // self-closing tag
    + '|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>' // open tag
    + '|^<\\?[\\s\\S]*?\\?>' // processing instruction, e.g. <?php ?>
    + '|^<![a-zA-Z]+\\s[\\s\\S]*?>' // declaration, e.g. <!DOCTYPE html>
    + '|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>',
    // CDATA section
    link: /^!?\[(label)\]\(\s*(href)(?:\s+(title))?\s*\)/,
    reflink: /^!?\[(label)\]\[(ref)\]/,
    nolink: /^!?\[(ref)\](?:\[\])?/,
    reflinkSearch: 'reflink|nolink(?!\\()',
    emStrong: {
      lDelim: /^(?:\*+(?:([punct_])|[^\s*]))|^_+(?:([punct*])|([^\s_]))/,
      //        (1) and (2) can only be a Right Delimiter. (3) and (4) can only be Left.  (5) and (6) can be either Left or Right.
      //          () Skip orphan inside strong                                      () Consume to delim     (1) #***                (2) a***#, a***                             (3) #***a, ***a                 (4) ***#              (5) #***#                 (6) a***a
      rDelimAst: /^(?:[^_*\\]|\\.)*?\_\_(?:[^_*\\]|\\.)*?\*(?:[^_*\\]|\\.)*?(?=\_\_)|(?:[^*\\]|\\.)+(?=[^*])|[punct_](\*+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\*+)(?=[punct_\s]|$)|[punct_\s](\*+)(?=[^punct*_\s])|[\s](\*+)(?=[punct_])|[punct_](\*+)(?=[punct_])|(?:[^punct*_\s\\]|\\.)(\*+)(?=[^punct*_\s])/,
      rDelimUnd: /^(?:[^_*\\]|\\.)*?\*\*(?:[^_*\\]|\\.)*?\_(?:[^_*\\]|\\.)*?(?=\*\*)|(?:[^_\\]|\\.)+(?=[^_])|[punct*](\_+)(?=[\s]|$)|(?:[^punct*_\s\\]|\\.)(\_+)(?=[punct*\s]|$)|[punct*\s](\_+)(?=[^punct*_\s])|[\s](\_+)(?=[punct*])|[punct*](\_+)(?=[punct*])/ // ^- Not allowed for _
    },

    code: /^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/,
    br: /^( {2,}|\\)\n(?!\s*$)/,
    del: noopTest,
    text: /^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/,
    punctuation: /^([\spunctuation])/
  };

  // list of punctuation marks from CommonMark spec
  // without * and _ to handle the different emphasis markers * and _
  inline._punctuation = '!"#$%&\'()+\\-.,/:;<=>?@\\[\\]`^{|}~';
  inline.punctuation = edit(inline.punctuation).replace(/punctuation/g, inline._punctuation).getRegex();

  // sequences em should skip over [title](link), `code`, <html>
  inline.blockSkip = /\[[^\]]*?\]\([^\)]*?\)|`[^`]*?`|<[^>]*?>/g;
  // lookbehind is not available on Safari as of version 16
  // inline.escapedEmSt = /(?<=(?:^|[^\\)(?:\\[^])*)\\[*_]/g;
  inline.escapedEmSt = /(?:^|[^\\])(?:\\\\)*\\[*_]/g;
  inline._comment = edit(block._comment).replace('(?:-->|$)', '-->').getRegex();
  inline.emStrong.lDelim = edit(inline.emStrong.lDelim).replace(/punct/g, inline._punctuation).getRegex();
  inline.emStrong.rDelimAst = edit(inline.emStrong.rDelimAst, 'g').replace(/punct/g, inline._punctuation).getRegex();
  inline.emStrong.rDelimUnd = edit(inline.emStrong.rDelimUnd, 'g').replace(/punct/g, inline._punctuation).getRegex();
  inline._escapes = /\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/g;
  inline._scheme = /[a-zA-Z][a-zA-Z0-9+.-]{1,31}/;
  inline._email = /[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/;
  inline.autolink = edit(inline.autolink).replace('scheme', inline._scheme).replace('email', inline._email).getRegex();
  inline._attribute = /\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/;
  inline.tag = edit(inline.tag).replace('comment', inline._comment).replace('attribute', inline._attribute).getRegex();
  inline._label = /(?:\[(?:\\.|[^\[\]\\])*\]|\\.|`[^`]*`|[^\[\]\\`])*?/;
  inline._href = /<(?:\\.|[^\n<>\\])+>|[^\s\x00-\x1f]*/;
  inline._title = /"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/;
  inline.link = edit(inline.link).replace('label', inline._label).replace('href', inline._href).replace('title', inline._title).getRegex();
  inline.reflink = edit(inline.reflink).replace('label', inline._label).replace('ref', block._label).getRegex();
  inline.nolink = edit(inline.nolink).replace('ref', block._label).getRegex();
  inline.reflinkSearch = edit(inline.reflinkSearch, 'g').replace('reflink', inline.reflink).replace('nolink', inline.nolink).getRegex();

  /**
   * Normal Inline Grammar
   */

  inline.normal = _extends({}, inline);

  /**
   * Pedantic Inline Grammar
   */

  inline.pedantic = _extends({}, inline.normal, {
    strong: {
      start: /^__|\*\*/,
      middle: /^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,
      endAst: /\*\*(?!\*)/g,
      endUnd: /__(?!_)/g
    },
    em: {
      start: /^_|\*/,
      middle: /^()\*(?=\S)([\s\S]*?\S)\*(?!\*)|^_(?=\S)([\s\S]*?\S)_(?!_)/,
      endAst: /\*(?!\*)/g,
      endUnd: /_(?!_)/g
    },
    link: edit(/^!?\[(label)\]\((.*?)\)/).replace('label', inline._label).getRegex(),
    reflink: edit(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace('label', inline._label).getRegex()
  });

  /**
   * GFM Inline Grammar
   */

  inline.gfm = _extends({}, inline.normal, {
    escape: edit(inline.escape).replace('])', '~|])').getRegex(),
    _extended_email: /[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/,
    url: /^((?:ftp|https?):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/,
    _backpedal: /(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/,
    del: /^(~~?)(?=[^\s~])([\s\S]*?[^\s~])\1(?=[^~]|$)/,
    text: /^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|https?:\/\/|ftp:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/
  });
  inline.gfm.url = edit(inline.gfm.url, 'i').replace('email', inline.gfm._extended_email).getRegex();
  /**
   * GFM + Line Breaks Inline Grammar
   */

  inline.breaks = _extends({}, inline.gfm, {
    br: edit(inline.br).replace('{2,}', '*').getRegex(),
    text: edit(inline.gfm.text).replace('\\b_', '\\b_| {2,}\\n').replace(/\{2,\}/g, '*').getRegex()
  });

  /**
   * smartypants text replacement
   * @param {string} text
   */
  function smartypants(text) {
    return text
    // em-dashes
    .replace(/---/g, "\u2014")
    // en-dashes
    .replace(/--/g, "\u2013")
    // opening singles
    .replace(/(^|[-\u2014/(\[{"\s])'/g, "$1\u2018")
    // closing singles & apostrophes
    .replace(/'/g, "\u2019")
    // opening doubles
    .replace(/(^|[-\u2014/(\[{\u2018\s])"/g, "$1\u201C")
    // closing doubles
    .replace(/"/g, "\u201D")
    // ellipses
    .replace(/\.{3}/g, "\u2026");
  }

  /**
   * mangle email addresses
   * @param {string} text
   */
  function mangle(text) {
    var out = '',
      i,
      ch;
    var l = text.length;
    for (i = 0; i < l; i++) {
      ch = text.charCodeAt(i);
      if (Math.random() > 0.5) {
        ch = 'x' + ch.toString(16);
      }
      out += '&#' + ch + ';';
    }
    return out;
  }

  /**
   * Block Lexer
   */
  var Lexer = /*#__PURE__*/function () {
    function Lexer(options) {
      this.tokens = [];
      this.tokens.links = Object.create(null);
      this.options = options || exports.defaults;
      this.options.tokenizer = this.options.tokenizer || new Tokenizer();
      this.tokenizer = this.options.tokenizer;
      this.tokenizer.options = this.options;
      this.tokenizer.lexer = this;
      this.inlineQueue = [];
      this.state = {
        inLink: false,
        inRawBlock: false,
        top: true
      };
      var rules = {
        block: block.normal,
        inline: inline.normal
      };
      if (this.options.pedantic) {
        rules.block = block.pedantic;
        rules.inline = inline.pedantic;
      } else if (this.options.gfm) {
        rules.block = block.gfm;
        if (this.options.breaks) {
          rules.inline = inline.breaks;
        } else {
          rules.inline = inline.gfm;
        }
      }
      this.tokenizer.rules = rules;
    }

    /**
     * Expose Rules
     */
    /**
     * Static Lex Method
     */
    Lexer.lex = function lex(src, options) {
      var lexer = new Lexer(options);
      return lexer.lex(src);
    }

    /**
     * Static Lex Inline Method
     */;
    Lexer.lexInline = function lexInline(src, options) {
      var lexer = new Lexer(options);
      return lexer.inlineTokens(src);
    }

    /**
     * Preprocessing
     */;
    var _proto = Lexer.prototype;
    _proto.lex = function lex(src) {
      src = src.replace(/\r\n|\r/g, '\n');
      this.blockTokens(src, this.tokens);
      var next;
      while (next = this.inlineQueue.shift()) {
        this.inlineTokens(next.src, next.tokens);
      }
      return this.tokens;
    }

    /**
     * Lexing
     */;
    _proto.blockTokens = function blockTokens(src, tokens) {
      var _this = this;
      if (tokens === void 0) {
        tokens = [];
      }
      if (this.options.pedantic) {
        src = src.replace(/\t/g, '    ').replace(/^ +$/gm, '');
      } else {
        src = src.replace(/^( *)(\t+)/gm, function (_, leading, tabs) {
          return leading + '    '.repeat(tabs.length);
        });
      }
      var token, lastToken, cutSrc, lastParagraphClipped;
      while (src) {
        if (this.options.extensions && this.options.extensions.block && this.options.extensions.block.some(function (extTokenizer) {
          if (token = extTokenizer.call({
            lexer: _this
          }, src, tokens)) {
            src = src.substring(token.raw.length);
            tokens.push(token);
            return true;
          }
          return false;
        })) {
          continue;
        }

        // newline
        if (token = this.tokenizer.space(src)) {
          src = src.substring(token.raw.length);
          if (token.raw.length === 1 && tokens.length > 0) {
            // if there's a single \n as a spacer, it's terminating the last line,
            // so move it there so that we don't get unecessary paragraph tags
            tokens[tokens.length - 1].raw += '\n';
          } else {
            tokens.push(token);
          }
          continue;
        }

        // code
        if (token = this.tokenizer.code(src)) {
          src = src.substring(token.raw.length);
          lastToken = tokens[tokens.length - 1];
          // An indented code block cannot interrupt a paragraph.
          if (lastToken && (lastToken.type === 'paragraph' || lastToken.type === 'text')) {
            lastToken.raw += '\n' + token.raw;
            lastToken.text += '\n' + token.text;
            this.inlineQueue[this.inlineQueue.length - 1].src = lastToken.text;
          } else {
            tokens.push(token);
          }
          continue;
        }

        // fences
        if (token = this.tokenizer.fences(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // heading
        if (token = this.tokenizer.heading(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // hr
        if (token = this.tokenizer.hr(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // blockquote
        if (token = this.tokenizer.blockquote(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // list
        if (token = this.tokenizer.list(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // html
        if (token = this.tokenizer.html(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // def
        if (token = this.tokenizer.def(src)) {
          src = src.substring(token.raw.length);
          lastToken = tokens[tokens.length - 1];
          if (lastToken && (lastToken.type === 'paragraph' || lastToken.type === 'text')) {
            lastToken.raw += '\n' + token.raw;
            lastToken.text += '\n' + token.raw;
            this.inlineQueue[this.inlineQueue.length - 1].src = lastToken.text;
          } else if (!this.tokens.links[token.tag]) {
            this.tokens.links[token.tag] = {
              href: token.href,
              title: token.title
            };
          }
          continue;
        }

        // table (gfm)
        if (token = this.tokenizer.table(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // lheading
        if (token = this.tokenizer.lheading(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // top-level paragraph
        // prevent paragraph consuming extensions by clipping 'src' to extension start
        cutSrc = src;
        if (this.options.extensions && this.options.extensions.startBlock) {
          (function () {
            var startIndex = Infinity;
            var tempSrc = src.slice(1);
            var tempStart = void 0;
            _this.options.extensions.startBlock.forEach(function (getStartIndex) {
              tempStart = getStartIndex.call({
                lexer: this
              }, tempSrc);
              if (typeof tempStart === 'number' && tempStart >= 0) {
                startIndex = Math.min(startIndex, tempStart);
              }
            });
            if (startIndex < Infinity && startIndex >= 0) {
              cutSrc = src.substring(0, startIndex + 1);
            }
          })();
        }
        if (this.state.top && (token = this.tokenizer.paragraph(cutSrc))) {
          lastToken = tokens[tokens.length - 1];
          if (lastParagraphClipped && lastToken.type === 'paragraph') {
            lastToken.raw += '\n' + token.raw;
            lastToken.text += '\n' + token.text;
            this.inlineQueue.pop();
            this.inlineQueue[this.inlineQueue.length - 1].src = lastToken.text;
          } else {
            tokens.push(token);
          }
          lastParagraphClipped = cutSrc.length !== src.length;
          src = src.substring(token.raw.length);
          continue;
        }

        // text
        if (token = this.tokenizer.text(src)) {
          src = src.substring(token.raw.length);
          lastToken = tokens[tokens.length - 1];
          if (lastToken && lastToken.type === 'text') {
            lastToken.raw += '\n' + token.raw;
            lastToken.text += '\n' + token.text;
            this.inlineQueue.pop();
            this.inlineQueue[this.inlineQueue.length - 1].src = lastToken.text;
          } else {
            tokens.push(token);
          }
          continue;
        }
        if (src) {
          var errMsg = 'Infinite loop on byte: ' + src.charCodeAt(0);
          if (this.options.silent) {
            console.error(errMsg);
            break;
          } else {
            throw new Error(errMsg);
          }
        }
      }
      this.state.top = true;
      return tokens;
    };
    _proto.inline = function inline(src, tokens) {
      if (tokens === void 0) {
        tokens = [];
      }
      this.inlineQueue.push({
        src: src,
        tokens: tokens
      });
      return tokens;
    }

    /**
     * Lexing/Compiling
     */;
    _proto.inlineTokens = function inlineTokens(src, tokens) {
      var _this2 = this;
      if (tokens === void 0) {
        tokens = [];
      }
      var token, lastToken, cutSrc;

      // String with links masked to avoid interference with em and strong
      var maskedSrc = src;
      var match;
      var keepPrevChar, prevChar;

      // Mask out reflinks
      if (this.tokens.links) {
        var links = Object.keys(this.tokens.links);
        if (links.length > 0) {
          while ((match = this.tokenizer.rules.inline.reflinkSearch.exec(maskedSrc)) != null) {
            if (links.includes(match[0].slice(match[0].lastIndexOf('[') + 1, -1))) {
              maskedSrc = maskedSrc.slice(0, match.index) + '[' + repeatString('a', match[0].length - 2) + ']' + maskedSrc.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex);
            }
          }
        }
      }
      // Mask out other blocks
      while ((match = this.tokenizer.rules.inline.blockSkip.exec(maskedSrc)) != null) {
        maskedSrc = maskedSrc.slice(0, match.index) + '[' + repeatString('a', match[0].length - 2) + ']' + maskedSrc.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);
      }

      // Mask out escaped em & strong delimiters
      while ((match = this.tokenizer.rules.inline.escapedEmSt.exec(maskedSrc)) != null) {
        maskedSrc = maskedSrc.slice(0, match.index + match[0].length - 2) + '++' + maskedSrc.slice(this.tokenizer.rules.inline.escapedEmSt.lastIndex);
        this.tokenizer.rules.inline.escapedEmSt.lastIndex--;
      }
      while (src) {
        if (!keepPrevChar) {
          prevChar = '';
        }
        keepPrevChar = false;

        // extensions
        if (this.options.extensions && this.options.extensions.inline && this.options.extensions.inline.some(function (extTokenizer) {
          if (token = extTokenizer.call({
            lexer: _this2
          }, src, tokens)) {
            src = src.substring(token.raw.length);
            tokens.push(token);
            return true;
          }
          return false;
        })) {
          continue;
        }

        // escape
        if (token = this.tokenizer.escape(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // tag
        if (token = this.tokenizer.tag(src)) {
          src = src.substring(token.raw.length);
          lastToken = tokens[tokens.length - 1];
          if (lastToken && token.type === 'text' && lastToken.type === 'text') {
            lastToken.raw += token.raw;
            lastToken.text += token.text;
          } else {
            tokens.push(token);
          }
          continue;
        }

        // link
        if (token = this.tokenizer.link(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // reflink, nolink
        if (token = this.tokenizer.reflink(src, this.tokens.links)) {
          src = src.substring(token.raw.length);
          lastToken = tokens[tokens.length - 1];
          if (lastToken && token.type === 'text' && lastToken.type === 'text') {
            lastToken.raw += token.raw;
            lastToken.text += token.text;
          } else {
            tokens.push(token);
          }
          continue;
        }

        // em & strong
        if (token = this.tokenizer.emStrong(src, maskedSrc, prevChar)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // code
        if (token = this.tokenizer.codespan(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // br
        if (token = this.tokenizer.br(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // del (gfm)
        if (token = this.tokenizer.del(src)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // autolink
        if (token = this.tokenizer.autolink(src, mangle)) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // url (gfm)
        if (!this.state.inLink && (token = this.tokenizer.url(src, mangle))) {
          src = src.substring(token.raw.length);
          tokens.push(token);
          continue;
        }

        // text
        // prevent inlineText consuming extensions by clipping 'src' to extension start
        cutSrc = src;
        if (this.options.extensions && this.options.extensions.startInline) {
          (function () {
            var startIndex = Infinity;
            var tempSrc = src.slice(1);
            var tempStart = void 0;
            _this2.options.extensions.startInline.forEach(function (getStartIndex) {
              tempStart = getStartIndex.call({
                lexer: this
              }, tempSrc);
              if (typeof tempStart === 'number' && tempStart >= 0) {
                startIndex = Math.min(startIndex, tempStart);
              }
            });
            if (startIndex < Infinity && startIndex >= 0) {
              cutSrc = src.substring(0, startIndex + 1);
            }
          })();
        }
        if (token = this.tokenizer.inlineText(cutSrc, smartypants)) {
          src = src.substring(token.raw.length);
          if (token.raw.slice(-1) !== '_') {
            // Track prevChar before string of ____ started
            prevChar = token.raw.slice(-1);
          }
          keepPrevChar = true;
          lastToken = tokens[tokens.length - 1];
          if (lastToken && lastToken.type === 'text') {
            lastToken.raw += token.raw;
            lastToken.text += token.text;
          } else {
            tokens.push(token);
          }
          continue;
        }
        if (src) {
          var errMsg = 'Infinite loop on byte: ' + src.charCodeAt(0);
          if (this.options.silent) {
            console.error(errMsg);
            break;
          } else {
            throw new Error(errMsg);
          }
        }
      }
      return tokens;
    };
    _createClass(Lexer, null, [{
      key: "rules",
      get: function get() {
        return {
          block: block,
          inline: inline
        };
      }
    }]);
    return Lexer;
  }();

  /**
   * Renderer
   */
  var Renderer = /*#__PURE__*/function () {
    function Renderer(options) {
      this.options = options || exports.defaults;
    }
    var _proto = Renderer.prototype;
    _proto.code = function code(_code, infostring, escaped) {
      var lang = (infostring || '').match(/\S*/)[0];
      if (this.options.highlight) {
        var out = this.options.highlight(_code, lang);
        if (out != null && out !== _code) {
          escaped = true;
          _code = out;
        }
      }
      _code = _code.replace(/\n$/, '') + '\n';
      if (!lang) {
        return '<pre><code>' + (escaped ? _code : escape(_code, true)) + '</code></pre>\n';
      }
      return '<pre><code class="' + this.options.langPrefix + escape(lang) + '">' + (escaped ? _code : escape(_code, true)) + '</code></pre>\n';
    }

    /**
     * @param {string} quote
     */;
    _proto.blockquote = function blockquote(quote) {
      return "<blockquote>\n" + quote + "</blockquote>\n";
    };
    _proto.html = function html(_html) {
      return _html;
    }

    /**
     * @param {string} text
     * @param {string} level
     * @param {string} raw
     * @param {any} slugger
     */;
    _proto.heading = function heading(text, level, raw, slugger) {
      if (this.options.headerIds) {
        var id = this.options.headerPrefix + slugger.slug(raw);
        return "<h" + level + " id=\"" + id + "\">" + text + "</h" + level + ">\n";
      }

      // ignore IDs
      return "<h" + level + ">" + text + "</h" + level + ">\n";
    };
    _proto.hr = function hr() {
      return this.options.xhtml ? '<hr/>\n' : '<hr>\n';
    };
    _proto.list = function list(body, ordered, start) {
      var type = ordered ? 'ol' : 'ul',
        startatt = ordered && start !== 1 ? ' start="' + start + '"' : '';
      return '<' + type + startatt + '>\n' + body + '</' + type + '>\n';
    }

    /**
     * @param {string} text
     */;
    _proto.listitem = function listitem(text) {
      return "<li>" + text + "</li>\n";
    };
    _proto.checkbox = function checkbox(checked) {
      return '<input ' + (checked ? 'checked="" ' : '') + 'disabled="" type="checkbox"' + (this.options.xhtml ? ' /' : '') + '> ';
    }

    /**
     * @param {string} text
     */;
    _proto.paragraph = function paragraph(text) {
      return "<p>" + text + "</p>\n";
    }

    /**
     * @param {string} header
     * @param {string} body
     */;
    _proto.table = function table(header, body) {
      if (body) body = "<tbody>" + body + "</tbody>";
      return '<table>\n' + '<thead>\n' + header + '</thead>\n' + body + '</table>\n';
    }

    /**
     * @param {string} content
     */;
    _proto.tablerow = function tablerow(content) {
      return "<tr>\n" + content + "</tr>\n";
    };
    _proto.tablecell = function tablecell(content, flags) {
      var type = flags.header ? 'th' : 'td';
      var tag = flags.align ? "<" + type + " align=\"" + flags.align + "\">" : "<" + type + ">";
      return tag + content + ("</" + type + ">\n");
    }

    /**
     * span level renderer
     * @param {string} text
     */;
    _proto.strong = function strong(text) {
      return "<strong>" + text + "</strong>";
    }

    /**
     * @param {string} text
     */;
    _proto.em = function em(text) {
      return "<em>" + text + "</em>";
    }

    /**
     * @param {string} text
     */;
    _proto.codespan = function codespan(text) {
      return "<code>" + text + "</code>";
    };
    _proto.br = function br() {
      return this.options.xhtml ? '<br/>' : '<br>';
    }

    /**
     * @param {string} text
     */;
    _proto.del = function del(text) {
      return "<del>" + text + "</del>";
    }

    /**
     * @param {string} href
     * @param {string} title
     * @param {string} text
     */;
    _proto.link = function link(href, title, text) {
      href = cleanUrl(this.options.sanitize, this.options.baseUrl, href);
      if (href === null) {
        return text;
      }
      var out = '<a href="' + href + '"';
      if (title) {
        out += ' title="' + title + '"';
      }
      out += '>' + text + '</a>';
      return out;
    }

    /**
     * @param {string} href
     * @param {string} title
     * @param {string} text
     */;
    _proto.image = function image(href, title, text) {
      href = cleanUrl(this.options.sanitize, this.options.baseUrl, href);
      if (href === null) {
        return text;
      }
      var out = "<img src=\"" + href + "\" alt=\"" + text + "\"";
      if (title) {
        out += " title=\"" + title + "\"";
      }
      out += this.options.xhtml ? '/>' : '>';
      return out;
    };
    _proto.text = function text(_text) {
      return _text;
    };
    return Renderer;
  }();

  /**
   * TextRenderer
   * returns only the textual part of the token
   */
  var TextRenderer = /*#__PURE__*/function () {
    function TextRenderer() {}
    var _proto = TextRenderer.prototype;
    // no need for block level renderers
    _proto.strong = function strong(text) {
      return text;
    };
    _proto.em = function em(text) {
      return text;
    };
    _proto.codespan = function codespan(text) {
      return text;
    };
    _proto.del = function del(text) {
      return text;
    };
    _proto.html = function html(text) {
      return text;
    };
    _proto.text = function text(_text) {
      return _text;
    };
    _proto.link = function link(href, title, text) {
      return '' + text;
    };
    _proto.image = function image(href, title, text) {
      return '' + text;
    };
    _proto.br = function br() {
      return '';
    };
    return TextRenderer;
  }();

  /**
   * Slugger generates header id
   */
  var Slugger = /*#__PURE__*/function () {
    function Slugger() {
      this.seen = {};
    }

    /**
     * @param {string} value
     */
    var _proto = Slugger.prototype;
    _proto.serialize = function serialize(value) {
      return value.toLowerCase().trim()
      // remove html tags
      .replace(/<[!\/a-z].*?>/ig, '')
      // remove unwanted chars
      .replace(/[\u2000-\u206F\u2E00-\u2E7F\\'!"#$%&()*+,./:;<=>?@[\]^`{|}~]/g, '').replace(/\s/g, '-');
    }

    /**
     * Finds the next safe (unique) slug to use
     * @param {string} originalSlug
     * @param {boolean} isDryRun
     */;
    _proto.getNextSafeSlug = function getNextSafeSlug(originalSlug, isDryRun) {
      var slug = originalSlug;
      var occurenceAccumulator = 0;
      if (this.seen.hasOwnProperty(slug)) {
        occurenceAccumulator = this.seen[originalSlug];
        do {
          occurenceAccumulator++;
          slug = originalSlug + '-' + occurenceAccumulator;
        } while (this.seen.hasOwnProperty(slug));
      }
      if (!isDryRun) {
        this.seen[originalSlug] = occurenceAccumulator;
        this.seen[slug] = 0;
      }
      return slug;
    }

    /**
     * Convert string to unique id
     * @param {object} [options]
     * @param {boolean} [options.dryrun] Generates the next unique slug without
     * updating the internal accumulator.
     */;
    _proto.slug = function slug(value, options) {
      if (options === void 0) {
        options = {};
      }
      var slug = this.serialize(value);
      return this.getNextSafeSlug(slug, options.dryrun);
    };
    return Slugger;
  }();

  /**
   * Parsing & Compiling
   */
  var Parser = /*#__PURE__*/function () {
    function Parser(options) {
      this.options = options || exports.defaults;
      this.options.renderer = this.options.renderer || new Renderer();
      this.renderer = this.options.renderer;
      this.renderer.options = this.options;
      this.textRenderer = new TextRenderer();
      this.slugger = new Slugger();
    }

    /**
     * Static Parse Method
     */
    Parser.parse = function parse(tokens, options) {
      var parser = new Parser(options);
      return parser.parse(tokens);
    }

    /**
     * Static Parse Inline Method
     */;
    Parser.parseInline = function parseInline(tokens, options) {
      var parser = new Parser(options);
      return parser.parseInline(tokens);
    }

    /**
     * Parse Loop
     */;
    var _proto = Parser.prototype;
    _proto.parse = function parse(tokens, top) {
      if (top === void 0) {
        top = true;
      }
      var out = '',
        i,
        j,
        k,
        l2,
        l3,
        row,
        cell,
        header,
        body,
        token,
        ordered,
        start,
        loose,
        itemBody,
        item,
        checked,
        task,
        checkbox,
        ret;
      var l = tokens.length;
      for (i = 0; i < l; i++) {
        token = tokens[i];

        // Run any renderer extensions
        if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[token.type]) {
          ret = this.options.extensions.renderers[token.type].call({
            parser: this
          }, token);
          if (ret !== false || !['space', 'hr', 'heading', 'code', 'table', 'blockquote', 'list', 'html', 'paragraph', 'text'].includes(token.type)) {
            out += ret || '';
            continue;
          }
        }
        switch (token.type) {
          case 'space':
            {
              continue;
            }
          case 'hr':
            {
              out += this.renderer.hr();
              continue;
            }
          case 'heading':
            {
              out += this.renderer.heading(this.parseInline(token.tokens), token.depth, unescape(this.parseInline(token.tokens, this.textRenderer)), this.slugger);
              continue;
            }
          case 'code':
            {
              out += this.renderer.code(token.text, token.lang, token.escaped);
              continue;
            }
          case 'table':
            {
              header = '';

              // header
              cell = '';
              l2 = token.header.length;
              for (j = 0; j < l2; j++) {
                cell += this.renderer.tablecell(this.parseInline(token.header[j].tokens), {
                  header: true,
                  align: token.align[j]
                });
              }
              header += this.renderer.tablerow(cell);
              body = '';
              l2 = token.rows.length;
              for (j = 0; j < l2; j++) {
                row = token.rows[j];
                cell = '';
                l3 = row.length;
                for (k = 0; k < l3; k++) {
                  cell += this.renderer.tablecell(this.parseInline(row[k].tokens), {
                    header: false,
                    align: token.align[k]
                  });
                }
                body += this.renderer.tablerow(cell);
              }
              out += this.renderer.table(header, body);
              continue;
            }
          case 'blockquote':
            {
              body = this.parse(token.tokens);
              out += this.renderer.blockquote(body);
              continue;
            }
          case 'list':
            {
              ordered = token.ordered;
              start = token.start;
              loose = token.loose;
              l2 = token.items.length;
              body = '';
              for (j = 0; j < l2; j++) {
                item = token.items[j];
                checked = item.checked;
                task = item.task;
                itemBody = '';
                if (item.task) {
                  checkbox = this.renderer.checkbox(checked);
                  if (loose) {
                    if (item.tokens.length > 0 && item.tokens[0].type === 'paragraph') {
                      item.tokens[0].text = checkbox + ' ' + item.tokens[0].text;
                      if (item.tokens[0].tokens && item.tokens[0].tokens.length > 0 && item.tokens[0].tokens[0].type === 'text') {
                        item.tokens[0].tokens[0].text = checkbox + ' ' + item.tokens[0].tokens[0].text;
                      }
                    } else {
                      item.tokens.unshift({
                        type: 'text',
                        text: checkbox
                      });
                    }
                  } else {
                    itemBody += checkbox;
                  }
                }
                itemBody += this.parse(item.tokens, loose);
                body += this.renderer.listitem(itemBody, task, checked);
              }
              out += this.renderer.list(body, ordered, start);
              continue;
            }
          case 'html':
            {
              // TODO parse inline content if parameter markdown=1
              out += this.renderer.html(token.text);
              continue;
            }
          case 'paragraph':
            {
              out += this.renderer.paragraph(this.parseInline(token.tokens));
              continue;
            }
          case 'text':
            {
              body = token.tokens ? this.parseInline(token.tokens) : token.text;
              while (i + 1 < l && tokens[i + 1].type === 'text') {
                token = tokens[++i];
                body += '\n' + (token.tokens ? this.parseInline(token.tokens) : token.text);
              }
              out += top ? this.renderer.paragraph(body) : body;
              continue;
            }
          default:
            {
              var errMsg = 'Token with "' + token.type + '" type was not found.';
              if (this.options.silent) {
                console.error(errMsg);
                return;
              } else {
                throw new Error(errMsg);
              }
            }
        }
      }
      return out;
    }

    /**
     * Parse Inline Tokens
     */;
    _proto.parseInline = function parseInline(tokens, renderer) {
      renderer = renderer || this.renderer;
      var out = '',
        i,
        token,
        ret;
      var l = tokens.length;
      for (i = 0; i < l; i++) {
        token = tokens[i];

        // Run any renderer extensions
        if (this.options.extensions && this.options.extensions.renderers && this.options.extensions.renderers[token.type]) {
          ret = this.options.extensions.renderers[token.type].call({
            parser: this
          }, token);
          if (ret !== false || !['escape', 'html', 'link', 'image', 'strong', 'em', 'codespan', 'br', 'del', 'text'].includes(token.type)) {
            out += ret || '';
            continue;
          }
        }
        switch (token.type) {
          case 'escape':
            {
              out += renderer.text(token.text);
              break;
            }
          case 'html':
            {
              out += renderer.html(token.text);
              break;
            }
          case 'link':
            {
              out += renderer.link(token.href, token.title, this.parseInline(token.tokens, renderer));
              break;
            }
          case 'image':
            {
              out += renderer.image(token.href, token.title, token.text);
              break;
            }
          case 'strong':
            {
              out += renderer.strong(this.parseInline(token.tokens, renderer));
              break;
            }
          case 'em':
            {
              out += renderer.em(this.parseInline(token.tokens, renderer));
              break;
            }
          case 'codespan':
            {
              out += renderer.codespan(token.text);
              break;
            }
          case 'br':
            {
              out += renderer.br();
              break;
            }
          case 'del':
            {
              out += renderer.del(this.parseInline(token.tokens, renderer));
              break;
            }
          case 'text':
            {
              out += renderer.text(token.text);
              break;
            }
          default:
            {
              var errMsg = 'Token with "' + token.type + '" type was not found.';
              if (this.options.silent) {
                console.error(errMsg);
                return;
              } else {
                throw new Error(errMsg);
              }
            }
        }
      }
      return out;
    };
    return Parser;
  }();

  var Hooks = /*#__PURE__*/function () {
    function Hooks(options) {
      this.options = options || exports.defaults;
    }
    var _proto = Hooks.prototype;
    /**
     * Process markdown before marked
     */
    _proto.preprocess = function preprocess(markdown) {
      return markdown;
    }

    /**
     * Process HTML after marked is finished
     */;
    _proto.postprocess = function postprocess(html) {
      return html;
    };
    return Hooks;
  }();
  Hooks.passThroughHooks = new Set(['preprocess', 'postprocess']);

  function onError(silent, async, callback) {
    return function (e) {
      e.message += '\nPlease report this to https://github.com/markedjs/marked.';
      if (silent) {
        var msg = '<p>An error occurred:</p><pre>' + escape(e.message + '', true) + '</pre>';
        if (async) {
          return Promise.resolve(msg);
        }
        if (callback) {
          callback(null, msg);
          return;
        }
        return msg;
      }
      if (async) {
        return Promise.reject(e);
      }
      if (callback) {
        callback(e);
        return;
      }
      throw e;
    };
  }
  function parseMarkdown(lexer, parser) {
    return function (src, opt, callback) {
      if (typeof opt === 'function') {
        callback = opt;
        opt = null;
      }
      var origOpt = _extends({}, opt);
      opt = _extends({}, marked.defaults, origOpt);
      var throwError = onError(opt.silent, opt.async, callback);

      // throw error in case of non string input
      if (typeof src === 'undefined' || src === null) {
        return throwError(new Error('marked(): input parameter is undefined or null'));
      }
      if (typeof src !== 'string') {
        return throwError(new Error('marked(): input parameter is of type ' + Object.prototype.toString.call(src) + ', string expected'));
      }
      checkSanitizeDeprecation(opt);
      if (opt.hooks) {
        opt.hooks.options = opt;
      }
      if (callback) {
        var highlight = opt.highlight;
        var tokens;
        try {
          if (opt.hooks) {
            src = opt.hooks.preprocess(src);
          }
          tokens = lexer(src, opt);
        } catch (e) {
          return throwError(e);
        }
        var done = function done(err) {
          var out;
          if (!err) {
            try {
              if (opt.walkTokens) {
                marked.walkTokens(tokens, opt.walkTokens);
              }
              out = parser(tokens, opt);
              if (opt.hooks) {
                out = opt.hooks.postprocess(out);
              }
            } catch (e) {
              err = e;
            }
          }
          opt.highlight = highlight;
          return err ? throwError(err) : callback(null, out);
        };
        if (!highlight || highlight.length < 3) {
          return done();
        }
        delete opt.highlight;
        if (!tokens.length) return done();
        var pending = 0;
        marked.walkTokens(tokens, function (token) {
          if (token.type === 'code') {
            pending++;
            setTimeout(function () {
              highlight(token.text, token.lang, function (err, code) {
                if (err) {
                  return done(err);
                }
                if (code != null && code !== token.text) {
                  token.text = code;
                  token.escaped = true;
                }
                pending--;
                if (pending === 0) {
                  done();
                }
              });
            }, 0);
          }
        });
        if (pending === 0) {
          done();
        }
        return;
      }
      if (opt.async) {
        return Promise.resolve(opt.hooks ? opt.hooks.preprocess(src) : src).then(function (src) {
          return lexer(src, opt);
        }).then(function (tokens) {
          return opt.walkTokens ? Promise.all(marked.walkTokens(tokens, opt.walkTokens)).then(function () {
            return tokens;
          }) : tokens;
        }).then(function (tokens) {
          return parser(tokens, opt);
        }).then(function (html) {
          return opt.hooks ? opt.hooks.postprocess(html) : html;
        })["catch"](throwError);
      }
      try {
        if (opt.hooks) {
          src = opt.hooks.preprocess(src);
        }
        var _tokens = lexer(src, opt);
        if (opt.walkTokens) {
          marked.walkTokens(_tokens, opt.walkTokens);
        }
        var html = parser(_tokens, opt);
        if (opt.hooks) {
          html = opt.hooks.postprocess(html);
        }
        return html;
      } catch (e) {
        return throwError(e);
      }
    };
  }

  /**
   * Marked
   */
  function marked(src, opt, callback) {
    return parseMarkdown(Lexer.lex, Parser.parse)(src, opt, callback);
  }

  /**
   * Options
   */

  marked.options = marked.setOptions = function (opt) {
    marked.defaults = _extends({}, marked.defaults, opt);
    changeDefaults(marked.defaults);
    return marked;
  };
  marked.getDefaults = getDefaults;
  marked.defaults = exports.defaults;

  /**
   * Use Extension
   */

  marked.use = function () {
    var extensions = marked.defaults.extensions || {
      renderers: {},
      childTokens: {}
    };
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    args.forEach(function (pack) {
      // copy options to new object
      var opts = _extends({}, pack);

      // set async to true if it was set to true before
      opts.async = marked.defaults.async || opts.async || false;

      // ==-- Parse "addon" extensions --== //
      if (pack.extensions) {
        pack.extensions.forEach(function (ext) {
          if (!ext.name) {
            throw new Error('extension name required');
          }
          if (ext.renderer) {
            // Renderer extensions
            var prevRenderer = extensions.renderers[ext.name];
            if (prevRenderer) {
              // Replace extension with func to run new extension but fall back if false
              extensions.renderers[ext.name] = function () {
                for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
                  args[_key2] = arguments[_key2];
                }
                var ret = ext.renderer.apply(this, args);
                if (ret === false) {
                  ret = prevRenderer.apply(this, args);
                }
                return ret;
              };
            } else {
              extensions.renderers[ext.name] = ext.renderer;
            }
          }
          if (ext.tokenizer) {
            // Tokenizer Extensions
            if (!ext.level || ext.level !== 'block' && ext.level !== 'inline') {
              throw new Error("extension level must be 'block' or 'inline'");
            }
            if (extensions[ext.level]) {
              extensions[ext.level].unshift(ext.tokenizer);
            } else {
              extensions[ext.level] = [ext.tokenizer];
            }
            if (ext.start) {
              // Function to check for start of token
              if (ext.level === 'block') {
                if (extensions.startBlock) {
                  extensions.startBlock.push(ext.start);
                } else {
                  extensions.startBlock = [ext.start];
                }
              } else if (ext.level === 'inline') {
                if (extensions.startInline) {
                  extensions.startInline.push(ext.start);
                } else {
                  extensions.startInline = [ext.start];
                }
              }
            }
          }
          if (ext.childTokens) {
            // Child tokens to be visited by walkTokens
            extensions.childTokens[ext.name] = ext.childTokens;
          }
        });
        opts.extensions = extensions;
      }

      // ==-- Parse "overwrite" extensions --== //
      if (pack.renderer) {
        (function () {
          var renderer = marked.defaults.renderer || new Renderer();
          var _loop = function _loop(prop) {
            var prevRenderer = renderer[prop];
            // Replace renderer with func to run extension, but fall back if false
            renderer[prop] = function () {
              for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
                args[_key3] = arguments[_key3];
              }
              var ret = pack.renderer[prop].apply(renderer, args);
              if (ret === false) {
                ret = prevRenderer.apply(renderer, args);
              }
              return ret;
            };
          };
          for (var prop in pack.renderer) {
            _loop(prop);
          }
          opts.renderer = renderer;
        })();
      }
      if (pack.tokenizer) {
        (function () {
          var tokenizer = marked.defaults.tokenizer || new Tokenizer();
          var _loop2 = function _loop2(prop) {
            var prevTokenizer = tokenizer[prop];
            // Replace tokenizer with func to run extension, but fall back if false
            tokenizer[prop] = function () {
              for (var _len4 = arguments.length, args = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
                args[_key4] = arguments[_key4];
              }
              var ret = pack.tokenizer[prop].apply(tokenizer, args);
              if (ret === false) {
                ret = prevTokenizer.apply(tokenizer, args);
              }
              return ret;
            };
          };
          for (var prop in pack.tokenizer) {
            _loop2(prop);
          }
          opts.tokenizer = tokenizer;
        })();
      }

      // ==-- Parse Hooks extensions --== //
      if (pack.hooks) {
        (function () {
          var hooks = marked.defaults.hooks || new Hooks();
          var _loop3 = function _loop3(prop) {
            var prevHook = hooks[prop];
            if (Hooks.passThroughHooks.has(prop)) {
              hooks[prop] = function (arg) {
                if (marked.defaults.async) {
                  return Promise.resolve(pack.hooks[prop].call(hooks, arg)).then(function (ret) {
                    return prevHook.call(hooks, ret);
                  });
                }
                var ret = pack.hooks[prop].call(hooks, arg);
                return prevHook.call(hooks, ret);
              };
            } else {
              hooks[prop] = function () {
                for (var _len5 = arguments.length, args = new Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
                  args[_key5] = arguments[_key5];
                }
                var ret = pack.hooks[prop].apply(hooks, args);
                if (ret === false) {
                  ret = prevHook.apply(hooks, args);
                }
                return ret;
              };
            }
          };
          for (var prop in pack.hooks) {
            _loop3(prop);
          }
          opts.hooks = hooks;
        })();
      }

      // ==-- Parse WalkTokens extensions --== //
      if (pack.walkTokens) {
        var _walkTokens = marked.defaults.walkTokens;
        opts.walkTokens = function (token) {
          var values = [];
          values.push(pack.walkTokens.call(this, token));
          if (_walkTokens) {
            values = values.concat(_walkTokens.call(this, token));
          }
          return values;
        };
      }
      marked.setOptions(opts);
    });
  };

  /**
   * Run callback for every token
   */

  marked.walkTokens = function (tokens, callback) {
    var values = [];
    var _loop4 = function _loop4() {
      var token = _step.value;
      values = values.concat(callback.call(marked, token));
      switch (token.type) {
        case 'table':
          {
            for (var _iterator2 = _createForOfIteratorHelperLoose(token.header), _step2; !(_step2 = _iterator2()).done;) {
              var cell = _step2.value;
              values = values.concat(marked.walkTokens(cell.tokens, callback));
            }
            for (var _iterator3 = _createForOfIteratorHelperLoose(token.rows), _step3; !(_step3 = _iterator3()).done;) {
              var row = _step3.value;
              for (var _iterator4 = _createForOfIteratorHelperLoose(row), _step4; !(_step4 = _iterator4()).done;) {
                var _cell = _step4.value;
                values = values.concat(marked.walkTokens(_cell.tokens, callback));
              }
            }
            break;
          }
        case 'list':
          {
            values = values.concat(marked.walkTokens(token.items, callback));
            break;
          }
        default:
          {
            if (marked.defaults.extensions && marked.defaults.extensions.childTokens && marked.defaults.extensions.childTokens[token.type]) {
              // Walk any extensions
              marked.defaults.extensions.childTokens[token.type].forEach(function (childTokens) {
                values = values.concat(marked.walkTokens(token[childTokens], callback));
              });
            } else if (token.tokens) {
              values = values.concat(marked.walkTokens(token.tokens, callback));
            }
          }
      }
    };
    for (var _iterator = _createForOfIteratorHelperLoose(tokens), _step; !(_step = _iterator()).done;) {
      _loop4();
    }
    return values;
  };

  /**
   * Parse Inline
   * @param {string} src
   */
  marked.parseInline = parseMarkdown(Lexer.lexInline, Parser.parseInline);

  /**
   * Expose
   */
  marked.Parser = Parser;
  marked.parser = Parser.parse;
  marked.Renderer = Renderer;
  marked.TextRenderer = TextRenderer;
  marked.Lexer = Lexer;
  marked.lexer = Lexer.lex;
  marked.Tokenizer = Tokenizer;
  marked.Slugger = Slugger;
  marked.Hooks = Hooks;
  marked.parse = marked;
  var options = marked.options;
  var setOptions = marked.setOptions;
  var use = marked.use;
  var walkTokens = marked.walkTokens;
  var parseInline = marked.parseInline;
  var parse = marked;
  var parser = Parser.parse;
  var lexer = Lexer.lex;

  exports.Hooks = Hooks;
  exports.Lexer = Lexer;
  exports.Parser = Parser;
  exports.Renderer = Renderer;
  exports.Slugger = Slugger;
  exports.TextRenderer = TextRenderer;
  exports.Tokenizer = Tokenizer;
  exports.getDefaults = getDefaults;
  exports.lexer = lexer;
  exports.marked = marked;
  exports.options = options;
  exports.parse = parse;
  exports.parseInline = parseInline;
  exports.parser = parser;
  exports.setOptions = setOptions;
  exports.use = use;
  exports.walkTokens = walkTokens;

}));
}(marked_umd, marked_umd.exports));

const taskMarkdownCss = ":host{display:block}.content{font-family:sans-serif}.content img{max-width:100%}";
const TaskMarkdownStyle0 = taskMarkdownCss;

const TaskMarkdown = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.markdown_url = undefined;
        this.markdownHTML = undefined;
        this.children = [];
    }
    componentWillLoad() {
        const assetMap = new Map();
        let child;
        for (child of Array.from(this.host.children)) {
            if (child.tagName === "TASK-ASSET") {
                assetMap.set(child.getAttribute("asset"), child.getAttribute("value"));
            }
        }
        fetch(this.markdown_url, {
            method: 'GET', cache: "no-cache"
        }).then(response => response.text())
            .then(response => {
            let html = marked_umd.exports.parse(response);
            assetMap.forEach((value, key) => {
                html = html.replace(key, value);
            });
            this.markdownHTML = html;
        });
    }
    render() {
        return (index.h("div", { key: 'fdaafad395aa5ba83f221867966fa1270ebda6d9', class: "content", innerHTML: this.markdownHTML }));
    }
    get host() { return index.getElement(this); }
};
TaskMarkdown.style = TaskMarkdownStyle0;

const taskOverlayCss = ".overlay-portal{bottom:0;left:0;position:absolute;right:0;top:0}.overlay{bottom:0;left:0;position:static;right:0;top:0;z-index:20}body.overlay-open{overflow:hidden}.overlay:not(.overlay-open){pointer-events:none}.overlay.overlay-container{overflow:hidden;position:fixed}.overlay.overlay-scroll-container{overflow:auto;position:fixed}.overlay-content{position:fixed;z-index:20}.overlay-closed{display:none}.overlay-scroll-container .overlay-content{position:absolute}.overlay-backdrop{bottom:0;left:0;position:fixed;right:0;top:0;opacity:1;background-color:rgba(17, 20, 24, 0.7);overflow:auto;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;z-index:20}.overlay-backdrop:focus{outline:none}";
const TaskOverlayStyle0 = taskOverlayCss;

const TaskOverlay = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.close = index.createEvent(this, "close", 7);
        this.closed = index.createEvent(this, "closed", 7);
        this.closing = index.createEvent(this, "closing", 7);
        this.opened = index.createEvent(this, "opened", 7);
        this.opening = index.createEvent(this, "opening", 7);
        this.isAutoFocusing = false;
        this.maybeRenderChild = (child) => {
            console.log(child);
            if (utils.isFunction(child)) {
                child = child();
            }
            if (child == null) {
                console.log("null");
                return null;
            }
            // decorate the child with a few injected props
            const tabIndex = this.enforceFocus || this.autoFocus ? 0 : undefined;
            let decoratedChild;
            if (typeof child === "object") {
                decoratedChild = child.cloneNode();
                decoratedChild.className = inputBase.classNames(child.className, "overlay-content");
                decoratedChild.tabIndex = tabIndex;
            }
            else {
                decoratedChild = index.h("span", { class: "content", tabIndex: tabIndex }, child);
            }
            return decoratedChild;
        };
        /**
         * Ensures repeatedly pressing shift+tab keeps focus inside the Overlay. Moves focus to
         * the `endFocusTrapElement` or the first keyboard-focusable element in the Overlay (excluding
         * the `startFocusTrapElement`), depending on whether the element losing focus is inside the
         * Overlay.
         */
        this.handleStartFocusTrapElementFocus = (e) => {
            var _a, _b;
            if (!this.enforceFocus || this.isAutoFocusing) {
                return;
            }
            // e.relatedTarget will not be defined if this was a programmatic focus event, as is the
            // case when we call this.bringFocusInsideOverlay() after a user clicked on the backdrop.
            // Otherwise, we're handling a user interaction, and we should wrap around to the last
            // element in this transition group.
            if (e.relatedTarget != null &&
                ((_a = this.host) === null || _a === void 0 ? void 0 : _a.contains(e.relatedTarget)) &&
                e.relatedTarget !== this.endFocusTrapElement) {
                (_b = this.endFocusTrapElement) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
            }
        };
        /**
         * Wrap around to the end of the dialog if `enforceFocus` is enabled.
         */
        this.handleStartFocusTrapElementKeyDown = (e) => {
            var _a;
            if (!this.enforceFocus) {
                return;
            }
            if (e.shiftKey && e.key === "Tab") {
                const lastFocusableElement = this.getKeyboardFocusableElements().pop();
                if (lastFocusableElement != null) {
                    lastFocusableElement.focus();
                }
                else {
                    (_a = this.endFocusTrapElement) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true });
                }
            }
        };
        /**
         * Ensures repeatedly pressing tab keeps focus inside the Overlay. Moves focus to the
         * `startFocusTrapElement` or the last keyboard-focusable element in the Overlay (excluding the
         * `startFocusTrapElement`), depending on whether the element losing focus is inside the
         * Overlay.
         */
        this.handleEndFocusTrapElementFocus = (e) => {
            var _a, _b, _c;
            console.log("handleEndFocusTrapElementFocus");
            // No need for this.props.enforceFocus check here because this element is only rendered
            // when that prop is true.
            // During user interactions, e.relatedTarget will be defined, and we should wrap around to the
            // "start focus trap" element.
            // Otherwise, we're handling a programmatic focus event, which can only happen after a user
            // presses shift+tab from the first focusable element in the overlay.
            console.log(e.target);
            console.log(e.relatedTarget);
            if (e.relatedTarget != null &&
                ((_a = this.host) === null || _a === void 0 ? void 0 : _a.contains(e.relatedTarget)) &&
                e.relatedTarget !== this.startFocusTrapElement) {
                console.log("a");
                const firstFocusableElement = this.getKeyboardFocusableElements().shift();
                // ensure we don't re-focus an already active element by comparing against e.relatedTarget
                console.log(firstFocusableElement);
                if (!this.isAutoFocusing && firstFocusableElement != null && firstFocusableElement !== e.relatedTarget) {
                    firstFocusableElement.focus({ preventScroll: true });
                }
                else {
                    (_b = this.startFocusTrapElement) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
                }
            }
            else {
                console.log("b");
                const lastFocusableElement = this.getKeyboardFocusableElements().pop();
                if (lastFocusableElement != null) {
                    lastFocusableElement.focus({ preventScroll: true });
                }
                else {
                    // Keeps focus within Overlay even if there are no keyboard-focusable children
                    (_c = this.startFocusTrapElement) === null || _c === void 0 ? void 0 : _c.focus({ preventScroll: true });
                }
            }
        };
        this.handleBackdropMouseDown = () => {
            if (this.canOutsideClickClose) {
                this.close.emit();
            }
            if (this.enforceFocus) {
                this.bringFocusInsideOverlay();
            }
        };
        this.handleDocumentClick = (e) => {
            const eventTarget = (e.composed ? e.composedPath()[0] : e.target);
            const stackIndex = openStack.indexOf(this);
            const isClickInThisOverlayOrDescendant = openStack
                .slice(stackIndex)
                .some(({ host: elem }) => {
                return (elem === null || elem === void 0 ? void 0 : elem.contains(eventTarget)) && !elem.isSameNode(eventTarget);
            });
            if (this.isOpen && !isClickInThisOverlayOrDescendant && this.canOutsideClickClose) {
                this.close.emit();
            }
        };
        this.handleDocumentFocus = (e) => {
            const eventTarget = e.composed ? e.composedPath()[0] : e.target;
            if (this.enforceFocus &&
                this.host != null &&
                eventTarget instanceof Node &&
                !this.host.contains(eventTarget)) {
                // prevent default focus behavior (sometimes auto-scrolls the page)
                e.preventDefault();
                e.stopImmediatePropagation();
                this.bringFocusInsideOverlay();
            }
        };
        this.isOpen = undefined;
        this.autoFocus = true;
        this.containerClass = undefined;
        this.enforceFocus = true;
        this.canEscapeKeyClose = true;
        this.canOutsideClickClose = true;
        this.hasBackdrop = true;
        this.shouldReturnFocusOnClose = true;
        this.transitionName = "overlay";
        this.transitionDuration = 300;
        this.backdropClass = undefined;
    }
    componentWillLoad() {
        this.children = Array.from(this.host.children);
    }
    componentDidLoad() {
        if (this.isOpen) {
            this.overlayWillOpen();
        }
    }
    watchIsOpen(newValue, oldValue) {
        if (oldValue && !newValue) {
            this.overlayWillClose();
        }
        else if (!oldValue && newValue) {
            this.overlayWillOpen();
        }
    }
    disconnectedCallback() {
        this.overlayWillClose();
    }
    bringFocusInsideOverlay() {
        // always delay focus manipulation to just before repaint to prevent scroll jumping
        return window.requestAnimationFrame(() => {
            // container element may be undefined between component mounting and Portal rendering
            // activeElement may be undefined in some rare cases in IE
            const activeElement = utils.getActiveElement(this.host);
            if (this.host == null || activeElement == null || !this.isOpen) {
                return;
            }
            const isFocusOutsideModal = !this.host.contains(activeElement);
            if (isFocusOutsideModal) {
                this.startFocusTrapElement.focus({ preventScroll: true });
                this.isAutoFocusing = false;
            }
        });
    }
    getKeyboardFocusableElements() {
        console.log("getKeyboardFocusableElements");
        const focusableElements = this.host !== null
            ? Array.from(
            // Order may not be correct if children elements use tabindex values > 0.
            // Selectors derived from this SO question:
            // https://stackoverflow.com/questions/1599660/which-html-elements-can-receive-focus
            this.host.querySelectorAll([
                'a[href]:not([tabindex="-1"])',
                'button:not([disabled]):not([tabindex="-1"])',
                'details:not([tabindex="-1"])',
                'input:not([disabled]):not([tabindex="-1"])',
                'select:not([disabled]):not([tabindex="-1"])',
                'textarea:not([disabled]):not([tabindex="-1"])',
                '[tabindex]:not([tabindex="-1"])',
            ].join(",")))
            : [];
        return focusableElements.filter(el => !el.classList.contains("start-focus-trap") &&
            !el.classList.contains("end-focus-trap"));
    }
    overlayWillOpen() {
        if (openStack.length > 0) {
            document.removeEventListener("focus", getLastOpened().handleDocumentFocus, { capture: true });
        }
        openStack.push(this);
        if (this.autoFocus) {
            this.isAutoFocusing = true;
            this.bringFocusInsideOverlay();
        }
        if (this.enforceFocus) {
            // Focus events do not bubble, but setting useCapture allows us to listen in and execute
            // our handler before all others
            document.addEventListener("focus", this.handleDocumentFocus, { capture: true });
        }
        if (this.canOutsideClickClose && !this.hasBackdrop) {
            document.addEventListener("mousedown", this.handleDocumentClick);
        }
        if (this.hasBackdrop) {
            // add a class to the body to prevent scrolling of content below the overlay
            document.body.classList.add("overlay-open");
        }
        this.lastActiveElementBeforeOpened = utils.getActiveElement(this.host);
    }
    overlayWillClose() {
        document.removeEventListener("focus", this.handleDocumentFocus, { capture: true });
        document.removeEventListener("mousedown", this.handleDocumentClick);
        const stackIndex = openStack.indexOf(this);
        if (stackIndex !== -1) {
            openStack.splice(stackIndex, 1);
            if (openStack.length > 0) {
                const lastOpenedOverlay = getLastOpened();
                // Only bring focus back to last overlay if it had autoFocus _and_ enforceFocus enabled.
                // If `autoFocus={false}`, it's likely that the overlay never received focus in the first place,
                // so it would be surprising for us to send it there. See https://github.com/palantir/blueprint/issues/4921
                if (lastOpenedOverlay.autoFocus && lastOpenedOverlay.enforceFocus) {
                    lastOpenedOverlay.bringFocusInsideOverlay();
                    document.addEventListener("focus", lastOpenedOverlay.handleDocumentFocus, /* useCapture */ true);
                }
            }
            if (openStack.filter(o => o.hasBackdrop).length === 0) {
                document.body.classList.remove("overlay-open");
            }
        }
    }
    handleKeyDown(e) {
        if (e.key === "Escape" && this.canEscapeKeyClose) {
            this.close.emit();
            e.stopPropagation();
            e.preventDefault();
        }
    }
    render2() {
        return (index.h(index.Host, { class: this.isOpen ? "overlay-open overlay-scroll-container" : "overlay-scroll-container" }, this.hasBackdrop && index.h("div", { class: "overlay-backdrop" }), index.h("div", { class: "content" }, index.h("slot", null))));
    }
    render() {
        for (let el of this.children) {
            if (this.isOpen) {
                if (!el.classList.contains('overlay-content')) {
                    el.className = inputBase.classNames(el.className, "overlay-content");
                }
                if (this.enforceFocus || this.autoFocus) {
                    el.tabIndex = 0;
                }
            }
            else {
                if (el.classList.contains('overlay-content')) {
                    el.classList.remove('overlay-content');
                }
                el.tabIndex = undefined;
            }
        }
        const containerClasses = inputBase.classNames("overlay", {
            ["overlay-open"]: this.isOpen
        }, this.containerClass, "overlay-portal" // TODO: Evaluate how exactly we want to handle top-level overlay
        );
        return (index.h(index.Host, { key: 'aaea07ee141019cf93d4d5f7149f0252483cbe0d', class: containerClasses, onKeyDown: e => this.handleKeyDown(e) }, this.isOpen && (this.autoFocus || this.enforceFocus) ?
            index.h("div", { key: "__start", class: "start-focus-trap", tabindex: 0, onFocus: e => this.handleStartFocusTrapElementFocus(e), onKeyDown: e => this.handleStartFocusTrapElementKeyDown(e), ref: el => this.startFocusTrapElement = el }) : null, this.hasBackdrop && this.isOpen ?
            index.h("div", { key: "__backdrop", class: inputBase.classNames("overlay-backdrop", this.backdropClass), onMouseDown: () => this.handleBackdropMouseDown(), ref: el => this.backdropElement = el }) : null, index.h("div", { key: "__content", class: this.isOpen ? "" : "overlay-closed" }, index.h("slot", { key: 'ecf013a18dec7d25a2c8deb0ef390e4c3d48faa0' })), this.isOpen && this.enforceFocus ?
            index.h("div", { key: "__end", class: "end-focus-trap", tabindex: 0, onFocus: e => this.handleEndFocusTrapElementFocus(e), ref: el => this.endFocusTrapElement = el }) : null));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "isOpen": ["watchIsOpen"]
    }; }
};
const openStack = [];
const getLastOpened = () => openStack[openStack.length - 1];
TaskOverlay.style = TaskOverlayStyle0;

const taskSubmitCss = ".sc-task-submit-h{display:block}button.sc-task-submit{display:-ms-inline-flexbox;display:inline-flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border:none;border-radius:3px;cursor:pointer;font-size:14px;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:5px 10px;text-align:left;vertical-align:middle;min-height:30px;min-width:30px;background-color:#2d72d2;background-image:-webkit-gradient(linear, left top, left bottom, from(rgba(17, 20, 24, 0)), to(rgba(17, 20, 24, 0.05)));background-image:linear-gradient(to bottom, rgba(17, 20, 24, 0), rgba(17, 20, 24, 0.05));-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.4), inset 0 -1px 0 rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.4), inset 0 -1px 0 rgba(17, 20, 24, 0.2);color:#fff;margin-bottom:6px}button.sc-task-submit:disabled{cursor:not-allowed;background-color:rgba(45, 114, 210, 0.5);background-image:none;border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}.message-hidden.sc-task-submit{display:none}";
const TaskSubmitStyle0 = taskSubmitCss;

const TaskSubmit = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.registerKeyboardShortcut = index.createEvent(this, "registerKeyboardShortcut", 7);
        this.showCorrections = index.createEvent(this, "showCorrections", 7);
        this.taskSubmit = index.createEvent(this, "taskSubmit", 7);
        this.keyboardShortcut = undefined;
        this.disabled = false;
        this.disableUntilComplete = true;
        this.label = "Submit";
        this.correctionMode = false;
        this.readyToSubmit = false;
    }
    componentWillLoad() {
        // TODO: This probably needs to be rerun if the mode changes for some reason
        this.refreshSubmitReady();
        if (this.keyboardShortcut) {
            this.registerKeyboardShortcut.emit({ label: "Submit", keys: this.keyboardShortcut });
        }
    }
    connectedCallback() {
        if (['interactive', 'complete'].includes(document.readyState)) {
            this.setupFormListener();
        }
        else {
            this.loadCallback = this.setupFormListener.bind(this);
            document.addEventListener("load", this.loadCallback);
        }
    }
    setupFormListener() {
        this.form = inputBase.getFormElement(this.host);
        if (this.form) {
            this.formUpdatedCallback = this.refreshSubmitReady.bind(this);
            this.form.addEventListener("input", this.formUpdatedCallback);
            this.refreshSubmitReady();
        }
        else {
            setTimeout(() => this.setupFormListener(), 100);
        }
    }
    disconnectedCallback() {
        if (this.formUpdatedCallback) {
            this.form.removeEventListener("input", this.formUpdatedCallback);
        }
        if (this.loadCallback) {
            document.removeEventListener("load", this.loadCallback);
        }
    }
    keypressHandler(event) {
        if (!utils.ignoreKeypress() && event.key === this.keyboardShortcut && !this.disabled) {
            this.button.click();
        }
    }
    async refreshSubmitReady() {
        if (this.form && this.disableUntilComplete) {
            Promise.all(inputBase.requiredChildInputs(this.form).map(i => i.readyToSubmit()))
                .then(values => {
                this.disabled = !values.every(Boolean);
            });
        }
    }
    handleValidationResult(values) {
        if (values.every(Boolean)) {
            this.readyToSubmit = true;
            this.button.click();
        }
        else {
            this.showCorrections.emit();
            this.correctionMode = true;
        }
    }
    handleSubmit(event) {
        const answeredInputs = inputBase.inputsWithAnswers();
        if (answeredInputs && answeredInputs.length > 0 && !this.readyToSubmit && !this.correctionMode) {
            event.preventDefault();
            Promise.all(answeredInputs.map(input => input.validateAgainstAnswer()))
                .then(values => this.handleValidationResult(values));
        }
        else {
            this.taskSubmit.emit();
        }
    }
    async setShowCorrections(value) {
        this.correctionMode = value;
    }
    render() {
        // Note that the button tag must be a single row to prevent crowd-form adding another one
        return (index.h(index.Host, { key: '707a0df3333865b0c88ee162427c5567169d311f' }, index.h("button", { key: 'd90af2681d8e7c9f09d92ade6ce66bb1f4b343ef', type: "submit", ref: el => this.button = el, disabled: this.disabled, onClick: this.handleSubmit.bind(this) }, this.label), index.h("div", { key: '5b5d87b901813ecfe033199fa260fbe0ebd8ce16', class: this.correctionMode ? "" : "message-hidden" }, index.h("slot", { key: 'd990bbd54ada648f46c38f5bc0b366c613316785' }))));
    }
    get host() { return index.getElement(this); }
};
TaskSubmit.style = TaskSubmitStyle0;

const taskTagCss = ".sc-task-tag-h{display:inline}.sc-task-tag-h{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:#5f6b7c;border:none;border-radius:3px;-webkit-box-shadow:none;box-shadow:none;color:#f6f7f9;font-size:12px;line-height:16px;max-width:100%;min-height:20px;min-width:20px;padding:2px 6px;position:relative;margin-right:4px;margin-bottom:4px}.interactive.sc-task-tag-h{cursor:pointer}.interactive.sc-task-tag-h:hover{background-color:rgba(95, 107, 124, 0)}.interactive.active.sc-task-tag-h,.interactive.sc-task-tag-h:active{background-color:rgba(95, 107, 124, 0)}.sc-task-tag-h>*.sc-task-tag{-webkit-box-flex:0;-ms-flex-positive:0;flex-grow:0;-ms-flex-negative:0;flex-shrink:0}.sc-task-tag-h::before,task-tag.sc-task-tag>*.sc-task-tag{margin-right:4px}.sc-task-tag-h:empty::before,.sc-task-tag-h>.sc-task-tag:last-child{margin-right:0}.sc-task-tag-h:focus{outline:rgba(45, 114, 210, 0.6) auto 2px;outline-offset:0;-moz-outline-radius:6px}.round.sc-task-tag-h{border-radius:30px;padding-left:8px;padding-right:8px}.large.sc-task-tag-h,.large .sc-task-tag-h{font-size:14px;line-height:20px;min-height:30px;min-width:30px;padding:5px 10px}.large.sc-task-tag-h::before,.large.sc-task-tag-h>*.sc-task-tag,.large .sc-task-tag-h::before,.large .sc-task-tag-h>*.sc-task-tag{margin-right:7px}.large.sc-task-tag-h:empty::before,.large.sc-task-tag-h>.sc-task-tag:last-child,.large .sc-task-tag-h:empty::before,.large .sc-task-tag-h>.sc-task-tag:last-child{margin-right:0}.large.round.sc-task-tag-h,.large .round.sc-task-tag-h{padding-left:12px;padding-right:12px}.small.sc-task-tag-h,.small .sc-task-tag-h{font-size:11px;line-height:14px;min-height:14px;min-width:18px;padding:2px 6px}.small.sc-task-tag-h::before,.small.sc-task-tag-h>*.sc-task-tag,.small .sc-task-tag-h::before,.small .sc-task-tag-h>*.sc-task-tag{margin-right:4px}.small.sc-task-tag-h:empty::before,.small.sc-task-tag-h>.sc-task-tag:last-child,.small .sc-task-tag-h:empty::before,.small .sc-task-tag-h>.sc-task-tag:last-child{margin-right:0}.small.round.sc-task-tag-h,.small .round.sc-task-tag-h{padding-left:6px;padding-right:6px}.color-blue.sc-task-tag-h{background:#2d72d2;color:#fff}.color-blue.interactive.sc-task-tag-h{cursor:pointer}.color-blue.interactive.sc-task-tag-h:hover{background-color:rgba(45, 114, 210, 0)}.color-blue.interactive.active.sc-task-tag-h,.color-blue.interactive.sc-task-tag-h:active{background-color:rgba(45, 114, 210, 0)}.color-green.sc-task-tag-h{background:#238551;color:#fff}.color-green.interactive.sc-task-tag-h{cursor:pointer}.color-green.interactive.sc-task-tag-h:hover{background-color:rgba(35, 133, 81, 0)}.color-green.interactive.active.sc-task-tag-h,.color-green.interactive.sc-task-tag-h:active{background-color:rgba(35, 133, 81, 0)}.color-orange.sc-task-tag-h{background:#c87619;color:#fff}.color-orange.interactive.sc-task-tag-h{cursor:pointer}.color-orange.interactive.sc-task-tag-h:hover{background-color:rgba(200, 118, 25, 0)}.color-orange.interactive.active.sc-task-tag-h,.color-orange.interactive.sc-task-tag-h:active{background-color:rgba(200, 118, 25, 0)}.color-red.sc-task-tag-h{background:#cd4246;color:#fff}.color-red.interactive.sc-task-tag-h{cursor:pointer}.color-red.interactive.sc-task-tag-h:hover{background-color:rgba(205, 66, 70, 0)}.color-red.interactive.active.sc-task-tag-h,.color-red.interactive.sc-task-tag-h:active{background-color:rgba(205, 66, 70, 0)}.minimal.sc-task-tag-h:not([class*=bp4-intent-]){background-color:rgba(143, 153, 168, 0.2);color:#1c2127}.minimal.sc-task-tag-h:not([class*=bp4-intent-]).interactive{cursor:pointer}.minimal.sc-task-tag-h:not([class*=bp4-intent-]).interactive:hover{background-color:rgba(95, 107, 124, 0.102)}.minimal.sc-task-tag-h:not([class*=bp4-intent-]).interactive.active,.minimal.sc-task-tag-h:not([class*=bp4-intent-]).interactive:active{background-color:rgba(95, 107, 124, 0.202)}.minimal.color-blue.sc-task-tag-h{background-color:rgba(45, 114, 210, 0.15);color:#215db0}.minimal.color-blue.interactive.sc-task-tag-h{cursor:pointer}.minimal.color-blue.interactive.sc-task-tag-h:hover{background-color:rgba(45, 114, 210, 0.1015)}.minimal.color-blue.interactive.active.sc-task-tag-h,.minimal.color-blue.interactive.sc-task-tag-h:active{background-color:rgba(45, 114, 210, 0.2015)}.minimal.color-green.sc-task-tag-h{background-color:rgba(35, 133, 81, 0.15);color:#1c6e42}.minimal.color-green.interactive.sc-task-tag-h{cursor:pointer}.minimal.color-green.interactive.sc-task-tag-h:hover{background-color:rgba(35, 133, 81, 0.1015)}.minimal.color-green.interactive.active.sc-task-tag-h,.minimal.color-green.interactive.sc-task-tag-h:active{background-color:rgba(35, 133, 81, 0.2015)}.minimal.color-orange.sc-task-tag-h{background-color:rgba(200, 118, 25, 0.15);color:#935610}.minimal.color-orange.interactive.sc-task-tag-h{cursor:pointer}.minimal.color-orange.interactive.sc-task-tag-h:hover{background-color:rgba(200, 118, 25, 0.1015)}.minimal.color-orange.interactive.active.sc-task-tag-h,.minimal.color-orange.interactive.sc-task-tag-h:active{background-color:rgba(200, 118, 25, 0.2015)}.minimal.color-red.sc-task-tag-h{background-color:rgba(205, 66, 70, 0.15);color:#ac2f33}.minimal.color-red.interactive.sc-task-tag-h{cursor:pointer}.minimal.color-red.interactive.sc-task-tag-h:hover{background-color:rgba(205, 66, 70, 0.1015)}.minimal.color-red.interactive.active.sc-task-tag-h,.minimal.color-red.interactive.sc-task-tag-h:active{background-color:rgba(205, 66, 70, 0.2015)}-remove.sc-task-tag-h{background:none;border:none;color:inherit;cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;margin-bottom:-2px;margin-right:-6px !important;margin-top:-2px;opacity:0.5;padding:2px;padding-left:0}-remove.sc-task-tag-h:hover{background:none;opacity:0.8;text-decoration:none}-remove.sc-task-tag-h:active{opacity:1}-remove.sc-task-tag-h:empty::before{font-family:\"blueprint-icons-16\", sans-serif;font-size:16px;font-style:normal;font-variant:normal;font-weight:400;line-height:1;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;content:\"\\f2ba\"}.large -remove.sc-task-tag-h{margin-right:-10px !important;padding:0 5px 0 0}.large -remove.sc-task-tag-h:empty::before{font-family:\"blueprint-icons-20\", sans-serif;font-size:20px;font-style:normal;font-variant:normal;font-weight:400;line-height:1}.sc-task-tag-h{color:#fff}.sc-task-tag-h -remove.sc-task-tag,.sc-task-tag-h -remove.sc-task-tag:hover,.sc-task-tag-h -remove.sc-task-tag:active{opacity:1}.interactive.sc-task-tag-h:hover{background:#404854}.interactive.sc-task-tag-h:active{background:#383e47}.color-blue.sc-task-tag-h{background:#2d72d2;color:#fff}.color-blue.interactive.sc-task-tag-h:hover{background-color:#215db0}.color-blue.interactive.sc-task-tag-h:active{background-color:#184a90}.color-green.sc-task-tag-h{background:#238551;color:#fff}.color-green.interactive.sc-task-tag-h:hover{background-color:#1c6e42}.color-green.interactive.sc-task-tag-h:active{background-color:#165a36}.color-orange.sc-task-tag-h{background:#fbb360;color:#1c2127}.color-orange.interactive.sc-task-tag-h:hover{background-color:#ec9a3c}.color-orange.interactive.sc-task-tag-h:active{background-color:#c87619}.color-red.sc-task-tag-h{background:#cd4246;color:#fff}.color-red.interactive.sc-task-tag-h:hover{background-color:#ac2f33}.color-red.interactive.sc-task-tag-h:active{background-color:#8e292c}.minimal.sc-task-tag-h{background-color:rgba(143, 153, 168, 0.15);color:#1c2127}.minimal.interactive.sc-task-tag-h:hover{background-color:rgba(143, 153, 168, 0.3);color:#111418}.minimal.interactive.sc-task-tag-h:active{background-color:rgba(143, 153, 168, 0.35);color:#111418}.minimal.color-blue.sc-task-tag-h{background-color:rgba(45, 114, 210, 0.1);color:#215db0}.minimal.color-blue.interactive.sc-task-tag-h:hover{background-color:rgba(45, 114, 210, 0.2);color:#184a90}.minimal.color-blue.interactive.sc-task-tag-h:active{background-color:rgba(45, 114, 210, 0.3);color:#184a90}.minimal.color-green.sc-task-tag-h{background-color:rgba(35, 133, 81, 0.1);color:#1c6e42}.minimal.color-green.interactive.sc-task-tag-h:hover{background-color:rgba(35, 133, 81, 0.2);color:#165a36}.minimal.color-green.interactive.sc-task-tag-h:active{background-color:rgba(35, 133, 81, 0.3);color:#165a36}.minimal.color-orange.sc-task-tag-h{background-color:rgba(200, 118, 25, 0.1);color:#935610}.minimal.color-orange.interactive.sc-task-tag-h:hover{background-color:rgba(200, 118, 25, 0.2);color:#77450d}.minimal.color-orange.interactive.sc-task-tag-h:active{background-color:rgba(200, 118, 25, 0.3);color:#77450d}.minimal.color-red.sc-task-tag-h{background-color:rgba(205, 66, 70, 0.1);color:#ac2f33}.minimal.color-red.interactive.sc-task-tag-h:hover{background-color:rgba(205, 66, 70, 0.2);color:#8e292c}.minimal.color-red.interactive.sc-task-tag-h:active{background-color:rgba(205, 66, 70, 0.3);color:#8e292c}";
const TaskTagStyle0 = taskTagCss;

const TaskTag = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.round = undefined;
        this.color = undefined;
        this.removable = undefined;
        this.large = undefined;
        this.small = undefined;
        this.minimal = undefined;
        this.interactive = undefined;
        this.onremove = () => { };
        this.removed = undefined;
    }
    classes() {
        const classList = [];
        if (this.round) {
            classList.push("round");
        }
        if (this.color) {
            classList.push("color-" + this.color);
        }
        if (this.large) {
            classList.push("large");
        }
        if (this.small) {
            classList.push("small");
        }
        if (this.minimal) {
            classList.push("minimal");
        }
        if (this.interactive) {
            classList.push("interactive");
        }
        return classList.join(" ");
    }
    render() {
        return (index.h(index.Host, { key: '1b9a5782d2a654bb82e586ffe55b99445a2c6f3d', class: this.classes() }, index.h("slot", { key: '954ad0c6d782781e1bfce79b19ac4d482df2d9c4' })));
    }
};
TaskTag.style = TaskTagStyle0;

exports.task_input_checkbox = inputBase.TaskInputCheckbox;
exports.task_asset = TaskAsset;
exports.task_body = TaskBody;
exports.task_button = TaskButton;
exports.task_button_group = TaskButtonGroup;
exports.task_card = TaskCard;
exports.task_click_to_view = TaskClickToView;
exports.task_column = TaskColumn;
exports.task_columns = TaskColumns;
exports.task_dialog = TaskDialog;
exports.task_icon = TaskIcon;
exports.task_info_pane = TaskInfoPane;
exports.task_info_section = TaskInfoSection;
exports.task_input_option = TaskInputOption;
exports.task_input_radio = TaskInputRadio;
exports.task_keyboard_shortcut_list = TaskKeyboardShortcutList;
exports.task_label = TaskLabel;
exports.task_main = TaskMain;
exports.task_markdown = TaskMarkdown;
exports.task_overlay = TaskOverlay;
exports.task_submit = TaskSubmit;
exports.task_tag = TaskTag;

//# sourceMappingURL=task-asset_22.cjs.entry.js.map