import { proxyCustomElement, HTMLElement, createEvent, h, Fragment, Host } from '@stencil/core/internal/client';
import { c as classNames } from './index2.js';
import { d as isKeyboardClick } from './utils.js';
import { d as defineCustomElement$1 } from './task-icon2.js';

const taskButtonCss = ":host{display:inline-block}button{font-family:inherit;font-size:100%;line-height:1.15;margin:0}.button{display:-ms-inline-flexbox;display:inline-flex;-ms-flex-direction:row;flex-direction:row;-ms-flex-align:center;align-items:center;border:none;border-radius:2px;cursor:pointer;font-size:14px;-ms-flex-pack:center;justify-content:center;padding:5px 10px;text-align:left;vertical-align:middle;min-height:30px;min-width:30px;-webkit-box-sizing:border-box;box-sizing:border-box}.button>*{-ms-flex-positive:0;flex-grow:0;-ms-flex-negative:0;flex-shrink:0}.button>.fill{-ms-flex-positive:1;flex-grow:1;-ms-flex-negative:1;flex-shrink:1}.button::before,.button>*{margin-right:7px}.button:empty::before,.button>:last-child{margin-right:0}.button:empty{padding:0 !important}.button:disabled,.button.disabled{cursor:not-allowed}.button.fill{display:-ms-flexbox;display:flex;width:100%}.button.align-right,.align-right .button{text-align:right}.button.align-left,.align-left .button{text-align:left}.button:not([class*=intent-]){background-color:#f6f7f9;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#1c2127}.button:not([class*=intent-]):hover{background-clip:padding-box;background-color:#edeff2;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button:not([class*=intent-]):active,.button:not([class*=intent-]).active{background-color:#dce0e5;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.selected,.button.selected:hover{background-color:#566573;color:white}@media (forced-colors: active) and (prefers-color-scheme: dark){.button:not([class*=intent-]):active,.button:not([class*=intent-]).active{background:highlight}}.button:not([class*=intent-]):disabled,.button:not([class*=intent-]).disabled{background-color:rgba(211, 216, 222, 0.5);-webkit-box-shadow:none;box-shadow:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed;outline:none}.button:not([class*=intent-]):disabled.active,.button:not([class*=intent-]):disabled.active:hover,.button:not([class*=intent-]).disabled.active,.button:not([class*=intent-]).disabled.active:hover{background:rgba(211, 216, 222, 0.7)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button:not([class*=intent-]){border:1px solid buttonborder}}.button.intent-primary{background-color:#2d72d2;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-primary:hover,.button.intent-primary:active,.button.intent-primary.active{color:#ffffff}.button.intent-primary:hover{background-color:#215db0;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-primary:active,.button.intent-primary.active{background-color:#184a90;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-primary:disabled,.button.intent-primary.disabled{background-color:rgba(45, 114, 210, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-primary:disabled,.button.intent-primary.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-primary{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-success{background-color:#238551;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-success:hover,.button.intent-success:active,.button.intent-success.active{color:#ffffff}.button.intent-success:hover{background-color:#1c6e42;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-success:active,.button.intent-success.active{background-color:#165a36;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-success:disabled,.button.intent-success.disabled{background-color:rgba(35, 133, 81, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-success:disabled,.button.intent-success.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-success{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-warning{background-color:#c87619;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-warning:hover,.button.intent-warning:active,.button.intent-warning.active{color:#ffffff}.button.intent-warning:hover{background-color:#935610;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-warning:active,.button.intent-warning.active{background-color:#77450d;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-warning:disabled,.button.intent-warning.disabled{background-color:rgba(200, 118, 25, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning:disabled,.button.intent-warning.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button.intent-danger{background-color:#cd4246;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.1);color:#ffffff}.button.intent-danger:hover,.button.intent-danger:active,.button.intent-danger.active{color:#ffffff}.button.intent-danger:hover{background-color:#ac2f33;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-danger:active,.button.intent-danger.active{background-color:#8e292c;-webkit-box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(17, 20, 24, 0.2), 0 1px 2px rgba(17, 20, 24, 0.2)}.button.intent-danger:disabled,.button.intent-danger.disabled{background-color:rgba(205, 66, 70, 0.5);border-color:transparent;-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.6)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-danger:disabled,.button.intent-danger.disabled{border-color:graytext;color:graytext}}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-danger{border:1px solid buttonborder;-webkit-box-shadow:none;box-shadow:none}}.button[class*=intent-] .button-spinner .spinner-head{stroke:#ffffff}.button.large,.large .button{min-height:40px;min-width:40px;font-size:16px;padding:5px 15px}.button.large::before,.button.large>*,.large .button::before,.large .button>*{margin-right:10px}.button.large:empty::before,.button.large>:last-child,.large .button:empty::before,.large .button>:last-child{margin-right:0}.button.small,.small .button{min-height:24px;min-width:24px;padding:0 7px}.button.loading{position:relative}.button.loading[class*=icon-]::before{visibility:hidden}.button.loading .button-spinner{margin:0;position:absolute}.button.loading>:not(.button-spinner){visibility:hidden}.button[class*=icon-]::before{font-family:\"blueprint-icons-16\", sans-serif;font-size:16px;font-style:normal;font-variant:normal;font-weight:400;height:16px;line-height:1;width:16px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;color:#5f6b7c}.button .icon,.button .icon-standard,.button .icon-large{color:#5f6b7c}.button .icon.align-right,.button .icon-standard.align-right,.button .icon-large.align-right{margin-left:7px}.button .icon:first-child:last-child,.button .spinner+.icon:last-child{margin:0 -7px}.dark .button:not([class*=intent-]){background-color:#383e47;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);color:#f6f7f9}.dark .button:not([class*=intent-]):hover,.dark .button:not([class*=intent-]):active,.dark .button:not([class*=intent-]).active{color:#f6f7f9}.dark .button:not([class*=intent-]):hover{background-color:#2f343c;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button:not([class*=intent-]):active,.dark .button:not([class*=intent-]).active{background-color:#1c2127;-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button:not([class*=intent-]):disabled,.dark .button:not([class*=intent-]).disabled{background-color:rgba(64, 72, 84, 0.5);-webkit-box-shadow:none;box-shadow:none;color:rgba(171, 179, 191, 0.6)}.dark .button:not([class*=intent-]):disabled.active,.dark .button:not([class*=intent-]).disabled.active{background:rgba(64, 72, 84, 0.7)}.dark .button:not([class*=intent-]) .button-spinner .spinner-head{background:rgba(17, 20, 24, 0.5);stroke:#8f99a8}.dark .button:not([class*=intent-])[class*=icon-]::before{color:#abb3bf}.dark .button:not([class*=intent-]) .icon:not([class*=intent-]),.dark .button:not([class*=intent-]) .icon-standard:not([class*=intent-]),.dark .button:not([class*=intent-]) .icon-large:not([class*=intent-]){color:#abb3bf}.dark .button[class*=intent-]{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2)}.dark .button[class*=intent-]:hover{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.2)}.dark .button[class*=intent-]:active,.dark .button[class*=intent-].active{-webkit-box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4);box-shadow:inset 0 0 0 1px rgba(255, 255, 255, 0.1), 0 1px 2px rgba(17, 20, 24, 0.4)}.dark .button[class*=intent-]:disabled,.dark .button[class*=intent-].disabled{-webkit-box-shadow:none;box-shadow:none;color:rgba(255, 255, 255, 0.3)}.dark .button[class*=intent-] .button-spinner .spinner-head{stroke:#8f99a8}.button:disabled::before,.button:disabled .icon,.button:disabled .icon-standard,.button:disabled .icon-large,.button.disabled::before,.button.disabled .icon,.button.disabled .icon-standard,.button.disabled .icon-large,.button[class*=intent-]::before,.button[class*=intent-] .icon,.button[class*=intent-] .icon-standard,.button[class*=intent-] .icon-large{color:inherit !important}.button.minimal{background:none;-webkit-box-shadow:none;box-shadow:none}.button.minimal:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button.minimal:active,.button.minimal.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button.minimal:disabled,.button.minimal:disabled:hover,.button.minimal.disabled,.button.minimal.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button.minimal:disabled.active,.button.minimal:disabled:hover.active,.button.minimal.disabled.active,.button.minimal.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button.minimal{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.minimal:hover,.dark .button.minimal:active,.dark .button.minimal.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.minimal:hover{background:rgba(143, 153, 168, 0.15)}.dark .button.minimal:active,.dark .button.minimal.active{background:rgba(143, 153, 168, 0.3)}.dark .button.minimal:disabled,.dark .button.minimal:disabled:hover,.dark .button.minimal.disabled,.dark .button.minimal.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button.minimal:disabled.active,.dark .button.minimal:disabled:hover.active,.dark .button.minimal.disabled.active,.dark .button.minimal.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button.minimal.intent-primary{color:#215db0}.button.minimal.intent-primary:hover,.button.minimal.intent-primary:active,.button.minimal.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button.minimal.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button.minimal.intent-primary:active,.button.minimal.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button.minimal.intent-primary:disabled,.button.minimal.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button.minimal.intent-primary:disabled.active,.button.minimal.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.minimal.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button.minimal.intent-primary{color:#8abbff}.dark .button.minimal.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button.minimal.intent-primary:active,.dark .button.minimal.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button.minimal.intent-primary:disabled,.dark .button.minimal.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button.minimal.intent-primary:disabled.active,.dark .button.minimal.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.minimal.intent-success{color:#1c6e42}.button.minimal.intent-success:hover,.button.minimal.intent-success:active,.button.minimal.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button.minimal.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button.minimal.intent-success:active,.button.minimal.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button.minimal.intent-success:disabled,.button.minimal.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button.minimal.intent-success:disabled.active,.button.minimal.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.minimal.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button.minimal.intent-success{color:#72ca9b}.dark .button.minimal.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button.minimal.intent-success:active,.dark .button.minimal.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button.minimal.intent-success:disabled,.dark .button.minimal.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button.minimal.intent-success:disabled.active,.dark .button.minimal.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.minimal.intent-warning{color:#935610}.button.minimal.intent-warning:hover,.button.minimal.intent-warning:active,.button.minimal.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button.minimal.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button.minimal.intent-warning:active,.button.minimal.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button.minimal.intent-warning:disabled,.button.minimal.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button.minimal.intent-warning:disabled.active,.button.minimal.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.minimal.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button.minimal.intent-warning{color:#fbb360}.dark .button.minimal.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button.minimal.intent-warning:active,.dark .button.minimal.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button.minimal.intent-warning:disabled,.dark .button.minimal.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button.minimal.intent-warning:disabled.active,.dark .button.minimal.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.minimal.intent-danger{color:#ac2f33}.button.minimal.intent-danger:hover,.button.minimal.intent-danger:active,.button.minimal.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button.minimal.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button.minimal.intent-danger:active,.button.minimal.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button.minimal.intent-danger:disabled,.button.minimal.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button.minimal.intent-danger:disabled.active,.button.minimal.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.minimal.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button.minimal.intent-danger{color:#fa999c}.dark .button.minimal.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button.minimal.intent-danger:active,.dark .button.minimal.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button.minimal.intent-danger:disabled,.dark .button.minimal.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button.minimal.intent-danger:disabled.active,.dark .button.minimal.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined{background:none;-webkit-box-shadow:none;box-shadow:none;border:1px solid rgba(28, 33, 39, 0.2);-webkit-box-sizing:border-box;box-sizing:border-box}.button.outlined:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button.outlined:active,.button.outlined.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button.outlined:disabled,.button.outlined:disabled:hover,.button.outlined.disabled,.button.outlined.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button.outlined:disabled.active,.button.outlined:disabled:hover.active,.button.outlined.disabled.active,.button.outlined.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button.outlined{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.outlined:hover,.dark .button.outlined:active,.dark .button.outlined.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button.outlined:hover{background:rgba(143, 153, 168, 0.15)}.dark .button.outlined:active,.dark .button.outlined.active{background:rgba(143, 153, 168, 0.3)}.dark .button.outlined:disabled,.dark .button.outlined:disabled:hover,.dark .button.outlined.disabled,.dark .button.outlined.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button.outlined:disabled.active,.dark .button.outlined:disabled:hover.active,.dark .button.outlined.disabled.active,.dark .button.outlined.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button.outlined.intent-primary{color:#215db0}.button.outlined.intent-primary:hover,.button.outlined.intent-primary:active,.button.outlined.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button.outlined.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button.outlined.intent-primary:active,.button.outlined.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button.outlined.intent-primary:disabled,.button.outlined.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button.outlined.intent-primary:disabled.active,.button.outlined.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.outlined.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button.outlined.intent-primary{color:#8abbff}.dark .button.outlined.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button.outlined.intent-primary:active,.dark .button.outlined.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button.outlined.intent-primary:disabled,.dark .button.outlined.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button.outlined.intent-primary:disabled.active,.dark .button.outlined.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button.outlined.intent-success{color:#1c6e42}.button.outlined.intent-success:hover,.button.outlined.intent-success:active,.button.outlined.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button.outlined.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button.outlined.intent-success:active,.button.outlined.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button.outlined.intent-success:disabled,.button.outlined.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button.outlined.intent-success:disabled.active,.button.outlined.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.outlined.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button.outlined.intent-success{color:#72ca9b}.dark .button.outlined.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button.outlined.intent-success:active,.dark .button.outlined.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button.outlined.intent-success:disabled,.dark .button.outlined.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button.outlined.intent-success:disabled.active,.dark .button.outlined.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button.outlined.intent-warning{color:#935610}.button.outlined.intent-warning:hover,.button.outlined.intent-warning:active,.button.outlined.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button.outlined.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button.outlined.intent-warning:active,.button.outlined.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button.outlined.intent-warning:disabled,.button.outlined.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button.outlined.intent-warning:disabled.active,.button.outlined.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.outlined.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button.outlined.intent-warning{color:#fbb360}.dark .button.outlined.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button.outlined.intent-warning:active,.dark .button.outlined.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button.outlined.intent-warning:disabled,.dark .button.outlined.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button.outlined.intent-warning:disabled.active,.dark .button.outlined.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button.outlined.intent-danger{color:#ac2f33}.button.outlined.intent-danger:hover,.button.outlined.intent-danger:active,.button.outlined.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button.outlined.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button.outlined.intent-danger:active,.button.outlined.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button.outlined.intent-danger:disabled,.button.outlined.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button.outlined.intent-danger:disabled.active,.button.outlined.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button.outlined.intent-danger{color:#fa999c}.dark .button.outlined.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button.outlined.intent-danger:active,.dark .button.outlined.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button.outlined.intent-danger:disabled,.dark .button.outlined.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button.outlined.intent-danger:disabled.active,.dark .button.outlined.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button.outlined:disabled,.button.outlined.disabled,.button.outlined:disabled:hover,.button.outlined.disabled:hover{border-color:rgba(95, 107, 124, 0.1)}.dark .button.outlined{border-color:rgba(255, 255, 255, 0.4)}.dark .button.outlined:disabled,.dark .button.outlined:disabled:hover,.dark .button.outlined.disabled,.dark .button.outlined.disabled:hover{border-color:rgba(255, 255, 255, 0.2)}.button.outlined.intent-primary{border-color:rgba(33, 93, 176, 0.6)}.button.outlined.intent-primary:disabled,.button.outlined.intent-primary.disabled{border-color:rgba(33, 93, 176, 0.2)}.dark .button.outlined.intent-primary{border-color:rgba(138, 187, 255, 0.6)}.dark .button.outlined.intent-primary:disabled,.dark .button.outlined.intent-primary.disabled{border-color:rgba(138, 187, 255, 0.2)}.button.outlined.intent-success{border-color:rgba(28, 110, 66, 0.6)}.button.outlined.intent-success:disabled,.button.outlined.intent-success.disabled{border-color:rgba(28, 110, 66, 0.2)}.dark .button.outlined.intent-success{border-color:rgba(114, 202, 155, 0.6)}.dark .button.outlined.intent-success:disabled,.dark .button.outlined.intent-success.disabled{border-color:rgba(114, 202, 155, 0.2)}.button.outlined.intent-warning{border-color:rgba(147, 86, 16, 0.6)}.button.outlined.intent-warning:disabled,.button.outlined.intent-warning.disabled{border-color:rgba(147, 86, 16, 0.2)}.dark .button.outlined.intent-warning{border-color:rgba(251, 179, 96, 0.6)}.dark .button.outlined.intent-warning:disabled,.dark .button.outlined.intent-warning.disabled{border-color:rgba(251, 179, 96, 0.2)}.button.outlined.intent-danger{border-color:rgba(172, 47, 51, 0.6)}.button.outlined.intent-danger:disabled,.button.outlined.intent-danger.disabled{border-color:rgba(172, 47, 51, 0.2)}.dark .button.outlined.intent-danger{border-color:rgba(250, 153, 156, 0.6)}.dark .button.outlined.intent-danger:disabled,.dark .button.outlined.intent-danger.disabled{border-color:rgba(250, 153, 156, 0.2)}.button.intent-warning{background:#fbb360;color:#1c2127}.button.intent-warning:not(.disabled).icon>svg{fill:rgba(28, 33, 39, 0.7)}.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):hover{background:#ec9a3c;color:#1c2127}.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):active,.button.intent-warning:not(.disabled):not(.minimal):not(.outlined).active{background:#c87619;color:#1c2127}@media (forced-colors: active) and (prefers-color-scheme: dark){.button.intent-warning:not(.disabled):not(.minimal):not(.outlined):active,.button.intent-warning:not(.disabled):not(.minimal):not(.outlined).active{background:highlight}}.button.intent-warning:disabled,.button.intent-warning.disabled{background:rgba(200, 118, 25, 0.5);color:rgba(28, 33, 39, 0.35)}.dark .button.intent-warning:disabled,.dark .button.intent-warning.disabled{color:rgba(28, 33, 39, 0.6)}.button.intent-warning.minimal,.button.intent-warning.outlined{background:none}.dark .button.intent-warning.minimal:not(.disabled).icon>svg,.dark .button.intent-warning.outlined:not(.disabled).icon>svg{fill:#fbb360}a.button{text-align:center;text-decoration:none;-webkit-transition:none;transition:none}a.button,a.button:hover,a.button:active{color:#1c2127}a.button.disabled{color:rgba(95, 107, 124, 0.6)}.button-text{-ms-flex:0 1 auto;flex:0 1 auto}.button.align-left .button-text,.button.align-right .button-text,.button-group.align-left .button-text,.button-group.align-right .button-text{-ms-flex:1 1 auto;flex:1 1 auto}.button-group{display:-ms-inline-flexbox;display:inline-flex}.button-group .button{-ms-flex:0 0 auto;flex:0 0 auto;position:relative;z-index:4}.button-group .button:focus{z-index:5}.button-group .button:hover{z-index:6}.button-group .button:active,.button-group .button.active{z-index:7}.button-group .button:disabled,.button-group .button.disabled{z-index:3}.button-group .button[class*=intent-]{z-index:9}.button-group .button[class*=intent-]:focus{z-index:10}.button-group .button[class*=intent-]:hover{z-index:11}.button-group .button[class*=intent-]:active,.button-group .button[class*=intent-].active{z-index:12}.button-group .button[class*=intent-]:disabled,.button-group .button[class*=intent-].disabled{z-index:8}.button-group:not(.minimal)>.popover-wrapper:not(:first-child) .button,.button-group:not(.minimal)>.button:not(:first-child){border-bottom-left-radius:0;border-top-left-radius:0}.button-group:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group:not(.minimal)>.button:not(:last-child){border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}.button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none}.button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15);-webkit-box-shadow:none;box-shadow:none;color:#1c2127;text-decoration:none}.button-group.minimal .button:active,.button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3);-webkit-box-shadow:none;box-shadow:none;color:#1c2127}.button-group.minimal .button:disabled,.button-group.minimal .button:disabled:hover,.button-group.minimal .button.disabled,.button-group.minimal .button.disabled:hover{background:none;color:rgba(95, 107, 124, 0.6);cursor:not-allowed}.button-group.minimal .button:disabled.active,.button-group.minimal .button:disabled:hover.active,.button-group.minimal .button.disabled.active,.button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover,.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ffffff}.dark .button-group.minimal .button:hover{background:rgba(143, 153, 168, 0.15)}.dark .button-group.minimal .button:active,.dark .button-group.minimal .button.active{background:rgba(143, 153, 168, 0.3)}.dark .button-group.minimal .button:disabled,.dark .button-group.minimal .button:disabled:hover,.dark .button-group.minimal .button.disabled,.dark .button-group.minimal .button.disabled:hover{background:none;color:rgba(171, 179, 191, 0.6);cursor:not-allowed}.dark .button-group.minimal .button:disabled.active,.dark .button-group.minimal .button:disabled:hover.active,.dark .button-group.minimal .button.disabled.active,.dark .button-group.minimal .button.disabled:hover.active{background:rgba(143, 153, 168, 0.3)}.button-group.minimal .button.intent-primary{color:#215db0}.button-group.minimal .button.intent-primary:hover,.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#215db0}.button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.15);color:#215db0}.button-group.minimal .button.intent-primary:active,.button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#184a90}.button-group.minimal .button.intent-primary:disabled,.button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(33, 93, 176, 0.5)}.button-group.minimal .button.intent-primary:disabled.active,.button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-primary .button-spinner .spinner-head{stroke:#215db0}.dark .button-group.minimal .button.intent-primary{color:#8abbff}.dark .button-group.minimal .button.intent-primary:hover{background:rgba(45, 114, 210, 0.2);color:#8abbff}.dark .button-group.minimal .button.intent-primary:active,.dark .button-group.minimal .button.intent-primary.active{background:rgba(45, 114, 210, 0.3);color:#99c4ff}.dark .button-group.minimal .button.intent-primary:disabled,.dark .button-group.minimal .button.intent-primary.disabled{background:none;color:rgba(138, 187, 255, 0.5)}.dark .button-group.minimal .button.intent-primary:disabled.active,.dark .button-group.minimal .button.intent-primary.disabled.active{background:rgba(45, 114, 210, 0.3)}.button-group.minimal .button.intent-success{color:#1c6e42}.button-group.minimal .button.intent-success:hover,.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#1c6e42}.button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.15);color:#1c6e42}.button-group.minimal .button.intent-success:active,.button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#165a36}.button-group.minimal .button.intent-success:disabled,.button-group.minimal .button.intent-success.disabled{background:none;color:rgba(28, 110, 66, 0.5)}.button-group.minimal .button.intent-success:disabled.active,.button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-success .button-spinner .spinner-head{stroke:#1c6e42}.dark .button-group.minimal .button.intent-success{color:#72ca9b}.dark .button-group.minimal .button.intent-success:hover{background:rgba(35, 133, 81, 0.2);color:#72ca9b}.dark .button-group.minimal .button.intent-success:active,.dark .button-group.minimal .button.intent-success.active{background:rgba(35, 133, 81, 0.3);color:#7cd7a2}.dark .button-group.minimal .button.intent-success:disabled,.dark .button-group.minimal .button.intent-success.disabled{background:none;color:rgba(114, 202, 155, 0.5)}.dark .button-group.minimal .button.intent-success:disabled.active,.dark .button-group.minimal .button.intent-success.disabled.active{background:rgba(35, 133, 81, 0.3)}.button-group.minimal .button.intent-warning{color:#935610}.button-group.minimal .button.intent-warning:hover,.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#935610}.button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.15);color:#935610}.button-group.minimal .button.intent-warning:active,.button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#77450d}.button-group.minimal .button.intent-warning:disabled,.button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(147, 86, 16, 0.5)}.button-group.minimal .button.intent-warning:disabled.active,.button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-warning .button-spinner .spinner-head{stroke:#935610}.dark .button-group.minimal .button.intent-warning{color:#fbb360}.dark .button-group.minimal .button.intent-warning:hover{background:rgba(200, 118, 25, 0.2);color:#fbb360}.dark .button-group.minimal .button.intent-warning:active,.dark .button-group.minimal .button.intent-warning.active{background:rgba(200, 118, 25, 0.3);color:#f5c186}.dark .button-group.minimal .button.intent-warning:disabled,.dark .button-group.minimal .button.intent-warning.disabled{background:none;color:rgba(251, 179, 96, 0.5)}.dark .button-group.minimal .button.intent-warning:disabled.active,.dark .button-group.minimal .button.intent-warning.disabled.active{background:rgba(200, 118, 25, 0.3)}.button-group.minimal .button.intent-danger{color:#ac2f33}.button-group.minimal .button.intent-danger:hover,.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:none;-webkit-box-shadow:none;box-shadow:none;color:#ac2f33}.button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.15);color:#ac2f33}.button-group.minimal .button.intent-danger:active,.button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#8e292c}.button-group.minimal .button.intent-danger:disabled,.button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(172, 47, 51, 0.5)}.button-group.minimal .button.intent-danger:disabled.active,.button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}.button-group.minimal .button.intent-danger .button-spinner .spinner-head{stroke:#ac2f33}.dark .button-group.minimal .button.intent-danger{color:#fa999c}.dark .button-group.minimal .button.intent-danger:hover{background:rgba(205, 66, 70, 0.2);color:#fa999c}.dark .button-group.minimal .button.intent-danger:active,.dark .button-group.minimal .button.intent-danger.active{background:rgba(205, 66, 70, 0.3);color:#ffa1a4}.dark .button-group.minimal .button.intent-danger:disabled,.dark .button-group.minimal .button.intent-danger.disabled{background:none;color:rgba(250, 153, 156, 0.5)}.dark .button-group.minimal .button.intent-danger:disabled.active,.dark .button-group.minimal .button.intent-danger.disabled.active{background:rgba(205, 66, 70, 0.3)}@media (forced-colors: active) and (prefers-color-scheme: dark){.button-group.minimal:not(:first-child){border-bottom-left-radius:0;border-left:none;border-top-left-radius:0}.button-group.minimal:not(:last-child){border-bottom-right-radius:0;border-top-right-radius:0;margin-right:-1px}}.button-group .popover-wrapper,.button-group .popover-target{display:-ms-flexbox;display:flex;-ms-flex:1 1 auto;flex:1 1 auto}.button-group.fill{display:-ms-flexbox;display:flex;width:100%}.button-group .button.fill,.button-group.fill .button:not(.fixed){-ms-flex:1 1 auto;flex:1 1 auto}.button-group.vertical{-ms-flex-align:stretch;align-items:stretch;-ms-flex-direction:column;flex-direction:column;vertical-align:top}.button-group.vertical.fill{height:100%;width:unset}.button-group.vertical .button{margin-right:0 !important;width:100%}.button-group.vertical:not(.minimal)>.popover-wrapper:first-child .button,.button-group.vertical:not(.minimal)>.button:first-child{border-radius:2px 2px 0 0}.button-group.vertical:not(.minimal)>.popover-wrapper:last-child .button,.button-group.vertical:not(.minimal)>.button:last-child{border-radius:0 0 2px 2px}.button-group.vertical:not(.minimal)>.popover-wrapper:not(:last-child) .button,.button-group.vertical:not(.minimal)>.button:not(:last-child){margin-bottom:-1px}.button-group.align-left .button{text-align:left}";
const TaskButtonStyle0 = taskButtonCss;

const TaskButton = /*@__PURE__*/ proxyCustomElement(class TaskButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.click = createEvent(this, "click", 7);
        this.focus = createEvent(this, "focus", 7);
        this.anchor = false;
        this.label = false;
        this.active = false;
        this.alignText = "center";
        this.disabled = false;
        this.fill = false;
        this.large = false;
        this.small = false;
        this.loading = false;
        this.type = "button";
        this.intent = undefined;
        this.selected = false;
        this.minimal = false;
        this.outlined = false;
        this.text = undefined;
        this.icon = undefined;
        this.iconSize = undefined;
        this.rightIcon = undefined;
        this.href = undefined;
        this.target = undefined;
        this.newWindow = false;
        this.tabindex = undefined;
        this.isActive = false;
        this.currentKeyPressed = undefined;
    }
    handleBlur() {
        if (this.isActive) {
            this.isActive = false;
        }
    }
    handleKeyDown(e) {
        if (isKeyboardClick(e)) {
            e.preventDefault();
            if (e.key !== this.currentKeyPressed) {
                this.isActive = true;
            }
        }
        this.currentKeyPressed = e.key;
        //props.onKeyDown?.(e)
    }
    handleKeyUp(e) {
        var _a;
        if (isKeyboardClick(e)) {
            this.isActive = false;
            (_a = this.button) === null || _a === void 0 ? void 0 : _a.click();
        }
        this.currentKeyPressed = undefined;
        //props.onKeyUp?.(e);
    }
    renderContents() {
        return h(Fragment, null, this.loading && h("task-spinner", { key: "loading", class: "button-spinner", size: "small" }), this.icon && h("task-icon", { key: "leftIcon", icon: this.icon, size: this.iconSize }), h("span", { key: "text", class: "button-text" }, this.text, h("slot", null)), this.rightIcon && h("task-icon", { key: "rightIcon", icon: this.rightIcon, size: this.iconSize }));
    }
    render() {
        const disabled = this.disabled || this.loading;
        const classes = classNames("button", {
            ["active"]: !disabled && (this.active || this.isActive),
            ["disabled"]: disabled,
            ["fill"]: this.fill,
            ["large"]: this.large,
            ["loading"]: this.loading,
            ["minimal"]: this.minimal,
            ["outlined"]: this.outlined,
            ["small"]: this.small,
            [`intent-${this.intent}`]: this.intent,
            ["selected"]: this.selected,
        }, this.alignText ? `align-${this.alignText}` : undefined);
        return (h(Host, { key: '4e4bf0f5b6e45274261f28f6e505f19f5c9f8312' }, this.anchor ?
            h("a", { key: "anchorButton", href: this.href, class: classes, target: this.newWindow ? "_blank" : this.target, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents())
            : (this.label ?
                h("label", { class: classes }, this.renderContents())
                :
                    h("button", { key: "button", type: this.type, class: classes, disabled: disabled, ref: el => this.button = el, onBlur: () => this.handleBlur(), onKeyDown: e => this.handleKeyDown(e), onKeyUp: e => this.handleKeyUp(e), tabindex: disabled ? -1 : this.tabindex }, this.renderContents()))));
    }
    get host() { return this; }
    static get style() { return TaskButtonStyle0; }
}, [4, "task-button", {
        "anchor": [4],
        "label": [4],
        "active": [4],
        "alignText": [1, "align-text"],
        "disabled": [4],
        "fill": [4],
        "large": [4],
        "small": [4],
        "loading": [4],
        "type": [1],
        "intent": [1],
        "selected": [4],
        "minimal": [4],
        "outlined": [4],
        "text": [1],
        "icon": [1],
        "iconSize": [2, "icon-size"],
        "rightIcon": [1, "right-icon"],
        "href": [1],
        "target": [1],
        "newWindow": [4, "new-window"],
        "tabindex": [1],
        "isActive": [32],
        "currentKeyPressed": [32]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-button", "task-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "task-button":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskButton);
            }
            break;
        case "task-icon":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { TaskButton as T, defineCustomElement as d };

//# sourceMappingURL=task-button2.js.map