import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as classNames } from './index2.js';

const icons = {
    "blank": {
        16: [],
        20: [],
    },
    "small-tick": {
        16: ["M12 5c-.28 0-.53.11-.71.29L7 9.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l5-5A1.003 1.003 0 0012 5z"],
        20: ["M15 5c-.28 0-.53.11-.71.29L8 11.59l-2.29-2.3a1.003 1.003 0 00-1.42 1.42l3 3c.18.18.43.29.71.29s.53-.11.71-.29l7-7A1.003 1.003 0 0015 5z"],
    },
    "caret-down": {
        16: ["M12 6.5c0-.28-.22-.5-.5-.5h-7a.495.495 0 00-.37.83l3.5 4c.09.1.22.17.37.17s.28-.07.37-.17l3.5-4c.08-.09.13-.2.13-.33z"],
        20: ["M16 7c0-.55-.45-1-1-1H5c-.55 0-1 .45-1 1 0 .24.1.46.24.63l-.01.01 5 6 .01-.01c.19.22.45.37.76.37s.57-.15.76-.37l.01.01 5-6-.01-.01c.14-.17.24-.39.24-.63z"],
    },
    "caret-left": {
        16: ["M9.5 4c-.13 0-.24.05-.33.13l-4 3.5c-.1.09-.17.22-.17.37s.07.28.17.37l4 3.5a.495.495 0 00.83-.37v-7c0-.28-.22-.5-.5-.5z"],
        20: ["M13 4c-.24 0-.46.1-.63.24l-.01-.01-6 5 .01.01c-.22.19-.37.45-.37.76s.15.57.37.76l-.01.01 6 5 .01-.01c.17.14.39.24.63.24.55 0 1-.45 1-1V5c0-.55-.45-1-1-1z"],
    },
    "caret-up": {
        16: ["M11.87 9.17s.01 0 0 0l-3.5-4C8.28 5.07 8.15 5 8 5s-.28.07-.37.17l-3.5 4a.495.495 0 00.37.83h7a.495.495 0 00.37-.83z"],
        20: ["M15.76 12.37l.01-.01-5-6-.01.01C10.57 6.15 10.31 6 10 6s-.57.15-.76.37l-.01-.01-5 6 .01.01c-.14.17-.24.39-.24.63 0 .55.45 1 1 1h10c.55 0 1-.45 1-1 0-.24-.1-.46-.24-.63z"],
    },
    "info-sign": {
        16: ["M8 0C3.58 0 0 3.58 0 8s3.58 8 8 8 8-3.58 8-8-3.58-8-8-8zM7 3h2v2H7V3zm3 10H6v-1h1V7H6V6h3v6h1v1z"],
        20: ["M10 0C4.48 0 0 4.48 0 10s4.48 10 10 10 10-4.48 10-10S15.52 0 10 0zM9 4h2v2H9V4zm4 12H7v-1h2V8H8V7h3v8h2v1z"],
    },
};

const taskIconCss = ".icon-add.sc-task-icon::before{content:\"\\f109\"}.icon-add-clip.sc-task-icon::before{content:\"\\f101\"}.icon-add-column-left.sc-task-icon::before{content:\"\\f102\"}.icon-add-column-right.sc-task-icon::before{content:\"\\f103\"}.icon-add-location.sc-task-icon::before{content:\"\\f104\"}.icon-add-row-bottom.sc-task-icon::before{content:\"\\f105\"}.icon-add-row-top.sc-task-icon::before{content:\"\\f106\"}.icon-add-to-artifact.sc-task-icon::before{content:\"\\f107\"}.icon-add-to-folder.sc-task-icon::before{content:\"\\f108\"}.icon-aimpoints-target.sc-task-icon::before{content:\"\\f335\"}.icon-airplane.sc-task-icon::before{content:\"\\f10a\"}.icon-align-center.sc-task-icon::before{content:\"\\f10b\"}.icon-align-justify.sc-task-icon::before{content:\"\\f10c\"}.icon-align-left.sc-task-icon::before{content:\"\\f10d\"}.icon-align-right.sc-task-icon::before{content:\"\\f10e\"}.icon-alignment-bottom.sc-task-icon::before{content:\"\\f10f\"}.icon-alignment-horizontal-center.sc-task-icon::before{content:\"\\f110\"}.icon-alignment-left.sc-task-icon::before{content:\"\\f111\"}.icon-alignment-right.sc-task-icon::before{content:\"\\f112\"}.icon-alignment-top.sc-task-icon::before{content:\"\\f113\"}.icon-alignment-vertical-center.sc-task-icon::before{content:\"\\f114\"}.icon-ammunition.sc-task-icon::before{content:\"\\f342\"}.icon-anchor.sc-task-icon::before{content:\"\\f330\"}.icon-annotation.sc-task-icon::before{content:\"\\f115\"}.icon-antenna.sc-task-icon::before{content:\"\\f116\"}.icon-app-header.sc-task-icon::before{content:\"\\f117\"}.icon-application.sc-task-icon::before{content:\"\\f118\"}.icon-applications.sc-task-icon::before{content:\"\\f119\"}.icon-archive.sc-task-icon::before{content:\"\\f11a\"}.icon-area-of-interest.sc-task-icon::before{content:\"\\f11b\"}.icon-array.sc-task-icon::before{content:\"\\f121\"}.icon-array-boolean.sc-task-icon::before{content:\"\\f11c\"}.icon-array-date.sc-task-icon::before{content:\"\\f11d\"}.icon-array-floating-point.sc-task-icon::before{content:\"\\f32d\"}.icon-array-numeric.sc-task-icon::before{content:\"\\f11e\"}.icon-array-string.sc-task-icon::before{content:\"\\f11f\"}.icon-array-timestamp.sc-task-icon::before{content:\"\\f120\"}.icon-arrow-bottom-left.sc-task-icon::before{content:\"\\f122\"}.icon-arrow-bottom-right.sc-task-icon::before{content:\"\\f123\"}.icon-arrow-down.sc-task-icon::before{content:\"\\f124\"}.icon-arrow-left.sc-task-icon::before{content:\"\\f125\"}.icon-arrow-right.sc-task-icon::before{content:\"\\f126\"}.icon-arrow-top-left.sc-task-icon::before{content:\"\\f127\"}.icon-arrow-top-right.sc-task-icon::before{content:\"\\f128\"}.icon-arrow-up.sc-task-icon::before{content:\"\\f129\"}.icon-arrows-horizontal.sc-task-icon::before{content:\"\\f12a\"}.icon-arrows-vertical.sc-task-icon::before{content:\"\\f12b\"}.icon-asterisk.sc-task-icon::before{content:\"\\f12c\"}.icon-at.sc-task-icon::before{content:\"\\f331\"}.icon-automatic-updates.sc-task-icon::before{content:\"\\f12d\"}.icon-axle.sc-task-icon::before{content:\"\\f338\"}.icon-backlink.sc-task-icon::before{content:\"\\f12e\"}.icon-badge.sc-task-icon::before{content:\"\\f12f\"}.icon-ban-circle.sc-task-icon::before{content:\"\\f130\"}.icon-bank-account.sc-task-icon::before{content:\"\\f131\"}.icon-barcode.sc-task-icon::before{content:\"\\f132\"}.icon-blank.sc-task-icon::before{content:\"\\f133\"}.icon-blocked-person.sc-task-icon::before{content:\"\\f134\"}.icon-bold.sc-task-icon::before{content:\"\\f135\"}.icon-book.sc-task-icon::before{content:\"\\f136\"}.icon-bookmark.sc-task-icon::before{content:\"\\f137\"}.icon-box.sc-task-icon::before{content:\"\\f138\"}.icon-briefcase.sc-task-icon::before{content:\"\\f139\"}.icon-bring-data.sc-task-icon::before{content:\"\\f13a\"}.icon-bug.sc-task-icon::before{content:\"\\f32e\"}.icon-buggy.sc-task-icon::before{content:\"\\f13b\"}.icon-build.sc-task-icon::before{content:\"\\f13c\"}.icon-calculator.sc-task-icon::before{content:\"\\f13d\"}.icon-calendar.sc-task-icon::before{content:\"\\f13e\"}.icon-camera.sc-task-icon::before{content:\"\\f13f\"}.icon-caret-down.sc-task-icon::before{content:\"\\f140\"}.icon-caret-left.sc-task-icon::before{content:\"\\f141\"}.icon-caret-right.sc-task-icon::before{content:\"\\f142\"}.icon-caret-up.sc-task-icon::before{content:\"\\f143\"}.icon-cargo-ship.sc-task-icon::before{content:\"\\f144\"}.icon-cell-tower.sc-task-icon::before{content:\"\\f145\"}.icon-changes.sc-task-icon::before{content:\"\\f146\"}.icon-chart.sc-task-icon::before{content:\"\\f147\"}.icon-chat.sc-task-icon::before{content:\"\\f148\"}.icon-chevron-backward.sc-task-icon::before{content:\"\\f149\"}.icon-chevron-down.sc-task-icon::before{content:\"\\f14a\"}.icon-chevron-forward.sc-task-icon::before{content:\"\\f14b\"}.icon-chevron-left.sc-task-icon::before{content:\"\\f14c\"}.icon-chevron-right.sc-task-icon::before{content:\"\\f14d\"}.icon-chevron-up.sc-task-icon::before{content:\"\\f14e\"}.icon-circle.sc-task-icon::before{content:\"\\f153\"}.icon-circle-arrow-down.sc-task-icon::before{content:\"\\f14f\"}.icon-circle-arrow-left.sc-task-icon::before{content:\"\\f150\"}.icon-circle-arrow-right.sc-task-icon::before{content:\"\\f151\"}.icon-circle-arrow-up.sc-task-icon::before{content:\"\\f152\"}.icon-citation.sc-task-icon::before{content:\"\\f154\"}.icon-clean.sc-task-icon::before{content:\"\\f155\"}.icon-clip.sc-task-icon::before{content:\"\\f156\"}.icon-clipboard.sc-task-icon::before{content:\"\\f157\"}.icon-cloud.sc-task-icon::before{content:\"\\f15a\"}.icon-cloud-download.sc-task-icon::before{content:\"\\f158\"}.icon-cloud-upload.sc-task-icon::before{content:\"\\f159\"}.icon-code.sc-task-icon::before{content:\"\\f15c\"}.icon-code-block.sc-task-icon::before{content:\"\\f15b\"}.icon-cog.sc-task-icon::before{content:\"\\f15d\"}.icon-collapse-all.sc-task-icon::before{content:\"\\f15e\"}.icon-color-fill.sc-task-icon::before{content:\"\\f328\"}.icon-column-layout.sc-task-icon::before{content:\"\\f15f\"}.icon-comment.sc-task-icon::before{content:\"\\f160\"}.icon-comparison.sc-task-icon::before{content:\"\\f161\"}.icon-compass.sc-task-icon::before{content:\"\\f162\"}.icon-compressed.sc-task-icon::before{content:\"\\f163\"}.icon-confirm.sc-task-icon::before{content:\"\\f164\"}.icon-console.sc-task-icon::before{content:\"\\f165\"}.icon-contrast.sc-task-icon::before{content:\"\\f166\"}.icon-control.sc-task-icon::before{content:\"\\f167\"}.icon-credit-card.sc-task-icon::before{content:\"\\f168\"}.icon-cross.sc-task-icon::before{content:\"\\f169\"}.icon-cross-circle.sc-task-icon::before{content:\"\\f336\"}.icon-crown.sc-task-icon::before{content:\"\\f16a\"}.icon-cube.sc-task-icon::before{content:\"\\f16d\"}.icon-cube-add.sc-task-icon::before{content:\"\\f16b\"}.icon-cube-remove.sc-task-icon::before{content:\"\\f16c\"}.icon-curved-range-chart.sc-task-icon::before{content:\"\\f16e\"}.icon-cut.sc-task-icon::before{content:\"\\f16f\"}.icon-cycle.sc-task-icon::before{content:\"\\f170\"}.icon-dashboard.sc-task-icon::before{content:\"\\f171\"}.icon-data-connection.sc-task-icon::before{content:\"\\f172\"}.icon-data-lineage.sc-task-icon::before{content:\"\\f173\"}.icon-database.sc-task-icon::before{content:\"\\f174\"}.icon-delete.sc-task-icon::before{content:\"\\f175\"}.icon-delta.sc-task-icon::before{content:\"\\f176\"}.icon-derive-column.sc-task-icon::before{content:\"\\f177\"}.icon-desktop.sc-task-icon::before{content:\"\\f178\"}.icon-detection.sc-task-icon::before{content:\"\\f341\"}.icon-diagnosis.sc-task-icon::before{content:\"\\f179\"}.icon-diagram-tree.sc-task-icon::before{content:\"\\f17a\"}.icon-direction-left.sc-task-icon::before{content:\"\\f17b\"}.icon-direction-right.sc-task-icon::before{content:\"\\f17c\"}.icon-disable.sc-task-icon::before{content:\"\\f17d\"}.icon-divide.sc-task-icon::before{content:\"\\f327\"}.icon-document.sc-task-icon::before{content:\"\\f180\"}.icon-document-open.sc-task-icon::before{content:\"\\f17e\"}.icon-document-share.sc-task-icon::before{content:\"\\f17f\"}.icon-dollar.sc-task-icon::before{content:\"\\f181\"}.icon-dot.sc-task-icon::before{content:\"\\f182\"}.icon-double-caret-horizontal.sc-task-icon::before{content:\"\\f183\"}.icon-double-caret-vertical.sc-task-icon::before{content:\"\\f184\"}.icon-double-chevron-down.sc-task-icon::before{content:\"\\f185\"}.icon-double-chevron-left.sc-task-icon::before{content:\"\\f186\"}.icon-double-chevron-right.sc-task-icon::before{content:\"\\f187\"}.icon-double-chevron-up.sc-task-icon::before{content:\"\\f188\"}.icon-doughnut-chart.sc-task-icon::before{content:\"\\f189\"}.icon-download.sc-task-icon::before{content:\"\\f18a\"}.icon-drag-handle-horizontal.sc-task-icon::before{content:\"\\f18b\"}.icon-drag-handle-vertical.sc-task-icon::before{content:\"\\f18c\"}.icon-draw.sc-task-icon::before{content:\"\\f18d\"}.icon-drawer-left.sc-task-icon::before{content:\"\\f18f\"}.icon-drawer-left-filled.sc-task-icon::before{content:\"\\f18e\"}.icon-drawer-right.sc-task-icon::before{content:\"\\f191\"}.icon-drawer-right-filled.sc-task-icon::before{content:\"\\f190\"}.icon-drive-time.sc-task-icon::before{content:\"\\f192\"}.icon-duplicate.sc-task-icon::before{content:\"\\f193\"}.icon-edit.sc-task-icon::before{content:\"\\f194\"}.icon-eject.sc-task-icon::before{content:\"\\f195\"}.icon-emoji.sc-task-icon::before{content:\"\\f196\"}.icon-endorsed.sc-task-icon::before{content:\"\\f197\"}.icon-envelope.sc-task-icon::before{content:\"\\f198\"}.icon-equals.sc-task-icon::before{content:\"\\f199\"}.icon-eraser.sc-task-icon::before{content:\"\\f19a\"}.icon-error.sc-task-icon::before{content:\"\\f19b\"}.icon-euro.sc-task-icon::before{content:\"\\f19c\"}.icon-exchange.sc-task-icon::before{content:\"\\f19d\"}.icon-exclude-row.sc-task-icon::before{content:\"\\f19e\"}.icon-expand-all.sc-task-icon::before{content:\"\\f19f\"}.icon-export.sc-task-icon::before{content:\"\\f1a0\"}.icon-eye-off.sc-task-icon::before{content:\"\\f1a1\"}.icon-eye-on.sc-task-icon::before{content:\"\\f1a2\"}.icon-eye-open.sc-task-icon::before{content:\"\\f1a3\"}.icon-fast-backward.sc-task-icon::before{content:\"\\f1a4\"}.icon-fast-forward.sc-task-icon::before{content:\"\\f1a5\"}.icon-feed.sc-task-icon::before{content:\"\\f1a7\"}.icon-feed-subscribed.sc-task-icon::before{content:\"\\f1a6\"}.icon-film.sc-task-icon::before{content:\"\\f1a8\"}.icon-filter.sc-task-icon::before{content:\"\\f1ad\"}.icon-filter-keep.sc-task-icon::before{content:\"\\f1a9\"}.icon-filter-list.sc-task-icon::before{content:\"\\f1aa\"}.icon-filter-open.sc-task-icon::before{content:\"\\f1ab\"}.icon-filter-remove.sc-task-icon::before{content:\"\\f1ac\"}.icon-flag.sc-task-icon::before{content:\"\\f1ae\"}.icon-flame.sc-task-icon::before{content:\"\\f1af\"}.icon-flash.sc-task-icon::before{content:\"\\f1b0\"}.icon-floating-point.sc-task-icon::before{content:\"\\f32c\"}.icon-floppy-disk.sc-task-icon::before{content:\"\\f1b1\"}.icon-flow-branch.sc-task-icon::before{content:\"\\f1b2\"}.icon-flow-end.sc-task-icon::before{content:\"\\f1b3\"}.icon-flow-linear.sc-task-icon::before{content:\"\\f1b4\"}.icon-flow-review.sc-task-icon::before{content:\"\\f1b6\"}.icon-flow-review-branch.sc-task-icon::before{content:\"\\f1b5\"}.icon-flows.sc-task-icon::before{content:\"\\f1b7\"}.icon-folder-close.sc-task-icon::before{content:\"\\f1b8\"}.icon-folder-new.sc-task-icon::before{content:\"\\f1b9\"}.icon-folder-open.sc-task-icon::before{content:\"\\f1ba\"}.icon-folder-shared.sc-task-icon::before{content:\"\\f1bc\"}.icon-folder-shared-open.sc-task-icon::before{content:\"\\f1bb\"}.icon-follower.sc-task-icon::before{content:\"\\f1bd\"}.icon-following.sc-task-icon::before{content:\"\\f1be\"}.icon-font.sc-task-icon::before{content:\"\\f1bf\"}.icon-fork.sc-task-icon::before{content:\"\\f1c0\"}.icon-form.sc-task-icon::before{content:\"\\f1c1\"}.icon-fuel.sc-task-icon::before{content:\"\\f323\"}.icon-full-circle.sc-task-icon::before{content:\"\\f1c2\"}.icon-full-stacked-chart.sc-task-icon::before{content:\"\\f1c3\"}.icon-fullscreen.sc-task-icon::before{content:\"\\f1c4\"}.icon-function.sc-task-icon::before{content:\"\\f1c5\"}.icon-gantt-chart.sc-task-icon::before{content:\"\\f1c6\"}.icon-geofence.sc-task-icon::before{content:\"\\f1c7\"}.icon-geolocation.sc-task-icon::before{content:\"\\f1c8\"}.icon-geosearch.sc-task-icon::before{content:\"\\f1c9\"}.icon-git-branch.sc-task-icon::before{content:\"\\f1ca\"}.icon-git-commit.sc-task-icon::before{content:\"\\f1cb\"}.icon-git-merge.sc-task-icon::before{content:\"\\f1cc\"}.icon-git-new-branch.sc-task-icon::before{content:\"\\f1cd\"}.icon-git-pull.sc-task-icon::before{content:\"\\f1ce\"}.icon-git-push.sc-task-icon::before{content:\"\\f1cf\"}.icon-git-repo.sc-task-icon::before{content:\"\\f1d0\"}.icon-glass.sc-task-icon::before{content:\"\\f1d1\"}.icon-globe.sc-task-icon::before{content:\"\\f1d3\"}.icon-globe-network.sc-task-icon::before{content:\"\\f1d2\"}.icon-graph.sc-task-icon::before{content:\"\\f1d5\"}.icon-graph-remove.sc-task-icon::before{content:\"\\f1d4\"}.icon-greater-than.sc-task-icon::before{content:\"\\f1d7\"}.icon-greater-than-or-equal-to.sc-task-icon::before{content:\"\\f1d6\"}.icon-grid.sc-task-icon::before{content:\"\\f1d9\"}.icon-grid-view.sc-task-icon::before{content:\"\\f1d8\"}.icon-group-objects.sc-task-icon::before{content:\"\\f1da\"}.icon-grouped-bar-chart.sc-task-icon::before{content:\"\\f1db\"}.icon-hand.sc-task-icon::before{content:\"\\f1e0\"}.icon-hand-down.sc-task-icon::before{content:\"\\f1dc\"}.icon-hand-left.sc-task-icon::before{content:\"\\f1dd\"}.icon-hand-right.sc-task-icon::before{content:\"\\f1de\"}.icon-hand-up.sc-task-icon::before{content:\"\\f1df\"}.icon-hat.sc-task-icon::before{content:\"\\f1e1\"}.icon-header.sc-task-icon::before{content:\"\\f1e5\"}.icon-header-one.sc-task-icon::before{content:\"\\f1e2\"}.icon-header-three.sc-task-icon::before{content:\"\\f1e3\"}.icon-header-two.sc-task-icon::before{content:\"\\f1e4\"}.icon-headset.sc-task-icon::before{content:\"\\f1e6\"}.icon-heart.sc-task-icon::before{content:\"\\f1e8\"}.icon-heart-broken.sc-task-icon::before{content:\"\\f1e7\"}.icon-heat-grid.sc-task-icon::before{content:\"\\f1e9\"}.icon-heatmap.sc-task-icon::before{content:\"\\f1ea\"}.icon-helicopter.sc-task-icon::before{content:\"\\f1eb\"}.icon-help.sc-task-icon::before{content:\"\\f1ec\"}.icon-helper-management.sc-task-icon::before{content:\"\\f1ed\"}.icon-high-priority.sc-task-icon::before{content:\"\\f1ee\"}.icon-high-voltage-pole.sc-task-icon::before{content:\"\\f333\"}.icon-highlight.sc-task-icon::before{content:\"\\f1ef\"}.icon-history.sc-task-icon::before{content:\"\\f1f0\"}.icon-home.sc-task-icon::before{content:\"\\f1f1\"}.icon-horizontal-bar-chart.sc-task-icon::before{content:\"\\f1f4\"}.icon-horizontal-bar-chart-asc.sc-task-icon::before{content:\"\\f1f2\"}.icon-horizontal-bar-chart-desc.sc-task-icon::before{content:\"\\f1f3\"}.icon-horizontal-distribution.sc-task-icon::before{content:\"\\f1f5\"}.icon-horizontal-inbetween.sc-task-icon::before{content:\"\\f329\"}.icon-hurricane.sc-task-icon::before{content:\"\\f1f6\"}.icon-id-number.sc-task-icon::before{content:\"\\f1f7\"}.icon-image-rotate-left.sc-task-icon::before{content:\"\\f1f8\"}.icon-image-rotate-right.sc-task-icon::before{content:\"\\f1f9\"}.icon-import.sc-task-icon::before{content:\"\\f1fa\"}.icon-inbox.sc-task-icon::before{content:\"\\f1ff\"}.icon-inbox-filtered.sc-task-icon::before{content:\"\\f1fb\"}.icon-inbox-geo.sc-task-icon::before{content:\"\\f1fc\"}.icon-inbox-search.sc-task-icon::before{content:\"\\f1fd\"}.icon-inbox-update.sc-task-icon::before{content:\"\\f1fe\"}.icon-info-sign.sc-task-icon::before{content:\"\\f200\"}.icon-inheritance.sc-task-icon::before{content:\"\\f201\"}.icon-inherited-group.sc-task-icon::before{content:\"\\f202\"}.icon-inner-join.sc-task-icon::before{content:\"\\f203\"}.icon-insert.sc-task-icon::before{content:\"\\f204\"}.icon-intelligence.sc-task-icon::before{content:\"\\f337\"}.icon-intersection.sc-task-icon::before{content:\"\\f205\"}.icon-ip-address.sc-task-icon::before{content:\"\\f206\"}.icon-issue.sc-task-icon::before{content:\"\\f209\"}.icon-issue-closed.sc-task-icon::before{content:\"\\f207\"}.icon-issue-new.sc-task-icon::before{content:\"\\f208\"}.icon-italic.sc-task-icon::before{content:\"\\f20a\"}.icon-join-table.sc-task-icon::before{content:\"\\f20b\"}.icon-key.sc-task-icon::before{content:\"\\f215\"}.icon-key-backspace.sc-task-icon::before{content:\"\\f20c\"}.icon-key-command.sc-task-icon::before{content:\"\\f20d\"}.icon-key-control.sc-task-icon::before{content:\"\\f20e\"}.icon-key-delete.sc-task-icon::before{content:\"\\f20f\"}.icon-key-enter.sc-task-icon::before{content:\"\\f210\"}.icon-key-escape.sc-task-icon::before{content:\"\\f211\"}.icon-key-option.sc-task-icon::before{content:\"\\f212\"}.icon-key-shift.sc-task-icon::before{content:\"\\f213\"}.icon-key-tab.sc-task-icon::before{content:\"\\f214\"}.icon-known-vehicle.sc-task-icon::before{content:\"\\f216\"}.icon-lab-test.sc-task-icon::before{content:\"\\f217\"}.icon-label.sc-task-icon::before{content:\"\\f218\"}.icon-layer.sc-task-icon::before{content:\"\\f21a\"}.icon-layer-outline.sc-task-icon::before{content:\"\\f219\"}.icon-layers.sc-task-icon::before{content:\"\\f21b\"}.icon-layout.sc-task-icon::before{content:\"\\f225\"}.icon-layout-auto.sc-task-icon::before{content:\"\\f21c\"}.icon-layout-balloon.sc-task-icon::before{content:\"\\f21d\"}.icon-layout-circle.sc-task-icon::before{content:\"\\f21e\"}.icon-layout-grid.sc-task-icon::before{content:\"\\f21f\"}.icon-layout-group-by.sc-task-icon::before{content:\"\\f220\"}.icon-layout-hierarchy.sc-task-icon::before{content:\"\\f221\"}.icon-layout-linear.sc-task-icon::before{content:\"\\f222\"}.icon-layout-skew-grid.sc-task-icon::before{content:\"\\f223\"}.icon-layout-sorted-clusters.sc-task-icon::before{content:\"\\f224\"}.icon-learning.sc-task-icon::before{content:\"\\f226\"}.icon-left-join.sc-task-icon::before{content:\"\\f227\"}.icon-lengthen-text.sc-task-icon::before{content:\"\\f33e\"}.icon-less-than.sc-task-icon::before{content:\"\\f229\"}.icon-less-than-or-equal-to.sc-task-icon::before{content:\"\\f228\"}.icon-lifesaver.sc-task-icon::before{content:\"\\f22a\"}.icon-lightbulb.sc-task-icon::before{content:\"\\f22b\"}.icon-lightning.sc-task-icon::before{content:\"\\f22c\"}.icon-link.sc-task-icon::before{content:\"\\f22d\"}.icon-list.sc-task-icon::before{content:\"\\f230\"}.icon-list-columns.sc-task-icon::before{content:\"\\f22e\"}.icon-list-detail-view.sc-task-icon::before{content:\"\\f22f\"}.icon-locate.sc-task-icon::before{content:\"\\f231\"}.icon-lock.sc-task-icon::before{content:\"\\f232\"}.icon-locomotive.sc-task-icon::before{content:\"\\f33b\"}.icon-log-in.sc-task-icon::before{content:\"\\f233\"}.icon-log-out.sc-task-icon::before{content:\"\\f234\"}.icon-low-voltage-pole.sc-task-icon::before{content:\"\\f332\"}.icon-manual.sc-task-icon::before{content:\"\\f235\"}.icon-manually-entered-data.sc-task-icon::before{content:\"\\f236\"}.icon-many-to-many.sc-task-icon::before{content:\"\\f237\"}.icon-many-to-one.sc-task-icon::before{content:\"\\f238\"}.icon-map.sc-task-icon::before{content:\"\\f23b\"}.icon-map-create.sc-task-icon::before{content:\"\\f239\"}.icon-map-marker.sc-task-icon::before{content:\"\\f23a\"}.icon-maximize.sc-task-icon::before{content:\"\\f23c\"}.icon-media.sc-task-icon::before{content:\"\\f23d\"}.icon-menu.sc-task-icon::before{content:\"\\f240\"}.icon-menu-closed.sc-task-icon::before{content:\"\\f23e\"}.icon-menu-open.sc-task-icon::before{content:\"\\f23f\"}.icon-merge-columns.sc-task-icon::before{content:\"\\f241\"}.icon-merge-links.sc-task-icon::before{content:\"\\f242\"}.icon-microphone.sc-task-icon::before{content:\"\\f343\"}.icon-minimize.sc-task-icon::before{content:\"\\f243\"}.icon-minus.sc-task-icon::before{content:\"\\f244\"}.icon-mobile-phone.sc-task-icon::before{content:\"\\f245\"}.icon-mobile-video.sc-task-icon::before{content:\"\\f246\"}.icon-modal.sc-task-icon::before{content:\"\\f248\"}.icon-modal-filled.sc-task-icon::before{content:\"\\f247\"}.icon-model.sc-task-icon::before{content:\"\\f33d\"}.icon-moon.sc-task-icon::before{content:\"\\f249\"}.icon-more.sc-task-icon::before{content:\"\\f24a\"}.icon-mountain.sc-task-icon::before{content:\"\\f24b\"}.icon-move.sc-task-icon::before{content:\"\\f24c\"}.icon-mugshot.sc-task-icon::before{content:\"\\f24d\"}.icon-multi-select.sc-task-icon::before{content:\"\\f24e\"}.icon-music.sc-task-icon::before{content:\"\\f24f\"}.icon-nest.sc-task-icon::before{content:\"\\f250\"}.icon-new-drawing.sc-task-icon::before{content:\"\\f251\"}.icon-new-grid-item.sc-task-icon::before{content:\"\\f252\"}.icon-new-layer.sc-task-icon::before{content:\"\\f253\"}.icon-new-layers.sc-task-icon::before{content:\"\\f254\"}.icon-new-link.sc-task-icon::before{content:\"\\f255\"}.icon-new-object.sc-task-icon::before{content:\"\\f256\"}.icon-new-person.sc-task-icon::before{content:\"\\f257\"}.icon-new-prescription.sc-task-icon::before{content:\"\\f258\"}.icon-new-text-box.sc-task-icon::before{content:\"\\f259\"}.icon-ninja.sc-task-icon::before{content:\"\\f25a\"}.icon-not-equal-to.sc-task-icon::before{content:\"\\f25b\"}.icon-notifications.sc-task-icon::before{content:\"\\f25e\"}.icon-notifications-snooze.sc-task-icon::before{content:\"\\f25c\"}.icon-notifications-updated.sc-task-icon::before{content:\"\\f25d\"}.icon-numbered-list.sc-task-icon::before{content:\"\\f25f\"}.icon-numerical.sc-task-icon::before{content:\"\\f260\"}.icon-office.sc-task-icon::before{content:\"\\f261\"}.icon-offline.sc-task-icon::before{content:\"\\f262\"}.icon-oil-field.sc-task-icon::before{content:\"\\f263\"}.icon-one-column.sc-task-icon::before{content:\"\\f264\"}.icon-one-to-many.sc-task-icon::before{content:\"\\f265\"}.icon-one-to-one.sc-task-icon::before{content:\"\\f266\"}.icon-open-application.sc-task-icon::before{content:\"\\f32b\"}.icon-outdated.sc-task-icon::before{content:\"\\f267\"}.icon-page-layout.sc-task-icon::before{content:\"\\f268\"}.icon-panel-stats.sc-task-icon::before{content:\"\\f269\"}.icon-panel-table.sc-task-icon::before{content:\"\\f26a\"}.icon-paperclip.sc-task-icon::before{content:\"\\f26b\"}.icon-paragraph.sc-task-icon::before{content:\"\\f26c\"}.icon-path.sc-task-icon::before{content:\"\\f26e\"}.icon-path-search.sc-task-icon::before{content:\"\\f26d\"}.icon-pause.sc-task-icon::before{content:\"\\f26f\"}.icon-people.sc-task-icon::before{content:\"\\f270\"}.icon-percentage.sc-task-icon::before{content:\"\\f271\"}.icon-person.sc-task-icon::before{content:\"\\f272\"}.icon-phone.sc-task-icon::before{content:\"\\f273\"}.icon-pie-chart.sc-task-icon::before{content:\"\\f274\"}.icon-pin.sc-task-icon::before{content:\"\\f275\"}.icon-pivot.sc-task-icon::before{content:\"\\f277\"}.icon-pivot-table.sc-task-icon::before{content:\"\\f276\"}.icon-play.sc-task-icon::before{content:\"\\f278\"}.icon-playbook.sc-task-icon::before{content:\"\\f324\"}.icon-plus.sc-task-icon::before{content:\"\\f279\"}.icon-polygon-filter.sc-task-icon::before{content:\"\\f27a\"}.icon-power.sc-task-icon::before{content:\"\\f27b\"}.icon-predictive-analysis.sc-task-icon::before{content:\"\\f27c\"}.icon-prescription.sc-task-icon::before{content:\"\\f27d\"}.icon-presentation.sc-task-icon::before{content:\"\\f27e\"}.icon-print.sc-task-icon::before{content:\"\\f27f\"}.icon-projects.sc-task-icon::before{content:\"\\f280\"}.icon-properties.sc-task-icon::before{content:\"\\f281\"}.icon-property.sc-task-icon::before{content:\"\\f282\"}.icon-publish-function.sc-task-icon::before{content:\"\\f283\"}.icon-pulse.sc-task-icon::before{content:\"\\f284\"}.icon-rain.sc-task-icon::before{content:\"\\f285\"}.icon-random.sc-task-icon::before{content:\"\\f286\"}.icon-record.sc-task-icon::before{content:\"\\f287\"}.icon-rect-height.sc-task-icon::before{content:\"\\f325\"}.icon-rect-width.sc-task-icon::before{content:\"\\f326\"}.icon-rectangle.sc-task-icon::before{content:\"\\f321\"}.icon-redo.sc-task-icon::before{content:\"\\f288\"}.icon-refresh.sc-task-icon::before{content:\"\\f289\"}.icon-regex.sc-task-icon::before{content:\"\\f32f\"}.icon-regression-chart.sc-task-icon::before{content:\"\\f28a\"}.icon-remove.sc-task-icon::before{content:\"\\f290\"}.icon-remove-column.sc-task-icon::before{content:\"\\f28d\"}.icon-remove-column-left.sc-task-icon::before{content:\"\\f28b\"}.icon-remove-column-right.sc-task-icon::before{content:\"\\f28c\"}.icon-remove-row-bottom.sc-task-icon::before{content:\"\\f28e\"}.icon-remove-row-top.sc-task-icon::before{content:\"\\f28f\"}.icon-repeat.sc-task-icon::before{content:\"\\f291\"}.icon-reset.sc-task-icon::before{content:\"\\f292\"}.icon-resolve.sc-task-icon::before{content:\"\\f293\"}.icon-rig.sc-task-icon::before{content:\"\\f294\"}.icon-right-join.sc-task-icon::before{content:\"\\f295\"}.icon-ring.sc-task-icon::before{content:\"\\f296\"}.icon-rocket.sc-task-icon::before{content:\"\\f298\"}.icon-rocket-slant.sc-task-icon::before{content:\"\\f297\"}.icon-rotate-document.sc-task-icon::before{content:\"\\f299\"}.icon-rotate-page.sc-task-icon::before{content:\"\\f29a\"}.icon-route.sc-task-icon::before{content:\"\\f29b\"}.icon-satellite.sc-task-icon::before{content:\"\\f29c\"}.icon-saved.sc-task-icon::before{content:\"\\f29d\"}.icon-scatter-plot.sc-task-icon::before{content:\"\\f29e\"}.icon-search.sc-task-icon::before{content:\"\\f2a2\"}.icon-search-around.sc-task-icon::before{content:\"\\f29f\"}.icon-search-template.sc-task-icon::before{content:\"\\f2a0\"}.icon-search-text.sc-task-icon::before{content:\"\\f2a1\"}.icon-segmented-control.sc-task-icon::before{content:\"\\f2a3\"}.icon-select.sc-task-icon::before{content:\"\\f2a4\"}.icon-selection.sc-task-icon::before{content:\"\\f2a5\"}.icon-send-message.sc-task-icon::before{content:\"\\f2a6\"}.icon-send-to.sc-task-icon::before{content:\"\\f2a9\"}.icon-send-to-graph.sc-task-icon::before{content:\"\\f2a7\"}.icon-send-to-map.sc-task-icon::before{content:\"\\f2a8\"}.icon-sensor.sc-task-icon::before{content:\"\\f33c\"}.icon-series-add.sc-task-icon::before{content:\"\\f2aa\"}.icon-series-configuration.sc-task-icon::before{content:\"\\f2ab\"}.icon-series-derived.sc-task-icon::before{content:\"\\f2ac\"}.icon-series-filtered.sc-task-icon::before{content:\"\\f2ad\"}.icon-series-search.sc-task-icon::before{content:\"\\f2ae\"}.icon-settings.sc-task-icon::before{content:\"\\f2af\"}.icon-shapes.sc-task-icon::before{content:\"\\f2b0\"}.icon-share.sc-task-icon::before{content:\"\\f2b1\"}.icon-shared-filter.sc-task-icon::before{content:\"\\f2b2\"}.icon-shield.sc-task-icon::before{content:\"\\f2b3\"}.icon-ship.sc-task-icon::before{content:\"\\f2b4\"}.icon-shop.sc-task-icon::before{content:\"\\f2b5\"}.icon-shopping-cart.sc-task-icon::before{content:\"\\f2b6\"}.icon-shorten-text.sc-task-icon::before{content:\"\\f33f\"}.icon-signal-search.sc-task-icon::before{content:\"\\f2b7\"}.icon-sim-card.sc-task-icon::before{content:\"\\f2b8\"}.icon-slash.sc-task-icon::before{content:\"\\f2b9\"}.icon-small-cross.sc-task-icon::before{content:\"\\f2ba\"}.icon-small-info-sign.sc-task-icon::before{content:\"\\f334\"}.icon-small-minus.sc-task-icon::before{content:\"\\f2bb\"}.icon-small-plus.sc-task-icon::before{content:\"\\f2bc\"}.icon-small-square.sc-task-icon::before{content:\"\\f2bd\"}.icon-small-tick.sc-task-icon::before{content:\"\\f2be\"}.icon-snowflake.sc-task-icon::before{content:\"\\f2bf\"}.icon-social-media.sc-task-icon::before{content:\"\\f2c0\"}.icon-sort.sc-task-icon::before{content:\"\\f2c7\"}.icon-sort-alphabetical.sc-task-icon::before{content:\"\\f2c2\"}.icon-sort-alphabetical-desc.sc-task-icon::before{content:\"\\f2c1\"}.icon-sort-asc.sc-task-icon::before{content:\"\\f2c3\"}.icon-sort-desc.sc-task-icon::before{content:\"\\f2c4\"}.icon-sort-numerical.sc-task-icon::before{content:\"\\f2c6\"}.icon-sort-numerical-desc.sc-task-icon::before{content:\"\\f2c5\"}.icon-spell-check.sc-task-icon::before{content:\"\\f340\"}.icon-split-columns.sc-task-icon::before{content:\"\\f2c8\"}.icon-square.sc-task-icon::before{content:\"\\f2c9\"}.icon-stacked-chart.sc-task-icon::before{content:\"\\f2ca\"}.icon-stadium-geometry.sc-task-icon::before{content:\"\\f2cb\"}.icon-star.sc-task-icon::before{content:\"\\f2cd\"}.icon-star-empty.sc-task-icon::before{content:\"\\f2cc\"}.icon-step-backward.sc-task-icon::before{content:\"\\f2ce\"}.icon-step-chart.sc-task-icon::before{content:\"\\f2cf\"}.icon-step-forward.sc-task-icon::before{content:\"\\f2d0\"}.icon-stop.sc-task-icon::before{content:\"\\f2d1\"}.icon-stopwatch.sc-task-icon::before{content:\"\\f2d2\"}.icon-strikethrough.sc-task-icon::before{content:\"\\f2d3\"}.icon-style.sc-task-icon::before{content:\"\\f2d4\"}.icon-subscript.sc-task-icon::before{content:\"\\f339\"}.icon-superscript.sc-task-icon::before{content:\"\\f33a\"}.icon-swap-horizontal.sc-task-icon::before{content:\"\\f2d5\"}.icon-swap-vertical.sc-task-icon::before{content:\"\\f2d6\"}.icon-switch.sc-task-icon::before{content:\"\\f2d7\"}.icon-symbol-circle.sc-task-icon::before{content:\"\\f2d8\"}.icon-symbol-cross.sc-task-icon::before{content:\"\\f2d9\"}.icon-symbol-diamond.sc-task-icon::before{content:\"\\f2da\"}.icon-symbol-rectangle.sc-task-icon::before{content:\"\\f322\"}.icon-symbol-square.sc-task-icon::before{content:\"\\f2db\"}.icon-symbol-triangle-down.sc-task-icon::before{content:\"\\f2dc\"}.icon-symbol-triangle-up.sc-task-icon::before{content:\"\\f2dd\"}.icon-syringe.sc-task-icon::before{content:\"\\f2de\"}.icon-tag.sc-task-icon::before{content:\"\\f2df\"}.icon-take-action.sc-task-icon::before{content:\"\\f2e0\"}.icon-tank.sc-task-icon::before{content:\"\\f2e1\"}.icon-target.sc-task-icon::before{content:\"\\f2e2\"}.icon-taxi.sc-task-icon::before{content:\"\\f2e3\"}.icon-temperature.sc-task-icon::before{content:\"\\f2e4\"}.icon-text-highlight.sc-task-icon::before{content:\"\\f2e5\"}.icon-th.sc-task-icon::before{content:\"\\f2ea\"}.icon-th-derived.sc-task-icon::before{content:\"\\f2e6\"}.icon-th-disconnect.sc-task-icon::before{content:\"\\f2e7\"}.icon-th-filtered.sc-task-icon::before{content:\"\\f2e8\"}.icon-th-list.sc-task-icon::before{content:\"\\f2e9\"}.icon-third-party.sc-task-icon::before{content:\"\\f2eb\"}.icon-thumbs-down.sc-task-icon::before{content:\"\\f2ec\"}.icon-thumbs-up.sc-task-icon::before{content:\"\\f2ed\"}.icon-tick.sc-task-icon::before{content:\"\\f2ef\"}.icon-tick-circle.sc-task-icon::before{content:\"\\f2ee\"}.icon-time.sc-task-icon::before{content:\"\\f2f0\"}.icon-timeline-area-chart.sc-task-icon::before{content:\"\\f2f1\"}.icon-timeline-bar-chart.sc-task-icon::before{content:\"\\f2f2\"}.icon-timeline-events.sc-task-icon::before{content:\"\\f2f3\"}.icon-timeline-line-chart.sc-task-icon::before{content:\"\\f2f4\"}.icon-tint.sc-task-icon::before{content:\"\\f2f5\"}.icon-torch.sc-task-icon::before{content:\"\\f2f6\"}.icon-tractor.sc-task-icon::before{content:\"\\f2f7\"}.icon-train.sc-task-icon::before{content:\"\\f2f8\"}.icon-translate.sc-task-icon::before{content:\"\\f2f9\"}.icon-trash.sc-task-icon::before{content:\"\\f2fa\"}.icon-tree.sc-task-icon::before{content:\"\\f2fb\"}.icon-trending-down.sc-task-icon::before{content:\"\\f2fc\"}.icon-trending-up.sc-task-icon::before{content:\"\\f2fd\"}.icon-truck.sc-task-icon::before{content:\"\\f2fe\"}.icon-two-columns.sc-task-icon::before{content:\"\\f2ff\"}.icon-unarchive.sc-task-icon::before{content:\"\\f300\"}.icon-underline.sc-task-icon::before{content:\"\\f301\"}.icon-undo.sc-task-icon::before{content:\"\\f302\"}.icon-ungroup-objects.sc-task-icon::before{content:\"\\f303\"}.icon-unknown-vehicle.sc-task-icon::before{content:\"\\f304\"}.icon-unlock.sc-task-icon::before{content:\"\\f305\"}.icon-unpin.sc-task-icon::before{content:\"\\f306\"}.icon-unresolve.sc-task-icon::before{content:\"\\f307\"}.icon-updated.sc-task-icon::before{content:\"\\f308\"}.icon-upload.sc-task-icon::before{content:\"\\f309\"}.icon-user.sc-task-icon::before{content:\"\\f30a\"}.icon-variable.sc-task-icon::before{content:\"\\f30b\"}.icon-vertical-bar-chart-asc.sc-task-icon::before{content:\"\\f30c\"}.icon-vertical-bar-chart-desc.sc-task-icon::before{content:\"\\f30d\"}.icon-vertical-distribution.sc-task-icon::before{content:\"\\f30e\"}.icon-vertical-inbetween.sc-task-icon::before{content:\"\\f32a\"}.icon-video.sc-task-icon::before{content:\"\\f30f\"}.icon-virus.sc-task-icon::before{content:\"\\f310\"}.icon-volume-down.sc-task-icon::before{content:\"\\f311\"}.icon-volume-off.sc-task-icon::before{content:\"\\f312\"}.icon-volume-up.sc-task-icon::before{content:\"\\f313\"}.icon-walk.sc-task-icon::before{content:\"\\f314\"}.icon-warning-sign.sc-task-icon::before{content:\"\\f315\"}.icon-waterfall-chart.sc-task-icon::before{content:\"\\f316\"}.icon-waves.sc-task-icon::before{content:\"\\f317\"}.icon-widget.sc-task-icon::before{content:\"\\f31b\"}.icon-widget-button.sc-task-icon::before{content:\"\\f318\"}.icon-widget-footer.sc-task-icon::before{content:\"\\f319\"}.icon-widget-header.sc-task-icon::before{content:\"\\f31a\"}.icon-wind.sc-task-icon::before{content:\"\\f31c\"}.icon-wrench.sc-task-icon::before{content:\"\\f31d\"}.icon-zoom-in.sc-task-icon::before{content:\"\\f31e\"}.icon-zoom-out.sc-task-icon::before{content:\"\\f31f\"}.icon-zoom-to-fit.sc-task-icon::before{content:\"\\f320\"}.icon-add.sc-task-icon::before{content:\"\\f109\"}.icon-add-clip.sc-task-icon::before{content:\"\\f101\"}.icon-add-column-left.sc-task-icon::before{content:\"\\f102\"}.icon-add-column-right.sc-task-icon::before{content:\"\\f103\"}.icon-add-location.sc-task-icon::before{content:\"\\f104\"}.icon-add-row-bottom.sc-task-icon::before{content:\"\\f105\"}.icon-add-row-top.sc-task-icon::before{content:\"\\f106\"}.icon-add-to-artifact.sc-task-icon::before{content:\"\\f107\"}.icon-add-to-folder.sc-task-icon::before{content:\"\\f108\"}.icon-aimpoints-target.sc-task-icon::before{content:\"\\f335\"}.icon-airplane.sc-task-icon::before{content:\"\\f10a\"}.icon-align-center.sc-task-icon::before{content:\"\\f10b\"}.icon-align-justify.sc-task-icon::before{content:\"\\f10c\"}.icon-align-left.sc-task-icon::before{content:\"\\f10d\"}.icon-align-right.sc-task-icon::before{content:\"\\f10e\"}.icon-alignment-bottom.sc-task-icon::before{content:\"\\f10f\"}.icon-alignment-horizontal-center.sc-task-icon::before{content:\"\\f110\"}.icon-alignment-left.sc-task-icon::before{content:\"\\f111\"}.icon-alignment-right.sc-task-icon::before{content:\"\\f112\"}.icon-alignment-top.sc-task-icon::before{content:\"\\f113\"}.icon-alignment-vertical-center.sc-task-icon::before{content:\"\\f114\"}.icon-ammunition.sc-task-icon::before{content:\"\\f342\"}.icon-anchor.sc-task-icon::before{content:\"\\f330\"}.icon-annotation.sc-task-icon::before{content:\"\\f115\"}.icon-antenna.sc-task-icon::before{content:\"\\f116\"}.icon-app-header.sc-task-icon::before{content:\"\\f117\"}.icon-application.sc-task-icon::before{content:\"\\f118\"}.icon-applications.sc-task-icon::before{content:\"\\f119\"}.icon-archive.sc-task-icon::before{content:\"\\f11a\"}.icon-area-of-interest.sc-task-icon::before{content:\"\\f11b\"}.icon-array.sc-task-icon::before{content:\"\\f121\"}.icon-array-boolean.sc-task-icon::before{content:\"\\f11c\"}.icon-array-date.sc-task-icon::before{content:\"\\f11d\"}.icon-array-floating-point.sc-task-icon::before{content:\"\\f32d\"}.icon-array-numeric.sc-task-icon::before{content:\"\\f11e\"}.icon-array-string.sc-task-icon::before{content:\"\\f11f\"}.icon-array-timestamp.sc-task-icon::before{content:\"\\f120\"}.icon-arrow-bottom-left.sc-task-icon::before{content:\"\\f122\"}.icon-arrow-bottom-right.sc-task-icon::before{content:\"\\f123\"}.icon-arrow-down.sc-task-icon::before{content:\"\\f124\"}.icon-arrow-left.sc-task-icon::before{content:\"\\f125\"}.icon-arrow-right.sc-task-icon::before{content:\"\\f126\"}.icon-arrow-top-left.sc-task-icon::before{content:\"\\f127\"}.icon-arrow-top-right.sc-task-icon::before{content:\"\\f128\"}.icon-arrow-up.sc-task-icon::before{content:\"\\f129\"}.icon-arrows-horizontal.sc-task-icon::before{content:\"\\f12a\"}.icon-arrows-vertical.sc-task-icon::before{content:\"\\f12b\"}.icon-asterisk.sc-task-icon::before{content:\"\\f12c\"}.icon-at.sc-task-icon::before{content:\"\\f331\"}.icon-automatic-updates.sc-task-icon::before{content:\"\\f12d\"}.icon-axle.sc-task-icon::before{content:\"\\f338\"}.icon-backlink.sc-task-icon::before{content:\"\\f12e\"}.icon-badge.sc-task-icon::before{content:\"\\f12f\"}.icon-ban-circle.sc-task-icon::before{content:\"\\f130\"}.icon-bank-account.sc-task-icon::before{content:\"\\f131\"}.icon-barcode.sc-task-icon::before{content:\"\\f132\"}.icon-blank.sc-task-icon::before{content:\"\\f133\"}.icon-blocked-person.sc-task-icon::before{content:\"\\f134\"}.icon-bold.sc-task-icon::before{content:\"\\f135\"}.icon-book.sc-task-icon::before{content:\"\\f136\"}.icon-bookmark.sc-task-icon::before{content:\"\\f137\"}.icon-box.sc-task-icon::before{content:\"\\f138\"}.icon-briefcase.sc-task-icon::before{content:\"\\f139\"}.icon-bring-data.sc-task-icon::before{content:\"\\f13a\"}.icon-bug.sc-task-icon::before{content:\"\\f32e\"}.icon-buggy.sc-task-icon::before{content:\"\\f13b\"}.icon-build.sc-task-icon::before{content:\"\\f13c\"}.icon-calculator.sc-task-icon::before{content:\"\\f13d\"}.icon-calendar.sc-task-icon::before{content:\"\\f13e\"}.icon-camera.sc-task-icon::before{content:\"\\f13f\"}.icon-caret-down.sc-task-icon::before{content:\"\\f140\"}.icon-caret-left.sc-task-icon::before{content:\"\\f141\"}.icon-caret-right.sc-task-icon::before{content:\"\\f142\"}.icon-caret-up.sc-task-icon::before{content:\"\\f143\"}.icon-cargo-ship.sc-task-icon::before{content:\"\\f144\"}.icon-cell-tower.sc-task-icon::before{content:\"\\f145\"}.icon-changes.sc-task-icon::before{content:\"\\f146\"}.icon-chart.sc-task-icon::before{content:\"\\f147\"}.icon-chat.sc-task-icon::before{content:\"\\f148\"}.icon-chevron-backward.sc-task-icon::before{content:\"\\f149\"}.icon-chevron-down.sc-task-icon::before{content:\"\\f14a\"}.icon-chevron-forward.sc-task-icon::before{content:\"\\f14b\"}.icon-chevron-left.sc-task-icon::before{content:\"\\f14c\"}.icon-chevron-right.sc-task-icon::before{content:\"\\f14d\"}.icon-chevron-up.sc-task-icon::before{content:\"\\f14e\"}.icon-circle.sc-task-icon::before{content:\"\\f153\"}.icon-circle-arrow-down.sc-task-icon::before{content:\"\\f14f\"}.icon-circle-arrow-left.sc-task-icon::before{content:\"\\f150\"}.icon-circle-arrow-right.sc-task-icon::before{content:\"\\f151\"}.icon-circle-arrow-up.sc-task-icon::before{content:\"\\f152\"}.icon-citation.sc-task-icon::before{content:\"\\f154\"}.icon-clean.sc-task-icon::before{content:\"\\f155\"}.icon-clip.sc-task-icon::before{content:\"\\f156\"}.icon-clipboard.sc-task-icon::before{content:\"\\f157\"}.icon-cloud.sc-task-icon::before{content:\"\\f15a\"}.icon-cloud-download.sc-task-icon::before{content:\"\\f158\"}.icon-cloud-upload.sc-task-icon::before{content:\"\\f159\"}.icon-code.sc-task-icon::before{content:\"\\f15c\"}.icon-code-block.sc-task-icon::before{content:\"\\f15b\"}.icon-cog.sc-task-icon::before{content:\"\\f15d\"}.icon-collapse-all.sc-task-icon::before{content:\"\\f15e\"}.icon-color-fill.sc-task-icon::before{content:\"\\f328\"}.icon-column-layout.sc-task-icon::before{content:\"\\f15f\"}.icon-comment.sc-task-icon::before{content:\"\\f160\"}.icon-comparison.sc-task-icon::before{content:\"\\f161\"}.icon-compass.sc-task-icon::before{content:\"\\f162\"}.icon-compressed.sc-task-icon::before{content:\"\\f163\"}.icon-confirm.sc-task-icon::before{content:\"\\f164\"}.icon-console.sc-task-icon::before{content:\"\\f165\"}.icon-contrast.sc-task-icon::before{content:\"\\f166\"}.icon-control.sc-task-icon::before{content:\"\\f167\"}.icon-credit-card.sc-task-icon::before{content:\"\\f168\"}.icon-cross.sc-task-icon::before{content:\"\\f169\"}.icon-cross-circle.sc-task-icon::before{content:\"\\f336\"}.icon-crown.sc-task-icon::before{content:\"\\f16a\"}.icon-cube.sc-task-icon::before{content:\"\\f16d\"}.icon-cube-add.sc-task-icon::before{content:\"\\f16b\"}.icon-cube-remove.sc-task-icon::before{content:\"\\f16c\"}.icon-curved-range-chart.sc-task-icon::before{content:\"\\f16e\"}.icon-cut.sc-task-icon::before{content:\"\\f16f\"}.icon-cycle.sc-task-icon::before{content:\"\\f170\"}.icon-dashboard.sc-task-icon::before{content:\"\\f171\"}.icon-data-connection.sc-task-icon::before{content:\"\\f172\"}.icon-data-lineage.sc-task-icon::before{content:\"\\f173\"}.icon-database.sc-task-icon::before{content:\"\\f174\"}.icon-delete.sc-task-icon::before{content:\"\\f175\"}.icon-delta.sc-task-icon::before{content:\"\\f176\"}.icon-derive-column.sc-task-icon::before{content:\"\\f177\"}.icon-desktop.sc-task-icon::before{content:\"\\f178\"}.icon-detection.sc-task-icon::before{content:\"\\f341\"}.icon-diagnosis.sc-task-icon::before{content:\"\\f179\"}.icon-diagram-tree.sc-task-icon::before{content:\"\\f17a\"}.icon-direction-left.sc-task-icon::before{content:\"\\f17b\"}.icon-direction-right.sc-task-icon::before{content:\"\\f17c\"}.icon-disable.sc-task-icon::before{content:\"\\f17d\"}.icon-divide.sc-task-icon::before{content:\"\\f327\"}.icon-document.sc-task-icon::before{content:\"\\f180\"}.icon-document-open.sc-task-icon::before{content:\"\\f17e\"}.icon-document-share.sc-task-icon::before{content:\"\\f17f\"}.icon-dollar.sc-task-icon::before{content:\"\\f181\"}.icon-dot.sc-task-icon::before{content:\"\\f182\"}.icon-double-caret-horizontal.sc-task-icon::before{content:\"\\f183\"}.icon-double-caret-vertical.sc-task-icon::before{content:\"\\f184\"}.icon-double-chevron-down.sc-task-icon::before{content:\"\\f185\"}.icon-double-chevron-left.sc-task-icon::before{content:\"\\f186\"}.icon-double-chevron-right.sc-task-icon::before{content:\"\\f187\"}.icon-double-chevron-up.sc-task-icon::before{content:\"\\f188\"}.icon-doughnut-chart.sc-task-icon::before{content:\"\\f189\"}.icon-download.sc-task-icon::before{content:\"\\f18a\"}.icon-drag-handle-horizontal.sc-task-icon::before{content:\"\\f18b\"}.icon-drag-handle-vertical.sc-task-icon::before{content:\"\\f18c\"}.icon-draw.sc-task-icon::before{content:\"\\f18d\"}.icon-drawer-left.sc-task-icon::before{content:\"\\f18f\"}.icon-drawer-left-filled.sc-task-icon::before{content:\"\\f18e\"}.icon-drawer-right.sc-task-icon::before{content:\"\\f191\"}.icon-drawer-right-filled.sc-task-icon::before{content:\"\\f190\"}.icon-drive-time.sc-task-icon::before{content:\"\\f192\"}.icon-duplicate.sc-task-icon::before{content:\"\\f193\"}.icon-edit.sc-task-icon::before{content:\"\\f194\"}.icon-eject.sc-task-icon::before{content:\"\\f195\"}.icon-emoji.sc-task-icon::before{content:\"\\f196\"}.icon-endorsed.sc-task-icon::before{content:\"\\f197\"}.icon-envelope.sc-task-icon::before{content:\"\\f198\"}.icon-equals.sc-task-icon::before{content:\"\\f199\"}.icon-eraser.sc-task-icon::before{content:\"\\f19a\"}.icon-error.sc-task-icon::before{content:\"\\f19b\"}.icon-euro.sc-task-icon::before{content:\"\\f19c\"}.icon-exchange.sc-task-icon::before{content:\"\\f19d\"}.icon-exclude-row.sc-task-icon::before{content:\"\\f19e\"}.icon-expand-all.sc-task-icon::before{content:\"\\f19f\"}.icon-export.sc-task-icon::before{content:\"\\f1a0\"}.icon-eye-off.sc-task-icon::before{content:\"\\f1a1\"}.icon-eye-on.sc-task-icon::before{content:\"\\f1a2\"}.icon-eye-open.sc-task-icon::before{content:\"\\f1a3\"}.icon-fast-backward.sc-task-icon::before{content:\"\\f1a4\"}.icon-fast-forward.sc-task-icon::before{content:\"\\f1a5\"}.icon-feed.sc-task-icon::before{content:\"\\f1a7\"}.icon-feed-subscribed.sc-task-icon::before{content:\"\\f1a6\"}.icon-film.sc-task-icon::before{content:\"\\f1a8\"}.icon-filter.sc-task-icon::before{content:\"\\f1ad\"}.icon-filter-keep.sc-task-icon::before{content:\"\\f1a9\"}.icon-filter-list.sc-task-icon::before{content:\"\\f1aa\"}.icon-filter-open.sc-task-icon::before{content:\"\\f1ab\"}.icon-filter-remove.sc-task-icon::before{content:\"\\f1ac\"}.icon-flag.sc-task-icon::before{content:\"\\f1ae\"}.icon-flame.sc-task-icon::before{content:\"\\f1af\"}.icon-flash.sc-task-icon::before{content:\"\\f1b0\"}.icon-floating-point.sc-task-icon::before{content:\"\\f32c\"}.icon-floppy-disk.sc-task-icon::before{content:\"\\f1b1\"}.icon-flow-branch.sc-task-icon::before{content:\"\\f1b2\"}.icon-flow-end.sc-task-icon::before{content:\"\\f1b3\"}.icon-flow-linear.sc-task-icon::before{content:\"\\f1b4\"}.icon-flow-review.sc-task-icon::before{content:\"\\f1b6\"}.icon-flow-review-branch.sc-task-icon::before{content:\"\\f1b5\"}.icon-flows.sc-task-icon::before{content:\"\\f1b7\"}.icon-folder-close.sc-task-icon::before{content:\"\\f1b8\"}.icon-folder-new.sc-task-icon::before{content:\"\\f1b9\"}.icon-folder-open.sc-task-icon::before{content:\"\\f1ba\"}.icon-folder-shared.sc-task-icon::before{content:\"\\f1bc\"}.icon-folder-shared-open.sc-task-icon::before{content:\"\\f1bb\"}.icon-follower.sc-task-icon::before{content:\"\\f1bd\"}.icon-following.sc-task-icon::before{content:\"\\f1be\"}.icon-font.sc-task-icon::before{content:\"\\f1bf\"}.icon-fork.sc-task-icon::before{content:\"\\f1c0\"}.icon-form.sc-task-icon::before{content:\"\\f1c1\"}.icon-fuel.sc-task-icon::before{content:\"\\f323\"}.icon-full-circle.sc-task-icon::before{content:\"\\f1c2\"}.icon-full-stacked-chart.sc-task-icon::before{content:\"\\f1c3\"}.icon-fullscreen.sc-task-icon::before{content:\"\\f1c4\"}.icon-function.sc-task-icon::before{content:\"\\f1c5\"}.icon-gantt-chart.sc-task-icon::before{content:\"\\f1c6\"}.icon-geofence.sc-task-icon::before{content:\"\\f1c7\"}.icon-geolocation.sc-task-icon::before{content:\"\\f1c8\"}.icon-geosearch.sc-task-icon::before{content:\"\\f1c9\"}.icon-git-branch.sc-task-icon::before{content:\"\\f1ca\"}.icon-git-commit.sc-task-icon::before{content:\"\\f1cb\"}.icon-git-merge.sc-task-icon::before{content:\"\\f1cc\"}.icon-git-new-branch.sc-task-icon::before{content:\"\\f1cd\"}.icon-git-pull.sc-task-icon::before{content:\"\\f1ce\"}.icon-git-push.sc-task-icon::before{content:\"\\f1cf\"}.icon-git-repo.sc-task-icon::before{content:\"\\f1d0\"}.icon-glass.sc-task-icon::before{content:\"\\f1d1\"}.icon-globe.sc-task-icon::before{content:\"\\f1d3\"}.icon-globe-network.sc-task-icon::before{content:\"\\f1d2\"}.icon-graph.sc-task-icon::before{content:\"\\f1d5\"}.icon-graph-remove.sc-task-icon::before{content:\"\\f1d4\"}.icon-greater-than.sc-task-icon::before{content:\"\\f1d7\"}.icon-greater-than-or-equal-to.sc-task-icon::before{content:\"\\f1d6\"}.icon-grid.sc-task-icon::before{content:\"\\f1d9\"}.icon-grid-view.sc-task-icon::before{content:\"\\f1d8\"}.icon-group-objects.sc-task-icon::before{content:\"\\f1da\"}.icon-grouped-bar-chart.sc-task-icon::before{content:\"\\f1db\"}.icon-hand.sc-task-icon::before{content:\"\\f1e0\"}.icon-hand-down.sc-task-icon::before{content:\"\\f1dc\"}.icon-hand-left.sc-task-icon::before{content:\"\\f1dd\"}.icon-hand-right.sc-task-icon::before{content:\"\\f1de\"}.icon-hand-up.sc-task-icon::before{content:\"\\f1df\"}.icon-hat.sc-task-icon::before{content:\"\\f1e1\"}.icon-header.sc-task-icon::before{content:\"\\f1e5\"}.icon-header-one.sc-task-icon::before{content:\"\\f1e2\"}.icon-header-three.sc-task-icon::before{content:\"\\f1e3\"}.icon-header-two.sc-task-icon::before{content:\"\\f1e4\"}.icon-headset.sc-task-icon::before{content:\"\\f1e6\"}.icon-heart.sc-task-icon::before{content:\"\\f1e8\"}.icon-heart-broken.sc-task-icon::before{content:\"\\f1e7\"}.icon-heat-grid.sc-task-icon::before{content:\"\\f1e9\"}.icon-heatmap.sc-task-icon::before{content:\"\\f1ea\"}.icon-helicopter.sc-task-icon::before{content:\"\\f1eb\"}.icon-help.sc-task-icon::before{content:\"\\f1ec\"}.icon-helper-management.sc-task-icon::before{content:\"\\f1ed\"}.icon-high-priority.sc-task-icon::before{content:\"\\f1ee\"}.icon-high-voltage-pole.sc-task-icon::before{content:\"\\f333\"}.icon-highlight.sc-task-icon::before{content:\"\\f1ef\"}.icon-history.sc-task-icon::before{content:\"\\f1f0\"}.icon-home.sc-task-icon::before{content:\"\\f1f1\"}.icon-horizontal-bar-chart.sc-task-icon::before{content:\"\\f1f4\"}.icon-horizontal-bar-chart-asc.sc-task-icon::before{content:\"\\f1f2\"}.icon-horizontal-bar-chart-desc.sc-task-icon::before{content:\"\\f1f3\"}.icon-horizontal-distribution.sc-task-icon::before{content:\"\\f1f5\"}.icon-horizontal-inbetween.sc-task-icon::before{content:\"\\f329\"}.icon-hurricane.sc-task-icon::before{content:\"\\f1f6\"}.icon-id-number.sc-task-icon::before{content:\"\\f1f7\"}.icon-image-rotate-left.sc-task-icon::before{content:\"\\f1f8\"}.icon-image-rotate-right.sc-task-icon::before{content:\"\\f1f9\"}.icon-import.sc-task-icon::before{content:\"\\f1fa\"}.icon-inbox.sc-task-icon::before{content:\"\\f1ff\"}.icon-inbox-filtered.sc-task-icon::before{content:\"\\f1fb\"}.icon-inbox-geo.sc-task-icon::before{content:\"\\f1fc\"}.icon-inbox-search.sc-task-icon::before{content:\"\\f1fd\"}.icon-inbox-update.sc-task-icon::before{content:\"\\f1fe\"}.icon-info-sign.sc-task-icon::before{content:\"\\f200\"}.icon-inheritance.sc-task-icon::before{content:\"\\f201\"}.icon-inherited-group.sc-task-icon::before{content:\"\\f202\"}.icon-inner-join.sc-task-icon::before{content:\"\\f203\"}.icon-insert.sc-task-icon::before{content:\"\\f204\"}.icon-intelligence.sc-task-icon::before{content:\"\\f337\"}.icon-intersection.sc-task-icon::before{content:\"\\f205\"}.icon-ip-address.sc-task-icon::before{content:\"\\f206\"}.icon-issue.sc-task-icon::before{content:\"\\f209\"}.icon-issue-closed.sc-task-icon::before{content:\"\\f207\"}.icon-issue-new.sc-task-icon::before{content:\"\\f208\"}.icon-italic.sc-task-icon::before{content:\"\\f20a\"}.icon-join-table.sc-task-icon::before{content:\"\\f20b\"}.icon-key.sc-task-icon::before{content:\"\\f215\"}.icon-key-backspace.sc-task-icon::before{content:\"\\f20c\"}.icon-key-command.sc-task-icon::before{content:\"\\f20d\"}.icon-key-control.sc-task-icon::before{content:\"\\f20e\"}.icon-key-delete.sc-task-icon::before{content:\"\\f20f\"}.icon-key-enter.sc-task-icon::before{content:\"\\f210\"}.icon-key-escape.sc-task-icon::before{content:\"\\f211\"}.icon-key-option.sc-task-icon::before{content:\"\\f212\"}.icon-key-shift.sc-task-icon::before{content:\"\\f213\"}.icon-key-tab.sc-task-icon::before{content:\"\\f214\"}.icon-known-vehicle.sc-task-icon::before{content:\"\\f216\"}.icon-lab-test.sc-task-icon::before{content:\"\\f217\"}.icon-label.sc-task-icon::before{content:\"\\f218\"}.icon-layer.sc-task-icon::before{content:\"\\f21a\"}.icon-layer-outline.sc-task-icon::before{content:\"\\f219\"}.icon-layers.sc-task-icon::before{content:\"\\f21b\"}.icon-layout.sc-task-icon::before{content:\"\\f225\"}.icon-layout-auto.sc-task-icon::before{content:\"\\f21c\"}.icon-layout-balloon.sc-task-icon::before{content:\"\\f21d\"}.icon-layout-circle.sc-task-icon::before{content:\"\\f21e\"}.icon-layout-grid.sc-task-icon::before{content:\"\\f21f\"}.icon-layout-group-by.sc-task-icon::before{content:\"\\f220\"}.icon-layout-hierarchy.sc-task-icon::before{content:\"\\f221\"}.icon-layout-linear.sc-task-icon::before{content:\"\\f222\"}.icon-layout-skew-grid.sc-task-icon::before{content:\"\\f223\"}.icon-layout-sorted-clusters.sc-task-icon::before{content:\"\\f224\"}.icon-learning.sc-task-icon::before{content:\"\\f226\"}.icon-left-join.sc-task-icon::before{content:\"\\f227\"}.icon-lengthen-text.sc-task-icon::before{content:\"\\f33e\"}.icon-less-than.sc-task-icon::before{content:\"\\f229\"}.icon-less-than-or-equal-to.sc-task-icon::before{content:\"\\f228\"}.icon-lifesaver.sc-task-icon::before{content:\"\\f22a\"}.icon-lightbulb.sc-task-icon::before{content:\"\\f22b\"}.icon-lightning.sc-task-icon::before{content:\"\\f22c\"}.icon-link.sc-task-icon::before{content:\"\\f22d\"}.icon-list.sc-task-icon::before{content:\"\\f230\"}.icon-list-columns.sc-task-icon::before{content:\"\\f22e\"}.icon-list-detail-view.sc-task-icon::before{content:\"\\f22f\"}.icon-locate.sc-task-icon::before{content:\"\\f231\"}.icon-lock.sc-task-icon::before{content:\"\\f232\"}.icon-locomotive.sc-task-icon::before{content:\"\\f33b\"}.icon-log-in.sc-task-icon::before{content:\"\\f233\"}.icon-log-out.sc-task-icon::before{content:\"\\f234\"}.icon-low-voltage-pole.sc-task-icon::before{content:\"\\f332\"}.icon-manual.sc-task-icon::before{content:\"\\f235\"}.icon-manually-entered-data.sc-task-icon::before{content:\"\\f236\"}.icon-many-to-many.sc-task-icon::before{content:\"\\f237\"}.icon-many-to-one.sc-task-icon::before{content:\"\\f238\"}.icon-map.sc-task-icon::before{content:\"\\f23b\"}.icon-map-create.sc-task-icon::before{content:\"\\f239\"}.icon-map-marker.sc-task-icon::before{content:\"\\f23a\"}.icon-maximize.sc-task-icon::before{content:\"\\f23c\"}.icon-media.sc-task-icon::before{content:\"\\f23d\"}.icon-menu.sc-task-icon::before{content:\"\\f240\"}.icon-menu-closed.sc-task-icon::before{content:\"\\f23e\"}.icon-menu-open.sc-task-icon::before{content:\"\\f23f\"}.icon-merge-columns.sc-task-icon::before{content:\"\\f241\"}.icon-merge-links.sc-task-icon::before{content:\"\\f242\"}.icon-microphone.sc-task-icon::before{content:\"\\f343\"}.icon-minimize.sc-task-icon::before{content:\"\\f243\"}.icon-minus.sc-task-icon::before{content:\"\\f244\"}.icon-mobile-phone.sc-task-icon::before{content:\"\\f245\"}.icon-mobile-video.sc-task-icon::before{content:\"\\f246\"}.icon-modal.sc-task-icon::before{content:\"\\f248\"}.icon-modal-filled.sc-task-icon::before{content:\"\\f247\"}.icon-model.sc-task-icon::before{content:\"\\f33d\"}.icon-moon.sc-task-icon::before{content:\"\\f249\"}.icon-more.sc-task-icon::before{content:\"\\f24a\"}.icon-mountain.sc-task-icon::before{content:\"\\f24b\"}.icon-move.sc-task-icon::before{content:\"\\f24c\"}.icon-mugshot.sc-task-icon::before{content:\"\\f24d\"}.icon-multi-select.sc-task-icon::before{content:\"\\f24e\"}.icon-music.sc-task-icon::before{content:\"\\f24f\"}.icon-nest.sc-task-icon::before{content:\"\\f250\"}.icon-new-drawing.sc-task-icon::before{content:\"\\f251\"}.icon-new-grid-item.sc-task-icon::before{content:\"\\f252\"}.icon-new-layer.sc-task-icon::before{content:\"\\f253\"}.icon-new-layers.sc-task-icon::before{content:\"\\f254\"}.icon-new-link.sc-task-icon::before{content:\"\\f255\"}.icon-new-object.sc-task-icon::before{content:\"\\f256\"}.icon-new-person.sc-task-icon::before{content:\"\\f257\"}.icon-new-prescription.sc-task-icon::before{content:\"\\f258\"}.icon-new-text-box.sc-task-icon::before{content:\"\\f259\"}.icon-ninja.sc-task-icon::before{content:\"\\f25a\"}.icon-not-equal-to.sc-task-icon::before{content:\"\\f25b\"}.icon-notifications.sc-task-icon::before{content:\"\\f25e\"}.icon-notifications-snooze.sc-task-icon::before{content:\"\\f25c\"}.icon-notifications-updated.sc-task-icon::before{content:\"\\f25d\"}.icon-numbered-list.sc-task-icon::before{content:\"\\f25f\"}.icon-numerical.sc-task-icon::before{content:\"\\f260\"}.icon-office.sc-task-icon::before{content:\"\\f261\"}.icon-offline.sc-task-icon::before{content:\"\\f262\"}.icon-oil-field.sc-task-icon::before{content:\"\\f263\"}.icon-one-column.sc-task-icon::before{content:\"\\f264\"}.icon-one-to-many.sc-task-icon::before{content:\"\\f265\"}.icon-one-to-one.sc-task-icon::before{content:\"\\f266\"}.icon-open-application.sc-task-icon::before{content:\"\\f32b\"}.icon-outdated.sc-task-icon::before{content:\"\\f267\"}.icon-page-layout.sc-task-icon::before{content:\"\\f268\"}.icon-panel-stats.sc-task-icon::before{content:\"\\f269\"}.icon-panel-table.sc-task-icon::before{content:\"\\f26a\"}.icon-paperclip.sc-task-icon::before{content:\"\\f26b\"}.icon-paragraph.sc-task-icon::before{content:\"\\f26c\"}.icon-path.sc-task-icon::before{content:\"\\f26e\"}.icon-path-search.sc-task-icon::before{content:\"\\f26d\"}.icon-pause.sc-task-icon::before{content:\"\\f26f\"}.icon-people.sc-task-icon::before{content:\"\\f270\"}.icon-percentage.sc-task-icon::before{content:\"\\f271\"}.icon-person.sc-task-icon::before{content:\"\\f272\"}.icon-phone.sc-task-icon::before{content:\"\\f273\"}.icon-pie-chart.sc-task-icon::before{content:\"\\f274\"}.icon-pin.sc-task-icon::before{content:\"\\f275\"}.icon-pivot.sc-task-icon::before{content:\"\\f277\"}.icon-pivot-table.sc-task-icon::before{content:\"\\f276\"}.icon-play.sc-task-icon::before{content:\"\\f278\"}.icon-playbook.sc-task-icon::before{content:\"\\f324\"}.icon-plus.sc-task-icon::before{content:\"\\f279\"}.icon-polygon-filter.sc-task-icon::before{content:\"\\f27a\"}.icon-power.sc-task-icon::before{content:\"\\f27b\"}.icon-predictive-analysis.sc-task-icon::before{content:\"\\f27c\"}.icon-prescription.sc-task-icon::before{content:\"\\f27d\"}.icon-presentation.sc-task-icon::before{content:\"\\f27e\"}.icon-print.sc-task-icon::before{content:\"\\f27f\"}.icon-projects.sc-task-icon::before{content:\"\\f280\"}.icon-properties.sc-task-icon::before{content:\"\\f281\"}.icon-property.sc-task-icon::before{content:\"\\f282\"}.icon-publish-function.sc-task-icon::before{content:\"\\f283\"}.icon-pulse.sc-task-icon::before{content:\"\\f284\"}.icon-rain.sc-task-icon::before{content:\"\\f285\"}.icon-random.sc-task-icon::before{content:\"\\f286\"}.icon-record.sc-task-icon::before{content:\"\\f287\"}.icon-rect-height.sc-task-icon::before{content:\"\\f325\"}.icon-rect-width.sc-task-icon::before{content:\"\\f326\"}.icon-rectangle.sc-task-icon::before{content:\"\\f321\"}.icon-redo.sc-task-icon::before{content:\"\\f288\"}.icon-refresh.sc-task-icon::before{content:\"\\f289\"}.icon-regex.sc-task-icon::before{content:\"\\f32f\"}.icon-regression-chart.sc-task-icon::before{content:\"\\f28a\"}.icon-remove.sc-task-icon::before{content:\"\\f290\"}.icon-remove-column.sc-task-icon::before{content:\"\\f28d\"}.icon-remove-column-left.sc-task-icon::before{content:\"\\f28b\"}.icon-remove-column-right.sc-task-icon::before{content:\"\\f28c\"}.icon-remove-row-bottom.sc-task-icon::before{content:\"\\f28e\"}.icon-remove-row-top.sc-task-icon::before{content:\"\\f28f\"}.icon-repeat.sc-task-icon::before{content:\"\\f291\"}.icon-reset.sc-task-icon::before{content:\"\\f292\"}.icon-resolve.sc-task-icon::before{content:\"\\f293\"}.icon-rig.sc-task-icon::before{content:\"\\f294\"}.icon-right-join.sc-task-icon::before{content:\"\\f295\"}.icon-ring.sc-task-icon::before{content:\"\\f296\"}.icon-rocket.sc-task-icon::before{content:\"\\f298\"}.icon-rocket-slant.sc-task-icon::before{content:\"\\f297\"}.icon-rotate-document.sc-task-icon::before{content:\"\\f299\"}.icon-rotate-page.sc-task-icon::before{content:\"\\f29a\"}.icon-route.sc-task-icon::before{content:\"\\f29b\"}.icon-satellite.sc-task-icon::before{content:\"\\f29c\"}.icon-saved.sc-task-icon::before{content:\"\\f29d\"}.icon-scatter-plot.sc-task-icon::before{content:\"\\f29e\"}.icon-search.sc-task-icon::before{content:\"\\f2a2\"}.icon-search-around.sc-task-icon::before{content:\"\\f29f\"}.icon-search-template.sc-task-icon::before{content:\"\\f2a0\"}.icon-search-text.sc-task-icon::before{content:\"\\f2a1\"}.icon-segmented-control.sc-task-icon::before{content:\"\\f2a3\"}.icon-select.sc-task-icon::before{content:\"\\f2a4\"}.icon-selection.sc-task-icon::before{content:\"\\f2a5\"}.icon-send-message.sc-task-icon::before{content:\"\\f2a6\"}.icon-send-to.sc-task-icon::before{content:\"\\f2a9\"}.icon-send-to-graph.sc-task-icon::before{content:\"\\f2a7\"}.icon-send-to-map.sc-task-icon::before{content:\"\\f2a8\"}.icon-sensor.sc-task-icon::before{content:\"\\f33c\"}.icon-series-add.sc-task-icon::before{content:\"\\f2aa\"}.icon-series-configuration.sc-task-icon::before{content:\"\\f2ab\"}.icon-series-derived.sc-task-icon::before{content:\"\\f2ac\"}.icon-series-filtered.sc-task-icon::before{content:\"\\f2ad\"}.icon-series-search.sc-task-icon::before{content:\"\\f2ae\"}.icon-settings.sc-task-icon::before{content:\"\\f2af\"}.icon-shapes.sc-task-icon::before{content:\"\\f2b0\"}.icon-share.sc-task-icon::before{content:\"\\f2b1\"}.icon-shared-filter.sc-task-icon::before{content:\"\\f2b2\"}.icon-shield.sc-task-icon::before{content:\"\\f2b3\"}.icon-ship.sc-task-icon::before{content:\"\\f2b4\"}.icon-shop.sc-task-icon::before{content:\"\\f2b5\"}.icon-shopping-cart.sc-task-icon::before{content:\"\\f2b6\"}.icon-shorten-text.sc-task-icon::before{content:\"\\f33f\"}.icon-signal-search.sc-task-icon::before{content:\"\\f2b7\"}.icon-sim-card.sc-task-icon::before{content:\"\\f2b8\"}.icon-slash.sc-task-icon::before{content:\"\\f2b9\"}.icon-small-cross.sc-task-icon::before{content:\"\\f2ba\"}.icon-small-info-sign.sc-task-icon::before{content:\"\\f334\"}.icon-small-minus.sc-task-icon::before{content:\"\\f2bb\"}.icon-small-plus.sc-task-icon::before{content:\"\\f2bc\"}.icon-small-square.sc-task-icon::before{content:\"\\f2bd\"}.icon-small-tick.sc-task-icon::before{content:\"\\f2be\"}.icon-snowflake.sc-task-icon::before{content:\"\\f2bf\"}.icon-social-media.sc-task-icon::before{content:\"\\f2c0\"}.icon-sort.sc-task-icon::before{content:\"\\f2c7\"}.icon-sort-alphabetical.sc-task-icon::before{content:\"\\f2c2\"}.icon-sort-alphabetical-desc.sc-task-icon::before{content:\"\\f2c1\"}.icon-sort-asc.sc-task-icon::before{content:\"\\f2c3\"}.icon-sort-desc.sc-task-icon::before{content:\"\\f2c4\"}.icon-sort-numerical.sc-task-icon::before{content:\"\\f2c6\"}.icon-sort-numerical-desc.sc-task-icon::before{content:\"\\f2c5\"}.icon-spell-check.sc-task-icon::before{content:\"\\f340\"}.icon-split-columns.sc-task-icon::before{content:\"\\f2c8\"}.icon-square.sc-task-icon::before{content:\"\\f2c9\"}.icon-stacked-chart.sc-task-icon::before{content:\"\\f2ca\"}.icon-stadium-geometry.sc-task-icon::before{content:\"\\f2cb\"}.icon-star.sc-task-icon::before{content:\"\\f2cd\"}.icon-star-empty.sc-task-icon::before{content:\"\\f2cc\"}.icon-step-backward.sc-task-icon::before{content:\"\\f2ce\"}.icon-step-chart.sc-task-icon::before{content:\"\\f2cf\"}.icon-step-forward.sc-task-icon::before{content:\"\\f2d0\"}.icon-stop.sc-task-icon::before{content:\"\\f2d1\"}.icon-stopwatch.sc-task-icon::before{content:\"\\f2d2\"}.icon-strikethrough.sc-task-icon::before{content:\"\\f2d3\"}.icon-style.sc-task-icon::before{content:\"\\f2d4\"}.icon-subscript.sc-task-icon::before{content:\"\\f339\"}.icon-superscript.sc-task-icon::before{content:\"\\f33a\"}.icon-swap-horizontal.sc-task-icon::before{content:\"\\f2d5\"}.icon-swap-vertical.sc-task-icon::before{content:\"\\f2d6\"}.icon-switch.sc-task-icon::before{content:\"\\f2d7\"}.icon-symbol-circle.sc-task-icon::before{content:\"\\f2d8\"}.icon-symbol-cross.sc-task-icon::before{content:\"\\f2d9\"}.icon-symbol-diamond.sc-task-icon::before{content:\"\\f2da\"}.icon-symbol-rectangle.sc-task-icon::before{content:\"\\f322\"}.icon-symbol-square.sc-task-icon::before{content:\"\\f2db\"}.icon-symbol-triangle-down.sc-task-icon::before{content:\"\\f2dc\"}.icon-symbol-triangle-up.sc-task-icon::before{content:\"\\f2dd\"}.icon-syringe.sc-task-icon::before{content:\"\\f2de\"}.icon-tag.sc-task-icon::before{content:\"\\f2df\"}.icon-take-action.sc-task-icon::before{content:\"\\f2e0\"}.icon-tank.sc-task-icon::before{content:\"\\f2e1\"}.icon-target.sc-task-icon::before{content:\"\\f2e2\"}.icon-taxi.sc-task-icon::before{content:\"\\f2e3\"}.icon-temperature.sc-task-icon::before{content:\"\\f2e4\"}.icon-text-highlight.sc-task-icon::before{content:\"\\f2e5\"}.icon-th.sc-task-icon::before{content:\"\\f2ea\"}.icon-th-derived.sc-task-icon::before{content:\"\\f2e6\"}.icon-th-disconnect.sc-task-icon::before{content:\"\\f2e7\"}.icon-th-filtered.sc-task-icon::before{content:\"\\f2e8\"}.icon-th-list.sc-task-icon::before{content:\"\\f2e9\"}.icon-third-party.sc-task-icon::before{content:\"\\f2eb\"}.icon-thumbs-down.sc-task-icon::before{content:\"\\f2ec\"}.icon-thumbs-up.sc-task-icon::before{content:\"\\f2ed\"}.icon-tick.sc-task-icon::before{content:\"\\f2ef\"}.icon-tick-circle.sc-task-icon::before{content:\"\\f2ee\"}.icon-time.sc-task-icon::before{content:\"\\f2f0\"}.icon-timeline-area-chart.sc-task-icon::before{content:\"\\f2f1\"}.icon-timeline-bar-chart.sc-task-icon::before{content:\"\\f2f2\"}.icon-timeline-events.sc-task-icon::before{content:\"\\f2f3\"}.icon-timeline-line-chart.sc-task-icon::before{content:\"\\f2f4\"}.icon-tint.sc-task-icon::before{content:\"\\f2f5\"}.icon-torch.sc-task-icon::before{content:\"\\f2f6\"}.icon-tractor.sc-task-icon::before{content:\"\\f2f7\"}.icon-train.sc-task-icon::before{content:\"\\f2f8\"}.icon-translate.sc-task-icon::before{content:\"\\f2f9\"}.icon-trash.sc-task-icon::before{content:\"\\f2fa\"}.icon-tree.sc-task-icon::before{content:\"\\f2fb\"}.icon-trending-down.sc-task-icon::before{content:\"\\f2fc\"}.icon-trending-up.sc-task-icon::before{content:\"\\f2fd\"}.icon-truck.sc-task-icon::before{content:\"\\f2fe\"}.icon-two-columns.sc-task-icon::before{content:\"\\f2ff\"}.icon-unarchive.sc-task-icon::before{content:\"\\f300\"}.icon-underline.sc-task-icon::before{content:\"\\f301\"}.icon-undo.sc-task-icon::before{content:\"\\f302\"}.icon-ungroup-objects.sc-task-icon::before{content:\"\\f303\"}.icon-unknown-vehicle.sc-task-icon::before{content:\"\\f304\"}.icon-unlock.sc-task-icon::before{content:\"\\f305\"}.icon-unpin.sc-task-icon::before{content:\"\\f306\"}.icon-unresolve.sc-task-icon::before{content:\"\\f307\"}.icon-updated.sc-task-icon::before{content:\"\\f308\"}.icon-upload.sc-task-icon::before{content:\"\\f309\"}.icon-user.sc-task-icon::before{content:\"\\f30a\"}.icon-variable.sc-task-icon::before{content:\"\\f30b\"}.icon-vertical-bar-chart-asc.sc-task-icon::before{content:\"\\f30c\"}.icon-vertical-bar-chart-desc.sc-task-icon::before{content:\"\\f30d\"}.icon-vertical-distribution.sc-task-icon::before{content:\"\\f30e\"}.icon-vertical-inbetween.sc-task-icon::before{content:\"\\f32a\"}.icon-video.sc-task-icon::before{content:\"\\f30f\"}.icon-virus.sc-task-icon::before{content:\"\\f310\"}.icon-volume-down.sc-task-icon::before{content:\"\\f311\"}.icon-volume-off.sc-task-icon::before{content:\"\\f312\"}.icon-volume-up.sc-task-icon::before{content:\"\\f313\"}.icon-walk.sc-task-icon::before{content:\"\\f314\"}.icon-warning-sign.sc-task-icon::before{content:\"\\f315\"}.icon-waterfall-chart.sc-task-icon::before{content:\"\\f316\"}.icon-waves.sc-task-icon::before{content:\"\\f317\"}.icon-widget.sc-task-icon::before{content:\"\\f31b\"}.icon-widget-button.sc-task-icon::before{content:\"\\f318\"}.icon-widget-footer.sc-task-icon::before{content:\"\\f319\"}.icon-widget-header.sc-task-icon::before{content:\"\\f31a\"}.icon-wind.sc-task-icon::before{content:\"\\f31c\"}.icon-wrench.sc-task-icon::before{content:\"\\f31d\"}.icon-zoom-in.sc-task-icon::before{content:\"\\f31e\"}.icon-zoom-out.sc-task-icon::before{content:\"\\f31f\"}.icon-zoom-to-fit.sc-task-icon::before{content:\"\\f320\"}.sc-task-icon-h{display:inline-block;color:inherit;-ms-flex:0 0 auto;flex:0 0 auto;vertical-align:text-bottom}@font-face{font-family:\"blueprint-icons-16\";src:url(\"/assets/blueprint-icons-16.woff2\") format(\"woff2\")}@font-face{font-family:\"blueprint-icons-20\";src:url(\"/assets/blueprint-icons-20.woff2\") format(\"woff2\")}.icon.sc-task-icon:not(:empty)::before{content:\"\" !important;content:unset !important}.icon.sc-task-icon>svg.sc-task-icon{display:block}.icon.sc-task-icon>svg.sc-task-icon:not([fill]){fill:currentcolor}span.icon-standard.sc-task-icon{font-family:\"blueprint-icons-16\", sans-serif;font-size:16px;font-style:normal;font-variant:normal;font-weight:400;height:16px;line-height:1;width:16px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;display:inline-block}span.icon-large.sc-task-icon{font-family:\"blueprint-icons-20\", sans-serif;font-size:20px;font-style:normal;font-variant:normal;font-weight:400;height:20px;line-height:1;width:20px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;display:inline-block}span.icon_.sc-task-icon:empty{font-family:\"blueprint-icons-20\";font-size:inherit;font-style:normal;font-weight:400;line-height:1}span.icon_.sc-task-icon:empty::before{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}";
const TaskIconStyle0 = taskIconCss;

const STANDARD = 16;
const LARGE = 20;
const TaskIcon = /*@__PURE__*/ proxyCustomElement(class TaskIcon extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.icon = "blank";
        this.size = STANDARD;
    }
    iconSVG() {
        const pathSize = this.size < LARGE ? STANDARD : LARGE;
        return h("svg", { "data-icon": this.icon, height: this.size, width: this.size, role: "img", viewBox: `0 0 ${pathSize} ${pathSize}` }, icons[this.icon][pathSize].map(p => h("path", { d: p, "fill-rule": "evenodd" })));
    }
    iconFont() {
        const sizeClass = this.size < LARGE ? "icon-standard" : "icon-large";
        const classes = classNames(sizeClass, `icon-${this.icon}`);
        let style = {};
        if (![16, 20].includes(this.size)) {
            const size = `${this.size}px`;
            style = {
                "font-size": size,
                height: size,
                width: size
            };
        }
        return h("span", { class: classes, style: style });
    }
    render() {
        return (
        // TODO: Figure out why this size override is necessary
        h(Host, { key: '01ffd92d301c600e799fe95a69ca42f9b7e00244', class: "icon", style: { height: `${this.size}px` } }, this.icon in icons ? this.iconSVG() : this.iconFont()));
    }
    static get style() { return TaskIconStyle0; }
}, [2, "task-icon", {
        "icon": [1],
        "size": [2]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["task-icon"];
    components.forEach(tagName => { switch (tagName) {
        case "task-icon":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TaskIcon);
            }
            break;
    } });
}

export { TaskIcon as T, defineCustomElement as d };

//# sourceMappingURL=task-icon2.js.map